(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8937,        153]*)
(*NotebookOutlinePosition[      9628,        177]*)
(*  CellTagsIndexPosition[      9584,        173]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Title\nHoop Algebras\nAuthor\nRoger Beresford\nRevision Date\n2007-2-21\n\
Description.\n\t\nHoops are \"Symmetry-conserving Partial-fraction-Division \
Algebras\" with symmetries or \"sizes\" that are conserved on vector \
multiplication and division. Conserved symmetries lead, via Noether's \
theorem, to forces and to particles. Consequently, Hoops subsume all the \
algebras (including Real, Complex, Quaternion, Octonion, Clifford and Wedge) \
relevant to particle physics. They may lead to a new paradigm for physics \
(possibly related to M-theory), based on finite Moufang Loops (so vectors \
have multiplicative inverses) with \"Frobenius conservation\" (so the factors \
of the symbolic multiplication table determinant are conserved symmetries). \
Do not confuse hoop multiplication (which multiplies two vectors to give a \
product and two, possibly null, remainders) with the use of groups to \
transform a single vector from one set of coordinates to another - as in the \
\"standard model\".\n\nHoops involve some neglected and some new mathematical \
concepts:-\n   1. \"Primal\" unsigned continuous numbers (the half-line, 0 U \
R+) can be developed from set theory without introducing negation or \
subtraction.\n   2. \"Folding\" sets of primal numbers introduces signs via \
equivalence relationships. 2-folding creates Integers and Reals with the \
signs {+, -}. Folding destroys some information.\n   3. \"Generalized signs\" \
are primitive (NOT cyclotomic) roots of unity s^j, with s^r = +1. They are \
created by r-fold equivalence relationships. Complex numbers are one case of \
r=4, with signs {+,i,-,-i}. r=3 gives \"terplex\" signs {+, J, J^2} with \
ternary symmetries relevant to quarks. Algebraic loops with r-fold symmetry \
fold to become algebras with generalized signs.\n   4. Algebraic loops with \
the division property (zx).(yz)=z.(xy).z are Moufang Loops; this ensures that \
every vector has a multiplicative inverse in Hoop vector multiplication. \
Groups are associative loops and have the Moufang property.\n   5. Real \
factors of the determinant of the inverse symbolic multiplication table are \
\"conserved symmetries\" or \"sizes\" for all group tables and for a few \
non-associative Moufang Loops. Sizes are conserved on multiplication, \
Det[AB]=Det[A] Det[B] (up to a sign); they provide denominators for \
partial-fraction formulations of the inverse.\n   6. \"Hoop Algebras\" are \
r-folded from (m.r).(m.r) conservative tables. They are division algebras \
because they possess addition and generalized subtraction using r-fold signs \
together with the Hoop multiplication-division property. All groups, together \
with octonions, split-octonions and some other non-associative Moufang loops, \
are hoops because they are folded versions of larger conservative loops.\n   \
7. \"Signed hoop tables\" may result from folding. They are not loops because \
their products include signed elements that are not members of the defining \
set. Examples - the complex set is {1,i} but the product i.i is -1. The \
quaternion set is {1,i,j,ij}, with i.j=ij but j.i=-ij. Pauli-",
  StyleBox["\[Sigma]",
    FontFamily->"Courier New Greek",
    FontSize->9],
  " algebra is {t,x,y,z} with z.y=ix etc.\n   8. \"Remainders\" are created \
to maintain size conservation on multiplication or division of vectors when \
some sizes are zero. Hoop operations then \"project\" the results into \
constrained sub-algebras (with the same zeroed sizes) and \"eject\" \
remainders. This maintains size conservation and eliminates division-by-zero. \
The Hoops.m package includes over 80 hoops with this property. Remainders \
have analogies with particle interactions, where properties are conserved by \
ejecting particles of lower symmetry.\n   9. \"Polar-Cartesian duals\" \
(generalizing the {r,theta} dual of the x+i y complex plane) exist when \
quadratic sizes occur. Cartesian-Polar interconversions are provided for 44 \
hoops in Hoops.m. Abelian duals have angles that add on vector \
multiplication. This generalises powers and roots.\n  10. \"Multi-phase \
sinusoidal orbits\" are duals with sizes that multiply to one (ignoring any \
\"factored-out\" zeroes). Some stable orbits resemble multi-phase de-Broglie \
waves with fundamental sizes resembling Planck areas and elements that act as \
quantum operators. This may determine which particles are stable. Higher \
frequency resonances may relate to unstable particle resonances.\n  11. \
\"Dozal\" multiplication rules (for vectors with 12 elements) may correspond \
to four types of interaction between particles, with different size \
combinations corresponding to particles with different conserved properties. \
Half-spin quantum operators are fermionic Dozal elements. Their three-phase \
orbits have reciprocal squared radii, giving three size regimes \
(point-particle scale, Planck-scale, cosmic scale), related to T-duality in \
M-theory and the \"large numbers hypothesis\".\n  12. Bosonic \"Hexal\" is \
supersymmetric to (i.e. folded from) Dozal, but has fewer symmetries, so \
supersymmetry gives fewer partner particles. This is, so far, the only \
prediction arising from the hoop concept. The Pauli exclusion principle may \
not apply to bosons because they are in equivalence relationships to many \
fermions.\n\nThe real division algebras R, C, H, & O are degenerate \
(monosized) hoops; complex functions are specialisations of more general \
functions. Hoops subsume, but do not invalidate, complex mathematics. Many \
standard mathematical operations are specialisations of general hoop \
operations; many \"obvious mathematical truths\" are special cases restricted \
to the \"real algebras without divisors of zero\".\n\nI am still seeking \
solutions to outstanding problems:\n\n   1. Non-abelian \"pseudo-polar\" \
duals do not have conserved radii, so they only provide \"pseudo-powers\" and \
\"pseudo-roots\". They may introduce uncertainty via non-commutative \
operations that produce rotated vectors.\n   2. Dozal hoops conserve many \
functions resembling the conserved properties of particles; I cannot \
correlate them with particles.\n   3. The Schrodinger equation describes \
\"information about particles\" and leads to dispersing wave-packets. \
Replacing the 4 directions implied by \"i\" with the 12 directions of Dozal, \
and possibly eliminating dispersion with non-linear terms (as in the KdV \
equation) could lead to a description of stable particles as multi-phase \
wave-packets.\n   4. I still hope to bring space-time (or perhaps a different \
description as \"time-space\", in which time enters the metric as an \
un-squared primal term) into the system. One possibility is to combine \
particle interactions (described by hoops) with the Lorentz transformation of \
coordinates (described by matrix multiplication using the P16 group or \
Clifford(4) ).\n   5. Testable predictions are needed, beyond \"most \
supersymmetric particles do not exist\".\n\nUpdated by the author to Version \
1c, February 21, 2007.\nOK with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 4.2 or later"
}], "Text"]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 887}},
WindowToolbars->"EditBar",
WindowSize->{1041, 687},
WindowMargins->{{50, Automatic}, {Automatic, 21}},
Magnification->2
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 7179, 100, 3196, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

