(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    140240,       3554]*)
(*NotebookOutlinePosition[    141304,       3587]*)
(*  CellTagsIndexPosition[    141260,       3583]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Hoop Algebras & Physics.", "Title",
  PageWidth->WindowWidth],

Cell["R.H.Beresford.  21/2/2007.", "Subsubtitle",
  PageWidth->PaperWidth],

Cell["\<\
Abstract.
Symmetry-conserving Hoop Algebras* (*=new mathematical concept) add, multiply \
and divide* vecs* (generalised vectors), introducing unsigned continuous \
Primal* numbers, generalised signs* and multiplication tables folded* \
(equivalenced) from finite group Cayley tables. Their Frobenius \
symmetry-conservation* and Moufang partial-fraction-division* properties \
suggest a new physics paradigm. Vecs have partial-fraction multiplicative \
inverses* with conserved symbolic determinant factors* (symmetries or \
\[OpenCurlyDoubleQuote]sizes\[CloseCurlyDoubleQuote]*) as denominators. \
Multiplying or dividing two vecs gives a third vec and two (often null) \
remainder* vecs carrying different symmetries, emulating symmetry-conserving \
particle interactions and eliminating division-by-zero. Non-Abelian hoops* \
may introduce uncertainty. Multi-phase sinusoidal orbits* generalise \
Cartesian-polar duality*. Some hoops have half-spin quantum operators*, \
stable de-Broglie-like orbits* and Planck-like intrinsic areas*, possibly \
explaining particle stability, ternary quark symmetry, mass, M-theory \
T-duality, and the \[OpenCurlyDoubleQuote]large numbers hypothesis\
\[CloseCurlyDoubleQuote]. Hoop symmetries complement the use of continuous \
groups as coordinate transformation matrices. Single-symmetry real, complex, \
quaternion and octonion algebras are degenerate* cases of the more general \
hoop operations that describe physics.\
\>", "Text"],

Cell[CellGroupData[{

Cell["1. Introduction", "Section",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["1.1 Overview.", "Subsection"],

Cell[TextData[{
  "\tGeneral relativity and quantum physics are both correct, but are \
incompatible in 20th century mathematics; is the mathematics wrong? A search \
for errors led to the conjecture that physics is over-reliant on real and \
complex numbers. A new approach was found. Sir W.R.Hamilton observed that \
quaternion and octonion algebra multiplication tables had four and eight \
signed \[OpenCurlyDoubleQuote]dimensions\[CloseCurlyDoubleQuote], and were \
obtained from tables with eight and sixteen unsigned \
\[OpenCurlyDoubleQuote]directions\[CloseCurlyDoubleQuote]. This generalizes; \
many algebras are obtained by equivalence relationships folding* (*=new \
mathematical concept) Cayley tables with r-fold symmetry, creating signed \
algebras. Real, complex, quaternion and Clifford algebras are folded from the \
C2, C4, quaternion, etc. groups. Folding is usually two-fold with signs \
{+,-}, or four-fold, with signs {+,i,-,-i}; three-fold symmetry gives \
terplex* algebras with signs {+, J, JJ}*. Generalised signs* arise as powers \
of orthogonal (NOT cyclotomic) primitive roots of unity. Frobenius [1] proved \
that associative tables \[OpenCurlyDoubleQuote]conserve\
\[CloseCurlyDoubleQuote] the determinant of the inverse symbolic table. All \
groups, \[OpenCurlyDoubleQuote]signed table\[CloseCurlyDoubleQuote] algebras \
folded from them, and a few \[OpenCurlyDoubleQuote]alternative\
\[CloseCurlyDoubleQuote] Moufang loops [2] (e.g. octonions and \
split-octonions) conserve the determinant factors as \
\[OpenCurlyDoubleQuote]symmetries\[CloseCurlyDoubleQuote] or \
\[OpenCurlyDoubleQuote]sizes\[CloseCurlyDoubleQuote]; most loops do not. \
Hoops* are defined as symmetry-conserving algebras based on unsigned \
continuous Primal Numbers*, \"generalised signs\" and multiplication tables \
folded (equivalenced to introduce signed elements*) from conservative Cayley \
tables. Hoops add, multiply and divide* generalised* vectors (abbreviated to \
\"vecs\"). They are implemented and demonstrated [3,4] in notebooks that \
Mathematica users can test with different data. [5] provides edited Word \
document transcripts of these demonstrations",
  StyleBox[".",
    FontSlant->"Italic"],
  "  \n\tFrobenius symmetry-conservation* and Moufang \
partial-fraction-division* properties make hoops relevant to, and hint at a \
possible new paradigm for, mathematical physics. Vec multiplicative inverses \
have conserved symbolic determinant factors as partial-fraction \
denominators*. In hoop multiplication and division two vecs produce a third \
vec and two (often null) remainder* vecs carrying different symmetries in \
different sub-algebras. This emulates symmetry-conserving particle \
interactions and eliminates division by zero by projection* (as in h-deformed \
algebras) into a sub-algebra when a size approaches zero. Multi-phase \
sinusoidal* polar-duals* (generalising Cartesian-polar duality) appear when \
quadratic sizes are conserved. Some hoops have stable de-Broglie-like orbits* \
with Planck-like intrinsic areas*. In Dozal* (the 12-element algebras) 3, 4, \
6 & 12-phase orbits have areas that multiply to one (or are zero, as missing \
symmetries*), possibly explaining particle families, particle stability, \
ternary quark symmetry, mass, M-theory T-duality, and the \
\[OpenCurlyDoubleQuote]law of large numbers\[CloseCurlyDoubleQuote]. Using \
experimental mathematics, the author has found many analogies between hoop \
algebras and particle physics. As a 77 yr. old chemical engineer he lacks the \
skills and time to take the subject much further.\n\tHoops complement the use \
of groups as coordinate transformation matrices. Real, complex, quaternion \
and octonion algebras are single-symmetry* hoops; their operations are \
degenerate* cases of more general hoop operations that describe mathematical \
physics."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.2. Implementation.", "Subsection"],

Cell[TextData[{
  "\tThe Hoops concept has been implemented in [3] as a Mathematica package \
",
  StyleBox["Hoops.m",
    FontSlant->"Italic"],
  ". This provides a databank of over 80 named Hoops (with five \
counter-example non-hoop Loops), three main procedures ",
  StyleBox["hoopTimes, hoopInverse, hoopPower",
    FontSlant->"Italic"],
  " and a few subsidiary procedures. Each hoop is defined by a name (relating \
it to a group or an algebra), a Cayley index table (a preferred isomorph) and \
a \"shape\" (the distinct factors of the inverse symbolic Cayley table). \
Multiplication, division, and (in many cases) conversion from Cartesian \
vector form {a,b,...} to polar form {r,\[Theta],...} are provided. The \
package is written in elementary ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", and includes (* comments *) and \"Usage\" explaining the details, so it \
should be readily comprehensible and easy to transcribe into other \
computer-aided-mathematics systems for independent verification. A larger \
package (creation and properties of groups, loops, & hoops) is available in \
[4], which also provides a glossary.\n\tThe figures in this document are \
self-explanatory output from a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session (with results of calculations appearing in bold-face) intended to \
be comprehensible to readers with no knowledge of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". They are based on the ",
  StyleBox["Hoops.m",
    FontSlant->"Italic"],
  " package. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " users can test them with different data, by installing ",
  StyleBox["Hoops.nb",
    FontSlant->"Italic"],
  " and running it (to create the ",
  StyleBox["Hoops.m",
    FontSlant->"Italic"],
  " package) in the ",
  StyleBox["Addons\\ExtraPackages",
    FontSlant->"Italic"],
  " directory, and then using the following instructions:-."
}], "Text"],

Cell["Quit[]", "Input"],

Cell[BoxData[
    \(<< "\<Hoops`\>"\)], "Input",
  PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2. Development of Hoop Concepts.",
  FontWeight->"Bold"]], "Section"],

Cell[TextData[StyleBox["Summary.\n\tSymmetry-conserving \"Hoop Algebras\" \
involve new mathematical concepts, starting with unsigned continuous \
\[OpenCurlyDoubleQuote]Primal Numbers\[CloseCurlyDoubleQuote]. Hoop \
multiplication tables are \[OpenCurlyDoubleQuote]folded\
\[CloseCurlyDoubleQuote] (via equivalence relations based on symmetries) from \
finite groups and Moufang loops; this introduces \"generalized signs\". Hoops \
multiply, divide, and add generalized vectors. Their \"Frobenius \
symmetry-conservation\" and \"Moufang partial-fraction-division\" properties \
make them relevant to physics. A few hoops have stable multi-phase \
de-Broglie-like \"orbits\" and Planck-like intrinsic areas; this may explain \
particle stability. Every vector has a multiplicative inverse, so Hoop \
multiplication and division use the same \"hoopTimes\" operation; two vectors \
produce a third vector and two (often null) \"remainder\" vectors carrying \
different symmetries. This is analogous to symmetry-conserving particle \
interactions. Do not confuse hoops with the traditional use of groups as \
coordinate transformation matrices for a single vector. Hoop tables are not \
restricted to complex matrix generators. Many complex operations are \
degenerate cases of more general hoop operations.",
  FontSlant->"Italic"]], "Text"],

Cell[TextData[{
  "\tThe development of hoops  involves some neglected and some new \
mathematical concepts. The latter are idistinguished by asterisks:- \n\n\t(1) \
Primal* unsigned continuous numbers (the half-line, the union of 0 & ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[DoubleStruckCapitalR]\^+\)\)]],
  ") can be developed from set theory via natural numbers N, (which have \
order and a lower bound and allow addition, multiplication, powers, and \
unique prime factorization) and Landau's [5] unsigned rational numbers ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[DoubleStruckCapitalQ]\^+\)\)]],
  "(which allow division). A continuity axiom converts ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[DoubleStruckCapitalQ]\^+\)\)]],
  "to Primal numbers (with unique roots and general factorization). \
Subtraction and negation are undefined for all these numbers.\n\tOnly the \
most rigorous mathematicians acknowledge that integers and reals are \
equivalence relations on pairs of natural or primal numbers; others conflate \
(unary) negation with (binary) subtraction by working in fields - implicitly \
assuming that minus one exists and is unique (which is then justified by a \
circular argument).\n\tSome physical concepts (time? mass?) should, perhaps, \
have primal (rather than real) measures."
}], "Text"],

Cell[TextData[{
  "\t(2) Algebraic loops are ",
  StyleBox["m\[Times]m",
    FontSlant->"Italic"],
  " multiplication tables for ",
  StyleBox["m",
    FontSlant->"Italic"],
  "-element sets of coefficients (or operators) that define \"vecs\" \
(generalized vectors, which are vectors in some algebras) such as A = {",
  Cell[BoxData[
      \(TraditionalForm\`\(\(a\_1\)\(,\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`a\_2\)]],
  ",...",
  Cell[BoxData[
      \(TraditionalForm\`a\_m\)]],
  "}, {",
  StyleBox["a,b,...,m",
    FontSlant->"Italic"],
  "}, or ",
  Cell[BoxData[
      \(TraditionalForm\`a\_1\)]],
  Cell[BoxData[
      \(TraditionalForm\`d\_1\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`a\_2\)]],
  Cell[BoxData[
      \(TraditionalForm\`d\_2\)]],
  "+...+",
  Cell[BoxData[
      FormBox[
        RowBox[{\(a\_m\), 
          FormBox[\(d\_m\),
            "TraditionalForm"]}], TraditionalForm]]],
  ". Loops can be developed without introducing negation, so the coefficients \
",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  " are unsigned. Moufang loops have the Moufang division property ",
  StyleBox["zx.yz=(z.xy)z ",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["(so ",
    FontWeight->"Plain"],
  StyleBox["every vec has a multiplicative inverse)",
    PageWidth->WindowWidth],
  StyleBox["; groups ",
    FontWeight->"Plain"],
  "are associative Moufang loops with ",
  StyleBox["x(yz)=(xy)z",
    FontSlant->"Italic"],
  " . Frobenius showed [2] that all groups conserve their determinants when \
they are used as vector multiplication tables; Det[A] Det[B] = \
\[PlusMinus]Det[AB], where Det is the determinant of the inverse \
multiplication table mapped with the appropriate vector. A few \
non-associative Moufang loops (including octonions and split-octonions) also \
have this Frobenius symmetry-conservation* property; general non-associative \
loops lack it."
}], "Text"],

Cell[TextData[{
  "\t(3) Generalized signs* are orthogonal primitive roots of unity*",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(s\^j\)\)\)]],
  " (with",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(s\^r\)\)\)]],
  " =1) describing ",
  StyleBox["r",
    FontSlant->"Italic"],
  "-directional spaces or sub-spaces. Describing roots of unity as ",
  StyleBox["cyclotomic numbers",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  " distorts their properties by projecting them onto the complex field. \
Reals, with signs {+.-}, are an ",
  StyleBox["r",
    FontSlant->"Italic"],
  "=2 case. Complex numbers are one case of ",
  StyleBox["r",
    FontSlant->"Italic"],
  "=4, with signs {+,\[ImaginaryI],-,-\[ImaginaryI]}. ",
  StyleBox["r",
    FontSlant->"Italic"],
  "=3 gives terplex* signs {+, \[DoubleStruckCapitalJ], ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalJ]\^2\)]],
  "} with ternary symmetries relevant to quarks. Many features of complex \
algebra are specializations of more general features involving generalized \
signs. Multi-phase sinusoids* are a key example, with ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(-\[ImaginaryI]\[Theta]\)\)]],
  "=Cos[\[Theta]]+\[ImaginaryI] Sin[\[Theta]] being collapsed from the ",
  StyleBox["r",
    FontSlant->"Italic"],
  "=4 case of E^(",
  StyleBox["s",
    FontSlant->"Italic"],
  "\[Theta])=",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_\(j = 0\)\%\(j = r - 1\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`s\^j\)]],
  StyleBox[" ",
    FontSlant->"Italic"],
  "Cos[\[Theta]+2j\[Pi]/r].\n\n\t(4) \"Directors\" are sets of primal \
coefficients with associated \"directions\", i.e. the ",
  Cell[BoxData[
      \(TraditionalForm\`d\_i\)]],
  "'s in (2). ",
  StyleBox["r",
    FontSlant->"Italic"],
  "-fold equivalence relationships on ",
  StyleBox["m",
    FontSlant->"Italic"],
  "-element directors \"fold\" them to \"signed vecs\", generalized vectors \
with ",
  StyleBox["r-",
    FontSlant->"Italic"],
  "signed coefficients and ",
  StyleBox["m/r",
    FontSlant->"Italic"],
  " associated dimensions. Real vecs are the result of 2-folding, ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(r\_i\), "~", 
          FormBox[\(a\_i\),
            "TraditionalForm"]}], TraditionalForm]],
    PageWidth->WindowWidth],
  "- ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(a\_\(i + m/2\)\), 
          FormBox["",
            "TraditionalForm"]}], TraditionalForm]],
    PageWidth->WindowWidth],
  "; this is the special case \"Minus 1 exists and is unique\" that allows \
negation and subtraction to be conflated. (The \"directions\" concept is due \
to Sir W.R.Hamilton. He related the eight directions of the quaternion group \
to the four dimensions of the quaternion algebra, and the sixteen directions \
of the octonion table to the eight dimensions of the octonion algebra.) ",
  StyleBox["Folding is a key concept because it relates generalized signs to \
loop symmetries. ",
    PageWidth->WindowWidth],
  "Equivalence relationships on conservative ",
  StyleBox["m\[Times]m",
    FontSlant->"Italic"],
  "-element loops with ",
  StyleBox["r",
    FontSlant->"Italic"],
  "-fold symmetry \"fold\" them to ",
  StyleBox["(m/r)\[Times](m/r)",
    FontSlant->"Italic"],
  " multiplication tables for ",
  StyleBox["r",
    FontSlant->"Italic"],
  "-signed vecs. I call such tables \"Hoop Algebras\". In many cases they are \
not loops, because some products are \"signed elements\" that are not members \
of the defining set. E.g. Quaternions have four elements {e,i,j,ij} with \
i.j=ij, but j.i=-ij. Each hoop in the database is defined by a name (relating \
it to a group or an algebra).\n\t",
  StyleBox["Figure 1 shows \[OpenCurlyDoubleQuote]protoloops\
\[CloseCurlyDoubleQuote] (preferred Cayley table isomorphs) for three Moufang \
loops (the C4C2, quaternion, and C9 groups). The top left corner is repeated \
in the tables; it also occurs with offsets of 3, 4, or 6, showing the \
symmetry. These sub-tables are then shown as folded tables C4, Q4, C9J, with \
the indices replaced by the usual complex or quaternion symbols, or (in the \
C9J algebra) by signed indices, ",
    PageWidth->WindowWidth],
  "using the ternary ",
  StyleBox["sign ",
    PageWidth->WindowWidth],
  StyleBox["J (",
    PageWidth->WindowWidth,
    FontVariations->{"Shadow"->True}],
  StyleBox["with ",
    PageWidth->WindowWidth],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["J",
            FontSlant->"Plain"], "3"], TraditionalForm]]],
  StyleBox["=1) so that indices 4 & 5 become ",
    PageWidth->WindowWidth],
  StyleBox["J",
    PageWidth->WindowWidth,
    FontVariations->{"Shadow"->True}],
  StyleBox["1 and",
    PageWidth->WindowWidth],
  StyleBox[" J",
    PageWidth->WindowWidth,
    FontVariations->{"Shadow"->True}],
  StyleBox["2. Note that the C4C2 table can be folded a second time, to give \
",
    PageWidth->WindowWidth],
  StyleBox["the complex algebra table with \[ImaginaryI] \[ImaginaryI] = -1. \
The \"Pauli-\[Sigma] algebra\" P4 is also shown; it is 4-folded from a \
16-element group ",
    PageWidth->WindowWidth,
    FontFamily->"Times New Roman"],
  StyleBox["(not shown) that can be created by dot-multiplying ",
    PageWidth->WindowWidth],
  StyleBox["the Pauli-\[Sigma] matrices",
    PageWidth->WindowWidth,
    FontFamily->"Times New Roman"],
  StyleBox[".",
    PageWidth->WindowWidth,
    FontFamily->"Times New Roman Greek"]
}], "Text"],

Cell[TextData[{
  StyleBox["Figure 1.",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox[" Two- Three- & four-fold folding of Moufang Loops, the\nresulting \
signed algebras, and the four-folded Pauli-",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["\[Sigma]",
    FontFamily->"Courier New Greek",
    FontSize->9],
  StyleBox[" algebra.\n  C4C2 Group       Quaternion group     C9 group\n",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["1 2 3 4",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox[" 5 6 7 8    ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["1 2 3 4",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox[" 5 6 7 8    ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["1 2 3 ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["4 5 6 7 8 9\n",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["2 3 4 1",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox[" 6 7 8 5    ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["2 5 8 3 ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["6 1 4 7    ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["2 3 4 ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["5 6 7 8 9 1\n",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["3 4 1 2 ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["7 8 5 6    ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["3 4 5 6 ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["7 8 1 2    ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["3 4 5 ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["6 7 8 9 1 2\n",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["4 1 2 3 ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["8 5 6 7    ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["4 7 2 5 ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["8 3 6 1    4 5 6 7 8 9 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["1 2 3\n",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["5 6 7 8 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["1 2 3 4    ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["5 6 7 8 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["1 2 3 4    ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["5 6 7 8 9 1 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["2 3 4\n",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["6 7 8 5 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["2 3 4 1    ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["6 1 4 7 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["2 5 8 3    ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["6 7 8 9 1 2 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["3 4 5\n",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["7 8 5 6 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["3 4 1 2    ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["7 8 1 2 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["3 4 5 6",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["    7 8 9 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["1 2 3",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox[" 4 5 6\n8 5 6 7 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["4 1 2 3    ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["8 3 6 1 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["4 7 2 5    ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["8 9 1 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["2 3 4 ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["5 6 7\n                                      9 1 2 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["3 4 5 ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["6 7 8\n\n C4 & Complex    Quaternion      C9J       Pauli-",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["\[Sigma]",
    FontFamily->"Courier New Greek",
    FontSize->9],
  StyleBox["\n Algebra C2c     Algebra Qr     Algebra   Algebra P4\n ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["1  ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["i",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"Shadow"->True}],
  StyleBox[" ",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["-1 -",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["i     ",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["1   i   j -ij   1  2  3   1   2   3   4\n",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox[" ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["i -1",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"Shadow"->True}],
  StyleBox[" ",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["-",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["i  ",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["1     i  -1 -ij   j   2  3 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["J",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["1   2   1 -i4  i3",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["\n",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["-1 -",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["i ",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox[" 1  ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["i",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["     j  ij  -1  -i",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["   ",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["3 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["J",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["1 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["J",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["2   3  i4   1 -i2\n",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["-i  ",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["1",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["  i",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox[" -1    ij  -j   1  -1             4 -i3",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["  i2",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["   1",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox[" ",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}]
}], "Text",
  FontSize->9],

Cell[TextData[StyleBox["\n  Octonion algebra         Split-Octonion algebra\n\
1  2  3  4  5  6  7  8     1  2  3  4  5  6  7  8\n2 -1  4 -3  6 -5 -8  7     \
2  1  4  3  6  5 -8 -7\n3 -4 -1  2  7  8 -5 -6     3 -4 -1  2  7  8 -5 -6\n4  \
3 -2 -1  8 -7  6 -5     4 -3 -2  1  8  7  6  5\n5 -6 -7 -8 -1  2  3  4     5 \
-6 -7 -8 -1  2  3  4\n6  5 -8  7 -2 -1 -4  3     6 -5 -8 -7 -2  1 -4 -3\n7  8 \
 5 -6 -3  4 -1 -2     7  8  5 -6 -3  4 -1 -2\n8 -7  6  5 -4 -3  2 -1     8  7 \
 6 -5 -4  3  2  1",
  FontFamily->"Courier New",
  FontSize->9]], "Text"],

Cell["\tThe two 8-element non-associative algebras are also shown.", "Text"],

Cell[TextData[{
  "\t(5) Factors of the symbolic inverse table determinant are conserved \
sizes* (symmetries) for hoop multiplication; this is the defining property \
for hoop algebras. The results of factorising quadratic or higher factors \
into complex-conjugate pairs are not conserved properties - complex algebra \
is only one of many hoop algebras.",
  StyleBox["\n\tFigure 2 shows the symbolic tables, the factorized \
determinants and the products ",
    FontFamily->"Times New Roman"],
  StyleBox["hoopTimes[{1,2,...},{a,b,...}] ",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["for the algebras in Figure 1. Calculated results are ",
    FontFamily->"Times New Roman"],
  StyleBox["bold",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox[".",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Figure 2.",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox[" Symbolic tables, products, factorized determinants.",
    FontFamily->"Courier New",
    FontSize->9],
  "\n",
  StyleBox["   C4        ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["C",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["      Quaternion     C9J         Pauli-",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["\[Sigma]",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontFamily->"Courier New Greek",
    FontSize->9],
  StyleBox[" ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["a b",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox[" c d    a  b    a  b  c  d    a  b  c     a   b   c   d\n ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["b c",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox[" d a    b -a    b -a -d  c    b  c ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["J",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["a     b   a -",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["i",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["d  ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["i",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["c\n",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox[" ",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["c d a b            c  d -a -b    c ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["J",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["a ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["J",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["b     c  ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["i",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["d   a -",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["i",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["b\n d a b c            d -c  b -a                d -",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["i",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["c  ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["i",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["b   a",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["\n",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["Factorized Determinants, Products :-\n",
    FontSize->9],
  StyleBox["C4",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox[" Factors",
    FontSize->9],
  StyleBox[" ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox[" ",
    FontSize->9],
  StyleBox["(a+b+c+d)(a-b+c-d)((a-c)",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["2",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["+(b-d)",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["2",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[")",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["\nhoopTimes[{1,2,3,4},{a,b,c,d}]=\n",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["{a+4b+3c+2d,2a+b+4c+3d,3a+2b+c+4d,4a+3b+2c+d}",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["C ",
    FontFamily->"Times New Roman",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"Shadow"->True}],
  StyleBox[" Factor",
    FontFamily->"Times New Roman",
    FontSize->9],
  StyleBox["              ",
    FontFamily->"Times New Roman",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"Shadow"->True}],
  StyleBox[" ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"Shadow"->True}],
  StyleBox["-a",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["2",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["-b",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["2",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["\nhoopTimes[{1,2},{a,b}]=",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["{a-2b,2a+b}",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["Quaternion",
    FontFamily->"Times New Roman",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox[" Factors",
    FontFamily->"Times New Roman",
    FontSize->9],
  StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"Shadow"->True}],
  StyleBox["(a",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["2",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["+b",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["2",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["+c",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["2",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["+d",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["2",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[")",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["2",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["\n",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["hoopTimes[{1,2,3,4},{a,b,c,d}]=\n",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["{a-2b-3c-4d,2a+b-4c+3d,3a+4b+c-2d,4a-3b+2c+d}\n",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["C9J",
    FontFamily->"Times New Roman",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox[" Factor",
    FontFamily->"Times New Roman",
    FontSize->9],
  StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"Shadow"->True}],
  StyleBox["      ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["-c",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["3",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["-b",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["3",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["J",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"Shadow"->True}],
  StyleBox["+3abc",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["J",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"Shadow"->True}],
  StyleBox["-a",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["3",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["J",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"Shadow"->True}],
  StyleBox["2",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["\nhoopTimes[{1,2,3},{a,b,c}]=",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["{a+3bJ+2cJ,2a+b+3cJ,3a+2b+c}",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["Pauli-\[Sigma] ",
    FontFamily->"Times New Roman",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox[" Factors",
    FontFamily->"Times New Roman",
    FontSize->9],
  StyleBox["    ",
    FontFamily->"Times New Roman",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"Shadow"->True}],
  StyleBox[" (a",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["2",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["-b",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["2",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["-c",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["2",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["-d",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["2",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[")",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["2",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["\n",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["hoopTimes[{1,2,3,4},{a,b,c,d}]=\n",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["{a+2b+3c+4d,2a+b+4\[ImaginaryI]c-3\[ImaginaryI]d,3a-4\[ImaginaryI]\
b+c+2\[ImaginaryI]d,4a+3\[ImaginaryI]b-2\[ImaginaryI]c+d}",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  StyleBox["Octonion Factors",
    FontFamily->"Times New Roman",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox[" (a^2+b^2+c^2+d^2+e^2+f^2+g^2+h^2)^4",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["hoopTimes[{1,2,3,4,5,6,7,8},{a,b,c,d,e,f,g,h}]=\n",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["{a-2b-3c-4d-5e-6f-7g-8h,2a+b-4c+3d-6e+5f+8g-7h,\n \
3a+4b+c-2d-7e-8f+5g+6h,4a-3b+2c+d-8e+7f-6g+5h,\n \
5a+6b+7c+8d+e-2f-3g-4h,6a-5b+8c-7d+2e+f+4g-3h,\n \
7a-8b-5c+6d+3e-4f+g+2h,8a+7b-6c-5d+4e+3f-2g+h}",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontFamily->"Courier New"],
  StyleBox["Split-Octonion Factors",
    FontFamily->"Times New Roman",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox[" (a^2-b^2+c^2-d^2+e^2-f^2+g^2-h^2)^4",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["hoopTimes[{1,2,3,4,5,6,7,8},{a,b,c,d,e,f,g,h}]=\n",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["{a+2b-3c+4d-5e+6f-7g+8h,2a+b-4c+3d-6e+5f+8g-7h,\n \
3a-4b+c+2d-7e+8f+5g-6h,4a-3b+2c+d-8e+7f-6g+5h,\n \
5a-6b+7c-8d+e+2f-3g+4h,6a-5b+8c-7d+2e+f+4g-3h,\n \
7a+8b-5c-6d+3e+4f+g-2h,8a+7b-6c-5d+4e+3f-2g+h}",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  "\t(Mathematica users can repeat the calculations with their own input \
data.) The three C4 sizes fold to the single conserved size ",
  Cell[BoxData[
      \(TraditionalForm\`a\^2\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`b\^2\)]],
  " of Complex algebra. Quaternion, Pauli-\[Sigma], octonion and \
split-octonion algebras conserve their single (but repeated) factors. C9J \
conserves ",
  Cell[BoxData[
      \(TraditionalForm\`a\^3\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`b\^3\)]],
  "J-3",
  StyleBox["abc",
    FontSlant->"Italic"],
  "J+",
  Cell[BoxData[
      \(TraditionalForm\`c\^3\)]],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["J",
            FontSlant->"Plain"], "2"], TraditionalForm]]],
  ", a conjugate of the determinant factor. (Conjugate conservation* appears \
to be the general rule, because the conserved factors are those of the \
inverse table determinant. Conjugation has no effect on most sizes.)  In many \
hoops (including C, H, O, split-octonions, P4, some Clifford algebras), \
multiplying a vector by its complex conjugate gives a result consisting of \
the conserved quadratic size, followed by a set of zeroes. This is why \
complex conjugates are useful. Other hoops have \
\[OpenCurlyDoubleQuote]plex-conjugates\[CloseCurlyDoubleQuote] (involutions) \
that give products related to the conserved sizes. This has allowed the \
determination of the sizes of some hoops with 16 or more elements.\n\n\t(6) \
The Moufang property ensures that every vec has a multiplicative inverse in \
each hoop of the same length, merging multiplication and division into one \
procedure. The inverse Ai solves Ai.A={1,0,..} (the \
\[OpenCurlyDoubleQuote]unit vec\[CloseCurlyDoubleQuote] with shape \
{1,1,...}). The determinant is a divisor for each element of the inverse, so \
multiple sizes provide denominators for partial-fraction formulations* of the \
inverse.",
  StyleBox[" Although the un-factored determinant becomes zero if one or more \
size becomes zero, the other factors (and the corresponding partial \
fractions) remain finite*.\n\tFigure 3 shows the symbolic C3 table, the C3 \
(terplex*) product of two symbolic vectors, and the two determinant factors. \
The inverse is then shown; each term splits into two partial fractions. Then \
two numeric vectors A & B are multiplied; the sizes are shown as sA, etc. ",
    PageWidth->WindowWidth,
    FontFamily->"Times New Roman"],
  "(Mathematica users can repeat the calculations with their own input data.) \
",
  StyleBox["The sizes of the product AB can be seen to be the products of the \
sizes of A & B. Ai is a left inverse, so ",
    PageWidth->WindowWidth,
    FontFamily->"Times New Roman"],
  StyleBox["hoopTimes[Ai,AB]",
    PageWidth->WindowWidth,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" recovers B. ",
    PageWidth->WindowWidth,
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Figure 3.",
    FontWeight->"Bold"],
  " C3 Product, Shape, Inverse, Division."
}], "Text",
  FontFamily->"Courier New",
  FontSize->9],

Cell[CellGroupData[{

Cell["\<\
Use[\"C3\"]; 
  {tf[hoopTbl /. {1 -> a, 
      2 -> b, 3 -> c, 4 -> d, 
      5 -> e, 6 -> f}], \"\\nho\\
opTimes[{a,b,c},{d,e,f}=\\n\", 
   bf[hoopTimes[{a, b, c}, 
     {d, e, f}]], 
   \"\\nshape =\\n\", bf[sh], 
   \"\\nInverse =\\n\", 
   bf[Apart[hoopInverse[
      {a, b, c, d, e, f}]]]}\
\>", "Input",
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"a", "b", "c"},
                  {"b", "c", "a"},
                  {"c", "a", "b"}
                  }], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nhoopTimes[{a,b,c},{d,e,f}=\\n\"\>", 
        ",", 
        TagBox[
          
          StyleBox[\({a\ d + c\ e + b\ f, b\ d + a\ e + c\ f, 
              c\ d + b\ e + a\ f}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"\\nshape =\\n\"\>", ",", 
        TagBox[
          
          StyleBox[\({a + b + c, 
              1\/2\ \((\((a - b)\)\^2 + \((b - c)\)\^2 + \((\(-a\) + c)\)\^2)\
\)}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"\\nInverse =\\n\"\>", ",", 
        TagBox[
          
          StyleBox[\({1\/\(3\ \((a + b + c)\)\) + \(2\ a - b - c\)\/\(3\ \((a\
\^2 - a\ b + b\^2 - a\ c - b\ c + c\^2)\)\), 
              1\/\(3\ \((a + b + c)\)\) + \(\(-a\) - b + 2\ c\)\/\(3\ \((a\^2 \
- a\ b + b\^2 - a\ c - b\ c + c\^2)\)\), 
              1\/\(3\ \((a + b + c)\)\) + \(\(-a\) + 2\ b - c\)\/\(3\ \((a\^2 \
- a\ b + b\^2 - a\ c - b\ c + c\^2)\)\)}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)]}], "}"}]], "Output",
  FontSize->9]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
tf[{Flatten[{\"If  A=\", 
     A = {3, 1, -2}, \"sA=\", 
     sh /. as[A]}], 
   Flatten[{\"and B=\", 
     B = {1, 0, 2}, \"sB=\", 
     sh /. as[B]}], 
   Flatten[{\"AB=\", 
     AB = hoopTimes[A, B], 
     \"sAB=\", sh /. as[AB]}], 
   Flatten[{\"Ai=\", 
     Ai = hoopInverse[A], 
     \"sAi=\", sh /. as[Ai]}], 
   Flatten[{\"AiAB=B\", 
     AiAB = hoopTimes[Ai, 
       AB], \"\", \"\", \"\"}]}]\
\>", "Input",
  CellOpen->False,
  FontSize->9],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"If  A=\"\>", "3", "1", \(-2\), "\<\"sA=\"\>", "2", "19"},
            {"\<\"and B=\"\>", "1", "0", "2", "\<\"sB=\"\>", "3", "3"},
            {"\<\"AB=\"\>", "5", \(-3\), "4", "\<\"sAB=\"\>", "6", "57"},
            {"\<\"Ai=\"\>", \(11\/38\), \(1\/38\), \(7\/38\), "\<\"sAi=\"\>", \
\(1\/2\), \(1\/19\)},
            {"\<\"AiAB=B\"\>", "1", "0", 
              "2", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
  FontSize->9]
}, Open  ]],

Cell["\<\
\tIt is shown in [3, Example 14] that, in general, loops do not conserve \
their determinant factors. \
\>", "Text"],

Cell[TextData[{
  "\t(7) Vecs with zero-sizes* exist in sub-algebras* where these sizes are \
constrained (as a result of conservation) to be zero. Their use in \
multiplication and division projects* the result into the sub-algebras and \
\"ejects\" remainders to maintain size conservation. This eliminates \
division-by-zero; zeroed sizes are \"factored-out\" by projection into the \
constrained sub-algebra. If a size is within an arbitrary ",
  StyleBox["hmin",
    FontSlant->"Italic"],
  " of zero ",
  StyleBox["hoopTimes",
    FontSlant->"Italic"],
  " sets it to zero and tests whether a remainder is created. Remainders are \
demonstrated in Figure 4 for the C3 and C4 hoops. The unit vecs in \
sub-algebras (A1 in Fig.4) are not {1,0,0..} (with shape {1,1,..}) because \
their shapes must have the appropriate zeroes; A1.A1=A1 correctly. \
\[OpenCurlyDoubleQuote]Ultra-violet divergence\[CloseCurlyDoubleQuote] may be \
eliminated by projection."
}], "Text"],

Cell[TextData[{
  StyleBox["Figure 4.",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox[" If A has a zero size, so do AB and Ai; \n       AB/A only become \
B after adding a remainder.",
    FontFamily->"Courier New"]
}], "Text",
  FontFamily->"Arial CYR",
  FontSize->9],

Cell[CellGroupData[{

Cell[BoxData[{
    \(TraditionalForm\`\(Use["\<C3\>"];\)\), "\n", 
    \(TraditionalForm\`tf[{Flatten[{"\<In C3, if  A=\>", 
            A0 = {2, \(-1\), \(-1\)}, "\<sA=\>", sh /. as[A0]}], 
        Flatten[{"\<and B=\>", B = {1, 0, 2}, "\<sB=\>", sh /. as[B]}], 
        Flatten[{"\<AB=\>", AB = hoopTimes[A0, B], "\<sAB=\>", 
            sh /. as[AB]}], 
        Flatten[{"\<Rleft=\>", Rleft = Rl, "\<sRleft=\>", sh /. as[Rleft]}], 
        Flatten[{"\<Rright=\>", Rright = Rr, "\<sRright=\>", sh /. as[Rr]}], 
        Flatten[{"\<Ai=\>", Ai = hoopInverse[A0], "\<sAi=\>", sh /. as[Ai]}], 
        Flatten[{"\<Ai.A (=A1)=\>", A1 = hoopTimes[Ai, A0], "\<sA1=\>", 
            sh /. as[A1]}], 
        Flatten[{"\<AB/A (=AiAB)=\>", AiAB = hoopTimes[Ai, AB], "\<sAiAB=\>", 
            sh /. as[AiAB]}], 
        Flatten[{"\<AiAB+Rright=B\>", R = AiAB + Rright, "\<s=\>", 
            sh /. as[R]}]}]\), "\n", 
    \(TraditionalForm\`\(Use["\<C4\>"];\)\), "\n", 
    \(TraditionalForm\`tf[{Flatten[{"\<In C4, if  A=\>", 
            A = {2, 3, 1, 0}, "\<sA=\>", sh /. as[A]}], 
        Flatten[{"\<and B=\>", B = {3, \(-1\), \(-2\), 0}, "\<sB=\>", 
            sh /. as[B]}], 
        Flatten[{"\<AB=\>", AB = hoopTimes[A, B], "\<sAB=\>", sh /. as[AB]}], 
        Flatten[{"\<Rleft=\>", Rleft = Rl, "\<sRleft=\>", sh /. as[Rleft]}], 
        Flatten[{"\<Rright=\>", Rright = Rr, "\<sRright=\>", sh /. as[Rr]}], 
        Flatten[{"\<1/A=Ai=\>", Ai = hoopInverse[A], "\<sAi=\>", 
            sh /. as[Ai]}], 
        Flatten[{"\<Ai.A (=A1)=\>", A1 = hoopTimes[Ai, A], "\<sA1=\>", 
            sh /. as[A1]}], 
        Flatten[{"\<AB/A (=AiAB)=\>", AiAB = hoopTimes[Ai, AB], "\<sAiAB=\>", 
            sh /. as[AiAB]}], 
        Flatten[{"\<AiAB+Rright=B\>", R = AiAB + Rright, "\<s=\>", 
            sh /. as[R]}], 
        Flatten[{"\<1/B=Bi=\>", Bi = hoopInverse[B], "\<sBi=\>", 
            sh /. as[Bi]}], 
        Flatten[{"\<Bi.B (=B1)=\>", B1 = hoopTimes[Bi, B], "\<sB1=\>", 
            sh /. as[B1]}], 
        Flatten[{"\<AB/B (=ABBi)=\>", ABBi = hoopTimes[AB, Bi], "\<sABBi=\>", 
            sh /. as[ABBi]}], 
        Flatten[{"\<ABBi+Rleft=A\>", R = ABBi + Rleft, "\<s=\>", 
            sh /. as[R]}]}]\)}], "Input",
  PageWidth->WindowWidth,
  CellOpen->False,
  FontSize->9],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"In C3, if  A=\"\>", "2", \(-1\), \(-1\), "\<\"sA=\"\>", "0",
               "9"},
            {"\<\"and B=\"\>", "1", "0", "2", "\<\"sB=\"\>", "3", "3"},
            {"\<\"AB=\"\>", "0", \(-3\), "3", "\<\"sAB=\"\>", "0", "27"},
            {"\<\"Rleft=\"\>", "0", "0", "0", "\<\"sRleft=\"\>", "0", "0"},
            {"\<\"Rright=\"\>", "1", "1", "1", "\<\"sRright=\"\>", "3", "0"},
            {"\<\"Ai=\"\>", \(2\/9\), \(-\(1\/9\)\), \(-\(1\/9\)\), "\<\"sAi=\
\"\>", "0", \(1\/9\)},
            {"\<\"Ai.A (=A1)=\"\>", \(2\/3\), \(-\(1\/3\)\), \(-\(1\/3\)\), "\
\<\"sA1=\"\>", "0", "1"},
            {"\<\"AB/A (=AiAB)=\"\>", "0", \(-1\), "1", "\<\"sAiAB=\"\>", "0",
               "3"},
            {"\<\"AiAB+Rright=B\"\>", "1", "0", "2", "\<\"s=\"\>", "3", "3"}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
  FontSize->9],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"In C4, if  A=\"\>", "2", "3", "1", "0", "\<\"sA=\"\>", "6", 
              "0", "10"},
            {"\<\"and B=\"\>", "3", \(-1\), \(-2\), "0", "\<\"sB=\"\>", "0", 
              "2", "26"},
            {"\<\"AB=\"\>", "4", "7", \(-4\), \(-7\), "\<\"sAB=\"\>", "0", 
              "0", "260"},
            {"\<\"Rleft=\"\>", \(3\/2\), \(3\/2\), \(3\/2\), \(3\/2\), \
"\<\"sRleft=\"\>", "6", "0", "0"},
            {"\<\"Rright=\"\>", \(1\/2\), \(-\(1\/2\)\), \(1\/2\), \
\(-\(1\/2\)\), "\<\"sRright=\"\>", "0", "2", "0"},
            {"\<\"1/A=Ai=\"\>", \(11\/120\), \(-\(13\/120\)\), \
\(-\(1\/120\)\), \(23\/120\), "\<\"sAi=\"\>", \(1\/6\), "0", \(1\/10\)},
            {"\<\"Ai.A (=A1)=\"\>", \(3\/4\), \(1\/4\), \(-\(1\/4\)\), \(1\/4\
\), "\<\"sA1=\"\>", "1", "0", "1"},
            {"\<\"AB/A (=AiAB)=\"\>", \(5\/2\), \(-\(1\/2\)\), \(-\(5\/2\)\), \
\(1\/2\), "\<\"sAiAB=\"\>", "0", "0", "26"},
            {"\<\"AiAB+Rright=B\"\>", "3", \(-1\), \(-2\), "0", "\<\"s=\"\>", 
              "0", "2", "26"},
            {"\<\"1/B=Bi=\"\>", \(23\/104\), \(-\(11\/104\)\), \(3\/104\), \
\(-\(15\/104\)\), "\<\"sBi=\"\>", "0", \(1\/2\), \(1\/26\)},
            {"\<\"Bi.B (=B1)=\"\>", \(3\/4\), \(-\(1\/4\)\), \(-\(1\/4\)\), \
\(-\(1\/4\)\), "\<\"sB1=\"\>", "0", "1", "1"},
            {"\<\"AB/B (=ABBi)=\"\>", \(1\/2\), \(3\/2\), \(-\(1\/2\)\), \
\(-\(3\/2\)\), "\<\"sABBi=\"\>", "0", "0", "10"},
            {"\<\"ABBi+Rleft=A\"\>", "2", "3", "1", "0", "\<\"s=\"\>", "6", 
              "0", "10"}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
  FontSize->9]
}, Open  ]],

Cell[TextData[{
  "\tNote the analogy between integer division, I/J=K+R where J*K+R=I, with \
Hoop operations, where A.B=C+Rleft+Rright and C/B+Rleft=A, C/A+Rright=B. \
Rleft carries the sizes that are zero in C but not in A; Rright carries the \
sizes that are zero in C but not in B. Remainders ensure that conservation is \
maintained in hoop multiplication (as well as division) when some sizes are \
zero. There is an obvious analogy with particle interactions, where there may \
be several products with different symmetries, and to ",
  StyleBox["h",
    FontSlant->"Italic"],
  "-deformed and ",
  StyleBox["q",
    FontSlant->"Italic"],
  "-deformed algebras.\n\tDo not confuse loop operations, acting on two \
vectors to give a new vector and two (possibly null) remainder vectors, with \
the use of matrices to transform a vector to different coordinates in the \
\[OpenCurlyDoubleQuote]standard model\[CloseCurlyDoubleQuote] of particle \
physics."
}], "Text"],

Cell[TextData[{
  "\t(8) Some hoops have quadratic sizes* that provide polar-Cartesian dual* \
formulations and allow the definition of continuous multi-phase sinusoidal \
orbits",
  StyleBox["*, as shown in Figures 5 & 7",
    PageWidth->WindowWidth],
  ". Quadratic sizes release a degree of freedom that is taken up by an \
angle",
  StyleBox[", which is a hidden variable* for the Cartesian form. \n\t",
    PageWidth->WindowWidth,
    FontFamily->"Times New Roman"],
  "Abelian polar duals have angles that add on vec multiplication*. This \
leads to powers and roots. ",
  StyleBox["Figure 5 shows that the polar form for the C3 vector {a,b,c} \
consists of expressions for two sizes {\[Alpha],",
    PageWidth->WindowWidth],
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\^2\)]],
  StyleBox["} and an angle \[Sigma]. The reversion from polar to cartesian \
form has \[Alpha] as an offset from zero and three equispaced phases. It then \
demonstrates that ",
    PageWidth->WindowWidth],
  StyleBox["vector[polar[A]=A",
    PageWidth->WindowWidth,
    FontSlant->"Italic"],
  StyleBox[", angles add on C3 multiplication, and taking a square root \
halves the angle and gives sizes that are square roots of the original sizes. \
C3 has a prototypical ternary (3-phase) form polar form. Figure 6 shows that \
C4 has the prototypical 4-phase. This folds to the (asymmetric) \
{Cos[\[Theta]],Sin[\[Theta]]} pair. All known polar duals are related to \
these two prototypes.",
    PageWidth->WindowWidth]
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  StyleBox["Figure 5a",
    FontWeight->"Bold"],
  ". C3 Polar Duals, Reversions, Powers & Roots."
}], "Text",
  FontFamily->"Courier New",
  FontSize->9],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Use["\<C3\>"]; "\<Polar C3\>"\), "\[IndentingNewLine]", 
    \(topol // bf\), "\[IndentingNewLine]", 
    \("\<Vector C3\>"\), "\[IndentingNewLine]", 
    \(tovec // bf\), "\[IndentingNewLine]", 
    \({Flatten[{"\<If  A=\>", A = {2. , \(-3. \), 5. }, "\<polarA=\>", 
            topol /. as[A]}], 
        Flatten[{"\<Vec(polar(A))=\>", 
            tovec /. as[
                topol /. as[
                    A]], "\<\>", "\<\>", "\<\>", "\<\>"}], \
\[IndentingNewLine]Flatten[{"\<and B=\>", 
            B = {1, \(-5\), 6. }, "\<polarB=\>", 
            topol /. as[B]}], \[IndentingNewLine]Flatten[{"\<AB=\>", 
            AB = hoopTimes[A, B], "\<polarAB=\>", topol /. as[AB]}], 
        Flatten[{\*"\"\<\!\(\@A\)=\>\"", 
            RootA = hoopPower[A], \*"\"\<polar\!\(\@A\)=\>\"", 
            topol /. as[RootA]}]} // tf\), "\[IndentingNewLine]", 
    \(\)}], "Input",
  CellOpen->False,
  FontSize->9],

Cell[BoxData[
    \("Polar C3"\)], "Output",
  FontSize->9]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[
      TagBox[
        StyleBox[\({a + b + c, 
            1\/2\ \((\((a - b)\)\^2 + \((b - c)\)\^2 + \((\(-a\) + \
c)\)\^2)\), ArcTan[2\ a - b - c, \(-\@3\)\ \((b - c)\)]}\),
          FontWeight->"Bold"],
        (StyleForm[ #, FontWeight -> "Bold"]&)],
      FontSize->9]], "Input"],

Cell[BoxData[
    \("Vector C3"\)], "Output",
  FontSize->9]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[
      TagBox[
        StyleBox[\({1\/3\ \((a + 2\ \@b\ Cos[c])\), 
            1\/3\ \((a + 2\ \@b\ Cos[c + \(2\ \[Pi]\)\/3])\), 
            1\/3\ \((a + 2\ \@b\ Cos[c - \(2\ \[Pi]\)\/3])\)}\),
          FontWeight->"Bold"],
        (StyleForm[ #, FontWeight -> "Bold"]&)],
      FontSize->9]], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"If  A=\"\>", "2.`", \(-3.`\), "5.`", "\<\"polarA=\"\>", 
              "4.`", "49.`", "1.4274487578895312`"},
            {"\<\"Vec(polar(A))=\"\>", "2.`", \(-3.0000000000000004`\), 
              "5.`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
            {"\<\"and B=\"\>", "1", \(-5\), "6.`", "\<\"polarB=\"\>", "2.`", 
              "91.`", "1.518358056045878`"},
            {"\<\"AB=\"\>", \(-41.`\), "17.`", "32.`", "\<\"polarAB=\"\>", 
              "8.`", "4459.`", "2.9458068139354094`"},
            {"\<\"\\!\\(\\@A\\)=\"\>", "2.`", \(-1.`\), 
              "1.0000000000000002`", "\<\"polar\\!\\(\\@A\\)=\"\>", "2.`", 
              "7.`", "0.7137243789447656`"}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Figure 5b",
    FontWeight->"Bold"],
  ". C4 Polar Duals, Reversions, Powers & Roots."
}], "Text",
  FontFamily->"Courier New",
  FontSize->9],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Use["\<C4\>"]; "\<Polar C4\>"\), "\n", 
    \(topol // bf\), "\n", 
    \("\<Vector C4\>"\), "\n", 
    \(tovec // bf\), "\n", 
    \({Flatten[{"\<If  A=\>", A = {2. , \(-3. \), 5. , 1. }, "\<polarA=\>", 
            topol /. as[A]}], 
        Flatten[{"\<Vec(polar(A))=\>", 
            tovec /. as[
                topol /. as[
                    A]], "\<=A\>", "\<\>", "\<\>", "\<\>", "\<\>"}], \
\[IndentingNewLine]Flatten[{"\<and B=\>", 
            B = {\(-1\), 5, \(-6. \), 3. }, "\<polarB=\>", 
            topol /. as[B]}], \[IndentingNewLine]Flatten[{"\<AB=\>", 
            AB = hoopTimes[A, B], "\<polarAB=\>", topol /. as[AB]}], 
        Flatten[{\*"\"\<\!\(\@A\)=\>\"", 
            RootA = hoopPower[A], \*"\"\<polar\!\(\@A\)=\>\"", 
            topol /. as[RootA]}]} // tf\)}], "Input",
  CellOpen->False,
  FontSize->9],

Cell[BoxData[
    \("Polar C4"\)], "Output",
  FontSize->9],

Cell[BoxData[
    TagBox[
      StyleBox[\({a + b + c + d, 
          a - b + c - d, \((a - c)\)\^2 + \((b - d)\)\^2, 
          ArcTan[a - c, b - d]}\),
        FontWeight->"Bold"],
      (StyleForm[ #, FontWeight -> "Bold"]&)]], "Output",
  FontSize->9],

Cell[BoxData[
    \("Vector C4"\)], "Output",
  FontSize->9],

Cell[BoxData[
    TagBox[
      StyleBox[\({1\/4\ \((a + b + 2\ \@c\ Cos[d])\), 
          1\/4\ \((a - b + 2\ \@c\ Sin[d])\), 
          1\/4\ \((a + b - 2\ \@c\ Cos[d])\), 
          1\/4\ \((a - b - 2\ \@c\ Sin[d])\)}\),
        FontWeight->"Bold"],
      (StyleForm[ #, FontWeight -> "Bold"]&)]], "Output",
  FontSize->9],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"If  A=\"\>", "2.`", \(-3.`\), "5.`", 
              "1.`", "\<\"polarA=\"\>", "5.`", "9.`", 
              "25.`", \(-2.214297435588181`\)},
            {"\<\"Vec(polar(A))=\"\>", 
              "2.0000000000000004`", \(-3.0000000000000004`\), "5.`", 
              "1.0000000000000004`", "\<\"=A\"\>", "\<\"\"\>", "\<\"\"\>", \
"\<\"\"\>", "\<\"\"\>"},
            {"\<\"and B=\"\>", \(-1\), "5", \(-6.`\), 
              "3.`", "\<\"polarB=\"\>", "1.`", \(-15.`\), "29.`", 
              "0.3805063771123649`"},
            {"\<\"AB=\"\>", \(-36.`\), "22.`", \(-29.`\), 
              "48.`", "\<\"polarAB=\"\>", "5.`", \(-135.`\), 
              "725.`", \(-1.8337910584758161`\)},
            {"\<\"\\!\\(\\@A\\)=\"\>", 
              "1.8090169943749475`", \(-1.1909830056250525`\), 
              "0.8090169943749473`", 
              "0.8090169943749475`", "\<\"polar\\!\\(\\@A\\)=\"\>", 
              "2.23606797749979`", "3.`", "5.`", \(-1.1071487177940904`\)}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
  FontSize->9]
}, Open  ]],

Cell[TextData[{
  "\tNote that the linear sizes are \[OpenCurlyDoubleQuote]offsets\
\[CloseCurlyDoubleQuote] that displace the centres of rotation for the \
sinusoidal terms. They are conserved linear symmetries. Pairs of linear sizes \
can be combined to give conserved differences of squares, from which \
hyperbolic duals can be constructed [S, Sect.3.10].\n\tNon-abelian hoops have \
repeated roots, often leading to \"pseudo-polar\" duals, demonstrated in the \
supplementary material [S,Ex.11]. ",
  StyleBox["The \[OpenCurlyDoubleQuote]pseudo-angles\[CloseCurlyDoubleQuote] \
do not add on vec multiplication, and the pseudo-powers differ from repeated \
products. This is discussed in the supplementary material.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  "\t(9) Some Hoops have stable orbits resembling \"multi-phase de Broglie \
waves\"; products of orbits are orbits [S,Ex.35]. They define intrinsic sizes \
resembling Planck areas and",
  StyleBox[" may determine which particles are stable. They have some \
elements (e.g. \[Zeta] in Figure 6) that are neither real nor complex but act \
as quantum operators [6]. ",
    PageWidth->WindowWidth,
    FontFamily->"Times New Roman"],
  StyleBox["Orbits with 3, 4, & 6 phases (and some multiples) appear to be \
stable; a 5-phase C5 function proved to have a zero radius",
    FontFamily->"Times New Roman"],
  ", making it unstable",
  StyleBox[". ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  "\t(10) Four \"Dozal\" multiplication rules (for vecs with 12 elements \
[S,Sect.3.3])  may correspond to four types of interaction between particles, \
with different sizes corresponding to different conserved properties and \
remainders corresponding to emitted particles. C3K and C3C4 are abelian,  Q12 \
& D3C2 are non-abelian. As with D3, the non-abelian rules have \"pseudo-polar \
duals\" with degrees of freedom that may introduce uncertainty. They are \
indirect compositions of C2 with (bosonic) abelian groups that appear to be \
\"supersymmetric\" to the (fermionic) larger groups. Fermionic hoops have \
more symmetries (and more particle types) than the bosons. Supersymmetry is \
not one-to-one. Conjecture - bosons are not subject to the Pauli exclusion \
principle because each is equivalent to many fermions.\n\tFigure 6 shows the \
symbolic vector and polar (orbit) forms for C3K. The orbit combines the two \
square roots of unity (Dual or Study numbers) of the Klein group K, with the \
cube root of unity of Terplex numbers. Each line of Figure 6 defines a single \
element of one form as a function of the elements of the other. Orbits are \
\[OpenCurlyDoubleQuote]unital\[CloseCurlyDoubleQuote]; their non-zero sizes \
multiply to one so that repeated products also multiply to one.",
  StyleBox[" Different orbits are obtained by constraining some of the sizes \
{\[Alpha],\[Beta],\[Gamma],\[Delta],\[Zeta],\[Lambda],\[Eta],\[Kappa]} to be \
zero whilst the rest multiply to one. Note that \[Zeta] has three phases ",
    FontFamily->"Times New Roman"],
  "(repeated four times)",
  StyleBox[", whilst {\[Lambda],\[Eta],\[Kappa]} each have six; \[Eta]=\
\[Kappa]+\[Pi]/6 gives twelve phases. The C3C4 orbits (",
    FontFamily->"Times New Roman"],
  "[S,Ex.25]",
  StyleBox[") are closely related to those for C3K, but include a four-phase \
system in which \[Gamma] and \[Delta] are replaced by ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\^2\)]],
  StyleBox[" and an angle \[Sigma]. The author conjectures that this relates \
to leptons as 4-phase orbits, with hadrons as 3, 6, and 12-phase quark \
orbits",
    FontFamily->"Times New Roman"],
  ".",
  StyleBox[" Orbits properties include spin, chirality and polarisation.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  "Figure 6. ",
  StyleBox["C3K Polar form and general orbit.",
    FontWeight->"Plain"]
}], "Text",
  FontFamily->"Courier New",
  FontSize->9,
  FontWeight->"Bold"],

Cell[BoxData[
    \({a + b + c + d + e + f + g + h + i + j + k + l, 
      a + b + c - d - e - f + g + h + i - j - k - l, \[IndentingNewLine]a + 
        b + c + d + e + f - g - h - i - j - k - l, 
      a + b + c - d - e - f - g - h - i + j + k + l, 
      1\/2\ \((\((a - b + d - e + g - h + j - k)\)\^2 + \((b - c + e - f + h \
- i + k - l)\)\^2 + \((\(-a\) + c - d + f - g + i - j + l)\)\^2)\), 
      ArcTan[2\ a - b - c + 2\ d - e - f + 2\ g - h - i + 2\ j - k - 
          l, \(-\@3\)\ \((b - c + e - f + h - i + k - l)\)], 
      1\/2\ \((\((a - b - d + e + g - h - j + k)\)\^2 + \((\(-a\) + c + d - f \
- g + i + j - l)\)\^2 + \((b - c - e + f + h - i - k + l)\)\^2)\), 
      ArcTan[2\ a - b - c - 2\ d + e + f + 2\ g - h - i - 2\ j + k + 
          l, \(-\@3\)\ \((b - c - e + f + h - i - k + l)\)], 
      1\/2\ \((\((a - b + d - e - g + h - j + k)\)\^2 + \((\(-a\) + c - d + f \
+ g - i + j - l)\)\^2 + \((b - c + e - f - h + i - k + l)\)\^2)\), 
      ArcTan[2\ a - b - c + 2\ d - e - f - 2\ g + h + i - 2\ j + k + 
          l, \(-\@3\)\ \((b - c + e - f - h + i - k + l)\)], 
      1\/2\ \((\((a - b - d + e - g + h + j - k)\)\^2 + \((b - c - e + f - h \
+ i + k - l)\)\^2 + \((\(-a\) + c + d - f + g - i - j + l)\)\^2)\), 
      ArcTan[2\ a - b - c - 2\ d + e + f - 2\ g + h + i + 2\ j - k - 
          l, \(-\@3\)\ \((b - c - e + f - h + i + k - l)\)]}\)], "Input",
  FontSize->9,
  FontWeight->"Plain"],

Cell[BoxData[
    \(\(\(\ \ \ \ \ \)\({\[Alpha] + \[Beta] + \[Gamma] + \[Delta] + \[Zeta]\ \
Cos[\[Tau]]\ \ \ \ \ \  + \[Lambda]\ Cos[\[Phi]]\ \ \ \ \  + \[Eta]\ Cos[\
\[Chi]]\ \ \ \ \ \ \  + \[Kappa]\ Cos[\[Psi]], \[IndentingNewLine]\[Alpha] + \
\[Beta] + \[Gamma] + \[Delta] + \[Zeta]\ Cos[\[Tau] + \[Omega]] + \[Lambda]\ \
Cos[\[Phi] + \[Omega]] + \[Eta]\ Cos[\[Chi] + \[Omega]] + \[Kappa]\ \
Cos[\[Psi] + \[Omega]], \ \[IndentingNewLine]\[Alpha] + \[Beta] + \[Gamma] + \
\[Delta] + \[Zeta]\ Cos[\[Tau] - \[Omega]] + \[Lambda]\ Cos[\[Phi] - \
\[Omega]] + \[Eta]\ Cos[\[Chi] - \[Omega]] + \[Kappa]\ Cos[\[Psi] - \
\[Omega]], \[IndentingNewLine]\[Alpha] - \[Beta] + \[Gamma] - \[Delta] + \
\[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  - \[Lambda]\ Cos[\[Phi]]\ \ \ \ \ \  + \
\[Eta]\ Cos[\[Chi]]\ \ \ \ \ \ \  - \[Kappa]\ Cos[\[Psi]], \
\[IndentingNewLine]\[Alpha] - \[Beta] + \[Gamma] - \[Delta] + \[Zeta]\ Cos[\
\[Tau] + \[Omega]] - \[Lambda]\ Cos[\[Phi] + \[Omega]] + \[Eta]\ Cos[\[Chi] + \
\[Omega]] - \[Kappa]\ Cos[\[Psi] + \[Omega]], \[IndentingNewLine]\[Alpha] - \
\[Beta] + \[Gamma] - \[Delta] + \[Zeta]\ Cos[\[Tau] - \[Omega]] - \[Lambda]\ \
Cos[\[Phi] - \[Omega]] + \[Eta]\ Cos[\[Chi] - \[Omega]] - \[Kappa]\ \
Cos[\[Psi] - \[Omega]], \[IndentingNewLine]\[Alpha] + \[Beta] - \[Gamma] - \
\[Delta] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  + \[Lambda]\ Cos[\[Phi]]\ \ \ \ \ \
\  - \[Eta]\ Cos[\[Chi]]\ \ \ \ \ \ \  - \[Kappa]\ Cos[\[Psi]], \
\[IndentingNewLine]\[Alpha] + \[Beta] - \[Gamma] - \[Delta] + \[Zeta]\ Cos[\
\[Tau] + \[Omega]] + \[Lambda]\ Cos[\[Phi] + \[Omega]] - \[Eta]\ Cos[\[Chi] + \
\[Omega]] - \[Kappa]\ Cos[\[Psi] + \[Omega]], \[IndentingNewLine]\[Alpha] + \
\[Beta] - \[Gamma] - \[Delta] + \[Zeta]\ Cos[\[Tau] - \[Omega]] + \[Lambda]\ \
Cos[\[Phi] - \[Omega]] - \[Eta]\ Cos[\[Chi] - \[Omega]] - \[Kappa]\ \
Cos[\[Psi] - \[Omega]], \[IndentingNewLine]\[Alpha] - \[Beta] - \[Gamma] + \
\[Delta] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  - \[Lambda]\ Cos[\[Phi]]\ \ \ \ \ \
\  - \[Eta]\ Cos[\[Chi]]\ \ \ \ \ \ \  + \[Kappa]\ Cos[\[Psi]], \
\[IndentingNewLine]\[Alpha] - \[Beta] - \[Gamma] + \[Delta] + \[Zeta]\ Cos[\
\[Tau] + \[Omega]] - \[Lambda]\ Cos[\[Phi] + \[Omega]] - \[Eta]\ Cos[\[Chi] + \
\[Omega]] + \[Kappa]\ Cos[\[Psi] + \[Omega]], \[IndentingNewLine]\[Alpha] - \
\[Beta] - \[Gamma] + \[Delta] + \[Zeta]\ Cos[\[Tau] - \[Omega]] - \[Lambda]\ \
Cos[\[Phi] - \[Omega]] - \[Eta]\ Cos[\[Chi] - \[Omega]] + \[Kappa]\ \
Cos[\[Psi] - \[Omega]]}/12;\)\)\)], "Input",
  FontSize->9,
  FontWeight->"Plain"],

Cell["\<\
\tThe following table (repeated in [S,Ex.30]) defines 39 functions (not all \
being sizes) that are conserved in one or more of the Dozal operations. The \
author has attempted to relate them to particle properties, without success. \
\
\>", "Text"],

Cell[BoxData[
    \(\(sh12[{a_, b_, c_, d_, e_, f_, g_, h_, i_, j_, k_, l_}] := 
        Module[{ab = a - b - g + h, ag = a - b + g - h, bc = b - c - h + i, 
            bh = b - c + h - i, \[IndentingNewLine]ca = a - c - g + i, 
            ci = a - c + g - i, de = d - e - j + k, 
            dj = d - e + j - k, \[IndentingNewLine]ef = e - f - k + l, 
            ek = e - f + k - l, fd = d - f - j + l, fl = d - f + j - l, 
            f1 = a - b - g + 
                h + \((d + e - 2\ f - j - k + 
                      2  l)\)/\@3, \[IndentingNewLine]f2 = \((a + b - 2  c - 
                      g - h + 2  i)\)/\@3 - d + e + j - 
                k, \[IndentingNewLine]f3 = 
              a - b - g + 
                h - \((d + e - 2\ f - j - k + 
                      2  l)\)/\@3, \[IndentingNewLine]f4 = \((a + b - 2  c - 
                      g - h + 2  i)\)/\@3 + d - e - j + k, abef, 
            agek}, \[IndentingNewLine]abef = 3 \((ab\ ef - bc\ de)\)\^2; 
          agek = 3 \((ag\ ek - bh\ dj)\)\^2; \[IndentingNewLine]{o1 = 
              a + b + c + d + e + f + g + h + i + j + k + l, 
            o2 = a + b + c - d - e - f + g + h + i - j - k - 
                l, \[IndentingNewLine]o3 = 
              a + b + c + d + e + f - g - h - i - j - k - l, 
            o4 = a + b + c - d - e - f - g - h - i + j + k + 
                l, \[IndentingNewLine] (*5*) l22a = 
              3 \((f1\^2 + f2\^2)\)/4,  (*6*) l22b = 
              3 \((f3\^2 + f4\^2)\)/4, \[IndentingNewLine] (*7*) 
              p22 = \((a + b + c + g + h + i)\)\^2 + \((d + e + f + j + k + \
l)\)\^2,  (*8*) 
              q22 = \((a + b + c - g - h - i)\)\^2 + \((d + e + f - j - k - \
l)\)\^2,  (*9*) 
              r22 = \((a + b + c + g + h + i)\)\^2 - \((d + e + f + j + k + \
l)\)\^2,  (*10*) 
              s22 = \((a + b + c - g - h - i)\)\^2 - \((d + e + f - j - k - \
l)\)\^2, \[IndentingNewLine] (*11*) 
              p23 = \((\((ag + dj)\)\^2 + \((bh + ek)\)\^2 + \((ci + \
fl)\)\^2)\)/2,  (*12*) 
              q23 = \((\((ag - dj)\)\^2 + \((bh - ek)\)\^2 + \((ci - \
fl)\)\^2)\)/2, \[IndentingNewLine] (*13*) 
              r23 = \((\((ab + de)\)\^2 + \((bc + ef)\)\^2 + \((ca + \
fd)\)\^2)\)/2,  (*14*) 
              s23 = \((\((ab - de)\)\^2 + \((bc - ef)\)\^2 + \((ca - \
fd)\)\^2)\)/2, \[IndentingNewLine] (*15*) 
              q24 = \((a + b + c)\)\^2 + \((d + e + f)\)\^2 + \((g + h + i)\)\
\^2 + \((j + k + l)\)\^2, \[IndentingNewLine] (*16*) 
              s24 = \((a + b + c)\)\^2 - \((d + e + f)\)\^2 - \((g + h + i)\)\
\^2 - \((j + k + l)\)\^2, \[IndentingNewLine] (*17*) 
              p26 = \((ag\^2 + bh\^2 + ci\^2 - dj\^2 - fl\^2 - ek\^2)\)/
                2,  (*18*) 
              q26 = \((ab\^2 + bc\^2 + ca\^2 - de\^2 - ef\^2 - fd\^2)\)/
                2, \[IndentingNewLine] (*19*) 
              r26 = \((ag\^2 + bh\^2 + ci\^2 + dj\^2 + fl\^2 + ek\^2)\)/
                2,  (*20*) 
              s26 = \((ab\^2 + bc\^2 + ca\^2 + de\^2 + ef\^2 + fd\^2)\)/
                2, \n\ \ \ \ \ \ \ \  (*21*) \ 
            l3 = \((a + d - g - j)\)\ \((a - d + g - j)\)\ \((a - d - g + 
                      j)\) + \((b + e - h - k)\)\ \((b - e + h - k)\)\ \((b - 
                      e - h + k)\) + \[IndentingNewLine]\((c + f - \ i\  - 
                      l)\)\ \((c - f + \ i\  - l)\)\ \((c - f - \ i\  + 
                      l)\) - \((a - d + g - j)\)\ \((b - e - h + k)\)\ \((c + 
                      f - \ i\  - l)\) - \[IndentingNewLine]\((a - d - g + 
                      j)\)\ \((b + e - h - k)\)\ \((c - f + i - l)\) - \((a + 
                      d - g - j)\)\ \((b - e + h - k)\)\ \((c - f - \ i\  + 
                      l)\), \[IndentingNewLine] (*22*) l4p = 
              p26\^2 + agek, \[IndentingNewLine] (*23*) l4q = 
              q26\^2 + abef, \[IndentingNewLine] (*24*) l4r = 
              r26\^2 - 3  agek, \[IndentingNewLine] (*25*) l4s = 
              l22a\ l22b (*s26\^2 - abef*) ,  (*26*) 
              L4Q = \((\((a - b)\)\^2 + \((b - c)\)\^2 + \((a - c)\)\^2 + \
\((d - e)\)\^2 + \((e - f)\)\^2 + \((d - f)\)\^2 + \((g - h)\)\^2 + \
\[IndentingNewLine]\((h - i)\)\^2 + \((g - i)\)\^2 + \((j - k)\)\^2 + \((k - \
l)\)\^2 + \((j - l)\)\^2)\)^2/4 - 
                3\ \((\((a\ \((f - e)\) + b\ \((d - f)\) + c\ \((e - \
d)\))\)\^2 + \((a\ \((i - h)\) + b\ \((g - i)\) + c\ \((h - g)\))\)\^2 + \((d\
\ \((h - i)\) + e\ \((i - g)\) + f\ \((g - h)\))\)\^2 + \((g\ \((k - l)\) + h\
\ \((l - j)\) + i\ \((j - k)\))\)\^2 + \[IndentingNewLine]\((\((b - c)\)\^2 + \
\((e - f)\)\^2)\)\ j\^2 + \((\((a - c)\)\^2 + \((d - f)\)\^2)\)\ k\^2 + \
\((\((a - b)\)\^2 + \((d - e)\)\^2)\)\ l\^2)\) + \[IndentingNewLine]6\ \((\((\
\((c - a)\)\ \((c - b)\) + \((f - d)\)\ \((f - e)\))\)\ j\ k + \((\((b - 
                        
                                a)\)\ \((b - c)\) + \((e - d)\)\ \((e - 
                                  f)\))\)\ j\ l + \[IndentingNewLine]\((\((a \
- b)\)\ \((a - c)\) + \((d - e)\)\ \((d - 
                                  f)\))\)\ k\ l)\), \[IndentingNewLine] (*27*) 
              L4\[Sigma] = \ \((\((a - b)\)\^2 + \((b - c)\)\^2 + \((c - a)\)\
\^2 - \((d - e)\)\^2 - \((e - f)\)\^2 - \((f - d)\)\^2 - \((g - h)\)\^2 - \
\((h - i)\)\^2 - \((i - g)\)\^2 - \((j - k)\)\^2 - \((k - l)\)\^2 - \((l - j)\
\)\^2)\)^2/4 + 
                3\ \((\((b\ d - c\ d - a\ e + c\ e + a\ f - b\ f)\)\^2 + \((b\
\ g - c\ g - a\ h + c\ h + a\ i - b\ i)\)\^2 - \((e\ g - f\ g - d\ h + f\ h + \
d\ i - e\ i)\)\^2 + \((b\ j - c\ j - a\ k + c\ k + a\ l - b\ l)\)\^2 - \
\((\(-e\)\ j + f\ j + d\ k - f\ k - d\ l + e\ l)\)\^2 - \((h\ j - i\ j - g\ k \
+ i\ k + g\ l - h\ l)\)\^2)\), \[IndentingNewLine] (*28*) 
              L4a3 = \((\((ag + dj)\)\^2 + \((bh + ek)\)\^2 + \((ci + \
fl)\)\^2)\)\^2/4 + agek,  (*29*) 
              L4b3 = \((\((ag - dj)\)\^2 + \((bh - ek)\)\^2 + \((ci - \
fl)\)\^2)\)\^2/4 + agek,  (*30*) 
              L4c3 = \((\((ab + de)\)\^2 + \((bc + ef)\)\^2 + \((ca + \
fd)\)\^2)\)\^2/4 - abef,  (*31*) 
              L4d3 = \((\((ab - de)\)\^2 + \((bc - ef)\)\^2 + \((ca - \
fd)\)\^2)\)\^2/4 - abef,  (*32*) 
              L4a6 = \((ag\^2 + bh\^2 + ci\^2 - dj\^2 - fl\^2 - ek\^2)\)\^2/
                  4 + agek,  (*33*) 
              L4b6 = \((ab\^2 + bc\^2 + ca\^2 - de\^2 - ef\^2 - fd\^2)\)\^2/
                  4 + abef,  (*34*) 
              L4c6 = \((ab\^2 + bc\^2 + ca\^2 - de\^2 - ef\^2 - fd\^2)\)\^2/
                  4 - abef, \n\t (*35*) 
              L4d6 = \ \((ag\^2 + bh\^2 + ci\^2 + dj\^2 + fl\^2 + ek\^2)\)\^2/
                  4 - agek, \[IndentingNewLine] (*36*) 
              L49 = \((\((ab\^2 - de\^2)\)\^2 + \((ab\^2 - ef\^2)\)\^2 + \
\((ab\^2 - fd\^2)\)\^2 + \((bc\^2 - de\^2)\)\^2 + \((bc\^2 - ef\^2)\)\^2 + \
\((bc\^2 - fd\^2)\)\^2 + \((ca\^2 - de\^2)\)\^2 + \((ca\^2 - ef\^2)\)\^2 + \
\((ca\^2 - fd\^2)\)\^2)\), \[IndentingNewLine] (*37*) 
              L49a = \((\((ag\^2 - dj\^2)\)\^2 + \((ag\^2 - ek\^2)\)\^2 + \
\((ag\^2 - fl\^2)\)\^2 + \((bh\^2 - dj\^2)\)\^2 + \((bh\^2 - ek\^2)\)\^2 + \
\((bh\^2 - fl\^2)\)\^2 + \((ci\^2 - dj\^2)\)\^2 + \((ci\^2 - ek\^2)\)\^2 + \
\((ci\^2 - fl\^2)\)\^2)\), \[IndentingNewLine] (*38*) 
              L49b = \((\((ab\^2 - dj\^2)\)\^2 + \((ab\^2 - ek\^2)\)\^2 + \
\((ab\^2 - fl\^2)\)\^2 + \((bc\^2 - dj\^2)\)\^2 + \((bc\^2 - ek\^2)\)\^2 + \
\((bc\^2 - fl\^2)\)\^2 + \((ca\^2 - dj\^2)\)\^2 + \((ca\^2 - ek\^2)\)\^2 + \
\((ca\^2 - fl\^2)\)\^2)\), \[IndentingNewLine] (*39*) 
              L49c = \((\((ag\^2 - de\^2)\)\^2 + \((ag\^2 - ef\^2)\)\^2 + \
\((ag\^2 - fd\^2)\)\^2 + \((bh\^2 - de\^2)\)\^2 + \((bh\^2 - ef\^2)\)\^2 + \
\((bh\^2 - fd\^2)\)\^2 + \((ci\^2 - de\^2)\)\^2 + \((ci\^2 - ef\^2)\)\^2 + \
\((ci\^2 - fd\^2)\)\^2)\)}];\)\)], "Input",
  Editable->False,
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  PageBreakWithin->Automatic,
  FontFamily->"Courier New",
  FontSize->9,
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],

Cell[TextData[{
  "\t(11) ",
  StyleBox["Many Dozal properties disappear when 2-folding converts the vecs \
to \[OpenCurlyDoubleQuote]Hexal\[CloseCurlyDoubleQuote]. Figure 7 shows the \
polar and vector forms for C3C2, ",
    FontFamily->"Times New Roman"],
  "which is obtained by to replacing ",
  StyleBox["g",
    FontSlant->"Italic"],
  " by -",
  StyleBox["a",
    FontSlant->"Italic"],
  " , etc, in Figure 6. This appears to correspond to supersymmetry, creating \
bosons as equivalence relations.",
  StyleBox[" \n",
    FontSize->9,
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  "Figure 7. ",
  StyleBox["C3C2 polar & Vector forms.",
    FontWeight->"Plain"]
}], "Text",
  FontFamily->"Courier New",
  FontSize->10,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Use["\<C3C2\>"]; topol\), "\[IndentingNewLine]", 
    \(tovec\)}], "Input",
  CellOpen->False,
  FontSize->9],

Cell[BoxData[
    \({a + b + c + d + e + f, a + b + c - d - e - f, 
      1\/2\ \((\((a - b + d - e)\)\^2 + \((b - c + e - f)\)\^2 + \((\(-a\) + \
c - d + f)\)\^2)\), 
      ArcTan[2\ a - b - c + 2\ d - e - f, \@3\ \((\(-b\) + c - e + f)\)], 
      1\/2\ \((\((a - b - d + e)\)\^2 + \((\(-a\) + c + d - f)\)\^2 + \((b - \
c - e + f)\)\^2)\), 
      ArcTan[2\ a - b - c - 2\ d + e + 
          f, \@3\ \((\(-b\) + c + e - f)\)]}\)], "Output",
  FontSize->9],

Cell[BoxData[
    \({1\/6\ \((a + b + 2\ \@c\ Cos[d] + 2\ \@e\ Cos[f])\), 
      1\/6\ \((a + b + 2\ \@c\ Cos[d + \(2\ \[Pi]\)\/3] + 
            2\ \@e\ Cos[f + \(2\ \[Pi]\)\/3])\), 
      1\/6\ \((a + b + 2\ \@c\ Cos[d - \(2\ \[Pi]\)\/3] + 
            2\ \@e\ Cos[f - \(2\ \[Pi]\)\/3])\), 
      1\/6\ \((a - b + 2\ \@c\ Cos[d] - 2\ \@e\ Cos[f])\), 
      1\/6\ \((a - b + 2\ \@c\ Cos[d + \(2\ \[Pi]\)\/3] - 
            2\ \@e\ Cos[f + \(2\ \[Pi]\)\/3])\), 
      1\/6\ \((a - b + 2\ \@c\ Cos[d - \(2\ \[Pi]\)\/3] - 
            2\ \@e\ Cos[f - \(2\ \[Pi]\)\/3])\)}\)], "Output",
  FontSize->9]
}, Open  ]],

Cell["\<\
\t(12) The real division algebras \[DoubleStruckCapitalR], \
\[DoubleStruckCapitalC], \[DoubleStruckCapitalH], \[DoubleStruckCapitalO] are \
degenerate (monosized) hoops without divisors of zero because their sizes \
(the sums of the squared elements) are non-negative. These hoops operate \
correctly if their coefficients are complex, but then have divisors of zero. \
This gives the light-cone in the complex quaternion case.\
\>", "Text"],

Cell[TextData[{
  "\t(13) Hoops subsume, but do not invalidate, complex mathematics. Complex \
functions are specializations of more general functions. Many standard \
mathematical operations are specialisations of more general hoop operations ; \
many \"obvious mathematical truths\" are special cases restricted to the \
\"real algebras without divisors of zero\". E.g. multiphase sinusoids; \
repeated products and powers (A.A & ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["A",
            FontSlant->"Plain"], "2"], TraditionalForm]]],
  ") may differ; vector division is defined; both multiplication and division \
of vectors may leave remainders."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. Further Properties.", "Section",
  PageWidth->PaperWidth],

Cell[TextData[{
  StyleBox["Note.",
    FontWeight->"Bold"],
  " The ",
  StyleBox["Hoops&Physic.doc",
    FontSlant->"Italic"],
  " Word transcript relegates much of the following material to ",
  StyleBox["HoopAlgebraSupplement.doc",
    FontSlant->"Italic"],
  " (which is transcribed from",
  StyleBox[" HoopSup.nb",
    FontSlant->"Italic"],
  ")",
  ", references [S,??] correlate the two documents."
}], "Text"],

Cell[TextData[{
  StyleBox["Summary. Further properties of Hoop Algebras are demonstrated and \
discussed. In general, loops do not conserve their determinant factors. C4 \
folds to Complex algebra. Even powers differ from repeated products if sizes \
are negative. Dot, cross and wedge products are restrictions on Clifford \
algebras. Many hoops have \[OpenCurlyDoubleQuote]plex-conjugate\
\[CloseCurlyDoubleQuote] involutions that generalize complex conjugation. ",
    FontSlant->"Italic"],
  StyleBox["Products of Abelian orbits are orbits with added angles.",
    FontSlant->"Italic"]
}], "Text"],

Cell["\<\
\tIn general, loops do not conserve their determinant factors. Figure 8 \
[S,Example 14] shows two examples. Their non-conserved factors resemble the \
sizes of Qr, P4, & D3. It also shows that the sum of elements of a product \
factorizes into the sums of the multiplicand elements for C6n (a quasi-group) \
but not for Q4n (a signed table). This distinction appears to be general - \
the sum of the elements of a product is the product of the multiplicand \
element sums iff the table is a quasi-group.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Figure 8.",
    FontWeight->"Bold"],
  " Two non-conservative Loops"
}], "Text",
  FontFamily->"Courier New",
  FontSize->9,
  FontWeight->"Plain"],

Cell[BoxData[
    \(Use["\<Q4n\>"]; {"\<Q4n Table\>", hoopTbl // tf, "\<\nShape\>", 
      sh, \[IndentingNewLine]"\<\nA =   \>", 
      A = {4, 2, 3, 5}, \[IndentingNewLine]"\<\nB =   \>", 
      B = {1, 6, 2, 2}, \[IndentingNewLine]"\<\nAB=   \>", 
      AB = hoopTimes[A, B], "\<\nShape of A    sa =\>", 
      sa = sh /. \ as[A], "\<\nShape of B    sb =\>", 
      sb = sh /. \ as[B], "\<\nShape of AB   sab=\>", \ 
      sh /. \ as[AB], "\<\nThis is not sa*sb =\>", 
      sa\ sb, "\<\nSum of elements does not factorize\>", 
      Factor[Plus @@ hoopTimes[{a, b, c, d}, {e, f, g, h}]], \n
      Use["\<C6n\>"]; \n"\<\nC6n Table\>", hoopTbl // tf, "\<\nShape\>", 
      sh, "\<\n A =\>", A = {4, 2, 3, 5, 1, 6}, "\<\n B =\>", 
      B = {0, 6, 2, 4, 3, 2}, "\<\nAB =              \>", 
      AB = hoopTimes[A, B], "\<\nshape of A  sa =  \>", 
      sa = sh /. \ as[A], "\<\nshape of B  sb =  \>", 
      sb = sh /. \ as[B], "\<\nshape of AB sab=  \>", 
      sab = sh /. \ as[AB], "\<\nThis is not sa*sb \>", 
      sa\ sb, "\<\nSum of elements factorizes\>", \[IndentingNewLine]Factor[
        Plus @@ hoopTimes[{a, b, c, d, e, f}, {g, h, i, j, k, 
              l}]]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False,
  FontSize->9],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\` < \)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Q4n Table\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4"},
                  {"2", "1", "4", \(-3\)},
                  {"3", \(-4\), "1", "2"},
                  {"4", "3", \(-2\), "1"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nShape\"\>", 
        ",", \({a\^2 - b\^2 - c\^2 - d\^2, a\^2 + b\^2 + c\^2 + d\^2}\), 
        ",", "\<\"\\nA =   \"\>", ",", \({4, 2, 3, 5}\), 
        ",", "\<\"\\nB =   \"\>", ",", \({1, 6, 2, 2}\), 
        ",", "\<\"\\nAB=   \"\>", ",", \({32, 22, 37, \(-1\)}\), 
        ",", "\<\"\\nShape of A    sa =\"\>", ",", \({\(-22\), 54}\), 
        ",", "\<\"\\nShape of B    sb =\"\>", ",", \({\(-43\), 45}\), 
        ",", "\<\"\\nShape of AB   sab=\"\>", ",", \({\(-830\), 2878}\), 
        ",", "\<\"\\nThis is not sa*sb =\"\>", ",", \({946, 2430}\), 
        ",", "\<\"\\nSum of elements does not factorize\"\>", 
        ",", \(a\ e + b\ e + c\ e + d\ e + a\ f + b\ f - c\ f + d\ f + a\ g + 
          b\ g + c\ g - d\ g + a\ h - b\ h + c\ h + d\ h\), 
        ",", "\<\"\\nC6n Table\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4", "5", "6"},
                  {"2", "3", "1", "6", "4", "5"},
                  {"3", "1", "2", "5", "6", "4"},
                  {"4", "5", "6", "2", "1", "3"},
                  {"5", "6", "4", "1", "3", "2"},
                  {"6", "4", "5", "3", "2", "1"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nShape\"\>", 
        ",", \({a + b + c - d - e - f, a + b + c + d + e + f, 
          
          1\/2\ \((\((a - b)\)\^2 + \((b - c)\)\^2 + \((\(-a\) + c)\)\^2 - \
\((d - e)\)\^2 - \((e - f)\)\^2 - \((\(-d\) + f)\)\^2)\), 
          1\/2\ \((\((a - b)\)\^2 + \((b - c)\)\^2 + \((\(-a\) + c)\)\^2 + \
\((d - e)\)\^2 + \((e - f)\)\^2 + \((\(-d\) + f)\)\^2)\)}\), 
        ",", "\<\"\\n A =\"\>", ",", \({4, 2, 3, 5, 1, 6}\), 
        ",", "\<\"\\n B =\"\>", ",", \({0, 6, 2, 4, 3, 2}\), 
        ",", "\<\"\\nAB =              \"\>", 
        ",", \({53, 70, 57, 66, 70, 41}\), 
        ",", "\<\"\\nshape of A  sa =  \"\>", 
        ",", \({\(-3\), 21, \(-18\), 24}\), 
        ",", "\<\"\\nshape of B  sb =  \"\>", ",", \({\(-1\), 17, 25, 31}\), 
        ",", "\<\"\\nshape of AB sab=  \"\>", 
        ",", \({3, 357, \(-504\), 978}\), 
        ",", "\<\"\\nThis is not sa*sb \"\>", 
        ",", \({3, 357, \(-450\), 744}\), 
        ",", "\<\"\\nSum of elements factorizes\"\>", 
        ",", \(\((a + b + c + d + e + f)\)\ \((g + h + i + j + k + l)\)\)}], 
      "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tFigure 9 [S,Examples.4,5,6] demonstrates that Complex algebra is \
obtained by folding C4. Multiplication, division, and various powers are \
shown to match those of the complex numbers created by 2-folding. The shape \
of the C4 vector includes the squared radius and the polar angle; it has two \
extra degrees of freedom (conserved linear sizes) that are destroyed by the \
folding process. Figure 10 also shows that if a size is negative, A.A will \
differ from ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["A",
            FontSlant->"Plain"], "2"], TraditionalForm]]],
  " (though they both fold to the correct complex number",
  "; folding is many-to-one",
  "). Repeated products will have this size alternately negative and \
positive, whilst it will be negative for all powers; ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["A",
            FontSlant->"Plain"], "n"], TraditionalForm]]],
  " is a continuous function of ",
  StyleBox["n",
    FontSlant->"Italic"],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Figure 9.",
    FontWeight->"Bold"],
  " C4 folds to Complex algebra."
}], "Text",
  FontFamily->"Courier New",
  FontSize->10],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(Use["\<C4\>"]\), ";", 
      RowBox[{"{", 
        RowBox[{
        "\"\<The table \>\"", ",", \(\(hoopTbl // tf\) // bf\), ",", 
          "\"\<can be written as\>\"", 
          ",", \(\({{1, i, \(-1\), \(-i\)}, {i, \(-1\), \(-i\), 
                  1}, {\(-1\), \(-i\), 1, i}, {\(-i\), 1, i, \(-1\)}} // 
              tf\) // bf\), ",", 
          RowBox[{"\"\<\\nMultiplication using\!\(\*
StyleBox[\" \",\nFontWeight->\"Plain\"]\)\!\(\*
StyleBox[\"hoopTimes\",\nFontWeight->\"Plain\",\nFontSlant->\"Italic\"]\):-\>\
\"", "//", "bf"}], ",", "\"\<\\n If A  =\>\"", 
          ",", \(A = {3. , 1. , 1. , 2. }\), ",", "\"\<and B =\>\"", 
          ",", \(B = {4. , 7. , 2. , 3. }\), ",", 
          "\"\<\\nmultiplication \!\(\*
StyleBox[\"gives\",\nFontSlant->\"Plain\"]\) \\n AB =\>\"", 
          ",", \(AB = hoopTimes[A, B]; AB // bf\), ",", 
          "\[IndentingNewLine]", 
          "\"\<\\nThis 'folds' to the product of 3-1 + \
(1-2)\[ImaginaryI]\\nand 4-2 + (7-3)\[ImaginaryI] to give 31-23 + (32-26)\
\[ImaginaryI],\\ni.e. (2-\[ImaginaryI])(2+4\[ImaginaryI])=\>\"", " ", 
          ",", \(\((2 - \[ImaginaryI])\) \((2 + 4  \[ImaginaryI])\) // bf\), 
          ",", 
          RowBox[{"\"\<\\n\\nDivision using \!\(\*
StyleBox[\"hoopInverse\",\nFontWeight->\"Plain\",\nFontSlant->\"Italic\"]\):-\
\>\"", "//", "bf"}], ",", "\"\<\\nThe inverse of A is\>\"", 
          ",", \(Ainv = hoopInverse[{3, 1, 1, 2}]; Ainv // bf\), ",", 
          "\"\<\\nAinv.A is the unit\>\"", ",", \(hoopTimes[Ainv, A] // bf\), 
          ",", "\"\<\\nand Ainv.AB recovers B\>\"", 
          ",", \(Simplify[hoopTimes[Ainv, AB]] // bf\), 
          ",", \("\<\n\nPowers and Roots:-\>" // bf\), ",", 
          "\"\<\\nhoopPower\!\(\*
StyleBox[\"[\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"A\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"3\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"]\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\"gives\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\"the\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\"cube\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\",\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\) \\nA3=\>\"", 
          ",", \(A3 = hoopPower[A, 3]\), ",", 
          "\"\<which folds to (2-\[ImaginaryI])^3=\>\"", 
          ",", \(\((2 - \[ImaginaryI])\)^3 // bf\), ",", "\"\<\\n\!\(\*
StyleBox[\"hoopPower\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"[\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"A3\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"2\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"/\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"3\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"]\",\nFontSlant->\"Italic\"]\) gives the 2/3 power of A3\>\"", 
          ",", \(hoopPower[A3, 2/3] // bf\), ",", 
          "\"\<which folds to 3 - 4i and matches the repeated product AA\>\"",
           ",", \(AA = hoopPower[A, 2] // bf\), ",", 
          "\"\<\\nA^3 is the same as the repeated product AAA\>\"", 
          ",", \(AAA = hoopTimes[A, hoopTimes[A, A]]; AAA // bf\), ",", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"\"\<\\n\\nIf A has a negative size \!\(\*
StyleBox[\"hoopTimes\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"[\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"A\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"A\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"]\",\nFontSlant->\"Italic\"]\) differs from \!\(\*
StyleBox[\"hoopPower\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"[\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"A\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"2\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"]\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)but folds correctly.\>\"", "//", 
            "bf"}], ",", "\"\<\\nIf A=\>\"", 
          ",", \(A = {1. , 1. , \(-1. \), 0. }\), ",", "\"\<with shape \>\"", 
          ",", \(sh /. as[A]\), ",", "\"\<hoopPower[A,3]\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\)gives the cube A3=\>\"", 
          ",", \(A3 = hoopPower[A, 3]; A3 // bf\), ",", 
          "\"\<\\nwhich folds correctly to (2+i)^3=2+11i\\nhoopPower[A3,2/3] \
is\>\"", 
          StyleBox[",",
            FontSlant->"Italic"], \(hoopPower[A3, 2/3] // bf\), 
          StyleBox[",",
            FontSlant->"Plain"], 
          
          StyleBox[
            "\"\<the 2/3 power of A3, which folds to 3+4i\\nand matches \
hoopPower[A,2]\\ni.e. A^2=\>\"",
            FontSlant->"Plain"], 
          StyleBox[",",
            FontSlant->"Plain"], 
          RowBox[{
            RowBox[{
              StyleBox["A2",
                FontSlant->"Plain"], 
              StyleBox["=",
                FontSlant->"Plain"], \(hoopPower[A, 2]\)}], 
            ";", \(A2 // bf\)}], ",", "\"\<\\nwith shape\>\"", 
          ",", \(sh /. as[A2]\), ",", 
          "\"\<\\nwhilst the repeated product AA\>\"", 
          ",", \(AA = hoopTimes[A, A]; AA // bf\), ",", 
          "\"\<\\n(which also folds to 3+4i) has the second size \
positive\>\"", ",", \(sh /. as[AA] // bf\), ",", 
          "\"\<\\npowers are continuous functions:-\\n A^1.99=\>\"", 
          ",", \(hoopPower[A, 1.99] // bf\), ",", "\"\<\\n A^2   =\>\"", 
          ",", \(hoopPower[A, 2] // bf\), ",", "\"\<\\n A^2.01=\>\"", 
          ",", \(hoopPower[A, 2.01] // bf\)}], "}"}]}]], "Input",
  PageWidth->WindowWidth,
  CellOpen->False,
  FontFamily->"Courier New"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"The table \"\>", ",", 
        TagBox[
          StyleBox[
            TagBox[
              FormBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"1", "2", "3", "4"},
                      {"2", "3", "4", "1"},
                      {"3", "4", "1", "2"},
                      {"4", "1", "2", "3"}
                      },
                    ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
                "TraditionalForm"],
              TraditionalForm,
              Editable->True],
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"can be written as\"\>", ",", 
        TagBox[
          StyleBox[
            TagBox[
              FormBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"1", "i", \(-1\), \(-i\)},
                      {"i", \(-1\), \(-i\), "1"},
                      {\(-1\), \(-i\), "1", "i"},
                      {\(-i\), "1", "i", \(-1\)}
                      }], "\[NoBreak]", ")"}],
                "TraditionalForm"],
              TraditionalForm,
              Editable->True],
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], ",", 
        TagBox[
          
          StyleBox["\<\"\\nMultiplication using\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontWeight->\\\"Plain\\\"]\\)\\!\\(\\* \
StyleBox[\\\"hoopTimes\\\",\\nFontWeight->\\\"Plain\\\",\\nFontSlant->\\\"\
Italic\\\"]\\):-\"\>",
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], ",", "\<\"\\n If A  =\"\>",
         ",", \({3.`, 1.`, 1.`, 2.`}\), ",", "\<\"and B =\"\>", 
        ",", \({4.`, 7.`, 2.`, 3.`}\), 
        ",", "\<\"\\nmultiplication \\!\\(\\* \
StyleBox[\\\"gives\\\",\\nFontSlant->\\\"Plain\\\"]\\) \\n AB =\"\>", ",", 
        TagBox[
          StyleBox[\({31.`, 32.`, 23.`, 26.`}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"\\nThis 'folds' to the product of 3-1 + \
(1-2)\[ImaginaryI]\\nand 4-2 + (7-3)\[ImaginaryI] to give 31-23 + (32-26)\
\[ImaginaryI],\\ni.e. (2-\[ImaginaryI])(2+4\[ImaginaryI])=\"\>", ",", 
        TagBox[
          StyleBox[\(8 + 6\ \[ImaginaryI]\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], ",", 
        TagBox[
          
          StyleBox["\<\"\\n\\nDivision using \\!\\(\\* \
StyleBox[\\\"hoopInverse\\\",\\nFontWeight->\\\"Plain\\\",\\nFontSlant->\\\"\
Italic\\\"]\\):-\"\>",
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"\\nThe inverse of A is\"\>", ",", 
        TagBox[
          StyleBox[\({17\/35, \(-\(4\/35\)\), 3\/35, \(-\(11\/35\)\)}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"\\nAinv.A is the unit\"\>", ",", 
        TagBox[
          StyleBox[\({0.9999999999999998`, 0.`, 0.`, 0.`}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"\\nand Ainv.AB recovers B\"\>", ",", 
        TagBox[
          StyleBox[\({4.`, 6.999999999999999`, 2.`, 3.0000000000000018`}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], ",", 
        TagBox[
          StyleBox["\<\"\\n\\nPowers and Roots:-\"\>",
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"\\nhoopPower\\!\\(\\* \
StyleBox[\\\"[\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"A\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"3\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"]\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \\\
\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* \
StyleBox[\\\"gives\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* \
StyleBox[\\\"the\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* \
StyleBox[\\\"cube\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* StyleBox[\\\",\
\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\\) \\nA3=\"\>", 
        ",", \({87.`, 80.`, 85.`, 91.`}\), 
        ",", "\<\"which folds to (2-\[ImaginaryI])^3=\"\>", ",", 
        TagBox[
          StyleBox[\(2 - 11\ \[ImaginaryI]\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"hoopPower\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"[\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"A3\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"2\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"/\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"3\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"]\\\",\\nFontSlant->\\\"Italic\\\"]\\) gives the 2/3 power of A3\
\"\>", ",", 
        TagBox[
          
          StyleBox[\({13.999999999999996`, 9.999999999999996`, 
              10.999999999999996`, 13.999999999999996`}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"which folds to 3 - 4i and matches the repeated product AA\"\
\>", ",", 
        TagBox[
          StyleBox[\({14.`, 10.`, 11.`, 14.`}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"\\nA^3 is the same as the repeated product AAA\"\>", ",", 
        TagBox[
          StyleBox[\({87.`, 80.`, 85.`, 91.`}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], ",", 
        TagBox[
          
          StyleBox["\<\"\\n\\nIf A has a negative size \\!\\(\\* \
StyleBox[\\\"hoopTimes\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"[\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"A\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"A\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"]\\\",\\nFontSlant->\\\"Italic\\\"]\\) differs from \\!\\(\\* \
StyleBox[\\\"hoopPower\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"[\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"A\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"2\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"]\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \\\
\",\\nFontSlant->\\\"Italic\\\"]\\)but folds correctly.\"\>",
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], ",", "\<\"\\nIf A=\"\>", 
        ",", \({1.`, 1.`, \(-1.`\), 0.`}\), ",", "\<\"with shape \"\>", 
        ",", \({1.`, \(-1.`\), 5.`}\), 
        ",", "\<\"hoopPower[A,3]\\!\\(\\* StyleBox[\\\" \\\",\\nFontSlant->\\\
\"Plain\\\"]\\)gives the cube A3=\"\>", ",", 
        TagBox[
          
          StyleBox[\({1.0000000000000007`, 
              6.`, \(-1.0000000000000007`\), \(-5.`\)}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"\\nwhich folds correctly to \
(2+i)^3=2+11i\\nhoopPower[A3,2/3] is\"\>", ",", 
        TagBox[
          
          StyleBox[\({1.5`, 
              2.4999999999999996`, \(-1.5`\), \(-1.4999999999999996`\)}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"the 2/3 power of A3, which folds to 3+4i\\nand matches \
hoopPower[A,2]\\ni.e. A^2=\"\>", ",", 
        TagBox[
          
          StyleBox[\({1.5000000000000002`, 
              2.5`, \(-1.5000000000000002`\), \(-1.4999999999999998`\)}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"\\nwith shape\"\>", 
        ",", \({1.0000000000000002`, \(-1.0000000000000002`\), 
          25.000000000000004`}\), 
        ",", "\<\"\\nwhilst the repeated product AA\"\>", ",", 
        TagBox[
          StyleBox[\({2.`, 2.`, \(-1.`\), \(-2.`\)}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"\\n(which also folds to 3+4i) has the second size \
positive\"\>", ",", 
        TagBox[
          StyleBox[\({1.`, 1.`, 25.`}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"\\npowers are continuous functions:-\\n A^1.99=\"\>", ",", 
        TagBox[
          
          StyleBox[\({1.4971602576129839`, 
              2.4770499321073896`, \(-1.4971602576129839`\), \
\(-1.4770499321073898`\)}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], ",", "\<\"\\n A^2   =\"\>",
         ",", 
        TagBox[
          
          StyleBox[\({1.5000000000000002`, 
              2.5`, \(-1.5000000000000002`\), \(-1.4999999999999998`\)}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], ",", "\<\"\\n A^2.01=\"\>",
         ",", 
        TagBox[
          
          StyleBox[\({1.5027553889648462`, 
              2.5231485205881197`, \(-1.5027553889648462`\), \
\(-1.5231485205881197`\)}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)]}], "}"}]], "Output",
  FontSize->9]
}, Open  ]],

Cell[TextData[{
  "\tFigure 10 [S,Ex.33] demonstrates that two and three dimensional dot, \
cross, and wedge products are obtained by quaternion, octonion and Clifford \
algebra multiplication of restricted vectors. The restriction is that the \
scalar and multi-vector components are zero in the multiplicands. The dot \
product is then the scalar element of the product. The 2D &3D cross products \
are given by the multi-vectors. The nomenclature matches [4,p 11] for \
quaternions and CL2, and [4,p 37] for octonions and CL3. More examples are \
given in the supplementary material. All Clifford algebras are hoops. (The \
term \[OpenCurlyDoubleQuote]univector\[CloseCurlyDoubleQuote] is proposed for \
their basis-vectors, by analogy with bivector and trivector. Basis-vectors \
are confusingly called vectors or scalars by some authors.) Clifford algebra \
tables are created in [2] by using the procedure ",
  StyleBox["cl",
    FontSlant->"Italic"],
  " or by folding a specific group isomorph. Wedge (exterior) algebras are \
the bivector part of the Clifford product ([3, p.10]. They multiply \
univectors using Clifford algebra rules; the scalars and multivectors are \
restricted to zero in the multiplicands and various products are zero (i.e. \
these are Grassmann algebras). Finite Lie algebras appear to be Clifford \
hoops for which the real (scalar) elements have been zeroed. This has yet to \
be explored."
}], "Text"],

Cell[BoxData[
    \(Figure\ 10. \ Dot, \ \(Cross\  &\)\ Wedge\ products\ are\ restricted\ \
\(\(Hoops\)\(.\)\)\)], "Input",
  FontSize->10],

Cell[CellGroupData[{

Cell[BoxData[
    \({Use["\<Qr\>"]; "\<Quaternion\>" // 
        bf, \*"\"\< hoopTimes[{0,\!\(e\_1\),\!\(e\_2\),0},{0,\!\(u\_1\),\!\(u\
\_2\),0}]\\ngives\>\"", 
      hoopTimes[{0, e\_1, e\_2, 0}, {0, u\_1, u\_2, 0}] // 
        bf, "\<\n     Scalar  &   Dot Products\>", 
      Use["\<Octr\>"]; "\<\nOctonion\>" // 
        bf, \*"\"\< \
hoopTimes[{0,\!\(a\_1\),\!\(a\_2\),0,\!\(a\_3\),0,0,0},{0,\!\(b\_1\),\!\(b\_2\
\),0,\!\(b\_3\),0,0,0}]\\ngives\>\"", 
      hoopTimes[{0, a\_1, a\_2, 0, a\_3, 0, 0, 0}, {0, b\_1, b\_2, 0, b\_3, 
            0, 0, 0}] // 
        bf, "\<\nNegated Scalar, components of Cross Product\>", "\<\n\
Clifford univector products\>" // bf, "\< are Wedge Products\>", 
      Use["\<CL2\>"]; "\<\nCL2 \>", 
      hoopTimes[{0, u\_1, u\_2, 0}, {0, v\_1, v\_2, 0}] // bf, 
      Use["\<CL3\>"]; "\<\nCL3 \>", 
      hoopTimes[{0, u\_1, u\_2, 0, u\_3, 0, 0, 0}, {0, v\_1, v\_2, 0, v\_3, 
            0, 0, 0}] // bf, \[IndentingNewLine]Use["\<CL4\>"]; "\<\nCL4 \>", 
      hoopTimes[{0, e\_1, e\_2, 0, e\_3, 0, 0, e\_4}, {0, u\_1, u\_2, 0, 
            u\_3, 0, 0, u\_4}] // bf}\)], "Input",
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          StyleBox["\<\"Quaternion\"\>",
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\" \
hoopTimes[{0,\\!\\(e\\_1\\),\\!\\(e\\_2\\),0},{0,\\!\\(u\\_1\\),\\!\\(u\\_2\\)\
,0}]\\ngives\"\>", ",", 
        TagBox[
          
          StyleBox[\({\(-e\_1\)\ u\_1 - e\_2\ u\_2, 0, 
              0, \(-e\_2\)\ u\_1 + e\_1\ u\_2}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"\\n     Scalar  &   Dot Products\"\>", ",", 
        TagBox[
          StyleBox["\<\"\\nOctonion\"\>",
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\" \
hoopTimes[{0,\\!\\(a\\_1\\),\\!\\(a\\_2\\),0,\\!\\(a\\_3\\),0,0,0},{0,\\!\\(b\
\\_1\\),\\!\\(b\\_2\\),0,\\!\\(b\\_3\\),0,0,0}]\\ngives\"\>", ",", 
        TagBox[
          
          StyleBox[\({\(-a\_1\)\ b\_1 - a\_2\ b\_2 - a\_3\ b\_3, 0, 
              0, \(-a\_2\)\ b\_1 + a\_1\ b\_2, 
              0, \(-a\_3\)\ b\_1 + a\_1\ b\_3, \(-a\_3\)\ b\_2 + a\_2\ b\_3, 
              0}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"\\nNegated Scalar, components of Cross Product\"\>", ",", 
        TagBox[
          StyleBox["\<\"\\nClifford univector products\"\>",
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\" are Wedge Products\"\>", ",", "\<\"\\nCL2 \"\>", ",", 
        TagBox[
          
          StyleBox[\({u\_1\ v\_1 - u\_2\ v\_2, 0, 
              0, \(-u\_2\)\ v\_1 + u\_1\ v\_2}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], ",", "\<\"\\nCL3 \"\>", 
        ",", 
        TagBox[
          
          StyleBox[\({u\_1\ v\_1 + u\_2\ v\_2 + u\_3\ v\_3, 0, 
              0, \(-u\_2\)\ v\_1 + u\_1\ v\_2, 
              0, \(-u\_3\)\ v\_1 + u\_1\ v\_3, \(-u\_3\)\ v\_2 + u\_2\ v\_3, 
              0}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], ",", "\<\"\\nCL4 \"\>", 
        ",", 
        TagBox[
          
          StyleBox[\({e\_1\ u\_1 + e\_2\ u\_2 + e\_3\ u\_3 - e\_4\ u\_4, 0, 
              0, \(-e\_2\)\ u\_1 + e\_1\ u\_2 + e\_4\ u\_3 + e\_3\ u\_4, 
              0, \(-e\_3\)\ u\_1 - e\_4\ u\_2 + e\_1\ u\_3 - e\_2\ u\_4, 
              e\_4\ u\_1 - e\_3\ u\_2 + e\_2\ u\_3 + e\_1\ u\_4, 0, 0, 0, 0, 
              0, 0, 0, 0, 0}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)]}], "}"}]], "Output",
  FontSize->9]
}, Open  ]],

Cell[TextData[{
  "\tComplex conjugation is an involution that replaces i by - i; multiplying \
a vector by its conjugate gives a real number (the conserved quadratic size) \
in complex, quaternion, and Octonion algebras. The other elements in the \
product are zero. Figure 11 [S,Ex.34] demonstrates that this also applies to \
the split-octonion hoop and to three Clifford Algebra hoops (though \
Clifford[3] gives a non-zero trivector element and the size is the sum of the \
squared terms). \"Plex-conjugates\" are generalizations of complex \
conjugation to other hoops. They are involutions that give size-related \
results on multiplication by the original vec. This is  demonstrated for C3; \
the second and third elements are interchanged to give the plex in hoops with \
ternary symmetry, corresponding to exchanging the signs J & ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["J",
            FontSlant->"Plain"], "2"], TraditionalForm]]],
  ". The sum and the signed sum of the product elements give the sizes \
(squared in the first case). C3C2 behaves similarly. Some plex-conjugates can \
be found easily; this has been used to discover the shapes of a few hoops \
with more than twelve elements."
}], "Text"],

Cell[BoxData[
    \(Figure\ 11. \ Some\ conjugate\ \(\(products\)\(.\)\)\)], "Input",
  FontSize->10],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(Use["\<Qr\>"]; "\<Quaternion conjugate is\>" // bf\), 
        ",", \(plex // bf\), ",", " ", "\"\<product with {a,b,c,d}= \>\"", 
        ",", 
        RowBox[{
          FormBox[\(hoopTimes[{a, b, c, d}, plex]\),
            "TraditionalForm"], "//", "bf"}], 
        ",", \(Use["\<Octr\>"]; "\<\nOctonion conjugate is\>" // bf\), 
        ",", \(plex // bf\), ",", " ", 
        "\"\<product with {a,b,c,d,e,f,g,h}= \>\"", ",", 
        RowBox[{
          FormBox[\(hoopTimes[{a, b, c, d, e, f, g, h}, plex]\),
            "TraditionalForm"], "//", "bf"}], 
        ",", \(Use["\<Octi\>"]; "\<\nSplit-octonion conjugate is\>" // bf\), 
        ",", \(plex // bf\), ",", " ", 
        "\"\<product with {a,b,c,d,e,f,g,h}= \>\"", ",", 
        RowBox[{
          FormBox[\(hoopTimes[{a, b, c, d, e, f, g, h}, plex]\),
            "TraditionalForm"], "//", "bf"}], ",", 
        "\[IndentingNewLine]", \(Use["\<CL2\>"]; "\<\nClifford[2] conjugate \
is\>" // bf\), ",", \(plex // bf\), ",", " ", 
        "\"\<product with {a,b,c,d}= \>\"", ",", 
        FormBox[\(hoopTimes[{a, b, c, d}, plex] // bf\),
          "TraditionalForm"], ",", 
        "\[IndentingNewLine]", \(Use["\<CL3\>"]; "\<\nClifford[3] conjugate \
is\>" // bf\), ",", \(plex // bf\), ",", " ", 
        "\"\<product with {a,b,c,d,e,f,g,h}= \>\"", ",", 
        RowBox[{
          FormBox[\(hoopTimes[{a, b, c, d, e, f, g, h}, plex]\),
            "TraditionalForm"], "//", "bf"}], 
        ",", \(Use["\<C3\>"]; "\<\nC3 conjugate is\>" // bf\), 
        ",", \(plex // bf\), ",", "\"\<product with {a,b,c}=\>\"", 
        ",", \(res = hoopTimes[{a, b, c}, plex]; res // bf\), ",", 
        "\"\<\\nThis sums to the square of the first size\>\"", 
        ",", \(Factor\ [Plus @@ res] // bf\), ",", 
        "\"\<\\nThe (+,-,-) signed sum gives the quadratic size\>\"", 
        ",", \(Factor\ [res[\([1]\)] - res[\([2]\)] - res[\([3]\)]] // bf\), 
        ",", \(Use["\<C3C2\>"]; "\<\nC3C2 conjugate is\>" // bf\), 
        ",", \(plex // bf\), ",", " ", "\"\<product with {a,b,c,d,e,f}= \>\"",
         ",", 
        RowBox[{
          RowBox[{"Pr", "=", 
            FormBox[\(hoopTimes[{a, b, c, d, e, f}, plex]\),
              "TraditionalForm"]}], ";", \(Pr // bf\)}], ",", 
        "\"\<\\nThis sums to the square of the first size\>\"", 
        ",", \(Factor\ [Plus @@ Pr] // bf\), ",", 
        "\"\<\\nThe third and fourth sizes are \
Pr[[1]]-Pr[[2]]\[PlusMinus]Pr[[4]]\[MinusPlus]Pr[[5]]\>\"", 
        ",", \(Expand[sh[\([3]\)]] == 
            Expand[Pr[\([1]\)] - Pr[\([2]\)] + Pr[\([4]\)] - Pr[\([5]\)]] // 
          bf\), ",", \(Expand[sh[\([4]\)]] == 
            Expand[Pr[\([1]\)] - Pr[\([2]\)] - Pr[\([4]\)] + Pr[\([5]\)]] // 
          bf\)}], "}"}]], "Input",
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          StyleBox["\<\"Quaternion conjugate is\"\>",
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], ",", 
        TagBox[
          StyleBox[\({a, \(-b\), \(-c\), \(-d\)}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"product with {a,b,c,d}= \"\>", ",", 
        TagBox[
          StyleBox[\({a\^2 + b\^2 + c\^2 + d\^2, 0, 0, 0}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], ",", 
        TagBox[
          StyleBox["\<\"\\nOctonion conjugate is\"\>",
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], ",", 
        TagBox[
          
          StyleBox[\({a, \(-b\), \(-c\), \(-d\), \(-e\), \(-f\), \(-g\), \(-h\
\)}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"product with {a,b,c,d,e,f,g,h}= \"\>", ",", 
        TagBox[
          
          StyleBox[\({a\^2 + b\^2 + c\^2 + d\^2 + e\^2 + f\^2 + g\^2 + h\^2, 
              0, 0, 0, 0, 0, 0, 0}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], ",", 
        TagBox[
          StyleBox["\<\"\\nSplit-octonion conjugate is\"\>",
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], ",", 
        TagBox[
          
          StyleBox[\({a, \(-b\), \(-c\), \(-d\), \(-e\), \(-f\), \(-g\), \(-h\
\)}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"product with {a,b,c,d,e,f,g,h}= \"\>", ",", 
        TagBox[
          
          StyleBox[\({a\^2 - b\^2 + c\^2 - d\^2 + e\^2 - f\^2 + g\^2 - h\^2, 
              0, 0, 0, 0, 0, 0, 0}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], ",", 
        TagBox[
          StyleBox["\<\"\\nClifford[2] conjugate is\"\>",
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], ",", 
        TagBox[
          StyleBox[\({a, \(-b\), \(-c\), \(-d\)}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"product with {a,b,c,d}= \"\>", ",", 
        TagBox[
          StyleBox[\({a\^2 - b\^2 + c\^2 - d\^2, 0, 0, 0}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], ",", 
        TagBox[
          StyleBox["\<\"\\nClifford[3] conjugate is\"\>",
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], ",", 
        TagBox[
          
          StyleBox[\({a, \(-b\), \(-c\), \(-d\), \(-e\), \(-f\), \(-g\), h}\),
            
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"product with {a,b,c,d,e,f,g,h}= \"\>", ",", 
        TagBox[
          
          StyleBox[\({a\^2 - b\^2 - c\^2 + d\^2 - e\^2 + f\^2 + g\^2 - h\^2, 
              0, 0, 0, 0, 0, 0, \(-2\)\ d\ e + 2\ c\ f - 2\ b\ g + 2\ a\ h}\),
            
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], ",", 
        TagBox[
          StyleBox["\<\"\\nC3 conjugate is\"\>",
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], ",", 
        TagBox[
          StyleBox[\({a, c, b}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"product with {a,b,c}=\"\>", ",", 
        TagBox[
          
          StyleBox[\({a\^2 + b\^2 + c\^2, a\ b + a\ c + b\ c, 
              a\ b + a\ c + b\ c}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"\\nThis sums to the square of the first size\"\>", ",", 
        TagBox[
          StyleBox[\(\((a + b + c)\)\^2\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"\\nThe (+,-,-) signed sum gives the quadratic size\"\>", 
        ",", 
        TagBox[
          StyleBox[\(a\^2 - 2\ a\ b + b\^2 - 2\ a\ c - 2\ b\ c + c\^2\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], ",", 
        TagBox[
          StyleBox["\<\"\\nC3C2 conjugate is\"\>",
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], ",", 
        TagBox[
          StyleBox[\({a, c, b, d, f, e}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"product with {a,b,c,d,e,f}= \"\>", ",", 
        TagBox[
          
          StyleBox[\({a\^2 + b\^2 + c\^2 + d\^2 + e\^2 + f\^2, 
              a\ b + a\ c + b\ c + d\ e + d\ f + e\ f, 
              a\ b + a\ c + b\ c + d\ e + d\ f + e\ f, 
              2\ a\ d + 2\ b\ e + 2\ c\ f, 
              b\ d + c\ d + a\ e + c\ e + a\ f + b\ f, 
              b\ d + c\ d + a\ e + c\ e + a\ f + b\ f}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"\\nThis sums to the square of the first size\"\>", ",", 
        TagBox[
          StyleBox[\(\((a + b + c + d + e + f)\)\^2\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"\\nThe third and fourth sizes are Pr[[1]]-Pr[[2]]\
\[PlusMinus]Pr[[4]]\[MinusPlus]Pr[[5]]\"\>", ",", 
        TagBox[
          StyleBox["True",
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], ",", 
        TagBox[
          StyleBox["True",
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)]}], "}"}]], "Output",
  FontSize->9]
}, Open  ]],

Cell["\<\
\tOrbits are sub-algebras with the product of non-zero sizes multiplying to \
one; they have angle parameters that add on abelian multiplication, and \
products of orbits are orbits. This is demonstrated for two C3 orbits in \
Figure 12. [S,Fig.35]\
\>", "Text"],

Cell[BoxData[
    \(Figure\ 12. \ Products\ of\ Orbits\ are\ \(\(Orbits\)\(.\)\)\)], "Input",\

  FontSize->10],

Cell[CellGroupData[{

Cell[BoxData[
    \({Use["\<C3\>"]; "\<OC301 polar form is \>", OC301 = {0, 1, \[Tau]}; 
      OC301 // bf, "\<with vector form\>", 
      v01 = tovec /. as[{0, 1, \[Tau]}, {a, b, c}]; 
      v01 // bf, "\<\nOC311 polar form is \>", OC311 = {1, 1, \[Phi]}; 
      OC311 // bf, "\<with vector form\>", 
      v11 = tovec /. as[{1, 1, \[Phi]}, {a, b, c}]; 
      v11 // bf, "\<\nThe product vector form is \>", 
      vv = Simplify[hoopTimes[v01, v11]]; vv // bf, "\<\nwith polar form \>", 
      Simplify[topol /. as[vv]] // 
        bf, "\<\nMathematica fails to simplify to \>", {1, 
          1, \[Tau] + \[Phi]} // bf}\)], "Input",
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"OC301 polar form is \"\>", ",", 
        TagBox[
          StyleBox[\({0, 1, \[Tau]}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"with vector form\"\>", ",", 
        TagBox[
          
          StyleBox[\({\(2\ Cos[\[Tau]]\)\/3, 
              2\/3\ Cos[\(2\ \[Pi]\)\/3 + \[Tau]], 
              2\/3\ Cos[\(2\ \[Pi]\)\/3 - \[Tau]]}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"\\nOC311 polar form is \"\>", ",", 
        TagBox[
          StyleBox[\({1, 1, \[Phi]}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"with vector form\"\>", ",", 
        TagBox[
          
          StyleBox[\({1\/3\ \((1 + 2\ Cos[\[Phi]])\), 
              1\/3\ \((1 + 2\ Cos[\(2\ \[Pi]\)\/3 + \[Phi]])\), 
              1\/3\ \((1 + 2\ Cos[\(2\ \[Pi]\)\/3 - \[Phi]])\)}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"\\nThe product vector form is \"\>", ",", 
        TagBox[
          
          StyleBox[\({2\/3\ Cos[\[Tau] + \[Phi]], \(-\(1\/3\)\)\ Cos[\[Tau] + \
\[Phi]] - Sin[\[Tau] + \[Phi]]\/\@3, \(-\(1\/3\)\)\ Cos[\[Tau] + \[Phi]] + 
                Sin[\[Tau] + \[Phi]]\/\@3}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"\\nwith polar form \"\>", ",", 
        TagBox[
          
          StyleBox[\({0, 1, 
              ArcTan[Cos[\[Tau] + \[Phi]], Sin[\[Tau] + \[Phi]]]}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"\\nMathematica fails to simplify to \"\>", ",", 
        TagBox[
          StyleBox[\({1, 1, \[Tau] + \[Phi]}\),
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4. Controversial",
  StyleBox[" ",
    PageWidth->WindowWidth,
    FontSize->12],
  StyleBox["concepts discussed in the supplementary material.",
    FontWeight->"Bold"]
}], "Section",
  PageWidth->WindowWidth],

Cell[TextData[{
  StyleBox["Summary.\n\tThe supplementary material discusses further \
properties of Hoop Algebras that are not present in conventional algebras. \
Subtraction generalizes to \[OpenCurlyDoubleQuote]additive elimination\
\[CloseCurlyDoubleQuote]. Exponents of generalized signs define multi-phase \
sinusoids, and arise from sets of differential equations that allow \
resonances. Half-spin quantum operators are neither real nor complex. Dozal \
orbits have three radii that multiply to 1 and could define three size \
regimes - point particle size, Planck size, cosmic size. The unit velocity \
wave equation may create mass via velocity being split between spatial \
dimensions and Kaluza-Klein field directions. The 12-directional",
    FontSlant->"Italic"],
  " ",
  StyleBox["Schrodinger equation",
    FontSlant->"Italic"],
  " ",
  StyleBox["might describe particles as non-dispersing wave packets. ",
    FontSlant->"Italic"]
}], "Text"],

Cell[TextData[{
  "\tNegation \"-a\" and subtraction \"b-a\" are conflated and treated as a \
single fundamental process by most mathematicians, but [4] requires over a \
hundred pages of \"Post-Modern Algebra\" before subtraction can be tackled. \
In hoops, ordinary negation is the result of ",
  StyleBox["r",
    FontSlant->"Italic"],
  "=2 folding. This equivalences {",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + m/2\)\)]],
  "} to a real number ",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  " with {",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  "} ~ -",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  " and {",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  "} ~ 0. The first size \[Sum]",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  " is destroyed, as it equivalences to zero. Subtraction can now be seen as \
\"additive elimination\", adding a set of coefficients that make all the \
terms of an un-folded vector identical, so that they equivalence to zero: \
{a,b}+{b,a} ={a+b,a+b} ~ 0. (The commutative property of addition is \
inherited from the natural numbers.)\n\tWhen ",
  StyleBox["r",
    FontSlant->"Italic"],
  " is 3, the equivalence relationship is ",
  Cell[BoxData[
      \(TraditionalForm\`t\_j\)]],
  " ~ {",
  Cell[BoxData[
      \(TraditionalForm\`a\_j\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(j + m/3\)\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(j + 2  m/3\)\)]],
  "} ~ {",
  Cell[BoxData[
      \(TraditionalForm\`b\_j\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`b\_\(j + m/3\)\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`b\_\(j + 2  m/3\)\)]],
  "} iff (",
  Cell[BoxData[
      \(TraditionalForm\`a\_j\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`b\_\(j + m/3\)\)]],
  ")=(",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(j + m/3\)\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`b\_\(j + 2  m/3\)\)]],
  ")=(",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(j + 2  m/3\)\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`b\_j\)]],
  ") . The \"terplex number\" {a,b,c} has a left negation (or rotation), \
{b,c,a} and a right negation {c,a,b}, with {a,b,c} +{b,c,a} +{c,a,b} ={a+b+c, \
a+b+c, a+b+c} ~0. A number is eliminated by adding the two rotations of its \
primal form. This extends to other ",
  StyleBox["r",
    FontSlant->"Italic"],
  " values; a number is eliminated by adding the ",
  StyleBox["r",
    FontSlant->"Italic"],
  "-1 rotations of a primal form. Simultaneous equations can be solved in \
this way in hoop algebras; this is demonstrated in Mathsource/4894, but \
suffers from multiple solutions."
}], "Text"],

Cell[TextData[{
  "\tOrbits are related to the interpretation of hoops as banded sets of \
differential equations with multi-phase cyclic solutions; resonances at \
multiples of the fundamental frequency may account for the resonances of \
particle physics. The function ",
  Cell[BoxData[
      RowBox[{\(x\_j\), "=", 
        RowBox[{\(c[t]\), "+", 
          RowBox[{\(\[Sum]\_p\), 
            RowBox[{\(c\_p\), " ", 
              RowBox[{
                RowBox[{"Sin", "[", 
                  RowBox[{
                    RowBox[{"2", "a", " ", 
                      RowBox[{"Sin", "[", 
                        RowBox[{"2", "k", " ", 
                          StyleBox[
                            FormBox[\(f\_p\),
                              "TraditionalForm"],
                            FontSlant->"Italic"], " ", \(\[Pi]/m\)}], "]"}], 
                      " ", "t"}], "+", \(\[Phi]\_p\), 
                    "+", \(2  j\ k\ \[Pi]/m\)}], "]"}], "/", 
                FormBox[\(f\_p\),
                  "TraditionalForm"]}]}]}]}]}]],
    FontFamily->"Times New Roman",
    FontWeight->"Plain"],
  " is a solution to \n",
  Cell[BoxData[
      StyleBox[\(D[x\_j, t] = \(c'\)[t] + 
            a \((x\_\(Mod[j + k, m]\) - x\_\(Mod[j - k, m]\))\), 
        j = \(0.  .. \)\ m - 1, k < m/2. \),
        FontFamily->"Times New Roman",
        FontWeight->"Plain"]], "Input"],
  " Here  ",
  StyleBox["j",
    FontSlant->"Italic"],
  " is one of the ",
  StyleBox["m",
    FontSlant->"Italic"],
  " phases; ",
  StyleBox["k",
    FontSlant->"Italic"],
  " is a phase step; c[t] gives freedom from the origin; the integer",
  StyleBox[" ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`f\_p\)],
    FontFamily->"Times New Roman",
    FontWeight->"Plain"],
  " is a resonance number, being 1 for the fundamental wave;",
  " ",
  Cell[BoxData[
      \(c\_p\)],
    FontFamily->"Times New Roman"],
  " and ",
  Cell[BoxData[
      StyleBox[\(\[Phi]\_p\),
        FontFamily->"Times New Roman"]]],
  " are phase amplitude and phase offset constants. The subscript ",
  StyleBox["p",
    FontSlant->"Italic"],
  " is needed ",
  "because independent sets can arise. Sin[2k \[Pi]/m] is a constant that \
determines the frequency & period.  When ",
  StyleBox["m",
    FontSlant->"Italic"],
  "=4, ",
  StyleBox["k",
    FontSlant->"Italic"],
  " must be 1; folding then removes the c[t] term and reproduces the ordinary \
sinusoid equation-pair with double the amplitude. Other values of ",
  StyleBox["m",
    FontSlant->"Italic"],
  " and ",
  StyleBox["k",
    FontSlant->"Italic"],
  " give a frequency reduction. The period is 2\[Pi]/Sin[2k \[Pi]/m]",
  Cell[BoxData[
      RowBox[{"/", 
        FormBox[\(f\_p\),
          "TraditionalForm"]}]],
    FontFamily->"Times New Roman",
    FontWeight->"Plain"],
  ", and the function is non-sinusoidal (constant) if 2/m is integral; ",
  StyleBox["m",
    FontSlant->"Italic"],
  "=12 gives half-spin with a period of 4\[Pi] if ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(f\_p\),
          FontSlant->"Italic"], TraditionalForm]],
    FontFamily->"Times New Roman",
    FontWeight->"Plain"],
  "=1. Spin-2 is ",
  Cell[BoxData[
      \(TraditionalForm\`Sin\^2\)]],
  " with period \[Pi]; this suggests that the spin-2 sinusoids (gravity \
waves) are essentially non-negative. The relationships between orbit \
resonances and the resonances of particle physics has not been explored \
(Neither has that between branes and multi-radius orbits.)"
}], "Text"],

Cell[TextData[{
  "\tThe Dozal sizes with ternary symmetry could have three sizes that \
multiply to 1, one corresponding to a Planck area ",
  Cell[BoxData[
      \(TraditionalForm\`P\^2\)]],
  " and the others in a reciprocal relationship, two squared radii ",
  Cell[BoxData[
      \(TraditionalForm\`r\^2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`R\^2\)]],
  " corresponding to the dimensions of \"pseudo-point\" particles and the \
universe. p.r.R=1 gives three size regimes. More work is needed."
}], "Text",
  PageWidth->WindowWidth],

Cell["\<\
\tThe basic wave equation in many dimensions gives a unit velocity, which is \
projected onto the different dimensions as velocity components. Massless \
particle waves would be restricted to space-like dimensions and would travel \
a the speed of light. Others would have velocities in Kaluza-Klein dimensions \
and their spatial velocities would be less than that of light.\
\>", "Text"],

Cell["\<\
\tGeneralizing the Schrodinger equation to 12 directions (instead of the 4 \
implied by using \[ImaginaryI]) might lead to a more general description of \
\"information about particles\", and a non-dispersing form (including \
non-linear terms) could describe stable particles. \
\>", "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["5. Outstanding problems.", "Section",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tThe author, as an amateur experimental mathematician who interprets Go\
\[EDoubleDot]del\[CloseCurlyQuote]s theorem as \[OpenCurlyDoubleQuote]Truth \
transcends Proof\[CloseCurlyDoubleQuote], has only concerned himself with the \
demonstrability of hoop algebras and their properties. Rigorous analysis, \
based on primal numbers rather than real numbers, is required.\n\tThe only \
known general \[OpenCurlyDoubleQuote]proof\[CloseCurlyDoubleQuote] that a \
table is conservative is by demonstration using random vectors; proof by \
factorization is only possible for small tables. Frobenius\[CloseCurlyQuote]s \
proof has not been extended to folded tables; it does not apply to general \
Moufang loops. Proof is needed for the observation that the Moufang property \
ensures that vecs are invertible.\n\tNon abelian algebras are not well \
understood. Some non-abelian hoops have \"pseudo-roots\" that may introduce \
uncertainty because their angles do not add on hoop multiplication. They have \
repeated quadratic roots that release extra degrees of freedom. D3 is the \
smallest non-commutative group. The supplementary material demonstrates that \
AB differs from BA in the D3 algebra; B & A are recovered by \
pre-multiplication by the appropriate inverse. The \"pseudo-power\" A",
  Cell[BoxData[
      \(TraditionalForm\`\^2\)]],
  " differs from the repeated product, but the \"pseudo-root\" recovers A.\n\t\
Conservation and orbits are \[OpenCurlyDoubleQuote]emergent properties\
\[CloseCurlyDoubleQuote]; others can be expected when techniques are \
developed to find the shapes of larger hoops. Higher-order sizes may lead to \
new emergent properties. They may be difficult to identify - C3 & C4 have \
duals with only a single angle each, but several years of effort were needed \
before \[OpenCurlyDoubleQuote]L4\[CloseCurlyDoubleQuote], a quartic size of \
C3C4, could be factorized and shown to define two orbits. A4 has one linear \
size, one quadratic size (giving an orbit) and a repeated cubic size that \
appears to discriminate between other types of Dozal orbit. This is a \
conserved symmetry; is there a related force or particle? Quartic sizes are \
common; if (like \[OpenCurlyDoubleQuote]L4\[CloseCurlyDoubleQuote]) they have \
a minimum of zero, they may be factorizable. A4 has one linear size, one \
quadratic size (giving an orbit) and a repeated cubic size that appears to \
discriminate between other types of Dozal orbit. This is a conserved \
symmetry; is there a related force or particle?\n\tThe (complex) Schr\
\[ODoubleDot]dinger equation describes \[OpenCurlyDoubleQuote]information \
about particles\[CloseCurlyDoubleQuote] and undergoes dispersion. Replacing \
",
  StyleBox["i ",
    FontVariations->{"Shadow"->True}],
  "by the 12",
  StyleBox["th",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  " root of unity could lead to a Dozal description of non-dispersing \
(solitonic) particles with 4-phase leptons and {3,6,12}-phase hadrons.\n\t\
Orbit instability is a vague concept. It may be related to the occurrence of \
determinant factors that are larger than quadratic.\nDozal may eventually \
lead to descriptions of particles as stable multi-phase wave-packets in \
bosonic and leptonic fields. Their space-time description may involve much \
larger groups, possibly composed from the 12-element Dozal groups and the \
gr",
  StyleBox["oups (derived from Pauli-sigma matrices) that conserve the \
Minkowski metric. There are no known techniques to find the ",
    FontFamily->"Times New Roman"],
  "non-linear conserved properties of such large groups.\n"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["6. Review.",
  FontWeight->"Bold"]], "Section"],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "Hoops provide a unified approach to many of the algebras that are relevant \
to physics. They introduce new concepts that transcend the limitations of \
real and complex fields. They are obtained by folding those Cayley tables \
that define multiplication for sets of unsigned (primal) coefficients, \
provided that they have the Frobenius conservation property for their \
symbolic table inverse determinant factors or \[OpenCurlyDoubleQuote]sizes\
\[CloseCurlyDoubleQuote]. Folding introduces generalized signs as symmetries. \
As these tables all have the Moufang division property, hoops are vector \
division algebras that project results into constrained sub-algebras whenever \
any sizes are zero. Remainders then have to be ejected to maintain the \
conservative property. Multi-phase polar-duals have been found for some \
hoops; these provide stable unital orbits in a few cases - possibly related \
to the limited number of stable particles. 12-element \
\[OpenCurlyDoubleQuote]dozal\[CloseCurlyDoubleQuote] algebras have some \
elements that act as half-spin quantum operators; the author conjectures that \
their 3, 4, 6, and 12-phase orbits are related to lepton and hadron \
wave-packets, and that three ternary orbits are related to M-theory \
dimensions and T-duality.\n\tMany problems remain to be solved before Hoops \
can provide the improved description of physics that is hinted at by their \
known properties."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["7. Validation.",
  FontWeight->"Bold"]], "Section"],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "The self-explanatory examples should need no knowledge of Mathematica",
  StyleBox[". ",
    FontSlant->"Italic"],
  "Mathematica users can access the programmes and data, and test the \
examples with different data, by installing ",
  StyleBox["Hoops.nb",
    FontSlant->"Italic"],
  " in the ",
  StyleBox["Addons\\ExtraPackages",
    FontSlant->"Italic"],
  " directory, and running it to create the ",
  StyleBox["Hoops.m",
    FontSlant->"Italic"],
  " package. This is written in elementary Mathematica, and includes \
\[OpenCurlyDoubleQuote]Usage\[CloseCurlyDoubleQuote] and (*comments*) \
explaining the details, so it should be readily comprehensible and easy to \
transcribe into other computer-aided-mathematics systems for independent \
validation.\n\tA larger package is available in [4]. It details the creation \
and properties of groups, loops, & hoops and provides further examples and a \
glossary."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["8. References", "Section",
  PageWidth->WindowWidth],

Cell[TextData[{
  "[1] G. ",
  StyleBox["Frobenius, Uber die Primfactoren der Gruppendeterminante, \
Sitzungsber.Preuss. Akad. Wiss. Berlin Phys. Math,KL. 1896,(985-1021)", 
    "RefAuthorFN"],
  "\n[2] J.D.H. Smith, A.B. Romanowska, Post-Modern Algebra, Wiley \
Interscience 1999.\n[3]  ",
  ButtonBox["http://library.wolfram.com/infocenter/MathSource/6198/ ",
    ButtonData:>{
      URL[ "http://library.wolfram.com/infocenter/MathSource/6198/ "], None},
    ButtonStyle->"Hyperlink"],
  " R.H.Beresford 2003-7.\n[4]  ",
  ButtonBox["http://library.wolfram.com/infocenter/MathSource/4894/",
    ButtonData:>{
      URL[ "http://library.wolfram.com/infocenter/MathSource/4894/"], None},
    ButtonStyle->"Hyperlink"],
  "  R.H.Beresford 2003-6.\n[5]  H.-D Ebbinghaus et al, Numbers, \
Springer-Verlag N.Y. 1991.\n[6] J.J.Hamilton, Hypercomplex numbers and the \
description of spin states, J.Math.Phys. ",
  StyleBox["38",
    FontWeight->"Bold"],
  "(10) Oct. 1997. pp4914-4928.\n[7] P. Lounesto, Clifford Algebras & Spinors \
2nd ed., Cambridge University Press 2001.\n[S] Supplementary material ",
  StyleBox["hoopSup.nb",
    FontSlant->"Italic"],
  " in [3]."
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 887}},
AutoGeneratedPackage->None,
WindowToolbars->"EditBar",
WindowSize->{1044, 682},
WindowMargins->{{84, Automatic}, {Automatic, 61}},
PrintingCopies->1,
PrintingPageRange->{1, 1},
PageHeaders->{{Inherited, Inherited, Inherited}, {None, Inherited, None}},
PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
        TextData[ "21/2/2007"]], Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Cell[ 
        TextData[ "Hoop Algebra Fundamentals."]]}},
Magnification->2
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 67, 1, 186, "Title"],
Cell[1846, 56, 74, 1, 58, "Subsubtitle"],
Cell[1923, 59, 1486, 22, 589, "Text"],

Cell[CellGroupData[{
Cell[3434, 85, 60, 1, 144, "Section"],

Cell[CellGroupData[{
Cell[3519, 90, 35, 0, 75, "Subsection"],
Cell[3557, 92, 3891, 56, 1348, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7485, 153, 42, 0, 75, "Subsection"],
Cell[7530, 155, 1960, 45, 622, "Text"],
Cell[9493, 202, 23, 0, 53, "Input"],
Cell[9519, 204, 74, 2, 55, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9642, 212, 93, 1, 144, "Section"],
Cell[9738, 215, 1340, 18, 523, "Text"],
Cell[11081, 235, 1334, 22, 523, "Text"],
Cell[12418, 259, 1944, 59, 391, "Text"],
Cell[14365, 320, 5560, 148, 1089, "Text"],
Cell[19928, 470, 8145, 317, 542, "Text"],
Cell[28076, 789, 551, 8, 288, "Text"],
Cell[28630, 799, 76, 0, 61, "Text"],
Cell[28709, 801, 849, 19, 226, "Text"],
Cell[29561, 822, 11222, 421, 622, "Text"],
Cell[40786, 1245, 1643, 49, 350, "Text"],
Cell[42432, 1296, 2982, 65, 853, "Text"],
Cell[45417, 1363, 163, 6, 55, "Text"],

Cell[CellGroupData[{
Cell[45605, 1373, 338, 13, 38, "Input",
  CellOpen->False],
Cell[45946, 1388, 1478, 39, 475, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47461, 1432, 460, 18, 38, "Input",
  CellOpen->False],
Cell[47924, 1452, 571, 11, 188, "Output"]
}, Open  ]],
Cell[48510, 1466, 126, 3, 94, "Text"],
Cell[48639, 1471, 971, 18, 325, "Text"],
Cell[49613, 1491, 290, 9, 81, "Text"],

Cell[CellGroupData[{
Cell[49928, 1504, 2286, 42, 38, "Input",
  CellOpen->False],
Cell[52217, 1548, 934, 17, 304, "Output"],
Cell[53154, 1567, 1668, 30, 506, "Output"]
}, Open  ]],
Cell[54837, 1600, 972, 18, 358, "Text"],
Cell[55812, 1620, 1548, 33, 457, "Text"],
Cell[57363, 1655, 170, 6, 55, "Text"],

Cell[CellGroupData[{
Cell[57558, 1665, 935, 20, 38, "Input",
  CellOpen->False],
Cell[58496, 1687, 59, 2, 48, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[58592, 1694, 312, 8, 76, "Input"],
Cell[58907, 1704, 60, 2, 48, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[59004, 1711, 332, 8, 76, "Input"],
Cell[59339, 1721, 837, 14, 189, "Output"]
}, Open  ]],
Cell[60191, 1738, 170, 6, 55, "Text"],

Cell[CellGroupData[{
Cell[60386, 1748, 858, 19, 38, "Input",
  CellOpen->False],
Cell[61247, 1769, 59, 2, 48, "Output"],
Cell[61309, 1773, 255, 7, 55, "Output"],
Cell[61567, 1782, 60, 2, 48, "Output"],
Cell[61630, 1786, 325, 8, 136, "Output"],
Cell[61958, 1796, 1139, 22, 151, "Output"]
}, Open  ]],
Cell[63112, 1821, 769, 12, 259, "Text"],
Cell[63884, 1835, 711, 15, 193, "Text"],
Cell[64598, 1852, 2363, 39, 688, "Text"],
Cell[66964, 1893, 182, 7, 55, "Text"],
Cell[67149, 1902, 1421, 22, 391, "Input"],
Cell[68573, 1926, 2506, 35, 323, "Input"],
Cell[71082, 1963, 259, 5, 127, "Text"],
Cell[71344, 1970, 7954, 131, 1952, "Input",
  PageBreakWithin->Automatic],
Cell[79301, 2103, 578, 17, 153, "Text"],
Cell[79882, 2122, 176, 7, 57, "Text"],

Cell[CellGroupData[{
Cell[80083, 2133, 130, 4, 38, "Input",
  CellOpen->False],
Cell[80216, 2139, 456, 9, 178, "Output"],
Cell[80675, 2150, 598, 11, 211, "Output"]
}, Open  ]],
Cell[81288, 2164, 452, 7, 160, "Text"],
Cell[81743, 2173, 698, 14, 226, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[82478, 2192, 66, 1, 144, "Section"],
Cell[82547, 2195, 418, 14, 127, "Text"],
Cell[82968, 2211, 602, 10, 193, "Text"],
Cell[83573, 2223, 528, 8, 193, "Text"],
Cell[84104, 2233, 175, 7, 55, "Text"],
Cell[84282, 2242, 1247, 23, 38, "Input",
  CellOpen->False],

Cell[CellGroupData[{
Cell[85554, 2269, 53, 1, 54, "Input"],
Cell[85610, 2272, 2966, 60, 1137, "Output"]
}, Open  ]],
Cell[88591, 2335, 1077, 26, 259, "Text"],
Cell[89671, 2363, 155, 6, 57, "Text"],

Cell[CellGroupData[{
Cell[89851, 2373, 5770, 113, 38, "Input",
  CellOpen->False],
Cell[95624, 2488, 9570, 212, 1057, "Output"]
}, Open  ]],
Cell[105209, 2703, 1438, 22, 457, "Text"],
Cell[106650, 2727, 139, 3, 51, "Input"],

Cell[CellGroupData[{
Cell[106814, 2734, 1135, 21, 38, "Input",
  CellOpen->False],
Cell[107952, 2757, 2638, 63, 304, "Output"]
}, Open  ]],
Cell[110605, 2823, 1255, 21, 391, "Text"],
Cell[111863, 2846, 101, 2, 51, "Input"],

Cell[CellGroupData[{
Cell[111989, 2852, 2819, 54, 38, "Input",
  CellOpen->False],
Cell[114811, 2908, 5648, 141, 653, "Output"]
}, Open  ]],
Cell[120474, 3052, 272, 5, 127, "Text"],
Cell[120749, 3059, 111, 3, 51, "Input"],

Cell[CellGroupData[{
Cell[120885, 3066, 653, 12, 38, "Input",
  CellOpen->False],
Cell[121541, 3080, 1944, 47, 411, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[123534, 3133, 229, 8, 194, "Section"],
Cell[123766, 3143, 961, 18, 325, "Text"],
Cell[124730, 3163, 2855, 92, 523, "Text"],
Cell[127588, 3257, 3543, 100, 524, "Text"],
Cell[131134, 3359, 555, 14, 160, "Text"],
Cell[131692, 3375, 399, 6, 160, "Text"],
Cell[132094, 3383, 328, 6, 127, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[132459, 3394, 69, 1, 144, "Section"],
Cell[132531, 3397, 3657, 56, 1199, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[136225, 3458, 71, 1, 144, "Section"],
Cell[136299, 3461, 1506, 23, 456, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[137842, 3489, 75, 1, 80, "Section"],
Cell[137920, 3492, 990, 23, 258, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[138947, 3520, 58, 1, 80, "Section"],
Cell[139008, 3523, 1204, 27, 358, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

