(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    221180,       5411]*)
(*NotebookOutlinePosition[    222232,       5444]*)
(*  CellTagsIndexPosition[    222188,       5440]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Hoop Algebra Fundamentals.", "Title",
  PageWidth->WindowWidth],

Cell[TextData[{
  "R.H.Beresford.  27/11/06. Minor revisions 21/2/07.\n",
  StyleBox["(This is retained in ",
    FontSize->12],
  StyleBox["MathSource",
    FontSize->12,
    FontSlant->"Italic"],
  StyleBox["/6198/ for continuity, as the source for\nmuch of ",
    FontSize->12],
  StyleBox["HoopAlg&Physics.nb",
    FontSize->12,
    FontSlant->"Italic"],
  StyleBox[" and ",
    FontSize->12],
  StyleBox["HoopSup.nb.",
    FontSize->12,
    FontSlant->"Italic"],
  StyleBox[")\n",
    FontSize->12]
}], "Subsubtitle",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell["1. Introduction", "Section",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tHoops are vector algebras that ",
  StyleBox["conserve the symbolic determinant factors of their Cayley \
multiplication tables as symmetries or \"sizes\". Symmetry conservation \
leads, via Noether's theorem, to forces and to particles",
    PageWidth->WindowWidth],
  ". Consequently, Hoops subsume and unify all the algebras (including Real, \
Complex, Quaternion, Octonion, Clifford and Wedge) relevant to physics. They \
may provide a new paradigm for particle physics, based on vector \
multiplication by finite Moufang loops as well as coordinate transformations \
using continuous groups. Using experimental mathematics, the author has found \
many analogies between hoop algebras and particle physics, but (as a 77 yr. \
old chemical engineer) lacks the skills and time to take the subject much \
further.\n\tThe Hoops concept has been implemented in ",
  StyleBox["MathSource/6198/",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  ". The Mathematica package ",
  StyleBox["Hoops.m",
    FontSlant->"Italic"],
  " provides a databank of over 80 named Hoops (with 5 counter-example \
non-hoop Loops), three main procedures ",
  StyleBox["hoopTimes, hoopInverse, hoopPower",
    FontSlant->"Italic"],
  " and a few subsidiary procedures. Each hoop is defined by a Cayley index \
table (a preferred isomorph) and its \"shape\" (the distinct factors of the \
symbolic Cayley table). Multiplication, division, and (in many cases) \
conversion from Cartesian vector {a,b,...} to polar {r,\[Theta]} form are \
provided."
}], "Text"],

Cell[TextData[{
  "\tThe figures are self-explanatory output from a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session (with results of calculations appearing in bold-face) intended to \
be comprehensible readers with no knowledge of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". They are based on the ",
  StyleBox["Hoops.m",
    FontSlant->"Italic"],
  " package. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " users can test them with different data, by installing ",
  StyleBox["Hoops.nb",
    FontSlant->"Italic"],
  " and running it (to create the ",
  StyleBox["Hoops.m",
    FontSlant->"Italic"],
  " package) in the ",
  StyleBox["Addons\\ExtraPackages",
    FontSlant->"Italic"],
  " directory, and then using the following instruction:-."
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(Quit[]\)], "Input"],

Cell[BoxData[
    \(<< "\<Hoops`\>"\)], "Input",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Hoop Concepts.", "Section",
  FontFamily->"Times New Roman"],

Cell[TextData[StyleBox["Summary.\n\tSymmetry-conserving \"Hoop Algebras\" \
involve new mathematical concepts, based on unsigned \
\[OpenCurlyDoubleQuote]Primal numbers\[CloseCurlyDoubleQuote]. Hoop \
multiplication tables are \[OpenCurlyDoubleQuote]folded\
\[CloseCurlyDoubleQuote] from finite groups and Moufang loops; this \
introduces \"generalized signs\". Hoops multiply, divide, and add \"vecs\" \
(generalized vectors). Their \"Frobenius\" symmetry-conservation property and \
\"Moufang\" partial-fraction-division property make them relevant to physics. \
A few hoops have stable multi-phase de-Broglie-like \"orbits\" and \
Planck-like fundamental areas; this may explain particle stability. Every vec \
has a multiplicative inverse, so Hoop multiplication and division use the \
same \"hoopTimes\" operation; two vecs produce a third vec and two (often \
null) \"remainder\" vecs carrying different symmetries. This is analogous to \
symmetry-conserving particle interactions. Do not confuse hoops with the \
traditional use of groups as coordinate transformation matrices for a single \
vector. Hoop tables are not restricted to complex matrix generators, and many \
complex operations are degenerate cases of more general hoop operations.",
  FontSlant->"Italic"]], "Text"],

Cell[TextData[{
  "\tThe development of hoops  involves some neglected and some new \
mathematical concepts. The latter are introduced in  \
\[OpenCurlyDoubleQuote]quotation marks\[CloseCurlyDoubleQuote]:-  \n(1) \
\"Primal\" unsigned continuous numbers (the half-line, the union of 0 & ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[DoubleStruckCapitalR]\^+\)\)]],
  ") can be developed from set theory, without introducing integers and reals \
(with negation and subtraction), by using a continuity axiom on Landau's [1] \
unsigned rational numbers ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[DoubleStruckCapitalQ]\^+\)\)]],
  ". Only the most rigorous mathematicians acknowledge that integers are \
equivalence relations on pairs of natural numbers; others conflate (unary) \
negation with (binary) subtraction by working in fields and implicitly \
assuming that minus one exists and is unique. Some physical concepts (time? \
mass?) should, perhaps, have primal (rather than real) measures.\n(2) \
Algebraic loops are ",
  StyleBox["m\[Times]m",
    FontSlant->"Italic"],
  " multiplication tables for ",
  StyleBox["m",
    FontSlant->"Italic"],
  "-element sets of coefficients or operators that define \"vecs\" \
(generalized vectors, which are vectors in some algebras) such as A = {",
  Cell[BoxData[
      \(TraditionalForm\`\(\(a\_1\)\(,\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`a\_2\)]],
  ",...",
  Cell[BoxData[
      \(TraditionalForm\`a\_m\)]],
  "},{",
  StyleBox["a,b,...,m",
    FontSlant->"Italic"],
  "}, or ",
  Cell[BoxData[
      \(TraditionalForm\`a\_1\)]],
  Cell[BoxData[
      \(TraditionalForm\`d\_1\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`a\_2\)]],
  Cell[BoxData[
      \(TraditionalForm\`d\_2\)]],
  "+...+",
  Cell[BoxData[
      FormBox[
        RowBox[{\(a\_m\), 
          FormBox[\(d\_m\),
            "TraditionalForm"]}], TraditionalForm]]],
  ". Loops can be developed without introducing negation, so their \
coefficients are unsigned. Moufang loops have the Moufang division property ( \
",
  StyleBox["zx.yz=(z.xy)z ",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[") (so ",
    FontWeight->"Plain"],
  StyleBox["every vector has a multiplicative inverse)",
    PageWidth->WindowWidth],
  StyleBox["; groups ",
    FontWeight->"Plain"],
  "are associative Moufang loops with (",
  StyleBox["x(yz)=(xy)z",
    FontSlant->"Italic"],
  ") .\n(3) Frobenius showed that all groups conserve their determinants when \
they are used as vector multiplication tables; Det[A] Det[B] = \
\[PlusMinus]Det[AB], where Det is the determinant of the inverse \
multiplication table mapped with the appropriate vector. A few \
non-associative Moufang loops (including octonions and split-octonions) also \
have this \"Frobenius conservation\" property.\n(4) \"Generalized signs\" are \
orthogonal primitive roots of unity ",
  StyleBox["s",
    FontSlant->"Italic",
    FontVariations->{"Shadow"->True}],
  StyleBox["j",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  " (with ",
  StyleBox["s",
    FontSlant->"Italic",
    FontVariations->{"Shadow"->True}],
  StyleBox["r",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  " =1) describing ",
  StyleBox["r",
    FontSlant->"Italic"],
  "-directional spaces or sub-spaces. Describing roots of unity as ",
  StyleBox["cyclotomic numbers",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  " distorts their properties by projecting them onto the complex field. \
Reals, with signs {+.-}, are an ",
  StyleBox["r",
    FontSlant->"Italic"],
  "=2 case. Complex numbers are one case of ",
  StyleBox["r",
    FontSlant->"Italic"],
  "=4, with signs {+,\[ImaginaryI],-,-\[ImaginaryI]}. ",
  StyleBox["r",
    FontSlant->"Italic"],
  "=3 gives \"terplex\" signs {+, \[DoubleStruckCapitalJ], ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalJ]\^2\)]],
  "} with ternary symmetries relevant to quarks.\n(5) \"Directors\" are sets \
of primal coefficients with associated \"directions\", i.e. the ",
  Cell[BoxData[
      \(TraditionalForm\`d\_i\)]],
  "'s in (2). ",
  StyleBox["r",
    FontSlant->"Italic"],
  "-fold equivalence relationships on ",
  StyleBox["m",
    FontSlant->"Italic"],
  "-element directors \"fold\" them to \"signed vecs\", generalized vectors \
with ",
  StyleBox["m/r",
    FontSlant->"Italic"],
  " associated dimensions and ",
  StyleBox["r-",
    FontSlant->"Italic"],
  "signed coefficients. Real vecs are the result of 2-folding, ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(r\_i\), "~", 
          FormBox[\(a\_i\),
            "TraditionalForm"]}], TraditionalForm]],
    PageWidth->WindowWidth],
  "-",
  Cell[BoxData[
      FormBox[
        RowBox[{\(a\_\(i + m/2\)\), 
          FormBox["",
            "TraditionalForm"]}], TraditionalForm]],
    PageWidth->WindowWidth],
  " with the signs {+, -}; this is the special case \"Minus 1 exists and is \
unique\" that allows negation and subtraction to be conflated. (The \
\"directions\" concept is due to Sir W.R.Hamilton. He related the eight \
directions of the quaternion group to the four dimensions of the quaternion \
algebra, and the sixteen directions of the octonion table to the eight \
dimensions of the octonion algebra.)\n(6) ",
  StyleBox["Folding is a key concept because it relates generalized signs to \
loop symmetries. ",
    PageWidth->WindowWidth],
  "An equivalence relationship on a conservative ",
  StyleBox["m\[Times]m",
    FontSlant->"Italic"],
  "-element loop with ",
  StyleBox["r",
    FontSlant->"Italic"],
  "-fold symmetry \"folds\" it to an ",
  StyleBox["(m/r)\[Times](m/r)",
    FontSlant->"Italic"],
  " multiplication table. I call such tables \"Hoop Algebra\". In many cases \
they are not loops, because some products are \"signed elements\" that are \
not members of the defining set. E.g. Quaternions have four elements \
{e,i,j,ij} with i.j=ij, but j.i=-ij. \n",
  StyleBox["Figure 1 shows \[OpenCurlyDoubleQuote]protoloops\
\[CloseCurlyDoubleQuote] (preferred Cayley table isomorphs) for three Moufang \
loops (the C4C2, quaternion, and C9 groups). The top left corner is repeated \
in the tables; it also occurs with offsets of 3, 4, or 6, showing the \
symmetry. These sub-tables are then shown as folded tables, with the indices \
replaced by the usual complex or quaternion symbols, or (in the C9J algebra) \
by signed indices, providing a new sign ",
    PageWidth->WindowWidth],
  StyleBox["J (",
    PageWidth->WindowWidth,
    FontVariations->{"Shadow"->True}],
  StyleBox["with",
    PageWidth->WindowWidth],
  StyleBox[" J",
    PageWidth->WindowWidth,
    FontVariations->{"Shadow"->True}],
  StyleBox["3",
    PageWidth->WindowWidth,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["=1) so that indices 4 & 5 become ",
    PageWidth->WindowWidth],
  StyleBox["J",
    PageWidth->WindowWidth,
    FontVariations->{"Shadow"->True}],
  StyleBox["1 and",
    PageWidth->WindowWidth],
  StyleBox[" J",
    PageWidth->WindowWidth,
    FontVariations->{"Shadow"->True}],
  StyleBox["2. Note that the C4C2 table can be folded a second time, to give \
",
    PageWidth->WindowWidth],
  StyleBox["the complex algebra table with \[ImaginaryI] \[ImaginaryI] = -1. \
The Pauli-\[Sigma] algebra is also shown; it is 4-folded from a 16-element \
group ",
    PageWidth->WindowWidth,
    FontFamily->"Times New Roman"],
  StyleBox["(not shown) that can be created by dot-multiplying ",
    PageWidth->WindowWidth],
  StyleBox["the Pauli-\[Sigma] matrices",
    PageWidth->WindowWidth,
    FontFamily->"Times New Roman"],
  StyleBox[".",
    PageWidth->WindowWidth,
    FontFamily->"Times New Roman Greek"]
}], "Text"],

Cell[TextData[{
  StyleBox["Figure 1.",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox[" Two- Three- & four-fold folding of Moufang Loops,\n    the \
resulting signed algebras, and the Pauli-",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["\[OAcute]",
    FontFamily->"Courier New Greek",
    FontSize->9],
  StyleBox[" algebra.\n  C4C2 Group       Quaternion group     C9 group\n",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["1 2 3 4",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox[" 5 6 7 8    ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["1 2 3 4",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox[" 5 6 7 8    ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["1 2 3 ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["4 5 6 7 8 9\n",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["2 3 4 1",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox[" 6 7 8 1    ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["2 5 8 3 ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["6 1 4 7    ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["2 3 4 ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["5 6 7 8 9 1\n",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["3 4 1 2 ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["7 8 5 6    ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["3 4 5 6 ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["7 8 1 2    ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["3 4 5 ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["6 7 8 9 1 2\n",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["4 1 2 3 ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["8 5 6 7    ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["4 7 2 5 ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["8 3 6 1    4 5 6 7 8 9 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["1 2 3\n",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["5 6 7 8 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["1 2 3 4    ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["5 6 7 8 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["1 2 3 4    ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["5 6 7 8 9 1 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["2 3 4\n",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["6 7 8 5 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["2 3 4 1    ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["6 1 4 7 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["2 5 8 3    ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["6 7 8 9 1 2 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["3 4 5\n",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["7 8 5 6 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["3 4 1 2    ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["7 8 1 2 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["3 4 5 6",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["    7 8 9 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["1 2 3",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox[" 4 5 6\n8 5 6 7 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["4 1 2 3    ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["8 3 6 1 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["4 7 2 5    ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["8 9 1 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["2 3 4 ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["5 6 7\n                                      9 1 2 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["3 4 5 ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["6 7 8\n\n C4 & Complex    Quaternion      C9J       Pauli-",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["\[Sigma]",
    FontFamily->"Courier New Greek",
    FontSize->9],
  StyleBox["\n    Algebra       Algebra       Algebra    Algebra\n ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["1  ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["i ",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["-1 -",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["i     ",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["1   i   j -ij   1  2  3   1   2   3   4\n",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox[" ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["i -1 ",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["-",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["i  ",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["1     i  -1 -ij   j   2  3 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["J",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["1   2   1 -4",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["i",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["  3",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["i",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["\n",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["-1 -",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["i ",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox[" 1  ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["i",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["     j  ij  -1  -i",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["   ",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["3 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["J",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["1 ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["J",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["2   3  4",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["i",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["   1 -2",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["i",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["\n",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["-i  ",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["1",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["  i",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox[" -1    ij  -j   1  -1             4 -3",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["i  2i",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["   1",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox[" ",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}]
}], "Text"],

Cell[TextData[{
  "(7) Factors of the symbolic inverse table determinant are \"conserved \
sizes\" (symmetries) for hoop multiplication; hoops are defined as \
multiplication tables with this property. The results of factorising \
quadratic or higher factors into complex-conjugate pairs are not conserved \
properties - complex algebra is only one of many hoop algebras.",
  StyleBox[" Figure 2 shows the symbolic tables, the factorized determinants \
and the products ",
    FontFamily->"Times New Roman"],
  StyleBox["hoopTimes[{1,2,...},{a,b,...}] ",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["for the algebras in Figure 1.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Figure 2.",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox[" Symbolic tables, products, factorized determinants.",
    FontFamily->"Courier New",
    FontSize->9],
  "\n",
  StyleBox["   C4        ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["C",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["      Quaternion     C9J         Pauli-",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["\[Sigma]",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontFamily->"Courier New Greek",
    FontSize->9],
  StyleBox[" a b c d    a  b    a  b  c  d    a  b  c     a   b   c   d\n b c \
d a    b -a    b -a -d  c    b  c ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["J",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["a     b   a -",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["i",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["d  ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["i",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["c\n",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox[" ",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["c d a b            c  d -a -b                c  ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["i",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["d   a -",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["i",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["b\n d a b c            d -c  b -a                d -",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["i",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["c  ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["i",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["b   a",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["\n",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["Factorized Determinants, Products :-\n",
    FontSize->9],
  StyleBox["C4",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox[" Factors",
    FontSize->9],
  StyleBox[" ",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox[" ",
    FontSize->9],
  StyleBox["(a+b+c+d)(a-b+c-d)((a-c)",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["2",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["+(b-d)",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["2",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[")\nhoopTimes[{1,2,3,4},{a,b,c,d}]=\n\
{a+4b+3c+2d,2a+b+4c+3d,3a+2b+c+4d,4a+3b+2c+d}\n",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["C ",
    FontFamily->"Times New Roman",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"Shadow"->True}],
  StyleBox[" Factors",
    FontFamily->"Times New Roman",
    FontSize->9],
  StyleBox["              ",
    FontFamily->"Times New Roman",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"Shadow"->True}],
  StyleBox[" ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"Shadow"->True}],
  StyleBox["-a",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["2",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["-b",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["2",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["\nhoopTimes[{1,2},{a,b}]={a-2b,2a+b}",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["\n",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["Quaternion",
    FontFamily->"Times New Roman",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox[" Factors",
    FontFamily->"Times New Roman",
    FontSize->9],
  StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"Shadow"->True}],
  StyleBox["(a",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["2",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["+b",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["2",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["+c",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["2",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["+d",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["2",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[")",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["2\n",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["hoopTimes[{1,2,3,4},{a,b,c,d}]=\n\
{a-2b-3c-4d,2a+b-4c+3d,3a+4b+c-2d,4a-3b+2c+d}",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["\n",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["C9J",
    FontFamily->"Times New Roman",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox[" Factors",
    FontFamily->"Times New Roman",
    FontSize->9],
  StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"Shadow"->True}],
  StyleBox["      -c",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["3",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["-b",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["3",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["J",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["+3abc",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["J",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["-a",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["3",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["J",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"Shadow"->True}],
  StyleBox["2",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["\nhoopTimes[{1,2,3},{a,b,c}]={a+3bJ+2cJ,2a+b+3cJ,3a+2b+c}\n",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["Pauli-\[Sigma] ",
    FontFamily->"Times New Roman",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox[" Factors",
    FontFamily->"Times New Roman",
    FontSize->9],
  StyleBox["    ",
    FontFamily->"Times New Roman",
    FontSize->9,
    FontWeight->"Bold",
    FontVariations->{"Shadow"->True}],
  StyleBox[" ",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["(a",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["2",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["-b",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["2",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["-c",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["2",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["-d",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["2",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[")",
    FontFamily->"Courier New",
    FontSize->9],
  StyleBox["2",
    FontFamily->"Courier New",
    FontSize->9,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox["\n",
    FontFamily->"Courier New",
    FontSize->9,
    FontWeight->"Bold"],
  StyleBox["hoopTimes[{1,2,3,4},{a,b,c,d}]=\n\
{a+2b+3c+4d,2a+b+4\[ImaginaryI]c-3\[ImaginaryI]d,3a-4\[ImaginaryI]b+c+2\
\[ImaginaryI]d,4a+3\[ImaginaryI]b-2\[ImaginaryI]c+d}",
    FontFamily->"Courier New",
    FontSize->9]
}], "Text",
  Editable->False],

Cell[TextData[{
  "\tThe three C4 sizes collapse to the single conserved size ",
  Cell[BoxData[
      \(TraditionalForm\`a\^2\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`b\^2\)]],
  " of Complex algebra. Quaternion and Pauli-\[Sigma] algebras conserve their \
single (but repeated) factors. C9J conserves ",
  Cell[BoxData[
      \(TraditionalForm\`a\^3\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`b\^3\)]],
  "J-3",
  StyleBox["abc",
    FontSlant->"Italic"],
  "J+",
  Cell[BoxData[
      \(TraditionalForm\`c\^3\)]],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["J",
            FontSlant->"Plain"], "2"], TraditionalForm]]],
  ", a conjugate of the determinant factor. (Conjugate conservation is the \
general rule, but conjugation has no effect on most sizes.)\n(8) The Moufang \
property ensures that every vec has a multiplicative inverse in each hoop of \
the same length, merging multiplication and division into one procedure. The \
inverse Ai solves Ai.A={1,0,..} (the \[OpenCurlyDoubleQuote]unit\
\[CloseCurlyDoubleQuote]). The determinant is a divisor for each element of \
the inverse, so multiple sizes provide denominators for partial-fraction \
formulations of the inverse.",
  StyleBox[" The un-factored determinant becomes zero if one or more size \
becomes zero; other factors remain finite.\n\tFigure 3 shows the symbolic C3 \
table, the product of two symbolic vectors, and the two determinant factors. \
The inverse is then shown; each term splits into two partial fractions. Then \
two numeric vectors A & B are multiplied; the sizes are shown as sA, etc. ",
    PageWidth->WindowWidth,
    FontFamily->"Times New Roman"],
  "(Mathematica users can repeat the calculations with their own input data \
in",
  StyleBox[" hoopDemo.nb",
    FontSlant->"Italic"],
  ".) ",
  StyleBox["The sizes of the product AB can be seen to be the products of the \
sizes of A & B. Ai is a left inverse, so ",
    PageWidth->WindowWidth,
    FontFamily->"Times New Roman"],
  StyleBox["hoopTimes[Ai,AB]",
    PageWidth->WindowWidth,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" recovers B. ",
    PageWidth->WindowWidth,
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[TextData[{
  StyleBox["Figure 3.",
    FontWeight->"Bold"],
  " C3 Product, Shape, Inverse, Division."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Use["\<C3\>"]; {hoopTbl /. {1 \[Rule] a, 2 \[Rule] b, 3 \[Rule] c, 
            4 -> d, 5 \[Rule] e, 6 \[Rule] f} // 
        tf, \[IndentingNewLine]"\<\nhoopTimes[{a,b,c},{d,e,f}=\n\>", 
      hoopTimes[{a, b, c}, {d, e, f}], \[IndentingNewLine]"\<\nshape =\n\>", 
      sh, "\<\nInverse =\n\>", \[IndentingNewLine]Apart[
        hoopInverse[{a, b, c, d, e, f}]]}\)], "Input",
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"a", "b", "c"},
                  {"b", "c", "a"},
                  {"c", "a", "b"}
                  }], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nhoopTimes[{a,b,c},{d,e,f}=\\n\"\>", 
        ",", \({a\ d + c\ e + b\ f, b\ d + a\ e + c\ f, c\ d + b\ e + a\ f}\),
         ",", "\<\"\\nshape =\\n\"\>", 
        ",", \({a + b + c, 
          1\/2\ \((\((a - b)\)\^2 + \((b - c)\)\^2 + \((\(-a\) + \
c)\)\^2)\)}\), ",", "\<\"\\nInverse =\\n\"\>", 
        ",", \({1\/\(3\ \((a + b + c)\)\) + \(2\ a - b - c\)\/\(3\ \((a\^2 - \
a\ b + b\^2 - a\ c - b\ c + c\^2)\)\), 
          1\/\(3\ \((a + b + c)\)\) + \(\(-a\) - b + 2\ c\)\/\(3\ \((a\^2 - a\
\ b + b\^2 - a\ c - b\ c + c\^2)\)\), 
          1\/\(3\ \((a + b + c)\)\) + \(\(-a\) + 2\ b - c\)\/\(3\ \((a\^2 - a\
\ b + b\^2 - a\ c - b\ c + c\^2)\)\)}\)}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({Flatten[{"\<If  A=\>", A = {3, 1, \(-2\)}, "\<sA=\>", 
            sh /. as[A]}], \[IndentingNewLine]Flatten[{"\<and B=\>", 
            B = {1, 0, 2}, "\<sB=\>", sh /. as[B]}], \n
        Flatten[{"\<AB=\>", AB = hoopTimes[A, B], "\<sAB=\>", 
            sh /. as[AB]}], \[IndentingNewLine]Flatten[{"\<Ai=\>", 
            Ai = hoopInverse[A], "\<sAi=\>", 
            sh /. as[Ai]}], \[IndentingNewLine]Flatten[{"\<AiAB=B\>", 
            AiAB = hoopTimes[Ai, AB], "\<sAiAB=\>", sh /. as[AiAB]}]} // 
      tf\)], "Input",
  CellOpen->False,
  FontSize->9],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"If  A=\"\>", "3", "1", \(-2\), "\<\"sA=\"\>", "2", "19"},
            {"\<\"and B=\"\>", "1", "0", "2", "\<\"sB=\"\>", "3", "3"},
            {"\<\"AB=\"\>", "5", \(-3\), "4", "\<\"sAB=\"\>", "6", "57"},
            {"\<\"Ai=\"\>", \(11\/38\), \(1\/38\), \(7\/38\), "\<\"sAi=\"\>", \
\(1\/2\), \(1\/19\)},
            {"\<\"AiAB=B\"\>", "1", "0", "2", "\<\"sAiAB=\"\>", "3", "3"}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
  FontSize->9]
}, Open  ]],

Cell["\<\
(9) Vecs with \"zero-sizes\" exist in sub-algebras where these sizes are \
constrained to zero. Their use in multiplication and division \"projects\" \
the result into the sub-algebras and \"ejects\" remainders to maintain size \
conservation. This eliminates division-by-zero; zeroed sizes are \
\"factored-out\" by projection into the constrained sub-algebra.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Figure 4.",
    FontWeight->"Bold"],
  " If A has a zero size in C3, so do AB and Ai; \n           AB/A only \
become B after adding a remainder."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Flatten[{"\<If  A=\>", A0 = {2, \(-1\), \(-1\)}, "\<sA=\>", 
            sh /. as[A0]}], \[IndentingNewLine]Flatten[{"\<and B=\>", 
            B = {1, 0, 2}, "\<sB=\>", 
            sh /. as[B]}], \[IndentingNewLine]Flatten[{"\<AB=\>", 
            AB = hoopTimes[A0, B], "\<sAB=\>", sh /. as[AB]}], 
        Flatten[{"\<Rleft=\>", Rleft = Rl, "\<sRleft=\>", 
            sh /. as[Rleft]}], \[IndentingNewLine]Flatten[{"\<Rright=\>", 
            Rright = Rr, "\<sRright=\>", 
            sh /. as[Rr]}], \[IndentingNewLine]Flatten[{"\<Ai=\>", 
            Ai = hoopInverse[A0], "\<sAi=\>", 
            sh /. as[Ai]}], \[IndentingNewLine]Flatten[{"\<AB/A (=AiAB)=\>", 
            AiAB = hoopTimes[Ai, AB], "\<sAiAB=\>", 
            sh /. as[
                AiAB]}], \[IndentingNewLine]Flatten[{"\<AiAB+Rright=B\>", 
            R = AiAB + Rright, "\<s=\>", sh /. as[R]}]} // tf\)], "Input",
  CellOpen->False],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"If  A=\"\>", "2", \(-1\), \(-1\), "\<\"sA=\"\>", "0", "9"},
            {"\<\"and B=\"\>", "1", "0", "2", "\<\"sB=\"\>", "3", "3"},
            {"\<\"AB=\"\>", "0", \(-3\), "3", "\<\"sAB=\"\>", "0", "27"},
            {"\<\"Rleft=\"\>", "0", "0", "0", "\<\"sRleft=\"\>", "0", "0"},
            {"\<\"Rright=\"\>", "1", "1", "1", "\<\"sRright=\"\>", "3", "0"},
            {"\<\"Ai=\"\>", \(2\/9\), \(-\(1\/9\)\), \(-\(1\/9\)\), "\<\"sAi=\
\"\>", "0", \(1\/9\)},
            {"\<\"AB/A (=AiAB)=\"\>", "0", \(-1\), "1", "\<\"sAiAB=\"\>", "0",
               "3"},
            {"\<\"AiAB+Rright=B\"\>", "1", "0", "2", "\<\"s=\"\>", "3", "3"}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
  FontSize->9]
}, Open  ]],

Cell["\<\
\tNote the analogy between integer division, I/J=K+R where JK+R=I, with Hoop \
operations, where A.B=C+Rleft+Rright and C/B+Rleft=A, C/A+Rright=B. Rleft \
carries the sizes that are zero in C but not in A; Rright carries the sizes \
that are zero in C but not in B. Remainders ensure that conservation is \
maintained in hoop multiplication (as well as division) when some sizes are \
zero. There is an obvious analogy with particle interactions, where there may \
be several products with different symmetries.
\tDo not confuse loop operations, acting on two vecs to give a new vec and \
two (possibly null) remainder vecs, with the use of matrices to transform a \
single vector to different coordinates in the \[OpenCurlyDoubleQuote]standard \
model\[CloseCurlyDoubleQuote] of particle physics.\
\>", "Text"],

Cell[TextData[{
  "(10) Some hoops have quadratic sizes that provide polar-Cartesian dual \
formulations and allow the definition of continuous multi-phase sinusoidal \
\"orbits",
  StyleBox["\", as shown in Example 5",
    PageWidth->WindowWidth],
  ". Quadratic sizes release a degree of freedom that is taken up by an \
angle",
  StyleBox[", which is a hidden variable for the Cartesian form. \n\t",
    PageWidth->WindowWidth,
    FontFamily->"Times New Roman"],
  "Abelian duals have angles that add on vector multiplication, leading to \
powers and roots. ",
  StyleBox["Figure 5 shows that the polar form for the C3 vec {a,b,c} \
consists of expressions for two sizes {\[Alpha],",
    PageWidth->WindowWidth],
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\^2\)]],
  StyleBox["} and an angle \[Sigma]. The reversion from polar to cartesian \
form has \[Alpha] as an offset from zero and three equispaced phases. It then \
demonstrates that ",
    PageWidth->WindowWidth],
  StyleBox["vector[polar[A]=A",
    PageWidth->WindowWidth,
    FontSlant->"Italic"],
  StyleBox[", angles add on C3 multiplication, and taking a square root \
halves the angle and gives sizes that are square roots of the original sizes. \
C3 has a prototypical ternary (3-phase) form polar form. Figure 5 goes on to \
show that C4 has the prototypical 4-phase. This folds to the (asymmetric) \
{Cos[\[Theta]],Sin[\[Theta]]} pair. All known polar duals are related to \
these two prototypes.",
    PageWidth->WindowWidth]
}], "Text",
  PageWidth->WindowWidth],

Cell["Figure 5. C3 & C4 Polar Duals, Reversions, Powers & Roots.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(0  Use["\<C3\>"]; "\<Polar C3\>"\), "\[IndentingNewLine]", 
    \(topol\), "\[IndentingNewLine]", 
    \("\<Vector C3\>"\), "\[IndentingNewLine]", 
    \(tovec\), "\[IndentingNewLine]", 
    \({Flatten[{"\<If  A=\>", A = {2. , \(-3. \), 5. }, "\<polarA=\>", 
            topol /. as[A]}], 
        Flatten[{"\<Vec(polar(A))=\>", 
            tovec /. as[
                topol /. as[
                    A]], "\<\>", "\<\>", "\<\>", "\<\>"}], \
\[IndentingNewLine]Flatten[{"\<and B=\>", 
            B = {1, \(-5\), 6. }, "\<polarB=\>", 
            topol /. as[B]}], \[IndentingNewLine]Flatten[{"\<AB=\>", 
            AB = hoopTimes[A, B], "\<polarAB=\>", topol /. as[AB]}], 
        Flatten[{\*"\"\<\!\(\@A\)=\>\"", 
            RootA = hoopPower[A], \*"\"\<polar\!\(\@A\)=\>\"", 
            topol /. as[RootA]}]} // tf\), "\[IndentingNewLine]", 
    \(Use["\<C4\>"]; "\<Polar C4\>"\), "\n", 
    \(topol\), "\n", 
    \("\<Vector C4\>"\), "\n", 
    \(tovec\), "\n", 
    \({Flatten[{"\<If  A=\>", A = {2. , \(-3. \), 5. , 1. }, "\<polarA=\>", 
            topol /. as[A]}], 
        Flatten[{"\<Vec(polar(A))=\>", 
            tovec /. as[
                topol /. as[
                    A]], "\<=A\>", "\<\>", "\<\>", "\<\>", "\<\>"}], \
\[IndentingNewLine]Flatten[{"\<and B=\>", 
            B = {\(-1\), 5, \(-6. \), 3. }, "\<polarB=\>", 
            topol /. as[B]}], \[IndentingNewLine]Flatten[{"\<AB=\>", 
            AB = hoopTimes[A, B], "\<polarAB=\>", topol /. as[AB]}], 
        Flatten[{\*"\"\<\!\(\@A\)=\>\"", 
            RootA = hoopPower[A], \*"\"\<polar\!\(\@A\)=\>\"", 
            topol /. as[RootA]}]} // tf\)}], "Input",
  CellOpen->False],

Cell[BoxData[
    \("Polar C3"\)], "Output"],

Cell[BoxData[
    \({a + b + c, 
      1\/2\ \((\((a - b)\)\^2 + \((b - c)\)\^2 + \((\(-a\) + c)\)\^2)\), 
      ArcTan[2\ a - b - c, \(-\@3\)\ \((b - c)\)]}\)], "Output"],

Cell[BoxData[
    \("Vector C3"\)], "Output"],

Cell[BoxData[
    \({1\/3\ \((a + 2\ \@b\ Cos[c])\), 
      1\/3\ \((a + 2\ \@b\ Cos[c + \(2\ \[Pi]\)\/3])\), 
      1\/3\ \((a + 2\ \@b\ Cos[c - \(2\ \[Pi]\)\/3])\)}\)], "Output"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"If  A=\"\>", "2.`", \(-3.`\), "5.`", "\<\"polarA=\"\>", 
              "4.`", "49.`", "1.4274487578895312`"},
            {"\<\"Vec(polar(A))=\"\>", "2.`", \(-3.0000000000000004`\), 
              "5.`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
            {"\<\"and B=\"\>", "1", \(-5\), "6.`", "\<\"polarB=\"\>", "2.`", 
              "91.`", "1.518358056045878`"},
            {"\<\"AB=\"\>", \(-41.`\), "17.`", "32.`", "\<\"polarAB=\"\>", 
              "8.`", "4459.`", "2.9458068139354094`"},
            {"\<\"\\!\\(\\@A\\)=\"\>", "2.`", \(-1.`\), 
              "1.0000000000000002`", "\<\"polar\\!\\(\\@A\\)=\"\>", "2.`", 
              "7.`", "0.7137243789447656`"}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output"],

Cell[BoxData[
    \("Polar C4"\)], "Output"],

Cell[BoxData[
    \({a + b + c + d, a - b + c - d, \((a - c)\)\^2 + \((b - d)\)\^2, 
      ArcTan[a - c, b - d]}\)], "Output"],

Cell[BoxData[
    \("Vector C4"\)], "Output"],

Cell[BoxData[
    \({1\/4\ \((a + b + 2\ \@c\ Cos[d])\), 
      1\/4\ \((a - b + 2\ \@c\ Sin[d])\), 1\/4\ \((a + b - 2\ \@c\ Cos[d])\), 
      1\/4\ \((a - b - 2\ \@c\ Sin[d])\)}\)], "Output"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"If  A=\"\>", "2.`", \(-3.`\), "5.`", 
              "1.`", "\<\"polarA=\"\>", "5.`", "9.`", 
              "25.`", \(-2.214297435588181`\)},
            {"\<\"Vec(polar(A))=\"\>", 
              "2.0000000000000004`", \(-3.0000000000000004`\), "5.`", 
              "1.0000000000000004`", "\<\"=A\"\>", "\<\"\"\>", "\<\"\"\>", \
"\<\"\"\>", "\<\"\"\>"},
            {"\<\"and B=\"\>", \(-1\), "5", \(-6.`\), 
              "3.`", "\<\"polarB=\"\>", "1.`", \(-15.`\), "29.`", 
              "0.3805063771123649`"},
            {"\<\"AB=\"\>", \(-36.`\), "22.`", \(-29.`\), 
              "48.`", "\<\"polarAB=\"\>", "5.`", \(-135.`\), 
              "725.`", \(-1.8337910584758161`\)},
            {"\<\"\\!\\(\\@A\\)=\"\>", 
              "1.8090169943749475`", \(-1.1909830056250525`\), 
              "0.8090169943749473`", 
              "0.8090169943749475`", "\<\"polar\\!\\(\\@A\\)=\"\>", 
              "2.23606797749979`", "3.`", "5.`", \(-1.1071487177940904`\)}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Note that the linear sizes are \[OpenCurlyDoubleQuote]offsets\
\[CloseCurlyDoubleQuote] that displace the centres of rotation for the \
sinusoidal terms. They are conserved linear symmetries. Pairs of linear sizes \
can be combined to give conserved differences of squares, from which \
hyperbolic duals can be constructed. Non-abelian hoops have repeated roots; \
their duals are discussed later.\n\n(11) A few Hoops have stable orbits \
resembling multi-phase de Broglie waves; they define fundamental sizes \
resembling Planck areas and",
  StyleBox[" may determine which particles are stable. They have some \
elements (e.g. \[Zeta] in figure 6) that are neither real nor complex but act \
as quantum operators. This is discussed later.\n",
    PageWidth->WindowWidth,
    FontFamily->"Times New Roman"],
  "\n(12) Four \"Dozal\" multiplication rules (for vecs with 12 elements) may \
correspond to four types of interaction between particles, with different \
sizes corresponding to different conserved properties and remainders \
corresponding to emitted particles. C3K and C3C4 are abelian,  Q12 & D3C2 are \
non abelian. The non-abelian rules have \"pseudo-polar duals\" with degrees \
of freedom that may introduce uncertainty. They are indirect compositions of \
C2 with (bosonic) abelian groups that appear to be \"supersymmetric\" to the \
(fermionic) larger groups. They have more symmetries (and more particle \
types) than the bosons. Supersymmetry is not one-to-one.\n\tFigure 6 shows \
the polar and vector forms for C3K. ",
  "This combines the two square roots of unity (Study numbers) of the Klein \
group K, with the cube root of unity of Terplex numbers. ",
  "Each line defines a single element of one form as a function of the \
elements of the other. Orbits are \[OpenCurlyDoubleQuote]unital\
\[CloseCurlyDoubleQuote]; their non-zero sizes multiply to one so that \
repeated products are unital.",
  StyleBox[" Different orbits are obtained by constraining some of the sizes \
{\[Alpha],\[Beta],\[Gamma],\[Delta],\[Zeta],\[Lambda],\[Eta],\[Kappa]} to be \
zero whilst the rest multiply to one. Note that \[Zeta] has three phases ",
    FontFamily->"Times New Roman"],
  "(repeated four times)",
  StyleBox[", whilst {\[Lambda],\[Eta],\[Kappa]} each  have six; different \
combinations can give twelve phases. The C3C4 orbits (not shown) are closely \
related to those for C3K, but include a four-phase system in which \[Gamma] \
and \[Delta] are replaced by ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\^2\)]],
  StyleBox[" and \[Sigma]. The author conjectures that this relates to \
hadrons with quarks as 3, 6, and 12-phase orbits, and leptons as 4-phase \
orbits",
    FontFamily->"Times New Roman"],
  ".",
  StyleBox[" Orbits properties include spin, chirality and polarisation.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell["Figure 6. C3K Polar form and general orbit.", "Text",
  FontWeight->"Bold"],

Cell[BoxData[
    \({a + b + c + d + e + f + g + h + i + j + k + l, 
      a + b + c - d - e - f + g + h + i - j - k - l, \[IndentingNewLine]a + 
        b + c + d + e + f - g - h - i - j - k - l, 
      a + b + c - d - e - f - g - h - i + j + k + l, 
      1\/2\ \((\((a - b + d - e + g - h + j - k)\)\^2 + \((b - c + e - f + h \
- i + k - l)\)\^2 + \((\(-a\) + c - d + f - g + i - j + l)\)\^2)\), 
      ArcTan[2\ a - b - c + 2\ d - e - f + 2\ g - h - i + 2\ j - k - 
          l, \(-\@3\)\ \((b - c + e - f + h - i + k - l)\)], 
      1\/2\ \((\((a - b - d + e + g - h - j + k)\)\^2 + \((\(-a\) + c + d - f \
- g + i + j - l)\)\^2 + \((b - c - e + f + h - i - k + l)\)\^2)\), 
      ArcTan[2\ a - b - c - 2\ d + e + f + 2\ g - h - i - 2\ j + k + 
          l, \(-\@3\)\ \((b - c - e + f + h - i - k + l)\)], 
      1\/2\ \((\((a - b + d - e - g + h - j + k)\)\^2 + \((\(-a\) + c - d + f \
+ g - i + j - l)\)\^2 + \((b - c + e - f - h + i - k + l)\)\^2)\), 
      ArcTan[2\ a - b - c + 2\ d - e - f - 2\ g + h + i - 2\ j + k + 
          l, \(-\@3\)\ \((b - c + e - f - h + i - k + l)\)], 
      1\/2\ \((\((a - b - d + e - g + h + j - k)\)\^2 + \((b - c - e + f - h \
+ i + k - l)\)\^2 + \((\(-a\) + c + d - f + g - i - j + l)\)\^2)\), 
      ArcTan[2\ a - b - c - 2\ d + e + f - 2\ g + h + i + 2\ j - k - 
          l, \(-\@3\)\ \((b - c - e + f - h + i + k - l)\)]}\)], "Input",
  FontSize->9],

Cell[BoxData[
    \(\(\(\ \ \ \ \ \)\({\[Alpha] + \[Beta] + \[Gamma] + \[Delta] + \[Zeta]\ \
Cos[\[Tau]]\ \ \ \ \ \  + \[Lambda]\ Cos[\[Phi]]\ \ \ \ \  + \[Eta]\ Cos[\
\[Chi]]\ \ \ \ \ \  + \[Kappa]\ Cos[\[Psi]], \[Alpha] + \[Beta] + \[Gamma] + \
\[Delta] + \[Zeta]\ Cos[\[Tau] + \[Omega]] + \[Lambda]\ Cos[\[Phi] + \
\[Omega]] + \[Eta]\ Cos[\[Chi] + \[Omega]] + \[Kappa]\ Cos[\[Psi] + \
\[Omega]], \ \[IndentingNewLine]\[Alpha] + \[Beta] + \[Gamma] + \[Delta] + \
\[Zeta]\ Cos[\[Tau] - \[Omega]] + \[Lambda]\ Cos[\[Phi] - \[Omega]] + \[Eta]\ \
Cos[\[Chi] - \[Omega]] + \[Kappa]\ Cos[\[Psi] - \[Omega]], \
\[IndentingNewLine]\[Alpha] - \[Beta] + \[Gamma] - \[Delta] + \[Zeta]\ Cos[\
\[Tau]]\ \ \ \ \ \  - \[Lambda]\ Cos[\[Phi]]\ \ \ \ \  + \[Eta]\ Cos[\[Chi]]\ \
\ \ \ \ \  - \[Kappa]\ Cos[\[Psi]], \ \[Alpha] - \[Beta] + \[Gamma] - \
\[Delta] + \[Zeta]\ Cos[\[Tau] + \[Omega]] - \[Lambda]\ Cos[\[Phi] + \
\[Omega]] + \[Eta]\ Cos[\[Chi] + \[Omega]] - \[Kappa]\ Cos[\[Psi] + \
\[Omega]], \ \[Alpha] - \[Beta] + \[Gamma] - \[Delta] + \[Zeta]\ Cos[\[Tau] - \
\[Omega]] - \[Lambda]\ Cos[\[Phi] - \[Omega]] + \[Eta]\ Cos[\[Chi] - \
\[Omega]] - \[Kappa]\ Cos[\[Psi] - \[Omega]], \ \[Alpha] + \[Beta] - \[Gamma] \
- \[Delta] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  + \[Lambda]\ Cos[\[Phi]]\ \ \ \ \
\  - \[Eta]\ Cos[\[Chi]]\ \ \ \ \ \  - \[Kappa]\ Cos[\[Psi]], \ \[Alpha] + \
\[Beta] - \[Gamma] - \[Delta] + \[Zeta]\ Cos[\[Tau] + \[Omega]] + \[Lambda]\ \
Cos[\[Phi] + \[Omega]] - \[Eta]\ Cos[\[Chi] + \[Omega]] - \[Kappa]\ \
Cos[\[Psi] + \[Omega]], \ \[Alpha] + \[Beta] - \[Gamma] - \[Delta] + \[Zeta]\ \
Cos[\[Tau] - \[Omega]] + \[Lambda]\ Cos[\[Phi] - \[Omega]] - \[Eta]\ Cos[\
\[Chi] - \[Omega]] - \[Kappa]\ Cos[\[Psi] - \[Omega]], \ \[Alpha] - \[Beta] - \
\[Gamma] + \[Delta] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  - \[Lambda]\ \
Cos[\[Phi]]\ \ \ \ \  - \[Eta]\ Cos[\[Chi]]\ \ \ \ \ \  + \[Kappa]\ \
Cos[\[Psi]], \ \[Alpha] - \[Beta] - \[Gamma] + \[Delta] + \[Zeta]\ Cos[\[Tau] \
+ \[Omega]] - \[Lambda]\ Cos[\[Phi] + \[Omega]] - \[Eta]\ Cos[\[Chi] + \
\[Omega]] + \[Kappa]\ Cos[\[Psi] + \[Omega]], \ \[Alpha] - \[Beta] - \[Gamma] \
+ \[Delta] + \[Zeta]\ Cos[\[Tau] - \[Omega]] - \[Lambda]\ Cos[\[Phi] - \
\[Omega]] - \[Eta]\ Cos[\[Chi] - \[Omega]] + \[Kappa]\ Cos[\[Psi] - \
\[Omega]]}/12;\)\)\)], "Input",
  FontSize->9],

Cell["\<\
\tThe following table (taken from GroupLoopHoop.nb, and omitted from the \
\"Word\" version) defines 39 functions that are conserved in one or more of \
the Dozal operations. The author has attempted to relate them to particle \
properties, without success. \
\>", "Text"],

Cell[BoxData[
    \(\(sh12[{a_, b_, c_, d_, e_, f_, g_, h_, i_, j_, k_, l_}] := 
        Module[{ab = a - b - g + h, ag = a - b + g - h, bc = b - c - h + i, 
            bh = b - c + h - i, \[IndentingNewLine]ca = a - c - g + i, 
            ci = a - c + g - i, de = d - e - j + k, 
            dj = d - e + j - k, \[IndentingNewLine]ef = e - f - k + l, 
            ek = e - f + k - l, fd = d - f - j + l, fl = d - f + j - l, 
            f1 = a - b - g + 
                h + \((d + e - 2\ f - j - k + 
                      2  l)\)/\@3, \[IndentingNewLine]f2 = \((a + b - 2  c - 
                      g - h + 2  i)\)/\@3 - d + e + j - 
                k, \[IndentingNewLine]f3 = 
              a - b - g + 
                h - \((d + e - 2\ f - j - k + 
                      2  l)\)/\@3, \[IndentingNewLine]f4 = \((a + b - 2  c - 
                      g - h + 2  i)\)/\@3 + d - e - j + k, abef, 
            agek}, \[IndentingNewLine]abef = 3 \((ab\ ef - bc\ de)\)\^2; 
          agek = 3 \((ag\ ek - bh\ dj)\)\^2; \[IndentingNewLine]{o1 = 
              a + b + c + d + e + f + g + h + i + j + k + l, 
            o2 = a + b + c - d - e - f + g + h + i - j - k - 
                l, \[IndentingNewLine]o3 = 
              a + b + c + d + e + f - g - h - i - j - k - l, 
            o4 = a + b + c - d - e - f - g - h - i + j + k + 
                l, \[IndentingNewLine] (*5*) l22a = 
              3 \((f1\^2 + f2\^2)\)/4,  (*6*) l22b = 
              3 \((f3\^2 + f4\^2)\)/4, \[IndentingNewLine] (*7*) 
              p22 = \((a + b + c + g + h + i)\)\^2 + \((d + e + f + j + k + \
l)\)\^2,  (*8*) 
              q22 = \((a + b + c - g - h - i)\)\^2 + \((d + e + f - j - k - \
l)\)\^2,  (*9*) 
              r22 = \((a + b + c + g + h + i)\)\^2 - \((d + e + f + j + k + \
l)\)\^2,  (*10*) 
              s22 = \((a + b + c - g - h - i)\)\^2 - \((d + e + f - j - k - \
l)\)\^2, \[IndentingNewLine] (*11*) 
              p23 = \((\((ag + dj)\)\^2 + \((bh + ek)\)\^2 + \((ci + \
fl)\)\^2)\)/2,  (*12*) 
              q23 = \((\((ag - dj)\)\^2 + \((bh - ek)\)\^2 + \((ci - \
fl)\)\^2)\)/2, \[IndentingNewLine] (*13*) 
              r23 = \((\((ab + de)\)\^2 + \((bc + ef)\)\^2 + \((ca + \
fd)\)\^2)\)/2,  (*14*) 
              s23 = \((\((ab - de)\)\^2 + \((bc - ef)\)\^2 + \((ca - \
fd)\)\^2)\)/2, \[IndentingNewLine] (*15*) 
              q24 = \((a + b + c)\)\^2 + \((d + e + f)\)\^2 + \((g + h + i)\)\
\^2 + \((j + k + l)\)\^2, \[IndentingNewLine] (*16*) 
              s24 = \((a + b + c)\)\^2 - \((d + e + f)\)\^2 - \((g + h + i)\)\
\^2 - \((j + k + l)\)\^2, \[IndentingNewLine] (*17*) 
              p26 = \((ag\^2 + bh\^2 + ci\^2 - dj\^2 - fl\^2 - ek\^2)\)/
                2,  (*18*) 
              q26 = \((ab\^2 + bc\^2 + ca\^2 - de\^2 - ef\^2 - fd\^2)\)/
                2, \[IndentingNewLine] (*19*) 
              r26 = \((ag\^2 + bh\^2 + ci\^2 + dj\^2 + fl\^2 + ek\^2)\)/
                2,  (*20*) 
              s26 = \((ab\^2 + bc\^2 + ca\^2 + de\^2 + ef\^2 + fd\^2)\)/
                2, \n\ \ \ \ \ \ \ \  (*21*) \ 
            l3 = \((a + d - g - j)\)\ \((a - d + g - j)\)\ \((a - d - g + 
                      j)\) + \((b + e - h - k)\)\ \((b - e + h - k)\)\ \((b - 
                      e - h + k)\) + \[IndentingNewLine]\((c + f - \ i\  - 
                      l)\)\ \((c - f + \ i\  - l)\)\ \((c - f - \ i\  + 
                      l)\) - \((a - d + g - j)\)\ \((b - e - h + k)\)\ \((c + 
                      f - \ i\  - l)\) - \[IndentingNewLine]\((a - d - g + 
                      j)\)\ \((b + e - h - k)\)\ \((c - f + i - l)\) - \((a + 
                      d - g - j)\)\ \((b - e + h - k)\)\ \((c - f - \ i\  + 
                      l)\), \[IndentingNewLine] (*22*) l4p = 
              p26\^2 + agek, \[IndentingNewLine] (*23*) l4q = 
              q26\^2 + abef, \[IndentingNewLine] (*24*) l4r = 
              r26\^2 - 3  agek, \[IndentingNewLine] (*25*) l4s = 
              l22a\ l22b (*s26\^2 - abef*) ,  (*26*) 
              L4Q = \((\((a - b)\)\^2 + \((b - c)\)\^2 + \((a - c)\)\^2 + \
\((d - e)\)\^2 + \((e - f)\)\^2 + \((d - f)\)\^2 + \((g - h)\)\^2 + \
\[IndentingNewLine]\((h - i)\)\^2 + \((g - i)\)\^2 + \((j - k)\)\^2 + \((k - \
l)\)\^2 + \((j - l)\)\^2)\)^2/4 - 
                3\ \((\((a\ \((f - e)\) + b\ \((d - f)\) + c\ \((e - \
d)\))\)\^2 + \((a\ \((i - h)\) + b\ \((g - i)\) + c\ \((h - g)\))\)\^2 + \((d\
\ \((h - i)\) + e\ \((i - g)\) + f\ \((g - h)\))\)\^2 + \((g\ \((k - l)\) + h\
\ \((l - j)\) + i\ \((j - k)\))\)\^2 + \[IndentingNewLine]\((\((b - c)\)\^2 + \
\((e - f)\)\^2)\)\ j\^2 + \((\((a - c)\)\^2 + \((d - f)\)\^2)\)\ k\^2 + \
\((\((a - b)\)\^2 + \((d - e)\)\^2)\)\ l\^2)\) + \[IndentingNewLine]6\ \((\((\
\((c - a)\)\ \((c - b)\) + \((f - d)\)\ \((f - e)\))\)\ j\ k + \((\((b - 
                        
                                a)\)\ \((b - c)\) + \((e - d)\)\ \((e - 
                                  f)\))\)\ j\ l + \[IndentingNewLine]\((\((a \
- b)\)\ \((a - c)\) + \((d - e)\)\ \((d - 
                                  f)\))\)\ k\ l)\), \[IndentingNewLine] (*27*) 
              L4\[Sigma] = \ \((\((a - b)\)\^2 + \((b - c)\)\^2 + \((c - a)\)\
\^2 - \((d - e)\)\^2 - \((e - f)\)\^2 - \((f - d)\)\^2 - \((g - h)\)\^2 - \
\((h - i)\)\^2 - \((i - g)\)\^2 - \((j - k)\)\^2 - \((k - l)\)\^2 - \((l - j)\
\)\^2)\)^2/4 + 
                3\ \((\((b\ d - c\ d - a\ e + c\ e + a\ f - b\ f)\)\^2 + \((b\
\ g - c\ g - a\ h + c\ h + a\ i - b\ i)\)\^2 - \((e\ g - f\ g - d\ h + f\ h + \
d\ i - e\ i)\)\^2 + \((b\ j - c\ j - a\ k + c\ k + a\ l - b\ l)\)\^2 - \
\((\(-e\)\ j + f\ j + d\ k - f\ k - d\ l + e\ l)\)\^2 - \((h\ j - i\ j - g\ k \
+ i\ k + g\ l - h\ l)\)\^2)\), \[IndentingNewLine] (*28*) 
              L4a3 = \((\((ag + dj)\)\^2 + \((bh + ek)\)\^2 + \((ci + \
fl)\)\^2)\)\^2/4 + agek,  (*29*) 
              L4b3 = \((\((ag - dj)\)\^2 + \((bh - ek)\)\^2 + \((ci - \
fl)\)\^2)\)\^2/4 + agek,  (*30*) 
              L4c3 = \((\((ab + de)\)\^2 + \((bc + ef)\)\^2 + \((ca + \
fd)\)\^2)\)\^2/4 - abef,  (*31*) 
              L4d3 = \((\((ab - de)\)\^2 + \((bc - ef)\)\^2 + \((ca - \
fd)\)\^2)\)\^2/4 - abef,  (*32*) 
              L4a6 = \((ag\^2 + bh\^2 + ci\^2 - dj\^2 - fl\^2 - ek\^2)\)\^2/
                  4 + agek,  (*33*) 
              L4b6 = \((ab\^2 + bc\^2 + ca\^2 - de\^2 - ef\^2 - fd\^2)\)\^2/
                  4 + abef,  (*34*) 
              L4c6 = \((ab\^2 + bc\^2 + ca\^2 - de\^2 - ef\^2 - fd\^2)\)\^2/
                  4 - abef, \n\t (*35*) 
              L4d6 = \ \((ag\^2 + bh\^2 + ci\^2 + dj\^2 + fl\^2 + ek\^2)\)\^2/
                  4 - agek, \[IndentingNewLine] (*36*) 
              L49 = \((\((ab\^2 - de\^2)\)\^2 + \((ab\^2 - ef\^2)\)\^2 + \
\((ab\^2 - fd\^2)\)\^2 + \((bc\^2 - de\^2)\)\^2 + \((bc\^2 - ef\^2)\)\^2 + \
\((bc\^2 - fd\^2)\)\^2 + \((ca\^2 - de\^2)\)\^2 + \((ca\^2 - ef\^2)\)\^2 + \
\((ca\^2 - fd\^2)\)\^2)\), \[IndentingNewLine] (*37*) 
              L49a = \((\((ag\^2 - dj\^2)\)\^2 + \((ag\^2 - ek\^2)\)\^2 + \
\((ag\^2 - fl\^2)\)\^2 + \((bh\^2 - dj\^2)\)\^2 + \((bh\^2 - ek\^2)\)\^2 + \
\((bh\^2 - fl\^2)\)\^2 + \((ci\^2 - dj\^2)\)\^2 + \((ci\^2 - ek\^2)\)\^2 + \
\((ci\^2 - fl\^2)\)\^2)\), \[IndentingNewLine] (*38*) 
              L49b = \((\((ab\^2 - dj\^2)\)\^2 + \((ab\^2 - ek\^2)\)\^2 + \
\((ab\^2 - fl\^2)\)\^2 + \((bc\^2 - dj\^2)\)\^2 + \((bc\^2 - ek\^2)\)\^2 + \
\((bc\^2 - fl\^2)\)\^2 + \((ca\^2 - dj\^2)\)\^2 + \((ca\^2 - ek\^2)\)\^2 + \
\((ca\^2 - fl\^2)\)\^2)\), \[IndentingNewLine] (*39*) 
              L49c = \((\((ag\^2 - de\^2)\)\^2 + \((ag\^2 - ef\^2)\)\^2 + \
\((ag\^2 - fd\^2)\)\^2 + \((bh\^2 - de\^2)\)\^2 + \((bh\^2 - ef\^2)\)\^2 + \
\((bh\^2 - fd\^2)\)\^2 + \((ci\^2 - de\^2)\)\^2 + \((ci\^2 - ef\^2)\)\^2 + \
\((ci\^2 - fd\^2)\)\^2)\)}];\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  PageBreakWithin->Automatic,
  FontSize->9],

Cell[TextData[{
  "(13) The real division algebras \[DoubleStruckCapitalR], \
\[DoubleStruckCapitalC], \[DoubleStruckCapitalH], \[DoubleStruckCapitalO] are \
degenerate (monosized) hoops without divisors of zero because their sizes are \
positive, being the sums of the squared elements. These hoops operate \
correctly if their coefficients are complex, but then have divisors of zero. \
This gives the light cone in the complex quaternion case.\n\n(14) Hoops \
subsume, but do not invalidate, complex mathematics. Complex functions are \
specializations of more general functions. Many standard mathematical \
operations are specialisations of more general hoop operations; many \
\"obvious mathematical truths\" are special cases restricted to the \"real \
algebras without divisors of zero\". E.g. repeated products and powers (",
  StyleBox["AA",
    FontSlant->"Italic"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`A\^2\)]],
  ") may differ; vector division is defined; both multiplication and division \
of vectors may leave remainders."
}], "Text"],

Cell[TextData[{
  "\tThe author believes that \"Truth transcends Proof\", and so relies on \
demonstrations of the existence and properties of concepts, even though he \
cannot prove their consistency. This document demonstrates the properties of \
many Hoop algebras, using a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " package ",
  StyleBox["hoops.m",
    FontSlant->"Italic"],
  "  and instructions with output that is meant to be self-explanatory to \
non-",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " users. A separate notebook ",
  StyleBox["hoops.nb",
    FontSlant->"Italic"],
  " provides the package as a databank of over 80 Hoops (with 5 \
counter-example non-hoop Loops), three main procedures ",
  StyleBox["hoopTimes, hoopInverse, hoopPower",
    FontSlant->"Italic"],
  ", and a few subsidiary procedures. The package is written in elementary ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", and includes Usage and (* comments *) explaining the details, so it \
should be readily comprehensible and easy to transcribe into other \
computer-aided-mathematics systems for independent verification. A larger \
package (creation and properties of groups, loops, & hoops) is available in \
[2], which also provides a glossary.\nPlease send any comments to me at ",
  StyleBox["rhberesford@btinternet.com",
    FontSlant->"Italic"]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Demonstrations of Hoop Properties.", "Section",
  FontFamily->"Times New Roman"],

Cell["\<\
Summary.
\tA set of examples demonstrates multiplication and division of vecs in \
different hoop algebras, the \"folding\" of loops to signed algebras with \
conserved sizes and remainders, polar-duals with powers and roots, \
non-Abelian algebras with rotated roots, and the unification of many algebras \
by the Hoop concept. Then \"Orbits\" are introduced, as unital dual \
sub-algebras with relevance to physics.\
\>", "Text",
  PageWidth->WindowWidth,
  FontSlant->"Italic"],

Cell[CellGroupData[{

Cell[TextData[{
  "2.1 ",
  StyleBox["S",
    FontSlant->"Italic"],
  "electing Hoop Algebras."
}], "Subsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tA specific Hoop is selected by ",
  StyleBox["Use[\"H\"]",
    FontSlant->"Italic"],
  ", where ",
  StyleBox["\"H\"",
    FontSlant->"Italic"],
  " is any Hoop name. This assigns values to the variables {",
  StyleBox["mm, nn, hoopTbl, sh, topol, tovec, gi, gp, plex",
    FontSlant->"Italic"],
  "}. The Cayley table is put into ",
  StyleBox["hoopTbl",
    FontSlant->"Italic"],
  ". ",
  StyleBox["sh",
    FontSlant->"Italic"],
  " is the shape. ",
  StyleBox["topol",
    FontSlant->"Italic"],
  " is the polar form (if known); it defines angles to go with each quadratic \
size in ",
  StyleBox["sh",
    FontSlant->"Italic"],
  ". ",
  StyleBox["tovec",
    FontSlant->"Italic"],
  " is the reversion from polar to vector form. This data allows the \
procedures ",
  StyleBox["hoopTimes, hoopInverse,",
    FontSlant->"Italic"],
  " &",
  StyleBox[" hoopPower",
    FontSlant->"Italic"],
  " to calculate vector products, inverses, powers, and roots. (Vector \
addition is element-by-element for all hoops with the same number of \
elements.)\n\tExample 1 shows the index table and the symbolic form for the \
\"C3\" algebra, and then gives the shape, the polar form and the vector \
reversion. (Index tables will be shown in later examples if they have not \
been shown previously and are not too large; later input instructions will be \
hidden in \"closed cells\" because they may be incomprehensible to non-",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " users.)  Please ignore the commas that separate explanatory messages and \
the calculated results."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\( (*Example\ 1*) \), 
      RowBox[{"{", 
        RowBox[{\("\<Example 1a\>" // bf\), " ", ",", 
          "\"\<C2 Table and properties.\\nThe C2 index table is\>\"", 
          ",", \(Use["\<C2\>"]; hoopTbl // tf\), ",", 
          "\"\<\\nThe symbolic form is \>\"", 
          ",", \(s = 
            hoopTbl /. 
              Table[ii \[Rule] 
                  alph\[LeftDoubleBracket]ii\[RightDoubleBracket], {ii, mm}]; 
          s // tf\), ",", "\"\<with determinant\>\"", ",", \(Det[s]\), ",", 
          
          RowBox[{\(s =. \), ";", 
            "\"\<\\nthis factorises into the shape \!\(\*
StyleBox[\"sh\",\nFontSlant->\"Italic\"]\)\>\""}], ",", "sh", ",", 
          "\"\<\\ntopol is\>\"", ",", "topol", ",", "\"\<\\ntovec is\>\"", 
          ",", "tovec", ",", 
          "\[IndentingNewLine]", \("\<\nExample 1b\>" // bf\), ",", 
          "\"\< C3 Table and properties.\\nThe C3 index table is\>\"", 
          ",", \(Use["\<C3\>"]; hoopTbl // tf\), ",", 
          "\"\<\\nThe symbolic form is \>\"", 
          ",", \(s = 
            hoopTbl /. 
              Table[ii \[Rule] 
                  alph\[LeftDoubleBracket]ii\[RightDoubleBracket], {ii, mm}]; 
          s // tf\), ",", "\"\<with determinant\>\"", ",", \(Det[s]\), ",", 
          
          RowBox[{\(s =. \), ";", 
            "\"\<\\nthis factorises into the shape \!\(\*
StyleBox[\"sh\",\nFontSlant->\"Italic\"]\)\>\""}], ",", "sh", ",", 
          "\"\<\\ntopol is\>\"", ",", "topol", ",", "\"\<\\ntovec is\>\"", 
          ",", "tovec", ",", 
          "\[IndentingNewLine]", \("\<\nExample 1c\>" // bf\), " ", ",", 
          "\"\< C4 Table and properties.\\nThe C4 index table is\>\"", 
          ",", \(Use["\<C4\>"]; hoopTbl // tf\), ",", 
          "\"\<\\nThe symbolic form is \>\"", 
          ",", \(s = 
            hoopTbl /. 
              Table[ii \[Rule] 
                  alph\[LeftDoubleBracket]ii\[RightDoubleBracket], {ii, mm}]; 
          s // tf\), ",", "\"\<with determinant\>\"", ",", \(Det[s]\), ",", 
          
          RowBox[{\(s =. \), ";", 
            "\"\<\\nthis factorises into the shape \!\(\*
StyleBox[\"sh\",\nFontSlant->\"Italic\"]\)\>\""}], ",", "sh", ",", 
          "\"\<\\ntopol is\>\"", ",", "topol", ",", "\"\<\\ntovec is\>\"", 
          ",", "tovec"}], "}"}]}]], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          StyleBox["\<\"Example 1a\"\>",
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"C2 Table and properties.\\nThe C2 index table is\"\>", ",", 
        
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2"},
                  {"2", "1"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nThe symbolic form is \"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"a", "b"},
                  {"b", "a"}
                  }], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"with determinant\"\>", 
        ",", \(a\^2 - b\^2\), 
        ",", "\<\"\\nthis factorises into the shape \\!\\(\\* StyleBox[\\\"sh\
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", ",", \({a - b, a + b}\), 
        ",", "\<\"\\ntopol is\"\>", ",", \({a - b, a + b}\), 
        ",", "\<\"\\ntovec is\"\>", 
        ",", \({\(a + b\)\/2, 1\/2\ \((\(-a\) + b)\)}\), ",", 
        TagBox[
          StyleBox["\<\"\\nExample 1b\"\>",
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\" C3 Table and properties.\\nThe C3 index table is\"\>", ",",
         
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3"},
                  {"2", "3", "1"},
                  {"3", "1", "2"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nThe symbolic form is \"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"a", "b", "c"},
                  {"b", "c", "a"},
                  {"c", "a", "b"}
                  }], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"with determinant\"\>", 
        ",", \(\(-a\^3\) - b\^3 + 3\ a\ b\ c - c\^3\), 
        ",", "\<\"\\nthis factorises into the shape \\!\\(\\* StyleBox[\\\"sh\
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
        ",", \({a + b + c, 
          1\/2\ \((\((a - b)\)\^2 + \((b - c)\)\^2 + \((\(-a\) + \
c)\)\^2)\)}\), ",", "\<\"\\ntopol is\"\>", 
        ",", \({a + b + c, 
          1\/2\ \((\((a - b)\)\^2 + \((b - c)\)\^2 + \((\(-a\) + c)\)\^2)\), 
          ArcTan[2\ a - b - c, \(-\@3\)\ \((b - c)\)]}\), 
        ",", "\<\"\\ntovec is\"\>", 
        ",", \({1\/3\ \((a + 2\ \@b\ Cos[c])\), 
          1\/3\ \((a + 2\ \@b\ Cos[c + \(2\ \[Pi]\)\/3])\), 
          1\/3\ \((a + 2\ \@b\ Cos[c - \(2\ \[Pi]\)\/3])\)}\), ",", 
        TagBox[
          StyleBox["\<\"\\nExample 1c\"\>",
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\" C4 Table and properties.\\nThe C4 index table is\"\>", ",",
         
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4"},
                  {"2", "3", "4", "1"},
                  {"3", "4", "1", "2"},
                  {"4", "1", "2", "3"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nThe symbolic form is \"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"a", "b", "c", "d"},
                  {"b", "c", "d", "a"},
                  {"c", "d", "a", "b"},
                  {"d", "a", "b", "c"}
                  }], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"with determinant\"\>", 
        ",", \(\(-a\^4\) + b\^4 - 4\ a\ b\^2\ c + 2\ a\^2\ c\^2 - c\^4 + 
          4\ a\^2\ b\ d + 4\ b\ c\^2\ d - 2\ b\^2\ d\^2 - 4\ a\ c\ d\^2 + 
          d\^4\), ",", "\<\"\\nthis factorises into the shape \\!\\(\\* \
StyleBox[\\\"sh\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
        ",", \({a + b + c + d, 
          a - b + c - d, \((a - c)\)\^2 + \((b - d)\)\^2}\), 
        ",", "\<\"\\ntopol is\"\>", 
        ",", \({a + b + c + d, 
          a - b + c - d, \((a - c)\)\^2 + \((b - d)\)\^2, 
          ArcTan[a - c, b - d]}\), ",", "\<\"\\ntovec is\"\>", 
        ",", \({1\/4\ \((a + b + 2\ \@c\ Cos[d])\), 
          1\/4\ \((a - b + 2\ \@c\ Sin[d])\), 
          1\/4\ \((a + b - 2\ \@c\ Cos[d])\), 
          1\/4\ \((a - b - 2\ \@c\ Sin[d])\)}\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.2 Vector multiplication and division.", "Subsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tGeneralized vectors (abbreviated to \"vecs\") are lists of ",
  StyleBox["m",
    FontSlant->"Italic"],
  " elements ",
  StyleBox["A=",
    FontSlant->"Italic"],
  "{",
  Cell[BoxData[
      \(TraditionalForm\`\(\(a\_1\)\(,\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`a\_2\)]],
  ",...",
  Cell[BoxData[
      \(TraditionalForm\`a\_m\)]],
  "}. Their components can be numbers (integer, real, complex, or unsigned), \
operators, or symbols; the \"standard form\" uses symbols from a table called \
",
  StyleBox["alph",
    FontSlant->"Italic"],
  ", i.e. A={",
  StyleBox["a,b,c, ",
    FontSlant->"Italic"],
  "...}. Vectors can also be thought of as summations of coefficients with \
associated dimensions, signs or directions, A = ",
  Cell[BoxData[
      \(TraditionalForm\`a\_1\)]],
  Cell[BoxData[
      \(TraditionalForm\`d\_1\)]],
  " +",
  Cell[BoxData[
      \(TraditionalForm\`a\_2\)]],
  Cell[BoxData[
      \(TraditionalForm\`d\_2\)]],
  " +...+ ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(a\_m\), 
          FormBox[\(d\_m\),
            "TraditionalForm"]}], TraditionalForm]]],
  ".\n\tGeneralized Hoop multiplication is effected by ",
  StyleBox["hoopTimes[A,B]",
    FontSlant->"Italic"],
  ". The elements of the product ",
  StyleBox["AB ",
    FontSlant->"Italic"],
  "are the sum of each ",
  StyleBox["a\[LeftDoubleBracket]k\[RightDoubleBracket] \
b\[LeftDoubleBracket]l\[RightDoubleBracket] Sign[hoopTbl[[k,l]]] ",
    FontSlant->"Italic"],
  "where Table[[k,l]] contains the (possibly signed) index ",
  StyleBox["j",
    FontSlant->"Italic"],
  ".",
  StyleBox[" ",
    FontSlant->"Italic"],
  "The Moufang property ensures that every vec has a multiplicative inverse; \
division of B by A is ",
  StyleBox["hoopTimes[hoopInverse[A],B].",
    FontSlant->"Italic"],
  "\n\tHoops are \"conservative\" - the real factors of the symbolic \
determinant are \"size\" functions that are conserved on multiplication, \
size[AB] = \[PlusMinus] size[A]size[B]. The sizes are supplied in ",
  StyleBox["sh",
    FontSlant->"Italic"],
  ". The inverse has been found by Cramer's method, so the determinant is a \
denominator of the inverse; multiple sizes allow inverses to split into \
partial fractions.\n\tExample 2 demonstrates multiplication and shape \
conservation in the C2 and C3 algebras; both have two sizes. Only the output \
is shown; commas separate a description of the input from the resulting \
output. Note that the sizes of AB are the product of the sizes of A and B. \
(Section 2.8 shows that this is untrue for many loops.)"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(Use["\<C2\>"]; {"\<Example 2. C2 & C3 multiplication & size \
conservation\>", "\<\nThe C2 table is\>", hoopTbl // tf, "\<with shape\>", 
      sh, "\<\nIf A  = \>", A = {3, 4}, "\<\nand B = \>", 
      B = {x, y}, "\<\nAB = \>", 
      AB = hoopTimes[A, B], "\<\nShape of A  = \>", 
      sh /. \ as[A], "\<\nShape of B  = \>", 
      sh /. \ as[B], "\<\nShape of AB = \>", sh /. \ as[AB], 
      Use["\<C3\>"]; "\<\n\nChange to C3.\nIf A  = \>", 
      A = {3, 4, 1}, "\<\nand B = \>", B = {5, 1, 2}, "\<\nAB = \>", 
      AB = hoopTimes[A, B], "\<\nShape of A  = \>", 
      sh /. \ as[A], "\<\nShape of B  = \>", 
      sh /. \ as[B], "\<\nShape of AB = \>", sh /. \ as[AB]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 2. C2 & C3 multiplication & size conservation\"\>",
         ",", "\<\"\\nThe C2 table is\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2"},
                  {"2", "1"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"with shape\"\>", ",", \({a - b, a + b}\),
         ",", "\<\"\\nIf A  = \"\>", ",", \({3, 4}\), 
        ",", "\<\"\\nand B = \"\>", ",", \({x, y}\), ",", "\<\"\\nAB = \"\>", 
        ",", \({3\ x + 4\ y, 4\ x + 3\ y}\), ",", "\<\"\\nShape of A  = \"\>",
         ",", \({\(-1\), 7}\), ",", "\<\"\\nShape of B  = \"\>", 
        ",", \({x - y, x + y}\), ",", "\<\"\\nShape of AB = \"\>", 
        ",", \({\(-x\) + y, 7\ x + 7\ y}\), 
        ",", "\<\"\\n\\nChange to C3.\\nIf A  = \"\>", ",", \({3, 4, 1}\), 
        ",", "\<\"\\nand B = \"\>", ",", \({5, 1, 2}\), 
        ",", "\<\"\\nAB = \"\>", ",", \({24, 25, 15}\), 
        ",", "\<\"\\nShape of A  = \"\>", ",", \({8, 7}\), 
        ",", "\<\"\\nShape of B  = \"\>", ",", \({8, 13}\), 
        ",", "\<\"\\nShape of AB = \"\>", ",", \({64, 91}\)}], 
      "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Example 3 calculates the inverses of A & B and shows that their sizes are \
inverses of the sizes of A & B. Then ",
  StyleBox["hoopTimes",
    FontSlant->"Italic"],
  " is used to show that Ainverse.AB recovers B, whilst AB.Binverse recovers \
A. (In general, the inverses are \"Left-inverses\"; C3 is abelian so the \
distinction is irrelevant here.)"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Use["\<C3\>"]; {"\<Example 3. C3 division\>", "\<\nAinverse  = \>", 
      Ai = hoopInverse[A], "\<\nShape of Ainverse  = \>", 
      sh /. \ as[Ai], "\<\nBinverse  = \>", 
      Bi = hoopInverse[B], "\<\nShape of Binverse  = \>", 
      sh /. \ as[Bi], "\<\nAinverse.AB recovers B\>", 
      hoopTimes[Ai, AB], "\<\nAB.Ainverse recovers A\>", 
      hoopTimes[AB, Bi]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"Example 3. C3 division", 
      "\nAinverse  = ", {5\/56, \(-\(11\/56\)\), 13\/56}, 
      "\nShape of Ainverse  = ", {1\/8, 1\/7}, 
      "\nBinverse  = ", {23\/104, \(-\(1\/104\)\), \(-\(9\/104\)\)}, 
      "\nShape of Binverse  = ", {1\/8, 1\/13}, 
      "\nAinverse.AB recovers B", {5, 1, 2}, 
      "\nAB.Ainverse recovers A", {3, 4, 1}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.3 \"Folding\" Vectors and Loops.", "Subsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tA key concept in Hoop algebra is the \"Folding\" of a vector via an \
equivalence relationship \"~\" such as ",
  StyleBox["r[[i]]=a[[i]]-a[[i+m/2]] ~ {a[[i]],a[[i+m/2]]}",
    FontSlant->"Italic"],
  ", which creates a single real number by the \"2-folding\" of pairs of \
unsigned numbers and introduces the sign \"-\". Similarly,  ",
  StyleBox["t[[i]] ~ a[[i]]+J a[[i+m/3]]+JJ a[[i+2m/3]]",
    FontSlant->"Italic"],
  " folds three unsigned numbers to a \"terplex\" number (with signs ",
  StyleBox["J ",
    FontSlant->"Italic"],
  "& ",
  StyleBox["JJ",
    FontSlant->"Italic"],
  ").\nOne way to fold four unsigned numbers is ",
  StyleBox["c[[i]] ~ a[[i]]+",
    FontSlant->"Italic"],
  StyleBox["i ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["a[[i+m/4]]-a[[i+2m/4]]-",
    FontSlant->"Italic"],
  StyleBox["i ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["a[[i+3m/4]].",
    FontSlant->"Italic"],
  " This creates a complex number and the signs ",
  StyleBox["i ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["&",
    FontSlant->"Italic"],
  " ",
  StyleBox["-",
    FontSlant->"Italic"],
  StyleBox["i",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  ".\nThe multiplication tables also fold; an ",
  StyleBox["m\[Times]m",
    FontSlant->"Italic"],
  " table with ",
  StyleBox["r",
    FontSlant->"Italic"],
  "-fold symmetry can undergo ",
  StyleBox["r",
    FontSlant->"Italic"],
  "-folding to an ",
  StyleBox["(m/r)\[Times](m/r)",
    FontSlant->"Italic"],
  " table. Following Sir William Hamilton, sets ",
  StyleBox["m",
    FontSlant->"Italic"],
  " of unsigned numbers are \"directors\" with \"",
  StyleBox["m ",
    FontSlant->"Italic"],
  "directions\"; they fold to vectors with \"",
  StyleBox["m/r",
    FontSlant->"Italic"],
  " dimensions\". \n\tExample 4 shows that \"C4\" folds to complex algebra. \
It demonstrates multiplication, division (multiplication by an inverse), \
raising to a power, and extracting a root. In each case, the result is shown \
to fold to the corresponding complex result:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(Use["\<C4\>"]\), ";", 
      RowBox[{"{", 
        RowBox[{
        "\"\<Example 4. C4 folds to Complex algebra.\\nThe table \>\"", 
          ",", \(hoopTbl // tf\), ",", "\"\<can be written as\>\"", 
          ",", \({{1, i, \(-1\), \(-i\)}, {i, \(-1\), \(-i\), 
                1}, {\(-1\), \(-i\), 1, i}, {\(-i\), 1, i, \(-1\)}} // tf\), 
          ",", "\"\<\\nMultiplication using\!\(\*
StyleBox[\" \",\nFontWeight->\"Plain\"]\)\!\(\*
StyleBox[\"hoopTimes\",\nFontWeight->\"Plain\",\n\
FontSlant->\"Italic\"]\):-\\n If A  =\>\"", ",", \(A = {3. , 1. , 1. , 2. }\),
           ",", "\"\<and B =\>\"", ",", \(B = {4. , 7. , 2. , 3. }\), ",", 
          "\"\<\\nmultiplication \!\(\*
StyleBox[\"gives\",\nFontSlant->\"Plain\"]\) \\n AB =\>\"", 
          ",", \(AB = hoopTimes[A, B]\), ",", "\[IndentingNewLine]", 
          "\"\<\\nThis 'folds' to the product of 3-1 + \
(1-2)\[ImaginaryI]\\nand 4-2 + (7-3)\[ImaginaryI] to give 31-23 + (32-26)\
\[ImaginaryI],\\ni.e. (2-\[ImaginaryI])(2+4\[ImaginaryI])=\>\"", " ", 
          ",", \(\((2 - \[ImaginaryI])\) \((2 + 4  \[ImaginaryI])\)\), ",", 
          "\"\<\\n\\nDivision using \!\(\*
StyleBox[\"hoopInverse\",\nFontWeight->\"Plain\",\nFontSlant->\"Italic\"]\):-\
\\nThe inverse of A is\>\"", ",", \(Ainv = hoopInverse[{3, 1, 1, 2}]\), ",", 
          "\"\<\\nAinv.A is the unit\>\"", ",", \(hoopTimes[Ainv, A]\), ",", 
          "\"\<\\nand Ainv.AB recovers B\>\"", 
          ",", \(Simplify[hoopTimes[Ainv, AB]]\), ",", 
          "\"\<\\n\\nPowers and Roots:-\\nhoopPower\!\(\*
StyleBox[\"[\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"A\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"3\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"]\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\"gives\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\"the\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\"cube\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\",\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\) \\nA3=\>\"", 
          ",", \(A3 = hoopPower[A, 3]\), ",", 
          "\"\<which folds to (2-\[ImaginaryI])^3=\>\"", 
          ",", \(\((2 - \[ImaginaryI])\)^3\), ",", "\"\<\\n\!\(\*
StyleBox[\"hoopPower\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"[\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"A3\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"2\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"/\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"3\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"]\",\nFontSlant->\"Italic\"]\) gives the 2/3 power of A3\>\"", 
          ",", \(hoopPower[A3, 2/3]\), ",", 
          "\"\<which folds to 3 - 4i and matches the repeated product AA\>\"",
           ",", \(AA = hoopPower[A, 2]\), ",", 
          "\"\<\\nA^3 is the same as the repeated product AAA\>\"", 
          ",", \(AAA = hoopTimes[A, hoopTimes[A, A]]\)}], "}"}]}]], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 4. C4 folds to Complex algebra.\\nThe table \"\>", 
        ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4"},
                  {"2", "3", "4", "1"},
                  {"3", "4", "1", "2"},
                  {"4", "1", "2", "3"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"can be written as\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "i", \(-1\), \(-i\)},
                  {"i", \(-1\), \(-i\), "1"},
                  {\(-1\), \(-i\), "1", "i"},
                  {\(-i\), "1", "i", \(-1\)}
                  }], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], 
        ",", "\<\"\\nMultiplication using\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontWeight->\\\"Plain\\\"]\\)\\!\\(\\* \
StyleBox[\\\"hoopTimes\\\",\\nFontWeight->\\\"Plain\\\",\\nFontSlant->\\\"\
Italic\\\"]\\):-\\n If A  =\"\>", ",", \({3.`, 1.`, 1.`, 2.`}\), 
        ",", "\<\"and B =\"\>", ",", \({4.`, 7.`, 2.`, 3.`}\), 
        ",", "\<\"\\nmultiplication \\!\\(\\* \
StyleBox[\\\"gives\\\",\\nFontSlant->\\\"Plain\\\"]\\) \\n AB =\"\>", 
        ",", \({31.`, 32.`, 23.`, 26.`}\), 
        ",", "\<\"\\nThis 'folds' to the product of 3-1 + \
(1-2)\[ImaginaryI]\\nand 4-2 + (7-3)\[ImaginaryI] to give 31-23 + (32-26)\
\[ImaginaryI],\\ni.e. (2-\[ImaginaryI])(2+4\[ImaginaryI])=\"\>", 
        ",", \(8 + 6\ \[ImaginaryI]\), 
        ",", "\<\"\\n\\nDivision using \\!\\(\\* \
StyleBox[\\\"hoopInverse\\\",\\nFontWeight->\\\"Plain\\\",\\nFontSlant->\\\"\
Italic\\\"]\\):-\\nThe inverse of A is\"\>", 
        ",", \({17\/35, \(-\(4\/35\)\), 3\/35, \(-\(11\/35\)\)}\), 
        ",", "\<\"\\nAinv.A is the unit\"\>", 
        ",", \({0.9999999999999998`, 0.`, 0.`, 0.`}\), 
        ",", "\<\"\\nand Ainv.AB recovers B\"\>", 
        ",", \({4.`, 6.999999999999999`, 2.`, 3.0000000000000018`}\), 
        ",", "\<\"\\n\\nPowers and Roots:-\\nhoopPower\\!\\(\\* \
StyleBox[\\\"[\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"A\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"3\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"]\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \\\
\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* \
StyleBox[\\\"gives\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* \
StyleBox[\\\"the\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* \
StyleBox[\\\"cube\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* StyleBox[\\\",\
\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\\) \\nA3=\"\>", 
        ",", \({87.`, 80.`, 85.`, 91.`}\), 
        ",", "\<\"which folds to (2-\[ImaginaryI])^3=\"\>", 
        ",", \(2 - 11\ \[ImaginaryI]\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"hoopPower\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"[\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"A3\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"2\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"/\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"3\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"]\\\",\\nFontSlant->\\\"Italic\\\"]\\) gives the 2/3 power of A3\
\"\>", ",", \({13.999999999999996`, 9.999999999999996`, 10.999999999999996`, 
          13.999999999999996`}\), 
        ",", "\<\"which folds to 3 - 4i and matches the repeated product AA\"\
\>", ",", \({14.`, 10.`, 11.`, 14.`}\), 
        ",", "\<\"\\nA^3 is the same as the repeated product AAA\"\>", 
        ",", \({87.`, 80.`, 85.`, 91.`}\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.4 Powers & repeated products may differ.", "Subsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tExample 4 checked whether ",
  Cell[BoxData[
      \(TraditionalForm\`A\^2\)]],
  " = ",
  StyleBox["AA",
    FontSlant->"Italic"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`A\^3\)]],
  " = ",
  StyleBox["AAA",
    FontSlant->"Italic"],
  ". Powers and repeated products may differ for two reasons, negative sizes \
and \"angle wrap-round\". If a size is negative for A it alternates in sign \
for repeated products but the power should be a continuous function of the \
exponent, as in Example 5."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(Use["\<C4\>"]\), ";", 
      RowBox[{"{", 
        RowBox[{
        "\"\<Example 5. C4 with negative size., so AA differs from A^2\\nIf A \
 =\>\"", ",", \(A = {1. , 1. , \(-1. \), 0. }\), ",", "\[IndentingNewLine]", 
          "\"\< with shape \>\"", ",", \(sh /. as[A]\), ",", "\"\<\\n\!\(\*
StyleBox[\"hoopPower\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"[\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"A\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"3\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"]\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\"gives\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\"the\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\"cube\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\",\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\\\ \)]\)A3= \>\"", 
          ",", \(A3 = hoopPower[A, 3]\), ",", 
          "\"\<\\nwhich folds to 2+11i.\\n\!\(\*
StyleBox[\"hoopPower\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"[\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"A3\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"2\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"/\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"3\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"]\",\nFontSlant->\"Italic\"]\) gives the 2/3 power of A3\>\"", 
          ",", \(hoopPower[A3, 2/3]\), ",", 
          "\"\<\\nwhich folds to 3+4i and matches A^2\>\"", 
          ",", \(A2 = hoopPower[A, 2]\), ",", "\[IndentingNewLine]", 
          "\"\<\\nwith shape\>\"", ",", \(sh /. as[A2]\), ",", 
          "\"\<\\nwhilst the repeated product AA\>\"", 
          ",", \(AA = hoopTimes[\ A, A]\), ",", "\[IndentingNewLine]", 
          "\"\<\\nhas the second size positive\>\"", ",", \(sh /. as[AA]\), 
          ",", "\"\<\\nA^3 is the same as the repeated product AAA\>\"", 
          ",", \(AAA = hoopTimes[A, hoopTimes[A, A]]\), ",", 
          "\"\<\\nThe second size of A^2 is negative, of AA is \
positive:-\\nPolar A   =\>\"", ",", \(topol /. \ as[A]\), ",", 
          "\"\<\\nPolar A^2 =\>\"", ",", \(topol /. \ as[A2]\), ",", 
          "\"\<\\nPolar AA  =\>\"", ",", \(topol /. \ as[AA]\), ",", 
          "\"\<\\nPolar AAA =\>\"", ",", \(topol /. \ as[A3]\), ",", 
          "\"\<\\n\\n  A^1.99\>\"", ",", \(hoopPower[A, 1.99]\), ",", 
          "\"\<\\n& A^2.01\>\"", ",", \(hoopPower[A, 2.01]\), ",", 
          "\"\<\\n  bracket A^2\\nwhilst AA =\>\"", ",", "AA"}], 
        "}"}]}]], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 5. C4 with negative size., so AA differs from \
A^2\\nIf A  =\"\>", ",", \({1.`, 1.`, \(-1.`\), 0.`}\), 
        ",", "\<\" with shape \"\>", ",", \({1.`, \(-1.`\), 5.`}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"hoopPower\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"[\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"A\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"3\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"]\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \\\
\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* \
StyleBox[\\\"gives\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* \
StyleBox[\\\"the\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* \
StyleBox[\\\"cube\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* StyleBox[\\\",\
\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* StyleBox[\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\\\\ \\)]\\)A3= \"\>", 
        ",", \({1.0000000000000007`, 
          6.`, \(-1.0000000000000007`\), \(-5.`\)}\), 
        ",", "\<\"\\nwhich folds to 2+11i.\\n\\!\\(\\* StyleBox[\\\"hoopPower\
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"[\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"A3\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"2\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"/\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"3\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"]\\\",\\nFontSlant->\\\"Italic\\\"]\\) gives the 2/3 power of A3\
\"\>", ",", \({1.5`, 
          2.4999999999999996`, \(-1.5`\), \(-1.4999999999999996`\)}\), 
        ",", "\<\"\\nwhich folds to 3+4i and matches A^2\"\>", 
        ",", \({1.5000000000000002`, 
          2.5`, \(-1.5000000000000002`\), \(-1.4999999999999998`\)}\), 
        ",", "\<\"\\nwith shape\"\>", 
        ",", \({1.0000000000000002`, \(-1.0000000000000002`\), 
          25.000000000000004`}\), 
        ",", "\<\"\\nwhilst the repeated product AA\"\>", 
        ",", \({2.`, 2.`, \(-1.`\), \(-2.`\)}\), 
        ",", "\<\"\\nhas the second size positive\"\>", 
        ",", \({1.`, 1.`, 25.`}\), 
        ",", "\<\"\\nA^3 is the same as the repeated product AAA\"\>", 
        ",", \({1.`, 6.`, \(-1.`\), \(-5.`\)}\), 
        ",", "\<\"\\nThe second size of A^2 is negative, of AA is \
positive:-\\nPolar A   =\"\>", 
        ",", \({1.`, \(-1.`\), 5.`, 0.4636476090008061`}\), 
        ",", "\<\"\\nPolar A^2 =\"\>", 
        ",", \({1.0000000000000002`, \(-1.0000000000000002`\), 
          25.000000000000004`, 0.9272952180016122`}\), 
        ",", "\<\"\\nPolar AA  =\"\>", 
        ",", \({1.`, 1.`, 25.`, 0.9272952180016122`}\), 
        ",", "\<\"\\nPolar AAA =\"\>", 
        ",", \({1.`, \(-1.`\), 125.`, 1.3909428270024182`}\), 
        ",", "\<\"\\n\\n  A^1.99\"\>", 
        ",", \({1.4971602576129839`, 
          2.4770499321073896`, \(-1.4971602576129839`\), \
\(-1.4770499321073898`\)}\), ",", "\<\"\\n& A^2.01\"\>", 
        ",", \({1.5027553889648462`, 
          2.5231485205881197`, \(-1.5027553889648462`\), \
\(-1.5231485205881197`\)}\), ",", "\<\"\\n  bracket A^2\\nwhilst AA =\"\>", 
        ",", \({2.`, 2.`, \(-1.`\), \(-2.`\)}\)}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
\tIf a polar-form angle parameter is large, raising to a power (which \
multiplies the angle by the exponent) may give an angle greater than 2\[Pi]. \
This will become a negative angle and the roots will be rotated. Their sizes \
will be correct. (Taking roots makes the angle parameter smaller, and so \
cannot cause wrap-round.)\
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(Use["\<C4\>"]\), ";", 
      RowBox[{"{", 
        RowBox[{
        "\"\<Example 6. C4 with large angle. (A^3)^(1/3) differs from A.\\nIf \
A  =\>\"", ",", \(A = {2. , 2. , 1. , 0. }\), ",", 
          "\"\<which folds to 1+2i\\n\!\(\*
StyleBox[\"hoopPower\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"[\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"A\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"3\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"]\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\"gives\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\"the\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\"cube\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\",\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\) A3= \>\"", 
          ",", \(A3 = hoopPower[A, 3]\), ",", 
          "\"\<\\nwhich folds to -11-2i\\n\!\(\*
StyleBox[\"hoopPower\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"[\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"A3\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"1\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"/\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"3\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"]\",\nFontSlant->\"Italic\"]\) gives rA3, the 1/3 power of A3\>\"",
           ",", \(rA3 = hoopPower[A3, 1/3]\), ",", 
          "\"\<\\nwhich folds to 1.232-1.866i (which cubes correctly)\\nrA3 \
differs from A, but has the same sizes\>\"", ",", 
          "\"\<\\nThe angle of A^3 exceeds 2Pi and so is negated:-\\nPolar A  \
 =\>\"", ",", \(topol /. \ as[A]\), ",", "\"\<\\nPolar AAA =\>\"", 
          ",", \(topol /. \ as[A3]\), ",", "\"\<\\nPolar rA3 =\>\"", 
          ",", \(topol /. \ as[rA3]\)}], "}"}]}]], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 6. C4 with large angle. (A^3)^(1/3) differs from \
A.\\nIf A  =\"\>", ",", \({2.`, 2.`, 1.`, 0.`}\), 
        ",", "\<\"which folds to 1+2i\\n\\!\\(\\* StyleBox[\\\"hoopPower\\\",\
\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"[\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"A\\\",\\nFontSlant->\\\"Italic\\\"]\\)\
\\!\\(\\* StyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"3\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"]\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* \
StyleBox[\\\"gives\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* \
StyleBox[\\\"the\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* \
StyleBox[\\\"cube\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* StyleBox[\\\",\
\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\\) A3= \"\>", 
        ",", \({26.`, 30.`, 37.`, 32.`}\), 
        ",", "\<\"\\nwhich folds to -11-2i\\n\\!\\(\\* StyleBox[\\\"hoopPower\
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"[\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"A3\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"1\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"/\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"3\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"]\\\",\\nFontSlant->\\\"Italic\\\"]\\) gives rA3, the 1/3 power \
of A3\"\>", 
        ",", \({2.1160254037844384`, 0.0669872981077807`, 
          0.8839745962155612`, 1.9330127018922187`}\), 
        ",", "\<\"\\nwhich folds to 1.232-1.866i (which cubes \
correctly)\\nrA3 differs from A, but has the same sizes\"\>", 
        ",", "\<\"\\nThe angle of A^3 exceeds 2Pi and so is negated:-\\nPolar \
A   =\"\>", ",", \({5.`, 1.`, 5.`, 1.1071487177940904`}\), 
        ",", "\<\"\\nPolar AAA =\"\>", 
        ",", \({125.`, 1.`, 125.`, \(-2.961739153797315`\)}\), 
        ",", "\<\"\\nPolar rA3 =\"\>", 
        ",", \({4.999999999999999`, 1.`, 
          4.9999999999999964`, \(-0.9872463845991049`\)}\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.5 Signed Tables, Generalized Signs.", "Subsection",
  PageWidth->PaperWidth],

Cell[TextData[{
  "\tMany Hoops are \"signed tables\" with signed products in the body of the \
multiplication table, but the elements are unsigned (unlike the second table \
in Example 4, where two elements are \"labeled\" -1 & -i). As these products \
are not members of the defining set, such tables are not loops. Signed tables \
are equivalence relations, folded from unsigned Moufang loops with ",
  StyleBox["r",
    FontSlant->"Italic"],
  "-fold symmetry. The commonest cases involve negation, where ",
  StyleBox["r",
    FontSlant->"Italic"],
  " = 2 and ",
  "the signed table is obtained from the top left quarter of the Moufang \
loop. Complex algebra is the \"C4c\" hoop, folded from C4. Compare the \
following table with the 2\[Cross]2 quarter-tables in Example 4. Index 3 \
becomes -1, corresponding to index 2 becoming ",
  StyleBox["i",
    FontWeight->"Bold"],
  " with ",
  StyleBox["i.i =",
    FontWeight->"Bold"],
  "-1. Example 7 is equivalent to the complex multiplication (3+1 ",
  StyleBox["i",
    FontWeight->"Bold"],
  ")(x+y ",
  StyleBox["i",
    FontWeight->"Bold"],
  ") = (3x-y)+",
  StyleBox["i",
    FontWeight->"Bold"],
  "(x+3y)."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(Use["\<C4c\>"]; {"\<Example 7. C4c multiplication & division is Complex \
Algebra\>", "\<\nThe table is\>", hoopTbl // tf, "\<\nA  = \>", 
      A = {3, 1}, "\<\nB  = \>", B = {x, y}, "\<\nAB = \>", 
      AB = hoopTimes[A, B], "\<\nAinv = \>", 
      Ainv = hoopInverse[A], "\<\nAinv.AB = B \>", 
      Simplify[hoopTimes[hoopInverse[A], 
          AB]], "\<\nComplex AB (3+\[ImaginaryI])(x+\[ImaginaryI]y) = (3x-y) \
+ \[ImaginaryI](x+3y)\>"}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 7. C4c multiplication & division is Complex \
Algebra\"\>", ",", "\<\"\\nThe table is\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2"},
                  {"2", \(-1\)}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nA  = \"\>", ",", \({3, 1}\), 
        ",", "\<\"\\nB  = \"\>", ",", \({x, y}\), ",", "\<\"\\nAB = \"\>", 
        ",", \({3\ x - y, x + 3\ y}\), ",", "\<\"\\nAinv = \"\>", 
        ",", \({3\/10, \(-\(1\/10\)\)}\), ",", "\<\"\\nAinv.AB = B \"\>", 
        ",", \({x, y}\), 
        ",", "\<\"\\nComplex AB (3+\[ImaginaryI])(x+\[ImaginaryI]y) = (3x-y) \
+ \[ImaginaryI](x+3y)\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
\tThe Davenport Algebra is another signed table. It is folded from the \
following C4C2 isomorph, with 5\[RightArrow]-1, 6\[RightArrow]-2, 7\
\[RightArrow]-3:-\
\>", "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "2", "3", "4", "5", "6", "7", "8"},
            {"2", "5", "4", "7", "6", "1", "8", "3"},
            {"3", "4", "5", "6", "7", "8", "1", "2"},
            {"4", "7", "6", "1", "8", "3", "2", "5"},
            {"5", "6", "7", "8", "1", "2", "3", "4"},
            {"6", "1", "8", "3", "2", "5", "4", "7"},
            {"7", "8", "1", "2", "3", "4", "5", "6"},
            {"8", "3", "2", "5", "4", "7", "6", "1"}
            },
          ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(Use["\<Dav\>"]; {"\<Example 8.  Dav division\>", "\<\nThe table is \>", 
      hoopTbl // tf, "\<\nA=  \>", A = {3, 4, 6, 1}, "\<\nB=  \>", 
      B = {w, x, y, z}, "\<\nAB =\>", 
      AB = hoopTimes[A, B], "\<\nAinv = \>", \[IndentingNewLine]hoopInverse[
        A], "\<\nAinv.AB = B \>", \n
      Simplify[hoopTimes[hoopInverse[A], AB]]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 8.  Dav division\"\>", 
        ",", "\<\"\\nThe table is \"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4"},
                  {"2", \(-1\), "4", \(-3\)},
                  {"3", "4", \(-1\), \(-2\)},
                  {"4", \(-3\), \(-2\), "1"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nA=  \"\>", ",", \({3, 4, 6, 1}\), 
        ",", "\<\"\\nB=  \"\>", ",", \({w, x, y, z}\), ",", "\<\"\\nAB =\"\>",
         ",", \({3\ w - 4\ x - 6\ y + z, 4\ w + 3\ x - y - 6\ z, 
          6\ w - x + 3\ y - 4\ z, w + 6\ x + 4\ y + 3\ z}\), 
        ",", "\<\"\\nAinv = \"\>", 
        ",", \({57\/520, 1\/520, \(-\(51\/520\)\), 47\/520}\), 
        ",", "\<\"\\nAinv.AB = B \"\>", ",", \({w, x, y, z}\)}], 
      "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tSome hoops have complex products, with ",
  StyleBox["i",
    FontWeight->"Bold"],
  " occurring in the body of the multiplication table. The g2401c algebra has \
6 elements; it is \"4-folded\" from the group g2401, i.e. the first group \
with 24 elements in the GAP Atlas (not shown):-"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(Use["\<g2401c\>"]; {"\<Example 9. g2401c division\n\>", "\<The table is \
\>", hoopTbl // tf, "\<\nA= \>", A = {3, 4, 6, 1, 2, 7}, "\<\nB= \>", 
      B = {u, v, w, x, y, z}, "\<\nAB = \>", 
      AB = hoopTimes[A, B], "\<\nAinv = \>", \[IndentingNewLine]hoopInverse[
        A], "\<\nAinv.AB = B \>", \n
      Simplify[hoopTimes[hoopInverse[A], AB]]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 9. g2401c division\\n\"\>", 
        ",", "\<\"The table is \"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4", "5", "6"},
                  {"2", "3", "1", "6", "4", "5"},
                  {"3", "1", "2", "5", "6", "4"},
                  {"4", "5", "6", 
                    "\[ImaginaryI]", \(2\ \[ImaginaryI]\), \(3\ \[ImaginaryI]\
\)},
                  {"5", "6", "4", \(3\ \[ImaginaryI]\), 
                    "\[ImaginaryI]", \(2\ \[ImaginaryI]\)},
                  {"6", "4", "5", \(2\ \[ImaginaryI]\), \(3\ \[ImaginaryI]\), 
                    "\[ImaginaryI]"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nA= \"\>", ",", \({3, 4, 6, 1, 2, 7}\),
         ",", "\<\"\\nB= \"\>", ",", \({u, v, w, x, y, z}\), 
        ",", "\<\"\\nAB = \"\>", 
        ",", \({3\ u + 6\ v + 4\ w + \[ImaginaryI]\ x + 2\ \[ImaginaryI]\ y + 
            7\ \[ImaginaryI]\ z, 
          4\ u + 3\ v + 6\ w + 7\ \[ImaginaryI]\ x + \[ImaginaryI]\ y + 
            2\ \[ImaginaryI]\ z, 
          6\ u + 4\ v + 3\ w + 2\ \[ImaginaryI]\ x + 
            7\ \[ImaginaryI]\ y + \[ImaginaryI]\ z, 
          u + 7\ v + 2\ w + 3\ x + 4\ y + 6\ z, 
          2\ u + v + 7\ w + 6\ x + 3\ y + 4\ z, 
          7\ u + 2\ v + w + 4\ x + 6\ y + 3\ z}\), ",", "\<\"\\nAinv = \"\>", 
        ",", \({189877\/19473305 - \(578094\ \[ImaginaryI]\)\/19473305, 
          237907\/7789322 + \(485997\ \[ImaginaryI]\)\/7789322, 
          649681\/38946610 + \(39203\ \[ImaginaryI]\)\/38946610, 
          60863\/38946610 + \(2452579\ \[ImaginaryI]\)\/38946610, \(-\(104532\
\/19473305\)\) + \(628594\ \[ImaginaryI]\)\/19473305, \
\(-\(1558699\/38946610\)\) - \(4719767\ \[ImaginaryI]\)\/38946610}\), 
        ",", "\<\"\\nAinv.AB = B \"\>", ",", \({u, v, w, x, y, z}\)}], 
      "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "A few hoops have ",
  StyleBox["J ",
    FontSlant->"Italic"],
  "& ",
  Cell[BoxData[
      \(TraditionalForm\`J\^2\)]],
  " (primitive cube roots of 1) as signs. \"C9J\" is 3-folded from the \
following C9 isomorph by 9\[RightArrow]",
  Cell[BoxData[
      \(TraditionalForm\`J\^2\)]],
  "3, 5\[RightArrow] ",
  StyleBox["J",
    FontSlant->"Italic"],
  " 2:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "2", "3", "4", "5", "6", "7", "8", "9"},
            {"2", "9", "1", "5", "3", "4", "8", "6", "7"},
            {"3", "1", "5", "6", "4", "8", "9", "7", "2"},
            {"4", "5", "6", "7", "8", "9", "1", "2", "3"},
            {"5", "3", "4", "8", "6", "7", "2", "9", "1"},
            {"6", "4", "8", "9", "7", "2", "3", "1", "5"},
            {"7", "8", "9", "1", "2", "3", "4", "5", "6"},
            {"8", "6", "7", "2", "9", "1", "5", "3", "4"},
            {"9", "7", "2", "3", "1", "5", "6", "4", "8"}
            },
          ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Input",
  Editable->False,
  PageWidth->PaperWidth,
  Evaluatable->False,
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],

Cell[TextData[{
  "Results need extensive simplification, using the rule ",
  StyleBox["js",
    FontSlant->"Italic"],
  ", i.e. ",
  StyleBox["J",
    FontSlant->"Italic"],
  "^any_\[RightArrow]",
  StyleBox["J",
    FontSlant->"Italic"],
  "^Mod[any,3]:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(Use["\<C9j\>"]; {"\<Example 10. C9j division.\n\>", "\<The table is \
\>", hoopTbl // tf, "\<\n A= \>", A = {3, 4, 6}, "\<\n B= \>", 
      B = {x, y, z}, "\<\nAB =\>", 
      AB = hoopTimes[A, B], "\<\nAinv = \>", \[IndentingNewLine]hoopInverse[
        A], "\<\nAinv.AB unsimplified \>", 
      hoopTimes[hoopInverse[A], AB], "\<\nSimplified Ainv.AB = B \>", \n
      Simplify[Simplify[hoopTimes[hoopInverse[A], AB]] //. js]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 10. C9j division.\\n\"\>", 
        ",", "\<\"The table is \"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3"},
                  {"2", \(3\ J\^2\), "1"},
                  {"3", "1", \(2\ J\)}
                  }], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\n A= \"\>", ",", \({3, 4, 6}\), 
        ",", "\<\"\\n B= \"\>", ",", \({x, y, z}\), ",", "\<\"\\nAB =\"\>", 
        ",", \({3\ x + 6\ y + 4\ z, 4\ x + 3\ y + 6\ J\ z, 
          6\ x + 4\ J\^2\ y + 3\ z}\), ",", "\<\"\\nAinv = \"\>", 
        ",", \({\(-\(15\/\(\(-189\) + 216\ J + 
                  64\ J\^2\)\)\), \(12\ \((\(-1\) + 3\ J)\)\)\/\(\(-189\) + \
216\ J + 64\ J\^2\), \(2\ \((\(-9\) + 8\ J\^2)\)\)\/\(\(-189\) + 216\ J + 64\ \
J\^2\)}\), ",", "\<\"\\nAinv.AB unsimplified \"\>", 
        ",", \({\(12\ \((\(-1\) + 3\ J)\)\ \((6\ x + 4\ J\^2\ y + 3\ z)\)\)\/\
\(\(-189\) + 216\ J + 64\ J\^2\) - \(15\ \((3\ x + 6\ y + 4\ z)\)\)\/\(\(-189\
\) + 216\ J + 64\ J\^2\) + \(2\ \((\(-9\) + 8\ J\^2)\)\ \((4\ x + 3\ y + 6\ J\
\ z)\)\)\/\(\(-189\) + 216\ J + 64\ J\^2\), \(2\ J\ \((\(-9\) + 8\ J\^2)\)\ \
\((6\ x + 4\ J\^2\ y + 3\ z)\)\)\/\(\(-189\) + 216\ J + 64\ J\^2\) + \(12\ \
\((\(-1\) + 3\ J)\)\ \((3\ x + 6\ y + 4\ z)\)\)\/\(\(-189\) + 216\ J + 64\ \
J\^2\) - \(15\ \((4\ x + 3\ y + 6\ J\ z)\)\)\/\(\(-189\) + 216\ J + 64\ \
J\^2\), \(-\(\(15\ \((6\ x + 4\ J\^2\ y + 3\ z)\)\)\/\(\(-189\) + 216\ J + 
                    64\ J\^2\)\)\) + \(2\ \((\(-9\) + 8\ J\^2)\)\ \((3\ x + 6\
\ y + 4\ z)\)\)\/\(\(-189\) + 216\ J + 64\ J\^2\) + \(12\ J\^2\ \((\(-1\) + 3\
\ J)\)\ \((4\ x + 3\ y + 6\ J\ z)\)\)\/\(\(-189\) + 216\ J + 64\ J\^2\)}\), 
        ",", "\<\"\\nSimplified Ainv.AB = B \"\>", ",", \({x, y, z}\)}], 
      "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "\t",
  StyleBox["J",
    FontSlant->"Italic"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`J\^2\)]],
  " are the only \"generalized signs\" used in this document; the ",
  StyleBox["Hoops.m ",
    FontSlant->"Italic"],
  "package includes instructions that make ",
  StyleBox["J",
    FontSlant->"Italic"],
  " behave as a sign. Other generalized signs are developed in a similar way \
in [2], as powers of primitive roots of unity."
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.6 Non-Abelian Hoops, Left & Right Inverses.", "Subsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tSo far all the examples (except g2401c) have used Abelian (commutative) \
hoops. The D3 algebra and the Clifford(2,1) algebra \"CL21\" are non-Abelian, \
and so AB differs from BA.\n\t",
  StyleBox["hoopInverse",
    FontSlant->"Italic"],
  " calculates a left inverse, so Ainv.AB divides AB by A, recovering B. \
Similarly Binv.BA recovers A, whilst BA.Ainv recovers B because A is the left \
inverse of Ainv."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \({"\<Example 11. D3 & CL21 Left and Right division\n\>", 
      Use["\<D3\>"]; "\<The D3 table is\>", hoopTbl // tf, "\<\nA= \>", 
      A = {3, 4, 6, 1, 2, 7}, "\<\nB= \>", 
      B = {4, \(-1\), 2, 2, 5, 3}, "\<\nAB = \>", 
      AB = hoopTimes[A, B], "\<\nAinv = \>", \[IndentingNewLine]Ainv = 
        hoopInverse[A], "\<\nAinv.AB = B \>", \n
      Simplify[hoopTimes[Ainv, AB]], \[IndentingNewLine]"\<\nBA = \>", 
      BA = hoopTimes[B, A], "\<\nBinv.BA = A \>", \n
      Simplify[hoopTimes[hoopInverse[B], BA]], "\<\nBA.Ainv = B \>", \n
      Simplify[hoopTimes[BA, Ainv, 
          AB]], \[IndentingNewLine]Use["\<CL21\>"]; "\<The CL21 table is\>", 
      hoopTbl // tf, "\<\nA= \>", A = {3, 4, 6, 1, 2, 7, 2, 1}, "\<\nB= \>", 
      B = {4, \(-1\), 2, 2, 5, 3, 2, \(-3\)}, "\<\nAB = \>", 
      AB = hoopTimes[A, B], "\<\nAinv = \>", \[IndentingNewLine]Ainv = 
        hoopInverse[A], "\<\nAinv.AB = B \>", \n
      Simplify[hoopTimes[Ainv, AB]], \[IndentingNewLine]"\<\nBA = \>", 
      BA = hoopTimes[B, A], "\<\nBinv.BA = A \>", \n
      Simplify[hoopTimes[hoopInverse[B], BA]], "\<\nBA.Ainv = B \>", \n
      Simplify[hoopTimes[BA, Ainv, AB]]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 11. D3 & CL21 Left and Right division\\n\"\>", 
        ",", "\<\"The D3 table is\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4", "5", "6"},
                  {"2", "1", "6", "5", "4", "3"},
                  {"3", "4", "5", "6", "1", "2"},
                  {"4", "3", "2", "1", "6", "5"},
                  {"5", "6", "1", "2", "3", "4"},
                  {"6", "5", "4", "3", "2", "1"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nA= \"\>", ",", \({3, 4, 6, 1, 2, 7}\),
         ",", "\<\"\\nB= \"\>", ",", \({4, \(-1\), 2, 2, 5, 3}\), 
        ",", "\<\"\\nAB = \"\>", ",", \({65, 72, 65, 44, 39, 60}\), 
        ",", "\<\"\\nAinv = \"\>", 
        ",", \({\(-\(18\/161\)\), 
          4\/23, \(-\(13\/322\)\), \(-\(13\/322\)\), \(-\(15\/46\)\), 
          125\/322}\), ",", "\<\"\\nAinv.AB = B \"\>", 
        ",", \({4, \(-1\), 2, 2, 5, 3}\), ",", "\<\"\\nBA = \"\>", 
        ",", \({65, 50, 44, 69, 60, 57}\), ",", "\<\"\\nBinv.BA = A \"\>", 
        ",", \({3, 4, 6, 1, 2, 7}\), ",", "\<\"\\nBA.Ainv = B \"\>", 
        ",", \({4, \(-1\), 2, 2, 5, 3}\), ",", "\<\"The CL21 table is\"\>", 
        ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4", "5", "6", "7", "8"},
                  {"2", \(-1\), "4", \(-3\), "6", \(-5\), "8", \(-7\)},
                  {"3", \(-4\), "1", \(-2\), "7", \(-8\), "5", \(-6\)},
                  {"4", "3", "2", "1", "8", "7", "6", "5"},
                  {"5", \(-6\), \(-7\), "8", "1", \(-2\), \(-3\), "4"},
                  {"6", "5", \(-8\), \(-7\), "2", "1", \(-4\), \(-3\)},
                  {"7", "8", \(-5\), \(-6\), "3", "4", \(-1\), \(-2\)},
                  {"8", \(-7\), \(-6\), "5", "4", \(-3\), \(-2\), "1"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nA= \"\>", 
        ",", \({3, 4, 6, 1, 2, 7, 2, 1}\), ",", "\<\"\\nB= \"\>", 
        ",", \({4, \(-1\), 2, 2, 5, 3, 2, \(-3\)}\), ",", "\<\"\\nAB = \"\>", 
        ",", \({54, 36, 45, 15, 11, 73, 42, \(-22\)}\), 
        ",", "\<\"\\nAinv = \"\>", 
        ",", \({5\/26, \(-\(1\/13\)\), 
          1\/10, \(-\(2\/13\)\), \(-\(19\/130\)\), 0, 8\/65, 27\/130}\), 
        ",", "\<\"\\nAinv.AB = B \"\>", 
        ",", \({4, \(-1\), 2, 2, 5, 3, 2, \(-3\)}\), ",", "\<\"\\nBA = \"\>", 
        ",", \({54, \(-2\), 51, 3, 33, 33, 12, \(-22\)}\), 
        ",", "\<\"\\nBinv.BA = A \"\>", ",", \({3, 4, 6, 1, 2, 7, 2, 1}\), 
        ",", "\<\"\\nBA.Ainv = B \"\>", 
        ",", \({4, \(-1\), 2, 2, 5, 3, 2, \(-3\)}\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.7 Many Algebras are Hoops.", "Subsection",
  PageWidth->WindowWidth],

Cell["\<\
\tExample 12 shows that traditional vector dot & cross products are hoop \
multiplications where only the \"univectors\" are multiplied i.e. the scalar \
and multivector elements of the multiplicands are kept at zero. (I use \
\"univectors\" where many authors confusingly use \"vectors\" or \"scalars\" \
for single element generators. Their products are bivectors, trivectors, \
etc.) The symbols are chosen to match those in [5, p11] for quaternions (Qr) \
and CL2, and to match [5, p37] for octonions (Octr) and CL3.\
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`{Use["\<Qr\>"]; \*"\"\<Example 12. Dot & Cross \
products with Qr & \
Octr.\\n{0,\!\(e\_1\),\!\(e\_2\),0}\[Times]{0,\!\(u\_1\),\!\(u\_2\),0} \
gives\\n   Qr Scalar       & Dot products\\n\>\"", 
      hoopTimes[{0, e\_1, e\_2, 0}, {0, u\_1, u\_2, 
          0}], \[IndentingNewLine]Use["\<Octr\>"]; \*"\"\<\\n\\nOctr  \
{0,\!\(a\_1\),\!\(a\_2\),0,\!\(a\_3\),0,0,0}\[Times]{0,\!\(b\_1\),\!\(b\_2\),\
0,\!\(b\_3\),0,0,0}=\>\"", \ 
      hoopTimes[{0, a\_1, a\_2, 0, a\_3, 0, 0, 0}, {0, b\_1, b\_2, 0, b\_3, 
          0, 0, 0}]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"Example 12. Dot & Cross products with Qr & Octr.\n{0,\!\(e\_1\),\!\(e\
\_2\),0}\[Times]{0,\!\(u\_1\),\!\(u\_2\),0} gives\n   Qr Scalar       & Dot \
products\n", {\(-e\_1\)\ u\_1 - e\_2\ u\_2, 0, 
        0, \(-e\_2\)\ u\_1 + e\_1\ u\_2}, 
      "\n\nOctr  {0,\!\(a\_1\),\!\(a\_2\),0,\!\(a\_3\),0,0,0}\[Times]{0,\!\(b\
\_1\),\!\(b\_2\),0,\!\(b\_3\),0,0,0}=", {\(-a\_1\)\ b\_1 - a\_2\ b\_2 - 
          a\_3\ b\_3, 0, 0, \(-a\_2\)\ b\_1 + a\_1\ b\_2, 
        0, \(-a\_3\)\ b\_1 + a\_1\ b\_3, \(-a\_3\)\ b\_2 + a\_2\ b\_3, 
        0}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tIn both cases the first element of the result is the scalar product (up \
to a sign), whilst the univectors (and octonion trivector) in the product are \
zero. The Qr trivector element ",
  Cell[BoxData[
      \(TraditionalForm\`\(e\_2\) u\_1 - \(e\_1\) u\_2\)]],
  " is the 2D cross product, and Octc gives the (negated) 3D scalar product \
",
  Cell[BoxData[
      StyleBox[\(a\_1\ b\_1 + a\_2\ b\_2 + a\_3\ b\_3\),
        FontFamily->"Times New Roman",
        FontSlant->"Italic",
        FontVariations->{"CompatibilityType"->0}]]],
  " together with elements that add to give the vector cross product  {",
  Cell[BoxData[
      \(TraditionalForm\`\((\(-a\_2\)\ b\_1 + a\_1\ b\_2)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(e\_1\) e\_2\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\((\(-a\_3\)\ b\_1 + a\_1\ b\_3)\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(e\_1\) e\_3\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(-a\_3\)\ b\_2 + a\_2\ b\_3)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(e\_2\) e\_3\)]],
  "}. \n(The bivector ",
  Cell[BoxData[
      \(TraditionalForm\`\(e\_1\) e\_2\)]],
  " is the 4th element basis direction, etc., having coefficient 0 in the \
multiplicands). "
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tAll Clifford algebras are hoops. Their tables are created in [2] by \
using the procedure ",
  StyleBox["cl",
    FontSlant->"Italic"],
  " or by folding a specific group isomorph. Wedge (exterior) algebras are \
the bivector part of the Clifford product ([5] p.10). They multiply \
univectors using Clifford algebra rules; the scalars and multivectors are \
kept at zero in the multiplicands so various products are zero (i.e. these \
are Grassmann algebras). Multiplying univectors ",
  Cell[BoxData[
      \(TraditionalForm\`u\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`u\_2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`v\_2\)]],
  " in CL2 gives a scalar ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_1\) v\_1 - \(u\_2\) v\_2\)]],
  " and a bivector ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_1\) v\_2 - \(u\_2\) v\_1\)]],
  "; the univectors in the product are zero. CL3 gives the wedge product of \
three univectors when the scalar and multivector terms are zero in the \
multiplicands. CL2 and CL3 univector products only differ from the quaternion \
and octonion univector products in the sign of the first term.\n\tDifferent \
16-element Clifford algebras multiply 4 univectors to give scalars and three \
bivectors with assorted signs:- "
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{\(Use["\<CL2\>"]; "\<Example 13. Wedge Products, Exterior \
Algebras. Clifford Algebras.\nCL2\>"\), 
          ",", \(hoopTimes[{0, u\_1, u\_2, 0}, {0, v\_1, v\_2, 0}]\), ",", 
          "\[IndentingNewLine]", \(Use["\<CL3\>"]; "\<\nCL3\>"\), 
          ",", \(hoopTimes[{0, u\_1, u\_2, 0, u\_3, 0, 0, 0}, {0, v\_1, v\_2, 
              0, v\_3, 0, 0, 0}]\), ",", 
          "\[IndentingNewLine]", \(Use["\<CL4\>"]; "\<\nCL4\>"\), ",", 
          
          FormBox[\(hoopTimes[{0, e\_1, e\_2, 0, e\_3, 0, 0, e\_4}, {0, u\_1, 
                u\_2, 0, u\_3, 0, 0, u\_4}]\),
            "TraditionalForm"], ",", "\n", \(Use["\<CL04\>"]; "\<\nCL04\>"\), 
          ",", 
          
          FormBox[\(hoopTimes[{0, e\_1, e\_2, 0, e\_3, 0, 0, e\_4}, {0, u\_1, 
                u\_2, 0, u\_3, 0, 0, u\_4}]\),
            "TraditionalForm"], ",", 
          "\[IndentingNewLine]", \(Use["\<CL31\>"]; "\<\nCL31\>"\), ",", 
          
          FormBox[\(hoopTimes[{0, e\_1, e\_2, 0, e\_3, 0, 0, e\_4}, {0, u\_1, 
                u\_2, 0, u\_3, 0, 0, u\_4}]\),
            "TraditionalForm"]}], "}"}], TraditionalForm]], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"Example 13. Wedge Products, Exterior Algebras. Clifford Algebras.\n\
CL2", {u\_1\ v\_1 - u\_2\ v\_2, 0, 0, \(-u\_2\)\ v\_1 + u\_1\ v\_2}, 
      "\nCL3", {u\_1\ v\_1 + u\_2\ v\_2 + u\_3\ v\_3, 0, 
        0, \(-u\_2\)\ v\_1 + u\_1\ v\_2, 
        0, \(-u\_3\)\ v\_1 + u\_1\ v\_3, \(-u\_3\)\ v\_2 + u\_2\ v\_3, 0}, 
      "\nCL4", {e\_1\ u\_1 + e\_2\ u\_2 + e\_3\ u\_3 - e\_4\ u\_4, 0, 
        0, \(-e\_2\)\ u\_1 + e\_1\ u\_2 + e\_4\ u\_3 + e\_3\ u\_4, 
        0, \(-e\_3\)\ u\_1 - e\_4\ u\_2 + e\_1\ u\_3 - e\_2\ u\_4, 
        e\_4\ u\_1 - e\_3\ u\_2 + e\_2\ u\_3 + e\_1\ u\_4, 0, 0, 0, 0, 0, 0, 
        0, 0, 0}, 
      "\nCL04", {\(-e\_1\)\ u\_1 - e\_2\ u\_2 - e\_3\ u\_3 + e\_4\ u\_4, 0, 
        0, \(-e\_2\)\ u\_1 + e\_1\ u\_2 - e\_4\ u\_3 - e\_3\ u\_4, 
        0, \(-e\_3\)\ u\_1 + e\_4\ u\_2 + e\_1\ u\_3 + 
          e\_2\ u\_4, \(-e\_4\)\ u\_1 - e\_3\ u\_2 + e\_2\ u\_3 - e\_1\ u\_4, 
        0, 0, 0, 0, 0, 0, 0, 0, 0}, 
      "\nCL31", {\(-e\_1\)\ u\_1 + e\_2\ u\_2 + e\_3\ u\_3 + e\_4\ u\_4, 0, 
        0, \(-e\_2\)\ u\_1 + e\_1\ u\_2 + e\_4\ u\_3 + e\_3\ u\_4, 
        0, \(-e\_3\)\ u\_1 - e\_4\ u\_2 + e\_1\ u\_3 - 
          e\_2\ u\_4, \(-e\_4\)\ u\_1 - e\_3\ u\_2 + e\_2\ u\_3 - e\_1\ u\_4, 
        0, 0, 0, 0, 0, 0, 0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell["\<\
\tFinite Lie algebras appear to be Clifford hoops for which the real (scalar) \
elements have been zeroed. This has yet to be explored.
\tOther hoops define many algebras, some of which appear to be new.\
\>", "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.8 Most loops are not conservative.", "Subsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tThe majority of loops (quasigroups used as multiplication tables) are \
not conservative. The data contains a few non-conservative loops as examples, \
identified by names ending in ",
  StyleBox["n",
    FontSlant->"Italic"],
  ". The determinants of \"Q4n\" and \"C6n\" factorize nicely, but their \
quadratic factors are not conserved:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(Use["\<Q4n\>"]; {"\<Example 14. Q4n is not conservative.\n\>", "\<Q4n \
Table\>", hoopTbl // tf, "\<\nShape\>", 
      sh, \[IndentingNewLine]"\<\nA =   \>", 
      A = {4, 2, 3, 5}, \[IndentingNewLine]"\<\nB =   \>", 
      B = {1, 6, 2, 2}, \[IndentingNewLine]"\<\nAB=   \>", 
      AB = hoopTimes[A, B], "\<\nShape of A    sa =\>", 
      sa = sh /. \ as[A], "\<\nShape of B    sb =\>", 
      sb = sh /. \ as[B], "\<\nShape of AB   sab=\>", \ 
      sh /. \ as[AB], "\<\nThis is not sa*sb =\>", sa\ sb}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 14. Q4n is not conservative.\\n\"\>", 
        ",", "\<\"Q4n Table\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4"},
                  {"2", "1", "4", \(-3\)},
                  {"3", \(-4\), "1", "2"},
                  {"4", "3", \(-2\), "1"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nShape\"\>", 
        ",", \({a\^2 - b\^2 - c\^2 - d\^2, a\^2 + b\^2 + c\^2 + d\^2}\), 
        ",", "\<\"\\nA =   \"\>", ",", \({4, 2, 3, 5}\), 
        ",", "\<\"\\nB =   \"\>", ",", \({1, 6, 2, 2}\), 
        ",", "\<\"\\nAB=   \"\>", ",", \({32, 22, 37, \(-1\)}\), 
        ",", "\<\"\\nShape of A    sa =\"\>", ",", \({\(-22\), 54}\), 
        ",", "\<\"\\nShape of B    sb =\"\>", ",", \({\(-43\), 45}\), 
        ",", "\<\"\\nShape of AB   sab=\"\>", ",", \({\(-830\), 2878}\), 
        ",", "\<\"\\nThis is not sa*sb =\"\>", ",", \({946, 2430}\)}], 
      "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Use["\<C6n\>"];\)\), "\[IndentingNewLine]", 
    \({"\<Example 15. C6n only conserves the linear factors.\n\>", "\<C6n \
Table\>", hoopTbl // tf, "\<\nShape\>", sh, "\<\n A =\>", 
      A = {4, 2, 3, 5, 1, 6}, "\<\n B =\>", 
      B = {0, 6, 2, 4, 3, 2}, "\<\nAB =              \>", 
      AB = hoopTimes[A, B], "\<\nshape of A  sa =  \>", 
      sa = sh /. \ as[A], "\<\nshape of B  sb =  \>", 
      sb = sh /. \ as[B], "\<\nshape of AB sab=  \>", 
      sab = sh /. \ as[AB], "\<\nThis is not sa*sb \>", sa\ sb}\)}], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 15. C6n only conserves the linear factors.\\n\"\>",
         ",", "\<\"C6n Table\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4", "5", "6"},
                  {"2", "3", "1", "6", "4", "5"},
                  {"3", "1", "2", "5", "6", "4"},
                  {"4", "5", "6", "2", "1", "3"},
                  {"5", "6", "4", "1", "3", "2"},
                  {"6", "4", "5", "3", "2", "1"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nShape\"\>", 
        ",", \({a + b + c - d - e - f, a + b + c + d + e + f, 
          1\/2\ \((\((a - b)\)\^2 + \((b - c)\)\^2 + \((\(-a\) + c)\)\^2 - \
\((d - e)\)\^2 - \((e - f)\)\^2 - \((\(-d\) + f)\)\^2)\), 
          1\/2\ \((\((a - b)\)\^2 + \((b - c)\)\^2 + \((\(-a\) + c)\)\^2 + \
\((d - e)\)\^2 + \((e - f)\)\^2 + \((\(-d\) + f)\)\^2)\)}\), 
        ",", "\<\"\\n A =\"\>", ",", \({4, 2, 3, 5, 1, 6}\), 
        ",", "\<\"\\n B =\"\>", ",", \({0, 6, 2, 4, 3, 2}\), 
        ",", "\<\"\\nAB =              \"\>", 
        ",", \({53, 70, 57, 66, 70, 41}\), 
        ",", "\<\"\\nshape of A  sa =  \"\>", 
        ",", \({\(-3\), 21, \(-18\), 24}\), 
        ",", "\<\"\\nshape of B  sb =  \"\>", ",", \({\(-1\), 17, 25, 31}\), 
        ",", "\<\"\\nshape of AB sab=  \"\>", 
        ",", \({3, 357, \(-504\), 978}\), 
        ",", "\<\"\\nThis is not sa*sb \"\>", 
        ",", \({3, 357, \(-450\), 744}\)}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
\tMany non-conservative loops, with various properties, have been \
investigated. The only conservative tables appear to be groups, a few \
non-commutative Moufang Loops (including octonions and split-octonions), the \
direct composition of these loops with abelian groups, and tables folded from \
conservative loops; all known conservative tables have the Moufang \
property.\
\>", "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2.9 Quadratic sizes, Abelian Polar-Vector Duals, Roots & Powers.\
\>", "Subsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tReal quadratic hoop determinant factors are conserved functions (though \
their complex-conjugate-pair factors are not conserved). They are symmetric \
real polynomials that can often be \"fragmented\", i.e. split into signed \
sums of smaller squared terms or \"fragments\". A generalisation (the \
\"PolyHelix Identity\") of ",
  Cell[BoxData[
      \(TraditionalForm\`Cos\^2\)]],
  "[\[Theta]]+",
  Cell[BoxData[
      \(TraditionalForm\`Sin\^2\)]],
  "[\[Theta]]=1 then leads to \"polar-dual\" formulations. E.g. C3 conserves \
",
  Cell[BoxData[
      \(TraditionalForm\`r\^2\)]],
  " =",
  Cell[BoxData[
      \(TraditionalForm\`a\^2\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`b\^2\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`c\^2\)]],
  StyleBox["- a b - b c - c a",
    FontSlant->"Italic"],
  " which fragments into",
  StyleBox[" ",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(TraditionalForm\`\((a - b)\)\^2\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`\((b - c)\)\^2\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`\((c - a)\)\^2\)]],
  ")/2. The associated angle is ",
  StyleBox["ArcTan[2a-b-c,-",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\@3\)],
    FontSlant->"Italic"],
  StyleBox["(b-c)]",
    FontSlant->"Italic"],
  ". (see Example 1.) Note that the \"-\" sign always occurs in squared terms \
so it corresponds to a \"symmetric difference\" that does not imply negation \
or subtraction, which only arise in hoops after 2-folding.\n\tIn effect, each \
conserved quadratic \"releases\" a degree of freedom, which is taken up by an \
angle. Angles are \"hidden variables\" for cartesian vectors. Polar-duals are \
the generalization of the {r,\[Theta]} formulation of the complex plane (or \
Argand - Wessel diagram) to other algebras. Linear sizes provide \"offsets\" \
for polar forms; these are extra degrees of freedom that are missing from \
complex algebra.\n\tAs angles add on abelian hoop multiplication, powers and \
roots can be obtained by raising sizes to the exponent and multiplying angles \
by the exponent. This is implemented by ",
  StyleBox["hoopPower",
    FontSlant->"Italic"],
  ", which converts a cartesian vector to the polar form, applies the \
exponent, and then reverts to cartesian form. It has been demonstrated in \
previous examples. Example 16 demonstrates a \"Hexal\" algebra, C3C4c, which \
is \"supersymmetric\" (see section 3) to one of the \"Dozal\" algebras, C3C4. \
These two algebras are unusual - they have sizes that involve ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\@3\)\(.\)\)\)]],
  " Note the \"If\" statements that handle specific cases in the angle \
calculations. These are essential when dealing with orbits (section 2.13); \
they are omitted (for simplicity) in most ",
  StyleBox["topol",
    FontSlant->"Italic"],
  " definitions in the data. ([2] supplies the complete versions.)"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(Use["\<C3C4c\>"]; {"\<Example 16. C3C4c Polar form and square root\nThe \
table is\>", hoopTbl // tf, "\<\nThe polar form is\>", 
      topol, "\<\nA simplified cartesian form, in terms of radii \[Epsilon],\
\[Eta],\[Kappa] and angles \[Sigma],\[Chi],\[Psi] is\n\>", \(tovec /. \ 
          as[{\[Epsilon]\^2, \[Sigma], \[Eta]\^2, \[Chi] - \[Pi]/
                  6, \[Kappa]\^2, \[Psi] - \[Pi]/6}]\) /. \@any_\^2 \[Rule] 
          6  any, "\<\nWhen A  = \>", 
      A = {6. , 2. , 4. , 3. , 1. , 1. }, "\<\nthe shape of A is \>", 
      sh /. \ as[A], "\<\nthe polar form is \>", 
      pA = topol /. \ as[A], \[IndentingNewLine]"\<tovec recovers  A \>", 
      tovec /. \ as[pA], \[IndentingNewLine]"\<\nThe square root is\>", 
      rootA = hoopPower[A], "\<\nwith polar form   \>", 
      topol /. \ as[rootA], "\<\nrootA.rootA = A   \>", 
      hoopTimes[rootA, rootA]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 16. C3C4c Polar form and square root\\nThe table \
is\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4", "5", "6"},
                  {"2", "3", "1", "5", "6", "4"},
                  {"3", "1", "2", "6", "4", "5"},
                  {"4", "5", "6", \(-1\), \(-2\), \(-3\)},
                  {"5", "6", "4", \(-2\), \(-3\), \(-1\)},
                  {"6", "4", "5", \(-3\), \(-1\), \(-2\)}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nThe polar form is\"\>", 
        ",", \({\((a + b + c)\)\^2 + \((d + e + f)\)\^2, 
          If[d + e + f \[Equal] 0, If[a + b + c < 0, \[Pi], 0], 
            ArcTan[a + b + c, d + e + f]], 
          3\/4\ \((\((\(a + b - 2\ c\)\/\@3 - d + e)\)\^2 + \((a - b + \(d + \
e - 2\ f\)\/\@3)\)\^2)\), \(-\(\[Pi]\/6\)\) + 
            If[\(a + b - 2\ c\)\/\@3 - d + e \[Equal] 0, 
              If[a - b + \(d + e - 2\ f\)\/\@3 < 0, \[Pi], 0], 
              ArcTan[a - b + \(d + e - 2\ f\)\/\@3, \(a + b - 2\ c\)\/\@3 - 
                  d + e]], 
          3\/4\ \((\((\(a + b - 2\ c\)\/\@3 + d - e)\)\^2 + \((a - b - \(d + \
e - 2\ f\)\/\@3)\)\^2)\), \(-\(\[Pi]\/6\)\) + 
            If[\(a + b - 2\ c\)\/\@3 + d - e \[Equal] 0, 
              If[a - b - \(d + e - 2\ f\)\/\@3 < 0, \[Pi], 0], 
              ArcTan[a - b - \(d + e - 2\ f\)\/\@3, \(a + b - 2\ c\)\/\@3 + 
                  d - e]]}\), 
        ",", "\<\"\\nA simplified cartesian form, in terms of radii \
\[Epsilon],\[Eta],\[Kappa] and angles \[Sigma],\[Chi],\[Psi] is\\n\"\>", 
        ",", \({2\ \[Epsilon]\ Cos[\[Sigma]] + \@3\ \[Eta]\ Cos[\[Chi]] + \@3\
\ \[Kappa]\ Cos[\[Psi]] + \[Eta]\ Sin[\[Chi]] + \[Kappa]\ Sin[\[Psi]], 
          2\ \[Epsilon]\ Cos[\[Sigma]] - \@3\ \[Eta]\ Cos[\[Chi]] - \@3\ \
\[Kappa]\ Cos[\[Psi]] + \[Eta]\ Sin[\[Chi]] + \[Kappa]\ Sin[\[Psi]], 
          2\ \[Epsilon]\ Cos[\[Sigma]] - 2\ \[Eta]\ Sin[\[Chi]] - 
            2\ \[Kappa]\ Sin[\[Psi]], \[Eta]\ Cos[\[Chi]] - \[Kappa]\ Cos[\
\[Psi]] + 
            2\ \[Epsilon]\ Sin[\[Sigma]] - \@3\ \[Eta]\ Sin[\[Chi]] + \@3\ \
\[Kappa]\ Sin[\[Psi]], \[Eta]\ Cos[\[Chi]] - \[Kappa]\ Cos[\[Psi]] + 
            2\ \[Epsilon]\ Sin[\[Sigma]] + \@3\ \[Eta]\ Sin[\[Chi]] - \@3\ \
\[Kappa]\ Sin[\[Psi]], \(-2\)\ \[Eta]\ Cos[\[Chi]] + 
            2\ \[Kappa]\ Cos[\[Psi]] + 2\ \[Epsilon]\ Sin[\[Sigma]]}\), 
        ",", "\<\"\\nWhen A  = \"\>", ",", \({6.`, 2.`, 4.`, 3.`, 1.`, 1.`}\),
         ",", "\<\"\\nthe shape of A is \"\>", 
        ",", \({169.`, 22.928203230275507`, 9.071796769724491`}\), 
        ",", "\<\"\\nthe polar form is \"\>", 
        ",", \({169.`, 0.3947911196997615`, 
          22.928203230275507`, \(-0.8937137001742207`\), 9.071796769724491`, 
          0.08908002307310836`}\), ",", "\<\"tovec recovers  A \"\>", 
        ",", \({6.`, 2.`, 4.`, 2.9999999999999996`, 0.9999999999999998`, 
          1.`}\), ",", "\<\"\\nThe square root is\"\>", 
        ",", \({2.414224259011073`, 0.3099888766376571`, 0.8113207702840068`, 
          0.576661967608032`, 
          0.13438651755665915`, \(-0.0039417039781438346`\)}\), 
        ",", "\<\"\\nwith polar form   \"\>", 
        ",", \({12.999999999999995`, 0.19739555984988075`, 
          4.788340341942652`, \(-0.4468568500871104`\), 3.01194235830045`, 
          0.04454001153655429`}\), ",", "\<\"\\nrootA.rootA = A   \"\>", 
        ",", \({5.9999999999999964`, 1.9999999999999991`, 
          3.9999999999999982`, 2.999999999999999`, 0.9999999999999994`, 
          0.9999999999999996`}\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2.10 Non-Abelian Polar-Vector Duals, Rotated-roots, Uncertainty?\
\>", "Subsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tNon-abelian hoops have repeated determinant factors. They do not have \
ordinary polar forms because the repeated sizes release extra degrees of \
freedom. (As the tables are non-abelian, the determinant should possibly be \
found and factorised by noncommutative procedures. No progress has been made \
with this topic.) Non-abelian quadratic sizes often have more than three \
fragments, and do not fit the patterns that give abelian polar forms. \
Splitting them into sets of two or three fragments allows the formulation of \
invertible pseudo-polar-powers with ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            FormBox[\(A\^\(1/p\)\),
              "TraditionalForm"], ")"}], "p"], TraditionalForm]]],
  "=A, but as the angles are not additive this gives \"pseudo-roots\" that do \
not multiply to recover the original vector i.e. ",
  Cell[BoxData[
      \(TraditionalForm\`A\^\(1/2\)\)]],
  ".",
  Cell[BoxData[
      \(TraditionalForm\`A\^\(1/2\)\)]],
  "\[NotEqual]A; the product has the correct sizes but the other elements of \
the polar form are modified in a non-obvious way. The angles are rotated. \
Conjecture - powers and roots may be associated with the introduction of \
uncertainty on making an observation of a quantum system.\n\tPseudo-roots are \
demonstrated for D3:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(Use["\<D3\>"]; {"\<Example 17. D3 Pseudo-polar form, rotated-roots.\n\
The table is\>", 
      hoopTbl // tf, "\<\nThe symbolic pseudo-polar-vector forms are\>", 
      topol, tovec, "\<\nA  = \>", 
      A = {3. \ , 1. , 4. , 2. , 6. , 
          9. }, "\<\nThe pseudo-polar form is \>", 
      pA = topol /. \ as[A], \[IndentingNewLine]"\<\ntovec recovers  A \>", 
      tovec /. \ as[pA], \[IndentingNewLine]"\<\nThe half-power is\>", 
      r2A = hoopPower[A], "\<\nwith pseudo-polar form   \>", 
      topol /. \ as[r2A], "\<\nr2A.r2A \[NotEqual] A   \>", 
      r2a2 = hoopTimes[r2A, r2A], "\<\nwith pseudo-polar form   \>", 
      topol /. \ as[r2a2], "\<\nr2A^2=A reversion OK\>", 
      hoopPower[r2A, 2], \[IndentingNewLine]"\<\nThe one-third power is\>", 
      r3A = hoopPower[A, 1/3], "\<\nwith pseudo-polar form   \>", 
      topol /. \ as[r3A], "\<\nr3A.r3A.r3A \[NotEqual] A   \>", 
      r3a3 = hoopTimes[r3A, 
          hoopTimes[r3A, r3A]], "\<\nbut has three correct sizes\>", 
      topol /. \ as[r3a3], "\<\nr3A^3=A reversion OK\>", 
      hoopPower[r3A, 3]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 17. D3 Pseudo-polar form, rotated-roots.\\nThe \
table is\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4", "5", "6"},
                  {"2", "1", "6", "5", "4", "3"},
                  {"3", "4", "5", "6", "1", "2"},
                  {"4", "3", "2", "1", "6", "5"},
                  {"5", "6", "1", "2", "3", "4"},
                  {"6", "5", "4", "3", "2", "1"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], 
        ",", "\<\"\\nThe symbolic pseudo-polar-vector forms are\"\>", 
        ",", \({a + b + c + d + e + f, a - b + c - d + e - f, 
          1\/2\ \((\((a - c)\)\^2 - \((b - d)\)\^2 + \((c - e)\)\^2 + \((\(-a\
\) + e)\)\^2 - \((d - f)\)\^2 - \((\(-b\) + f)\)\^2)\), 
          ArcTan[2\ a - c - e, \@3\ \((\(-c\) + e)\)], 
          1\/2\ \((\((a - c)\)\^2 + \((c - e)\)\^2 + \((\(-a\) + e)\)\^2)\), 
          ArcTan[2\ b - d - f, \@3\ \((\(-d\) + f)\)]}\), 
        ",", \({1\/6\ \((a + b + 4\ \@e\ Cos[d])\), 
          1\/6\ \((a - b + 4\ \@\(\(-c\) + e\)\ Cos[f])\), 
          1\/6\ \((a + b + 4\ \@e\ Cos[d + \(2\ \[Pi]\)\/3])\), 
          1\/6\ \((a - b + 4\ \@\(\(-c\) + e\)\ Cos[f + \(2\ \[Pi]\)\/3])\), 
          1\/6\ \((a + b + 4\ \@e\ Cos[d - \(2\ \[Pi]\)\/3])\), 
          1\/6\ \((a - b + 
                4\ \@\(\(-c\) + e\)\ Cos[f - \(2\ \[Pi]\)\/3])\)}\), 
        ",", "\<\"\\nA  = \"\>", ",", \({3.`, 1.`, 4.`, 2.`, 6.`, 9.`}\), 
        ",", "\<\"\\nThe pseudo-polar form is \"\>", 
        ",", \({25.`, 1.`, \(-50.`\), 2.4278682746450277`, 7.`, 
          2.209356022893902`}\), ",", "\<\"\\ntovec recovers  A \"\>", 
        ",", \({3.`, 0.9999999999999993`, 4.`, 1.9999999999999991`, 6.`, 
          9.`}\), ",", "\<\"\\nThe half-power is\"\>", 
        ",", \({1.378814323049811`, 
          1.6006200942110909`, \(-0.06934573050425892`\), \
\(-1.4080220717003953`\), 1.6905314074544475`, 1.8074019774893046`}\), 
        ",", "\<\"\\nwith pseudo-polar form   \"\>", 
        ",", \({5.`, 0.9999999999999996`, \(-7.071067811865475`\), 
          1.2139341373225139`, 2.6457513110645907`, 1.104678011446951`}\), 
        ",", "\<\"\\nr2A.r2A \[NotEqual] A   \"\>", 
        ",", \({9.47787941528671`, 5.061384806245875`, 0.7610602923566447`, 
          1.6422345701092436`, 2.761060292356644`, 5.296380623644881`}\), 
        ",", "\<\"\\nwith pseudo-polar form   \"\>", 
        ",", \({24.999999999999993`, 1.`, 50.00000000000001`, 
          0.22079220972595706`, 62.54929737601914`, 1.1046780114469512`}\), 
        ",", "\<\"\\nr2A^2=A reversion OK\"\>", 
        ",", \({3.`, 1.`, 4.`, 1.9999999999999993`, 6.`, 9.`}\), 
        ",", "\<\"\\nThe one-third power is\"\>", 
        ",", \({1.2902351436656412`, 
          1.4891432367494186`, \(-0.24208388089593505`\), \
\(-1.180985456845474`\), 0.913857606336727`, 0.6538510892024889`}\), 
        ",", "\<\"\\nwith pseudo-polar form   \"\>", 
        ",", \({2.9240177382128665`, 
          0.9999999999999996`, \(-3.684031498640386`\), 0.8092894248816759`, 
          1.9129311827723887`, 0.7364520076313007`}\), 
        ",", "\<\"\\nr3A.r3A.r3A \[NotEqual] A   \"\>", 
        ",", \({13.682903427041946`, 
          12.56158618741602`, \(-4.576332396489963`\), \
\(-7.002858121295428`\), 3.893428969448026`, 6.441271933879416`}\), 
        ",", "\<\"\\nbut has three correct sizes\"\>", 
        ",", \({25.000000000000018`, 1.`, \(-50.00000000000002`\), 
          0.48189413225415095`, 250.4851803055853`, 0.7364520076313006`}\), 
        ",", "\<\"\\nr3A^3=A reversion OK\"\>", 
        ",", \({3.000000000000002`, 1.0000000000000022`, 4.000000000000002`, 
          2.0000000000000018`, 6.000000000000001`, 9.`}\)}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The repeated quadratic factor (",
  Cell[BoxData[
      \(TraditionalForm\`a\^2 - c\ a - e\ a\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(-b\^2\) + c\^2 - d\^2 + \)],
    PageWidth->PaperWidth,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`e\^2 - f\^2 + b\ d\)]],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`\(-c\)\ \ e + b\ f + d\ f\)]],
  ")/2\nhas been handled as two sets of sums of three squares ",
  Cell[BoxData[
      \(TraditionalForm\`\((\((e - a)\)\^2 + \((a - c)\)\^2 + \((c - e)\)\^2)\
\)/2\)],
    PageWidth->PaperWidth,
    FontFamily->"Times New Roman"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\((\((f - b)\)\^2 + \((b - d)\)\^2 + \((d - f)\)\^2)\
\)/2\)]],
  " to allow the formulation of a pseudo-polar dual. The angles do not add, \
nor are the squared radii conserved. (The conserved length is their \
difference.) I have sought (without success) a reformulation with additive \
angles, using the distinction between left and right multiplication."
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.11 Vectors with some zero sizes, Remainders.", "Subsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tSizes provide the denominators of the partial-fraction formulation of \
the multiplicative inverse (because it is found by Cramer's method). Vectors \
can have coefficients that make one or more size zero in a particular \
algebra; these algebras have \"divisors of zero\". Most mathematicians choose \
to restrict their work to the \"algebras without real divisors of zero\", \
\[DoubleStruckCapitalR], \[DoubleStruckCapitalC], \[DoubleStruckCapitalH] \
(Quaternions), and \[DoubleStruckCapitalO] (Octonions). A determinant is zero \
if it has one or more zero factor, but it may still have non-zero factors. \
Hoop algebras overcome division-by-zero via two innovations, ",
  StyleBox["projection",
    FontSlant->"Italic"],
  " into sub-algebras and ",
  StyleBox["ejection",
    FontSlant->"Italic"],
  " of remainders. Zeroed sizes correspond to operations in sub-algebras with \
these sizes constrained to be zero; inverses are in the same sub-algebras, \
and also have these zeroes. In effect, zeroes are \"factored out\". \
Conservation is maintained by ejecting remainders A/B = C +Rl +Rr; sizes that \
are zero in C but not in A go into the left remainder Rl; sizes that are zero \
in C but not in B go into the right remainder. This is a generalization of \
integer division. Remainders also extend to multiplication A*B=P+Rl+Rr so \
that P/A+Rr=B and P/B+Rl=A. Example 18 sets up two vectors with C4 shapes \
{6,2,0} & {0,10,10}; their product has shape {0,20,0}; Rl conserves the 6 \
from A0; Rr conserves the second 10 from B0. Dividing AB by A does not \
recover B until Rr is added; dividing AB by B does not recover A until Rl is \
added.  "
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(Use["\<C4\>"]\), ";", 
      RowBox[{"Chop", "[", 
        RowBox[{"{", 
          RowBox[{
          "\"\<Example 18. C4 multiplication with remainders\>\"", ",", 
            "\"\<\\n         A0 = \>\"", ",", \(A0 = {2, 1, 2, 1}\), ",", 
            "\[IndentingNewLine]", "\"\<\\n\!\(\*
StyleBox[\"shape\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)A0 = \>\"", 
            ",", \(sA0 = sh /. \ as[A0]\), ",", "\[IndentingNewLine]", 
            "\"\<\\n         B0 = \>\"", ",", \(B0 = {3, \(-1\), 2, \(-4\)}\),
             ",", "\[IndentingNewLine]", "\"\<\\n\!\(\*
StyleBox[\"shape\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",\nFontSlant->\"Italic\"]\) B0 = \>\"", 
            ",", \(sh /. \ as[B0]\), ",", "\[IndentingNewLine]", 
            "\"\<\\n         AB = \>\"", ",", \(AB = hoopTimes[A0, B0]\), ",",
             "\[IndentingNewLine]", "\"\<\\n\!\(\*
StyleBox[\"shape\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",\nFontSlant->\"Italic\"]\) AB = \>\"", 
            ",", \(sh /. \ as[AB]\), ",", "\[IndentingNewLine]", 
            "\"\<\\n\!\(\*
StyleBox[\"Note\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"that\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"sizes\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"  \",\nFontSlant->\"Italic\"]\)\[UpArrow]     \[UpArrow]\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"have\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"become\",\nFontSlant->\"Italic\"]\) 0\>\"", ",", 
            "\[IndentingNewLine]", "\"\<\\n\!\(\*
StyleBox[\"Remainder\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"Rl\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"=\",\nFontSlant->\"Italic\"]\)\>\"", ",", \(RA = Rl\), ",", 
            "\"\<\\n\!\(\*
StyleBox[\"has\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"a\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"shape\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"     \",\nFontSlant->\"Italic\"]\) \>\"", ",", \(sh /. \ as[Rl]\), 
            ",", "\"\<\\n\!\(\*
StyleBox[\"Remainder\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"Rr\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"=\",\nFontSlant->\"Italic\"]\)\>\"", ",", \(RB = Rr\), ",", 
            "\"\<\\n\!\(\*
StyleBox[\"has\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"a\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"shape\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"   \",\nFontSlant->\"Italic\"]\)\>\"", ",", \(sh /. \ as[Rr]\), 
            ",", "\"\<\\n\!\(\*
StyleBox[\"Ainverse\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"    \",\nFontSlant->\"Italic\"]\)= \>\"", 
            ",", \(Ainv = hoopInverse[A0]\), ",", "\"\<\\nwith shape    \>\"",
             ",", \(sh /. \ as[Ainv]\), ",", "\"\<\\nAB/A0       = \>\"", 
            ",", \(ABoA = hoopTimes[Ainv, AB]\), ",", 
            "\"\<\\nwith shape    \>\"", ",", \(sh /. \ as[ABoA]\), ",", 
            "\"\<\\nAdding Rr recovers B0\>\"", ",", \(ABoA + RB\), ",", 
            "\[IndentingNewLine]", "\"\<\\n\!\(\*
StyleBox[\"Binverse\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"    \",\nFontSlant->\"Italic\"]\)= \>\"", 
            ",", \(Binv = hoopInverse[B0]\), ",", "\"\<\\nwith shape    \>\"",
             ",", \(sh /. \ as[Binv]\), ",", "\"\<\\nAB/B0       = \>\"", 
            ",", \(ABoB = hoopTimes[AB, Binv]\), ",", 
            "\"\<\\nwith shape    \>\"", ",", \(sh /. \ as[ABoB]\), ",", 
            "\"\<\\nAdding Rl recovers A0  \>\"", ",", \(ABoB + RA\)}], 
          StyleBox["}",
            FontSlant->"Italic"]}], "]"}]}]], "Input",
  PageWidth->WindowWidth,
  CellOpen->False,
  FontFamily->"Courier New",
  FontSize->10],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 18. C4 multiplication with remainders\"\>", 
        ",", "\<\"\\n         A0 = \"\>", ",", \({2, 1, 2, 1}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"shape\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)A0 = \"\>", ",", \({6, 2, 0}\), 
        ",", "\<\"\\n         B0 = \"\>", ",", \({3, \(-1\), 2, \(-4\)}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"shape\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\\) B0 = \"\>", 
        ",", \({0, 10, 10}\), ",", "\<\"\\n         AB = \"\>", 
        ",", \({5, \(-5\), 5, \(-5\)}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"shape\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\\) AB = \"\>", 
        ",", \({0, 20, 0}\), 
        ",", "\<\"\\n\\!\\(\\* StyleBox[\\\"Note\\\",\\nFontSlant->\\\"Italic\
\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"that\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"sizes\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"  \\\",\\nFontSlant->\\\"Italic\\\"]\\)\[UpArrow]     \[UpArrow]\
\\!\\(\\* StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"have\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"become\\\",\\nFontSlant->\\\"Italic\\\"]\\) 0\"\>", 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"Remainder\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"Rl\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"=\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
        ",", \({3\/2, 3\/2, 3\/2, 3\/2}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"has\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"a\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"shape\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"     \\\",\\nFontSlant->\\\"Italic\\\"]\\) \"\>", 
        ",", \({6, 0, 0}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"Remainder\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"Rr\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"=\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
        ",", \({1\/2, 3\/2, \(-\(1\/2\)\), \(-\(3\/2\)\)}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"has\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"a\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"shape\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"   \\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
        ",", \({0, 0, 10}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"Ainverse\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\
\\\"    \\\",\\nFontSlant->\\\"Italic\\\"]\\)= \"\>", 
        ",", \({1\/6, \(-\(1\/12\)\), 1\/6, \(-\(1\/12\)\)}\), 
        ",", "\<\"\\nwith shape    \"\>", ",", \({1\/6, 1\/2, 0}\), 
        ",", "\<\"\\nAB/A0       = \"\>", 
        ",", \({5\/2, \(-\(5\/2\)\), 5\/2, \(-\(5\/2\)\)}\), 
        ",", "\<\"\\nwith shape    \"\>", ",", \({0, 10, 0}\), 
        ",", "\<\"\\nAdding Rr recovers B0\"\>", 
        ",", \({3, \(-1\), 2, \(-4\)}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"Binverse\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\
\\\"    \\\",\\nFontSlant->\\\"Italic\\\"]\\)= \"\>", 
        ",", \({3\/40, \(-\(7\/40\)\), \(-\(1\/40\)\), 1\/8}\), 
        ",", "\<\"\\nwith shape    \"\>", ",", \({0, 1\/10, 1\/10}\), 
        ",", "\<\"\\nAB/B0       = \"\>", 
        ",", \({1\/2, \(-\(1\/2\)\), 1\/2, \(-\(1\/2\)\)}\), 
        ",", "\<\"\\nwith shape    \"\>", ",", \({0, 2, 0}\), 
        ",", "\<\"\\nAdding Rl recovers A0  \"\>", ",", \({2, 1, 2, 1}\)}], 
      "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "\t\[DoubleStruckCapitalC], \[DoubleStruckCapitalH], and \
\[DoubleStruckCapitalO] can have divisors of zero if their coefficients are \
complex.The algebras defined by the Pauli-\[Sigma] matrices (P4, P8, P16) \
conserve variations on the Minkowski metric ",
  Cell[BoxData[
      \(TraditionalForm\`t\^2\)]],
  "-",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  "-",
  Cell[BoxData[
      \(TraditionalForm\`y\^2\)]],
  "-",
  Cell[BoxData[
      \(TraditionalForm\`z\^2\)]],
  " and can have real divisors of zero. The \"light cone\" is a zero \
sub-space.\n\tSome algebras can have \"annihilators\", real vectors with all \
sizes zero. Operations with them give results with all sizes zero (but with \
non-zero coefficients), so one remainder will be the other operand, \
unchanged. Example 18a shows this for left and right multiplication by the D3 \
annihilator A0."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(Use["\<D3\>"]; 
    Chop[{"\<Example 18a. D3 annihilator\>", "\<\nD3 has shape\>", 
        sh, "\<\nA0 =  \>", 
        A0 = {2, 0, \(-2\), \(-2\), 0, 
            2}, \[IndentingNewLine]"\<\nA0 shape\>", 
        sh /. \ as[A0], "\<\nB  =  \>", 
        B = {2, 3, \(-4\), \(-1\), 5, 
            2}, \[IndentingNewLine]"\<\nB shape \>", 
        sh /. \ as[B], "\<\nAB  = \>", 
        AB = hoopTimes[A0, B], "\<\nAB shape\>", 
        sh /. \ as[AB], "\<\nRl =  \>", Rl, "\<\nRr = B\>", 
        Rr, "\<\nBA  = \>", BA = hoopTimes[B, A0], "\<\nBA shape\>", 
        sh /. \ as[BA], "\<\nRl = B\>", Rl, "\<\nRr =  \>", Rr}]\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"Example 18a. D3 annihilator", 
      "\nD3 has shape", {a + b + c + d + e + f, a - b + c - d + e - f, 
        1\/2\ \((\((a - c)\)\^2 - \((b - d)\)\^2 + \((c - e)\)\^2 + \((\(-a\) \
+ e)\)\^2 - \((d - f)\)\^2 - \((\(-b\) + f)\)\^2)\)}, 
      "\nA0 =  ", {2, 0, \(-2\), \(-2\), 0, 2}, "\nA0 shape", {0, 0, 0}, 
      "\nB  =  ", {2, 3, \(-4\), \(-1\), 5, 2}, 
      "\nB shape ", {7, \(-1\), 50}, 
      "\nAB  = ", {0, 20, \(-20\), \(-20\), 20, 0}, "\nAB shape", {0, 0, 0}, 
      "\nRl =  ", {0, 0, 0, 0, 0, 0}, 
      "\nRr = B", {2, 3, \(-4\), \(-1\), 5, 2}, 
      "\nBA  = ", {0, \(-10\), \(-10\), 0, 10, 10}, "\nBA shape", {0, 0, 0}, 
      "\nRl = B", {2, 3, \(-4\), \(-1\), 5, 2}, 
      "\nRr =  ", {0, 0, 0, 0, 0, 0}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.12 Subtraction is Additive Elimination.", "Subsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tNegation \"-a\" and subtraction \"b-a\" are conflated and treated as a \
single fundamental process by most mathematicians, but [3] requires over a \
hundred pages of \"Post-Modern Algebra\" before subtraction can be tackled. \
In hoops, negation is the result of an ",
  StyleBox["r",
    FontSlant->"Italic"],
  "=2 fold. This equivalences {",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + m/2\)\)]],
  "} to a real number ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["a",
            FontWeight->"Bold"], "i"], TraditionalForm]]],
  ", with {",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + m/2\)\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  "}~-",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["a",
            FontWeight->"Bold"], "i"], TraditionalForm]]],
  " and {",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  "}~",
  StyleBox["0",
    FontWeight->"Bold"],
  ". The first size, \[Sum]",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  ", is destroyed, as it equivalences to zero. Subtraction can now be seen as \
\"additive elimination\", adding a set of coefficients that make all the \
terms of an un-folded vector identical, so that they equivalence to zero: \
{a,b}+{b,a} ={a+b,a+b} ~ ",
  StyleBox["0",
    FontWeight->"Bold"],
  ". (The commutative property of addition is inherited from the natural \
numbers.)\n\tWhen ",
  StyleBox["r",
    FontSlant->"Italic"],
  " is 3, the equivalence relationship is ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["t",
            FontWeight->"Bold"], "i"], TraditionalForm]]],
  "~{",
  Cell[BoxData[
      \(TraditionalForm\`a\_j\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(j + m/3\)\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(j + 2  m/3\)\)]],
  "} ~{",
  Cell[BoxData[
      \(TraditionalForm\`b\_j\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`b\_\(j + m/3\)\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`b\_\(j + 2  m/3\)\)]],
  "} iff (",
  Cell[BoxData[
      \(TraditionalForm\`a\_j\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`b\_\(j + m/3\)\)]],
  ") = (",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(j + m/3\)\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`b\_\(j + 2  m/3\)\)]],
  ") = (",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(j + 2  m/3\)\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`b\_j\)]],
  "). The \"terplex number\" {a,b,c} has a left negation (or rotation), \
{b,c,a} and a right negation {c,a,b}, with {a,b,c} +{b,c,a} +{c,a,b} ={a+b+c, \
a+b+c, a+b+c} ~ ",
  StyleBox["0",
    FontWeight->"Bold"],
  ". A number is eliminated by adding the two rotations of its primal form. \
This extends to other ",
  StyleBox["r",
    FontSlant->"Italic"],
  " values; a number is eliminated by adding the ",
  StyleBox["r",
    FontSlant->"Italic"],
  "-1 rotations of a primal form. Simultaneous equations can be solved in \
this way in hoop algebras, but this is not demonstrated here."
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.13. Orbits.", "Subsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tI define a \"unital\" sub-algebra by the restriction that \"the product \
of non-zero sizes is unity\". The name \"orbit\" is appropriate to polar \
forms of unital sub-algebras because the coefficients are restricted to \
circles in ",
  StyleBox["m",
    FontSlant->"Italic"],
  "-dimensional space, and the group orbits are points on these circles. \
Multiplying one orbit by another (using the same hoop) gives another orbit, \
and any remainders will also be orbits. If some sizes are zero, operations \
are restricted to a sub-algebra in which these sizes remain at zero, by \
conservation. This generates sub-orbits that have analogies with particles - \
discussed in section 3.\n \tI use the convention that orbit polar forms have \
names like OHijk, with vector forms VHijk, where H is the hoop name and \
ijk... gives the sizes. Linear sizes provide \"offsets\", displacing the \
orbit origin from zero. This may be a new concept; it introduces additive \
properties to orbits. The squared radius is a multiplicative property for \
abelian radius/angle formulations."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(Use["\<C3\>"]; {"\<Example 19. C3 Orbits\>", "\<\nOC301 is {0,1,a} with \
vector form\>", 
      OC301 = tovec /. \ 
          as[{0, 1, a}], "\<\nOC311 is {1,1,b} with vector form\>", 
      OC311 = tovec /. \ 
          as[{1, 1, 
              b}], "\<\nProducts are orbits with added angles; the polar form \
of the product of OC301 & OC311 is\>", 
      Simplify[topol /. \ 
          as[hoopTimes[OC301, OC311]]], "\<\nand the remainders are\>", Rl, 
      Rr}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"Example 19. C3 Orbits", 
      "\nOC301 is {0,1,a} with vector form", {\(2\ Cos[a]\)\/3, 
        2\/3\ Cos[a + \(2\ \[Pi]\)\/3], 2\/3\ Cos[a - \(2\ \[Pi]\)\/3]}, 
      "\nOC311 is {1,1,b} with vector form", {1\/3\ \((1 + 2\ Cos[b])\), 
        1\/3\ \((1 + 2\ Cos[b + \(2\ \[Pi]\)\/3])\), 
        1\/3\ \((1 + 2\ Cos[b - \(2\ \[Pi]\)\/3])\)}, 
      "\nProducts are orbits with added angles; the polar form of the product \
of OC301 & OC311 is", {0, 1, ArcTan[Cos[a + b], Sin[a + b]]}, 
      "\nand the remainders are", {0, 0, 0}, {1\/3, 1\/3, 1\/3}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Use["\<C4\>"]; {"\<Example 20. C4 Orbits\>", "\<\nOC4001 is \>", 
      OC4001 = {0, 0, 1, a}, "\<\n with vector form\>", 
      VC4001 = tovec /. \ as[OC4001], "\<\nOC4011 is\>", 
      OC4011 = {0, 1, 1, b}, "\<\n with vector form\>"\ , 
      VC4011 = tovec /. \ as[OC4011], "\<\nOC4101 =\>", 
      OC4101\  = \ {1, 0, 1, c}, "\<\n with vector form\>", 
      VC4101 = tovec /. \ as[OC4101], "\<\nOC4111 is\>", 
      OC4111\  = \ {1, 1, 1, d}, "\<\nwith vector form\>", 
      VC4111 = tovec /. \ 
          as[OC4111], "\<\n\n\>", \[IndentingNewLine]Simplify[{"\<OC4001\
\[Times]OC4001 has the 001 shape\>", 
          sh /. \ as[
              hoopTimes[VC4001, 
                VC4001]], "\<\nOC4101\[Times]OC4011 also has the 001 shape\n\
as the two offsets disappear   \>", 
          sh /. \ as[hoopTimes[VC4101, VC4011]], "\<\nwith remainders \>", 
          Rl, Rr, "\<\nOC4101\[Times]OC4111 has the 101 shape\>", \
\[IndentingNewLine]sh /. \ 
            as[hoopTimes[VC4101, VC4111]], "\<\nwith remainders \>", Rl, 
          Rr, "\<\nOC4111\[Times]OC4111 has the 111 shape\>", 
          sh /. \ as[hoopTimes[VC4111, VC4111]]}], "\<\nwith remainders \>", 
      Rl, Rr}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"Example 20. C4 Orbits", "\nOC4001 is ", {0, 0, 1, a}, 
      "\n with vector form", {Cos[a]\/2, 
        Sin[a]\/2, \(-\(Cos[a]\/2\)\), \(-\(Sin[a]\/2\)\)}, 
      "\nOC4011 is", {0, 1, 1, b}, 
      "\n with vector form", {1\/4\ \((1 + 2\ Cos[b])\), 
        1\/4\ \((\(-1\) + 2\ Sin[b])\), 1\/4\ \((1 - 2\ Cos[b])\), 
        1\/4\ \((\(-1\) - 2\ Sin[b])\)}, "\nOC4101 =", {1, 0, 1, c}, 
      "\n with vector form", {1\/4\ \((1 + 2\ Cos[c])\), 
        1\/4\ \((1 + 2\ Sin[c])\), 1\/4\ \((1 - 2\ Cos[c])\), 
        1\/4\ \((1 - 2\ Sin[c])\)}, "\nOC4111 is", {1, 1, 1, d}, 
      "\nwith vector form", {1\/4\ \((2 + 2\ Cos[d])\), Sin[d]\/2, 
        1\/4\ \((2 - 2\ Cos[d])\), \(-\(Sin[d]\/2\)\)}, 
      "\n\n", {"OC4001\[Times]OC4001 has the 001 shape", {0, 0, 1}, 
        "\nOC4101\[Times]OC4011 also has the 001 shape\nas the two offsets \
disappear   ", {0, 0, 1}, 
        "\nwith remainders ", {1\/4, 1\/4, 1\/4, 1\/4}, {1\/4, \(-\(1\/4\)\), 
          1\/4, \(-\(1\/4\)\)}, 
        "\nOC4101\[Times]OC4111 has the 101 shape", {1, 0, 1}, 
        "\nwith remainders ", {0, 0, 0, 0}, {1\/4, \(-\(1\/4\)\), 
          1\/4, \(-\(1\/4\)\)}, 
        "\nOC4111\[Times]OC4111 has the 111 shape", {1, 1, 1}}, 
      "\nwith remainders ", {0, 0, 0, 0}, {0, 0, 0, 0}}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. Analogies with particles.", "Section",
  FontFamily->"Times New Roman"],

Cell[TextData[StyleBox["Summary\n\tThe algebras based on 12-element groups, \
\"Dozal\", have elements that act as half-spin (fermionic) and unit-spin \
(bosonic) quantum operators, and have orbits that have analogies with \
fundamental particles. This leads to the possibility that hoop algebras may \
provide a new paradigm for physics. The following conjectures, which the \
author cannot develop further, are outlined:- \n\tDozal interactions, with \
remainders conserving different properties, resemble particle interactions \
and decay, with four hoops corresponding to four forces. \n\tHexal is \
supersymmetric to Dozal; it has fewer elements that are not subject to the \
Pauli exlusion principle because they are equivalence relations.\n\tStable \
orbits may relate to stable particles. \n\tOrbits resemble multi-phase \
deBroglie waves, and quadratic sizes resemble Planck areas.  ",
  FontSlant->"Italic"]], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["3.1. Dozal and Hexal.", "Subsubsection",
  PageWidth->WindowWidth],

Cell["\<\
\tDozal and Hexal algebras, with 12 and 6 elements, have many analogies with \
fundamental particles. They may lead to a new paradigm for physics, based on \
finite Moufang Loops rather than Lie groups. Sporadic discoveries, spread \
over fifteen years of research, have repeatedly related different physical \
phenomena to new aspects of hoop algebra, encouraging the conjecture that \
these algebras are \"physical mathematics\".\
\>", "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.2. Elements act as Quantum Operators.", "Subsubsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tJ. J. Hamilton [4] developed a \"hypercomplex arithmetic\", with \
half-spin \"non-real, non-complex\" quantum operators {",
  StyleBox["a",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(a\^*\)\)],
    PageWidth->WindowWidth,
    Evaluatable->False],
  ",",
  StyleBox["b ",
    FontSlant->"Italic"],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`\(b\^*\)\)],
    PageWidth->WindowWidth,
    Evaluatable->False],
  "} as well as integer-spin quantum operators, having the following \
multiplication table:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    RowBox[{"     ", 
      FormBox[GridBox[{
            {
              " ", \(E\_0\), \(E\_1\), \(E\_2\), \(E\_3\), \(E\_4\), \
\(E\_5\), \(E\_6\), \(E\_7\)},
            {\(E\_0\), "1", "i", "h", "k", "a", \(b\^*\), \(a\^*\), "b"},
            {\(E\_1\), "i", \(-1\), "k", \(-h\), \(b\^*\), \(-a\), 
              "b", \(-\(a\^*\)\)},
            {\(E\_2\), "h", "k", "1", "i", \(a\^*\), "b", "a", \(b\^*\)},
            {\(E\_3\), "k", \(-h\), "i", \(-1\), 
              "b", \(-\(a\^*\)\), \(b\^*\), \(-a\)},
            {\(E\_4\), "a", \(b\^*\), \(a\^*\), "b", "1", "i", "h", "k"},
            {\(E\_5\), \(b\^*\), \(-a\), "b", \(-\(a\^*\)\), "i", \(-1\), 
              "k", \(-h\)},
            {\(E\_6\), \(a\^*\), "b", "a", \(b\^*\), "h", "k", "1", "i"},
            {\(E\_7\), "b", \(-\(a\^*\)\), \(b\^*\), \(-a\), "k", \(-h\), 
              "i", \(-1\)}
            }],
        "TraditionalForm"]}]], "Input",
  PageWidth->WindowWidth,
  Evaluatable->False],

Cell[TextData[{
  StyleBox["a",
    FontSlant->"Italic"],
  "* and ",
  StyleBox["b",
    FontSlant->"Italic"],
  "* are \"biconjugates\" (my term) with ",
  StyleBox["a",
    FontSlant->"Italic"],
  "**=-",
  StyleBox["a",
    FontSlant->"Italic"],
  ", ",
  StyleBox["b",
    FontSlant->"Italic"],
  "**=-",
  StyleBox["b",
    FontSlant->"Italic"],
  ". The table has four elements that square to -1; Hamilton also introduces \
several other elements and many aliases. Replacing the ambiguous \"-1\" by ii \
and including extra rows and columns that match his multiplication rules \
gives a 12\[Times]12 table with his table embedded (in boldface, with ii in \
place of -1):-"
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[GridBox[{
        {"1", "i", 
          StyleBox["ii",
            FontWeight->"Plain"], "h", "k", 
          StyleBox[\(-h\),
            FontWeight->"Plain"], "a", \(b\^*\), 
          StyleBox[\(-a\),
            FontWeight->"Plain"], \(a\^*\), "b", 
          StyleBox[\(-\(a\^*\)\),
            FontWeight->"Plain"]},
        {"i", "ii", 
          StyleBox["1",
            FontWeight->"Plain"], "k", \(-h\), 
          StyleBox["h",
            FontWeight->"Plain"], \(b\^*\), \(-a\), 
          StyleBox["a",
            FontWeight->"Plain"], "b", \(-\(a\^*\)\), 
          StyleBox[\(a\^*\),
            FontWeight->"Plain"]},
        {
          StyleBox["ii",
            FontWeight->"Plain"], 
          StyleBox["1",
            FontWeight->"Plain"], 
          StyleBox["i",
            FontWeight->"Plain"], 
          StyleBox[\(-h\),
            FontWeight->"Plain"], 
          StyleBox["h",
            FontWeight->"Plain"], 
          StyleBox["k",
            FontWeight->"Plain"], 
          StyleBox[\(-a\),
            FontWeight->"Plain"], 
          StyleBox["a",
            FontWeight->"Plain"], 
          StyleBox[\(b\^*\),
            FontWeight->"Plain"], 
          StyleBox[\(-\(a\^*\)\),
            FontWeight->"Plain"], 
          StyleBox[\(a\^*\),
            FontWeight->"Plain"], 
          StyleBox["b",
            FontWeight->"Plain"]},
        {"h", "k", 
          StyleBox[\(-h\),
            FontWeight->"Plain"], "1", "i", 
          StyleBox["ii",
            FontWeight->"Plain"], \(a\^*\), "b", 
          StyleBox[\(-\(a\^*\)\),
            FontWeight->"Plain"], "a", \(b\^*\), 
          StyleBox[\(-a\),
            FontWeight->"Plain"]},
        {"k", \(-h\), 
          StyleBox["h",
            FontWeight->"Plain"], "i", "ii", 
          StyleBox["1",
            FontWeight->"Plain"], "b", \(-\(a\^*\)\), 
          StyleBox[\(a\^*\),
            FontWeight->"Plain"], \(b\^*\), \(-a\), 
          StyleBox["a",
            FontWeight->"Plain"]},
        {
          StyleBox[\(-h\),
            FontWeight->"Plain"], 
          StyleBox["h",
            FontWeight->"Plain"], 
          StyleBox["k",
            FontWeight->"Plain"], 
          StyleBox["ii",
            FontWeight->"Plain"], 
          StyleBox["1",
            FontWeight->"Plain"], 
          StyleBox["i",
            FontWeight->"Plain"], 
          StyleBox[\(-\(a\^*\)\),
            FontWeight->"Plain"], 
          StyleBox[\(a\^*\),
            FontWeight->"Plain"], 
          StyleBox["b",
            FontWeight->"Plain"], 
          StyleBox[\(-a\),
            FontWeight->"Plain"], 
          StyleBox["a",
            FontWeight->"Plain"], 
          StyleBox[\(b\^*\),
            FontWeight->"Plain"]},
        {"a", \(b\^*\), 
          StyleBox[\(-a\),
            FontWeight->"Plain"], \(a\^*\), "b", 
          StyleBox[\(-\(a\^*\)\),
            FontWeight->"Plain"], "1", "i", 
          StyleBox["ii",
            FontWeight->"Plain"], "h", "k", 
          StyleBox[\(-h\),
            FontWeight->"Plain"]},
        {\(b\^*\), \(-a\), 
          StyleBox["a",
            FontWeight->"Plain"], "b", \(-\(a\^*\)\), 
          StyleBox[\(a\^*\),
            FontWeight->"Plain"], "i", "ii", 
          StyleBox["1",
            FontWeight->"Plain"], "k", \(-h\), 
          StyleBox["h",
            FontWeight->"Plain"]},
        {
          StyleBox[\(-a\),
            FontWeight->"Plain"], 
          StyleBox["a",
            FontWeight->"Plain"], 
          StyleBox[\(b\^*\),
            FontWeight->"Plain"], 
          StyleBox[\(-\(a\^*\)\),
            FontWeight->"Plain"], 
          StyleBox[\(a\^*\),
            FontWeight->"Plain"], 
          StyleBox["b",
            FontWeight->"Plain"], 
          StyleBox["ii",
            FontWeight->"Plain"], 
          StyleBox["1",
            FontWeight->"Plain"], 
          StyleBox["i",
            FontWeight->"Plain"], 
          StyleBox[\(-h\),
            FontWeight->"Plain"], 
          StyleBox["h",
            FontWeight->"Plain"], 
          StyleBox["k",
            FontWeight->"Plain"]},
        {\(a\^*\), "b", 
          StyleBox[\(-\(a\^*\)\),
            FontWeight->"Plain"], "a", \(b\^*\), 
          StyleBox[\(-a\),
            FontWeight->"Plain"], "h", "k", 
          StyleBox[\(-h\),
            FontWeight->"Plain"], "1", "i", 
          StyleBox["ii",
            FontWeight->"Plain"]},
        {"b", \(-\(a\^*\)\), 
          StyleBox[\(a\^*\),
            FontWeight->"Plain"], \(b\^*\), \(-a\), 
          StyleBox["a",
            FontWeight->"Plain"], "k", \(-h\), 
          StyleBox["h",
            FontWeight->"Plain"], "i", "ii", 
          StyleBox["1",
            FontWeight->"Plain"]},
        {
          StyleBox[\(-\(a\^*\)\),
            FontWeight->"Plain"], 
          StyleBox[\(a\^*\),
            FontWeight->"Plain"], 
          StyleBox["b",
            FontWeight->"Plain"], 
          StyleBox[\(-a\),
            FontWeight->"Plain"], 
          StyleBox["a",
            FontWeight->"Plain"], 
          StyleBox[\(b\^*\),
            FontWeight->"Plain"], 
          StyleBox[\(-h\),
            FontWeight->"Plain"], 
          StyleBox["h",
            FontWeight->"Plain"], 
          StyleBox["k",
            FontWeight->"Plain"], 
          StyleBox["ii",
            FontWeight->"Plain"], 
          StyleBox["1",
            FontWeight->"Plain"], 
          StyleBox["i",
            FontWeight->"Plain"]}
        }]], "Input",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tThis is isomorphic to C3K, so ",
  StyleBox["i",
    FontSlant->"Italic"],
  " and ",
  StyleBox["ii",
    FontSlant->"Italic"],
  " are interpreted as a cube roots of 1. His half-spin operators {",
  StyleBox["a, a*, -a\[Congruent]  a**,b, b*, -b\[Congruent] b**\[Congruent] \
-a*",
    FontSlant->"Italic"],
  "} are {",
  StyleBox["a, a h, a i i, a h i, a i , a h i i",
    FontSlant->"Italic"],
  "}; conjugation ",
  StyleBox["a",
    FontSlant->"Italic"],
  "* is multiplication by ",
  StyleBox["h",
    FontSlant->"Italic"],
  " (with ",
  StyleBox["h h",
    FontSlant->"Italic"],
  " =1), but biconjugation ",
  StyleBox["a**",
    FontSlant->"Italic"],
  " becomes multiplication by ",
  StyleBox["i",
    FontSlant->"Italic"],
  " or ",
  StyleBox["ii",
    FontSlant->"Italic"],
  ". His half-spin operators are still valid, but they are now defined in \
terms of two distinct square roots of 1 (",
  StyleBox["h & a",
    FontSlant->"Italic"],
  ") and the cube roots (",
  StyleBox["i, ii",
    FontSlant->"Italic"],
  ") of 1. Complex numbers are not involved."
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.2. Half-spin and Dozal algebra.", "Subsubsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tBanded sets of differential equations generate multi-phase sinusoids \
(just as ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\)\& . \)]],
  StyleBox[" = a ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`x\_\(\(2\)\(,\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(x\_2\)\& . \)\)\)]],
  StyleBox["= -a",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  ", equivalent to ",
  Cell[BoxData[
      \(TraditionalForm\`x\&\[DoubleDot]\)]],
  " = -",
  Cell[BoxData[
      \(TraditionalForm\`a\^2\)]],
  "x, generates ordinary sinusoids). A relevant simple set is the ",
  StyleBox["m",
    FontSlant->"Italic"],
  " equations (with ",
  StyleBox["m",
    FontSlant->"Italic"],
  "-1 being independent):- \n     ",
  Cell[BoxData[
      StyleBox[\(D[x\_j, t] = \(c'\)[t] + 
            a \((x\_\(Mod[j + k, m]\) - x\_\(Mod[j - k, m]\))\), 
        j = \(0.  .. \)\ m - 1, k < m/2. \),
        FontFamily->"Times New Roman",
        FontWeight->"Plain"]], "Input"],
  "\nSubstituting the trial function ",
  Cell[BoxData[
      \(x\_j = c[t] + \(c\_1\) Sin[c\_2\ t + \[Phi] + 2  j\ k\ \[Pi]/m]\)],
    FontFamily->"Times New Roman"],
  " leads to          ",
  Cell[BoxData[
      \(\(\(\ \ \ \ \ \ \ \ \)\(x\_j = 
        c[t] + \[Sum]\_p\( c\_p\) 
              Sin[2  a\ Sin[2  k\ \[Pi]/m]\ t + \[Phi]\_p + 
                  2  j\ k\ \[Pi]/m]\)\)\)], "Input",
    FontFamily->"Times New Roman",
    FontWeight->"Plain"],
  ".\n",
  StyleBox["j",
    FontSlant->"Italic"],
  " is one of the ",
  StyleBox["m",
    FontSlant->"Italic"],
  " phases; c[t] gives freedom from the origin;",
  StyleBox[" ",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(c\_p\)],
    FontFamily->"Times New Roman"],
  " and ",
  Cell[BoxData[
      StyleBox[\(\[Phi]\_p\),
        FontFamily->"Times New Roman"]]],
  " are phase amplitude and phase offset constants which hav to be \
subscripted because independent sets can arise; ",
  StyleBox["k",
    FontSlant->"Italic"],
  " is a phase step. Sin[2k \[Pi]/m] is a constant that determines the \
frequency & period.  When ",
  StyleBox["m",
    FontSlant->"Italic"],
  "=4, ",
  StyleBox["k",
    FontSlant->"Italic"],
  " must be 1; deflating then removes the c[t] term and reproduces the \
ordinary sinusoid equation-pair with double the amplitude. Other values of ",
  StyleBox["m",
    FontSlant->"Italic"],
  " and ",
  StyleBox["k",
    FontSlant->"Italic"],
  " give a frequency reduction.\n\tThe period is 2\[Pi]/Sin[2k \[Pi]/m], and \
the function is non-sinusoidal (constant) if 2/m is integral.\n\tHalf-spin \
with a period of 4\[Pi] results when ",
  StyleBox["m",
    FontSlant->"Italic"],
  "=12, k=1. The twelve components are elements of the C12 hoop; its C3C4 \
isomorph is the preferred isomorph because it has sizes in common with the \
other Dozal hoops C3K, Q12, D3C2, and A4.\n\t A lot more research is needed \
here. The differential equations need to be related to hoops; the resonances \
(orbits with frequencies that are integer or half-integer multiples of the \
fundamental frequency) need study; what is the relationship between hoops and \
the theory of strings and branes, etc."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3.3. Sizes and Orbits as Planck Areas & deBroglie Waves with polarization & \
chirality.\
\>", "Subsubsection",
  PageWidth->WindowWidth],

Cell["\<\
\tC3K has a polar dual that can be expressed as {\[Alpha], \[Beta], \[Gamma], \
\[Delta], \[Zeta]\[Zeta], \[Tau], \[Lambda]\[Lambda], \[Phi], \[Eta]\[Eta], \
\[Chi], \[Kappa]\[Kappa], \[Psi]} and reverted to a vector as follows:-\
\>", "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\(\(\ \ \ \ \)\(C3KO = {\[IndentingNewLine]\[Alpha] + \[Beta] + \
\[Gamma] + \[Delta] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  + \[Lambda]\ \
Cos[\[Phi]]\ \ \ \ \  + \[Eta]\ Cos[\[Chi]]\ \ \ \ \ \  + \[Kappa]\ \
Cos[\[Psi]], \[Alpha] + \[Beta] + \[Gamma] + \[Delta] + \[Zeta]\ Cos[\[Tau] + \
\[Omega]] + \[Lambda]\ Cos[\[Phi] + \[Omega]] + \[Eta]\ Cos[\[Chi] + \
\[Omega]] + \[Kappa]\ Cos[\[Psi] + \[Omega]], \ \[IndentingNewLine]\[Alpha] + \
\[Beta] + \[Gamma] + \[Delta] + \[Zeta]\ Cos[\[Tau] - \[Omega]] + \[Lambda]\ \
Cos[\[Phi] - \[Omega]] + \[Eta]\ Cos[\[Chi] - \[Omega]] + \[Kappa]\ \
Cos[\[Psi] - \[Omega]], \[IndentingNewLine]\[Alpha] - \[Beta] + \[Gamma] - \
\[Delta] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  - \[Lambda]\ Cos[\[Phi]]\ \ \ \ \ \
 + \[Eta]\ Cos[\[Chi]]\ \ \ \ \ \  - \[Kappa]\ Cos[\[Psi]], \ \[Alpha] - \
\[Beta] + \[Gamma] - \[Delta] + \[Zeta]\ Cos[\[Tau] + \[Omega]] - \[Lambda]\ \
Cos[\[Phi] + \[Omega]] + \[Eta]\ Cos[\[Chi] + \[Omega]] - \[Kappa]\ \
Cos[\[Psi] + \[Omega]], \ \[Alpha] - \[Beta] + \[Gamma] - \[Delta] + \[Zeta]\ \
Cos[\[Tau] - \[Omega]] - \[Lambda]\ Cos[\[Phi] - \[Omega]] + \[Eta]\ Cos[\
\[Chi] - \[Omega]] - \[Kappa]\ Cos[\[Psi] - \[Omega]], \ \[Alpha] + \[Beta] - \
\[Gamma] - \[Delta] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  + \[Lambda]\ \
Cos[\[Phi]]\ \ \ \ \  - \[Eta]\ Cos[\[Chi]]\ \ \ \ \ \  - \[Kappa]\ \
Cos[\[Psi]], \ \[Alpha] + \[Beta] - \[Gamma] - \[Delta] + \[Zeta]\ Cos[\[Tau] \
+ \[Omega]] + \[Lambda]\ Cos[\[Phi] + \[Omega]] - \[Eta]\ Cos[\[Chi] + \
\[Omega]] - \[Kappa]\ Cos[\[Psi] + \[Omega]], \ \[Alpha] + \[Beta] - \[Gamma] \
- \[Delta] + \[Zeta]\ Cos[\[Tau] - \[Omega]] + \[Lambda]\ Cos[\[Phi] - \
\[Omega]] - \[Eta]\ Cos[\[Chi] - \[Omega]] - \[Kappa]\ Cos[\[Psi] - \
\[Omega]], \ \[Alpha] - \[Beta] - \[Gamma] + \[Delta] + \[Zeta]\ Cos[\[Tau]]\ \
\ \ \ \ \  - \[Lambda]\ Cos[\[Phi]]\ \ \ \ \  - \[Eta]\ Cos[\[Chi]]\ \ \ \ \ \
\  + \[Kappa]\ Cos[\[Psi]], \ \[Alpha] - \[Beta] - \[Gamma] + \[Delta] + \
\[Zeta]\ Cos[\[Tau] + \[Omega]] - \[Lambda]\ Cos[\[Phi] + \[Omega]] - \[Eta]\ \
Cos[\[Chi] + \[Omega]] + \[Kappa]\ Cos[\[Psi] + \[Omega]], \ \[Alpha] - \
\[Beta] - \[Gamma] + \[Delta] + \[Zeta]\ Cos[\[Tau] - \[Omega]] - \[Lambda]\ \
Cos[\[Phi] - \[Omega]] - \[Eta]\ Cos[\[Chi] - \[Omega]] + \[Kappa]\ \
Cos[\[Psi] - \[Omega]]}/12;\)\)\)], "Input",
  FormatType->TraditionalForm,
  FontSize->9],

Cell[CellGroupData[{

Cell[BoxData[
    \(Use["\<C3K\>"]; topol\)], "Input",
  CellOpen->False],

Cell[BoxData[
    \({a + b + c + d + e + f + g + h + i + j + k + l, 
      a + b + c - d - e - f + g + h + i - j - k - l, 
      a + b + c + d + e + f - g - h - i - j - k - l, 
      a + b + c - d - e - f - g - h - i + j + k + l, 
      1\/2\ \((\((a - b + d - e + g - h + j - k)\)\^2 + \((b - c + e - f + h \
- i + k - l)\)\^2 + \((\(-a\) + c - d + f - g + i - j + l)\)\^2)\), 
      ArcTan[2\ a - b - c + 2\ d - e - f + 2\ g - h - i + 2\ j - k - 
          l, \(-\@3\)\ \((b - c + e - f + h - i + k - l)\)], 
      1\/2\ \((\((a - b - d + e + g - h - j + k)\)\^2 + \((\(-a\) + c + d - f \
- g + i + j - l)\)\^2 + \((b - c - e + f + h - i - k + l)\)\^2)\), 
      ArcTan[2\ a - b - c - 2\ d + e + f + 2\ g - h - i - 2\ j + k + 
          l, \(-\@3\)\ \((b - c - e + f + h - i - k + l)\)], 
      1\/2\ \((\((a - b + d - e - g + h - j + k)\)\^2 + \((\(-a\) + c - d + f \
+ g - i + j - l)\)\^2 + \((b - c + e - f - h + i - k + l)\)\^2)\), 
      ArcTan[2\ a - b - c + 2\ d - e - f - 2\ g + h + i - 2\ j + k + 
          l, \(-\@3\)\ \((b - c + e - f - h + i - k + l)\)], 
      1\/2\ \((\((a - b - d + e - g + h + j - k)\)\^2 + \((b - c - e + f - h \
+ i + k - l)\)\^2 + \((\(-a\) + c + d - f + g - i - j + l)\)\^2)\), 
      ArcTan[2\ a - b - c - 2\ d + e + f - 2\ g + h + i + 2\ j - k - 
          l, \(-\@3\)\ \((b - c - e + f - h + i + k - l)\)]}\)], "Output",
  FontSize->9]
}, Open  ]],

Cell[TextData[{
  "\tHere the substitutions \[Zeta]=2",
  Cell[BoxData[
      \(TraditionalForm\`\@\[Zeta]\[Zeta]\)]],
  ", \[Lambda]=2",
  Cell[BoxData[
      \(TraditionalForm\`\@\[Lambda]\[Lambda]\)]],
  ", \[Eta]=2",
  Cell[BoxData[
      \(TraditionalForm\`\@\[Eta]\[Eta]\)]],
  ", \[Kappa]=2",
  Cell[BoxData[
      \(TraditionalForm\`\@\[Kappa]\[Kappa]\)]],
  " are made, to give a compact expression. \n\tNote that \[Zeta]\[Zeta], \
\[Lambda]\[Lambda], \[Eta]\[Eta], & \[Kappa]\[Kappa] represent quadratic \
sizes that are expressible as a sums of squares, so they are positive for \
real elements. I conjecture that they correspond to Planck areas, and provide \
a fundamental scale; their square roots provide radii (2",
  Cell[BoxData[
      \(TraditionalForm\`\@\[Zeta]\[Zeta]\)]],
  "/12 etc) for multiphase deBroglie-like sinusoids. The angles \[Tau], \
\[Phi], \[Chi], & \[Psi] are \"hidden variables\" in the vector form. PROBLEM \
1 - how do these relate to space-time? PROBLEM 2 - resonances and higher \
frequencies?"
}], "Text",
  PageWidth->WindowWidth],

Cell["\<\
\tC3C4 has a polar dual that can be expressed as {\[Alpha], \[Beta], \
\[Epsilon]\[Epsilon], \[Sigma], \[Zeta]\[Zeta], \[Tau], \[Lambda]\[Lambda], \
\[Phi], \[Eta]\[Eta], \[Chi], \[Kappa]\[Kappa], \[Psi]} (with {\[Alpha], \
\[Beta], \[Zeta]\[Zeta], \[Tau], \[Lambda]\[Lambda], \[Phi], \[Eta]\[Eta]} in \
common with C3K) :-\
\>", "Text"],

Cell[BoxData[
    \({\[Alpha] = a + b + c + d + e + f + g + h + i + j + k + l, \[Beta] = 
        a + b + c - d - e - f + g + h + i - j - k - 
          l, \[Epsilon]\[Epsilon] = \((a + b + c - g - h - i)\)\^2 + \((d + e \
+ f - j - k - l)\)\^2, \[Sigma] = 
        ArcTan[a + b + c - g - h - i, 
          d + e + f - j - k - 
            l], \[Zeta]\[Zeta] = \((\((a - b + d - e + g - h + j - k)\)\^2 + \
\((b - c + e - f + h - i + k - l)\)\^2 + \((\(-a\) + c - d + f - g + i - j + \
l)\)\^2)\)/2, \[Tau] = 
        ArcTan[2\ a - b - c + 2\ d - e - f + 2\ g - h - i + 2\ j - k - 
            l, \(-\@3\)\ \((b - c + e - f + h - i + k - 
                l)\)], \[Lambda]\[Lambda] = \((\((a - b - d + e + g - h - j + \
k)\)\^2 + \((\(-a\) + c + d - f - g + i + j - l)\)\^2 + \((b - c - e + f + h \
- i - k + l)\)\^2)\)/2, \[Phi] = 
        ArcTan[2\ a - b - c - 2\ d + e + f + 2\ g - h - i - 2\ j + k + 
            l, \(-\@3\)\ \((b - c - e + f + h - i - k + 
                l)\)], \[Eta]\[Eta] = \ \((\((a - b + d - e - g + h - j + \
k)\)\^2 + \((\(-a\) + c - d + f + g - i + j - l)\)\^2 + \((b - c + e - f - h \
+ i - k + l)\)\^2)\)/2, \[Chi] = 
        ArcTan[2\ a - b - c + 2\ d - e - f - 2\ g + h + i - 2\ j + k + 
            l, \(-\@3\)\ \((b - c + e - f - h + i - k + 
                l)\)], \[Kappa]\[Kappa] = \((\((a - b - d + e - g + h + j - \
k)\)\^2 + \((b - c - e + f - h + i + k - l)\)\^2 + \((\(-a\) + c + d - f + g \
- i - j + l)\)\^2)\)/2, \[Psi] = 
        ArcTan[2\ a - b - c - 2\ d + e + f - 2\ g + h + i + 2\ j - k - 
            l, \(-\@3\)\ \((b - c - e + f - h + i + k - l)\)]}\)], "Input",
  FontSize->9],

Cell["\<\
\tIt can be reverted as follows:-\
\>", "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\(\(\ \ \)\(C3C4O = {\[IndentingNewLine]\[Alpha] + \[Beta] + \
\[Epsilon]\ \ Cos[\[Sigma]] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  + \[Lambda]\ \
Cos[\[Phi]]\ \ \ \ \ \ \ \ \ \  + \[Eta]\ Cos[x] + \[Eta]\ r3\ Sin[
                  x] + \[Kappa]\ Cos[y] + \[Kappa]\ r3\ Sin[
                  y], \[IndentingNewLine]\[Alpha] + \[Beta] + \
\[Epsilon]\ \ Cos[\[Sigma]] + \[Zeta]\ Cos[\[Tau] + \[Omega]] + \[Lambda]\ \
Cos[\[Phi] + \[Omega]]\ \ \ \ \  - \[Eta]\ Cos[x] + \[Eta]\ r3\ Sin[
                  x] - \[Kappa]\ Cos[y] + \[Kappa]\ r3\ Sin[
                  y], \ \[IndentingNewLine]\[Alpha] + \[Beta] + \
\[Epsilon]\ \ Cos[\[Sigma]] + \[Zeta]\ Cos[\[Tau] - \[Omega]] + \[Lambda]\ \
Cos[\[Phi] - \[Omega]] - \[Eta]\ r6\ Sin[
                  x]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \  - \[Kappa]\ r6\ Sin[
                  y], \[IndentingNewLine]\[Alpha] - \[Beta] + \
\[Epsilon]\ \ Sin[\[Sigma]] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \  - \[Lambda]\ \
Cos[\[Phi]]\ \ \ \ \ \  + \[Eta]\ r3\ Cos[x]\ \ \ \ \  - \[Eta]\ Sin[
                  x] - \[Kappa]\ r3\ Cos[y] + \[Kappa]\ Sin[
                  y], \[IndentingNewLine]\[Alpha] - \[Beta] + \
\[Epsilon]\ \ Sin[\[Sigma]] + \[Zeta]\ Cos[\[Tau] + \[Omega]] - \[Lambda]\ \
Cos[\[Phi] + \[Omega]] + \[Eta]\ r3\ Cos[x]\ \ \ \ \  + \[Eta]\ Sin[
                  x] - \[Kappa]\ r3\ Cos[y] - \[Kappa]\ Sin[
                  y], \[IndentingNewLine]\[Alpha] - \[Beta] + \
\[Epsilon]\ \ Sin[\[Sigma]] + \[Zeta]\ Cos[\[Tau] - \[Omega]] - \[Lambda]\ \
Cos[\[Phi] - \[Omega]] - \[Eta]\ r6\ Cos[
                  x]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \  + \[Kappa]\ r6\ Cos[
                  y], \[IndentingNewLine]\[Alpha] + \[Beta] - \
\[Epsilon]\ \ Cos[\[Sigma]] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \  + \[Lambda]\ \
Cos[\[Phi]]\ \ \ \ \ \ \ \ \ \ \  - \[Eta]\ Cos[x] - \[Eta]\ r3\ Sin[
                  x] - \[Kappa]\ Cos[y] - \[Kappa]\ r3\ Sin[
                  y]\ , \[IndentingNewLine]\[Alpha] + \[Beta] - \
\[Epsilon]\ \ Cos[\[Sigma]] + \[Zeta]\ Cos[\[Tau] + \[Omega]] + \[Lambda]\ \
Cos[\[Phi] + \[Omega]]\ \ \ \ \  + \[Eta]\ Cos[x] - \[Eta]\ r3\ Sin[
                  x] + \[Kappa]\ Cos[y] - \[Kappa]\ r3\ Sin[
                  y], \ \[IndentingNewLine]\[Alpha] + \[Beta] - \
\[Epsilon]\ \ Cos[\[Sigma]] + \[Zeta]\ Cos[\[Tau] - \[Omega]] + \[Lambda]\ \
Cos[\[Phi] - \[Omega]] + \[Eta]\ r6\ Sin[
                  x]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \  - \[Kappa]\ r6\ Sin[
                  y], \[IndentingNewLine]\[Alpha] - \[Beta] - \
\[Epsilon]\ \ Sin[\[Sigma]] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \  - \[Lambda]\ \
Cos[\[Phi]]\ \ \ \ \ \  - \[Eta]\ r3\ Cos[x]\ \ \ \ \  + \[Eta]\ Sin[
                  x] + \[Kappa]\ r3\ Cos[y] - \[Kappa]\ Sin[
                  y], \[IndentingNewLine]\[Alpha] - \[Beta] - \
\[Epsilon]\ \ Sin[\[Sigma]] + \[Zeta]\ Cos[\[Tau] + \[Omega]] - \[Lambda]\ \
Cos[\[Phi] + \[Omega]] - \[Eta]\ r3\ Cos[x]\ \ \ \ \  - \[Eta]\ Sin[
                  x] + \[Kappa]\ r3\ Cos[y] + \[Kappa]\ Sin[
                  y], \[IndentingNewLine]\[Alpha] - \[Beta] - \
\[Epsilon]\ \ Sin[\[Sigma]] + \[Zeta]\ Cos[\[Tau] - \[Omega]] - \[Lambda]\ \
Cos[\[Phi] - \[Omega]] + \[Eta]\ r6\ Cos[
                  x]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  + \[Kappa]\
\ r6\ Cos[y]}/12;\)\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  FontSize->9],

Cell[TextData[{
  "(Here \[Epsilon]=2",
  Cell[BoxData[
      \(TraditionalForm\`\@\[Epsilon]\[Epsilon]\)]],
  ", \[Zeta]=2",
  Cell[BoxData[
      \(TraditionalForm\`\@\[Zeta]\[Zeta]\)]],
  ", \[Lambda]=2",
  Cell[BoxData[
      \(TraditionalForm\`\@\[Lambda]\[Lambda]\)]],
  ", \[Eta]=",
  Cell[BoxData[
      \(TraditionalForm\`\@\(3  \[Eta]\[Eta]\)\)]],
  ", \[Kappa]=",
  Cell[BoxData[
      \(TraditionalForm\`\@\(3  \[Kappa]\[Kappa]\)\)]],
  ",  x=\[Chi]+\[Pi]/6, y=\[Psi]+\[Pi]/6, \[Omega]=2\[Pi]/3, r3=",
  Cell[BoxData[
      \(TraditionalForm\`\@3\)]],
  ", r6=2",
  Cell[BoxData[
      \(TraditionalForm\`\@3\)]],
  ")\n\tOrbits are obtained by setting some of the parameters {\[Alpha], \
\[Beta], \[Gamma], \[Delta], \[Epsilon]\[Epsilon], \[Zeta]\[Zeta] ,\[Lambda]\
\[Lambda] , ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\[Eta]\)]],
  ", \[Kappa]\[Kappa]} to zero or 1 and constraining the product of the \
remainder to be 1.\n\tSimilar, but simpler, expressions give Q12 & D3C2 \
orbits.The parameters are related to those for C3K and C3C4."
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\(Q12O = \[IndentingNewLine]{\ \ \((\[Alpha] + \[Beta] + \[Epsilon]\ \
Cos[\[Sigma]] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  + \[Eta]\ Cos[\[Chi]])\), \
\[IndentingNewLine]\((\[Alpha] + \[Beta] + \[Epsilon]\ Cos[\[Sigma]] + \
\[Zeta]\ Cos[\[Tau] + \[Omega]] + \[Eta]\ Cos[\[Chi] + \[Omega]])\), \
\[IndentingNewLine]\((\[Alpha] + \[Beta] + \[Epsilon]\ Cos[\[Sigma]] + \
\[Zeta]\ Cos[\[Tau] - \[Omega]] + \[Eta]\ Cos[\[Chi] - \[Omega]])\), \
\[IndentingNewLine]\((\[Alpha] - \[Beta] + \[Epsilon]\ Sin[\[Sigma]]\ \ \ \ \ \
 + \[Lambda]\ Cos[\[Phi]]\ \ \ \ \  + \[CurlyKappa]\ Cos[\[Psi]])\), \
\[IndentingNewLine]\((\[Alpha] - \[Beta] + \[Epsilon]\ Sin[\[Sigma]]\ \ \ \ \ \
 + \[Lambda]\ Cos[\[Phi] + \[Omega]] + \[CurlyKappa]\ Cos[\[Psi] + \[Omega]])\
\), \[IndentingNewLine]\((\[Alpha] - \[Beta] + \[Epsilon]\ Sin[\[Sigma]]\ \ \ \
\ \  + \[Lambda]\ Cos[\[Phi] - \[Omega]] + \[CurlyKappa]\ Cos[\[Psi] - \
\[Omega]])\), \[IndentingNewLine]\((\[Alpha] + \[Beta] - \[Epsilon]\ Cos[\
\[Sigma]] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  - \[Eta]\ Cos[\[Chi]])\), \
\[IndentingNewLine]\((\[Alpha] + \[Beta] - \[Epsilon]\ Cos[\[Sigma]] + \
\[Zeta]\ Cos[\[Tau] + \[Omega]] - \[Eta]\ Cos[\[Chi] + \[Omega]])\), \
\[IndentingNewLine]\((\[Alpha] + \[Beta] - \[Epsilon]\ Cos[\[Sigma]] + \
\[Zeta]\ Cos[\[Tau] - \[Omega]] - \[Eta]\ Cos[\[Chi] - \[Omega]])\), \
\[IndentingNewLine]\((\[Alpha] - \[Beta] - \[Epsilon]\ Sin[\[Sigma]]\ \ \ \ \ \
\  + \[Lambda]\ Cos[\[Phi]]\ \ \ \ \  - \[CurlyKappa]\ Cos[\[Psi]])\), \
\[IndentingNewLine]\((\[Alpha] - \[Beta] - \[Epsilon]\ Sin[\[Sigma]]\ \ \ \ \ \
\  + \[Lambda]\ Cos[\[Phi] - \[Omega]] - \[CurlyKappa]\ Cos[\[Psi] + \
\[Omega]])\), \[IndentingNewLine]\((\[Alpha] - \[Beta] - \[Epsilon]\ Sin[\
\[Sigma]]\ \ \ \ \ \  + \[Lambda]\ Cos[\[Phi] - \[Omega]] - \[CurlyKappa]\ \
Cos[\[Psi] - \[Omega]])\)}/12;\)\)], "Input",
  PageWidth->WindowWidth,
  FontSize->9],

Cell["\<\
\tThis (and D3C2O, below) gives a 12-phase system if \
\[Psi]=\[Chi]\[PlusMinus]\[Pi]/6 & \[CurlyKappa]=\[Eta]. A polarised 3-phase \
system (with polarisation angle \[CurlyPhi]) is given by \[Phi]=\[Tau]+\
\[CurlyPhi] & \[Lambda]=\[PlusMinus]\[Zeta].\
\>", "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\(D3C2O = \[IndentingNewLine]{\ \ \((\[Alpha] + \[Beta] + \[Gamma] + \
\[Delta] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  + \[Eta]\ Cos[\[Chi]])\), \
\[IndentingNewLine]\((\[Alpha] + \[Beta] + \[Gamma] + \[Delta] + \[Zeta]\ \
Cos[\[Tau] + \[Omega]] + \[Eta]\ Cos[\[Chi] + \[Omega]])\), \
\[IndentingNewLine]\((\[Alpha] + \[Beta] + \[Gamma] + \[Delta] + \[Zeta]\ \
Cos[\[Tau] - \[Omega]] + \[Eta]\ Cos[\[Chi] - \[Omega]])\), \
\[IndentingNewLine]\((\[Alpha] - \[Beta] + \[Gamma] - \[Delta]\ \ \ \ \ \  - \
\[Lambda]\ Cos[\[Phi]]\ \ \ \ \ \  - \[CurlyKappa]\ Cos[\[Psi]])\), \
\[IndentingNewLine]\((\[Alpha] - \[Beta] + \[Gamma] - \[Delta]\ \ \ \ \ \  - \
\[Lambda]\ Cos[\[Phi] + \[Omega]] - \[CurlyKappa]\ Cos[\[Psi] + \[Omega]])\), \
\[IndentingNewLine]\((\[Alpha] - \[Beta] + \[Gamma] - \[Delta]\ \ \ \ \ \  - \
\[Lambda]\ Cos[\[Phi] - \[Omega]] - \[CurlyKappa]\ Cos[\[Psi] - \[Omega]])\), \
\[IndentingNewLine]\((\[Alpha] + \[Beta] - \[Gamma] - \[Delta] + \[Zeta]\ \
Cos[\[Tau]]\ \ \ \ \ \  - \[Eta]\ Cos[\[Chi]])\), \[IndentingNewLine]\((\
\[Alpha] + \[Beta] - \[Gamma] - \[Delta] + \[Zeta]\ Cos[\[Tau] + \[Omega]] - \
\[Eta]\ Cos[\[Chi] + \[Omega]])\), \[IndentingNewLine]\((\[Alpha] + \[Beta] - \
\[Gamma] - \[Delta] + \[Zeta]\ Cos[\[Tau] - \[Omega]] - \[Eta]\ Cos[\[Chi] - \
\[Omega]])\), \[IndentingNewLine]\((\[Alpha] - \[Beta] - \[Gamma] + \[Delta]\ \
\ \ \ \ \  - \[Lambda]\ Cos[\[Phi]]\ \ \ \ \ \  + \[CurlyKappa]\ Cos[\[Psi]])\
\), \[IndentingNewLine]\((\[Alpha] - \[Beta] - \[Gamma] + \[Delta]\ \ \ \ \ \ \
 - \[Lambda]\ Cos[\[Phi] + \[Omega]] + \[CurlyKappa]\ Cos[\[Psi] + \[Omega]])\
\), \[IndentingNewLine]\((\[Alpha] - \[Beta] - \[Gamma] + \[Delta]\ \ \ \ \ \ \
 - \[Lambda]\ Cos[\[Phi] - \[Omega]] + \[CurlyKappa]\ Cos[\[Psi] - \[Omega]])\
\)}/12;\)\)], "Input",
  PageWidth->WindowWidth,
  FontSize->9],

Cell["\<\
\tEach set of angles involving \[Omega]=2\[Pi]/3 gives a chiral orbit; the \
chirality is reversed if the angle is negated.\
\>", "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.4. C5, C7 & C8 Orbits have unstable amplitudes.", "Subsubsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tThe orbits of C3 have squared radius of magnitude 2/3, with offsets \
{0,0,0} or {1/3, 1/3, 1/3).  Those of C4 have squared radii or ulnae of \
magnitude 1/2, and offsets {0,..} or {\[PlusMinus]1/4,..}. Orbits of C5, C7, \
Cp (p prime>3) etc can be developed, with p sinusoidal phases, but their \
radii are unconstrained, though their offsets are 0 or 1/p. Example 21 shows \
that OC5dr, a five-phase orbit with a displacement d and radius ",
  StyleBox["r",
    FontSlant->"Italic"],
  ", has a quartic size of zero and so is unconstrained. The angle, linear L1 \
and quartic parameters only use 3 of the 5 degrees of freedom. Similarly, a \
seven-phase orbit with radius ",
  StyleBox["r",
    FontSlant->"Italic"],
  " has a zero size in C7 (I have not found a polar expression for this \
group) and an eight-phase orbit with radius ",
  StyleBox["r",
    FontSlant->"Italic"],
  " has a zero size in C8. These orbits also appear to be unstable - \
numerical integration of the relevant differential-equation sets is \
unstable."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["\<\
{Use[\"C5\"];\"Example 21.  Zero-sized C5 orbit.\\nOC5dr is\",OC5dr = 
    tovec/. as[{d, r, \[Sigma]}], 
  \"\\nThe radius disappears from the shape\", 
  Simplify[sh/. as[OC5dr]]}\
\>", "Input",
  PageWidth->WindowWidth,
  CellOpen->False,
  FontFamily->"Courier"],

Cell[BoxData[
    \({"Example 21.  Zero-sized C5 orbit.\nOC5dr is", {1\/5\ \((d + 
              r\ Sin[\[Sigma]])\), 
        1\/5\ \((d + r\ Sin[\(2\ \[Pi]\)\/5 + \[Sigma]])\), 
        1\/5\ \((d + r\ Sin[\(4\ \[Pi]\)\/5 + \[Sigma]])\), 
        1\/5\ \((d + r\ Sin[\(6\ \[Pi]\)\/5 + \[Sigma]])\), 
        1\/5\ \((d + r\ Sin[\(8\ \[Pi]\)\/5 + \[Sigma]])\)}, 
      "\nThe radius disappears from the shape", {d, 0}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3.5. The limited number of stable orbits may limit the number of stable \
particles.\
\>", "Subsubsection",
  PageWidth->WindowWidth],

Cell["\<\
\tI surmise that stable orbits represent stable particles, and that the \
number of stable particles is determined by the limited number of stable \
particles. 
\tStable, finite amplitude, orbits with 3, 4, & 6 phases have been found, \
some of which have polarization and chirality. Some of these require the \
angles to be related. The following examples are restrictions (with various \
radii and offsets set to zero) of the tables in section 3.3.\
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \({"\<Example 22. 3-phase C3K Orbit (0mitting the 1/12 factor).\n\>", \ 
      12  C3KO /. {\[Lambda] \[Rule] 0, \[Eta] \[Rule] 0, \[Kappa] \[Rule] 
              0, \[CurlyKappa] \[Rule] 0} // tf}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 22. 3-phase C3K Orbit (0mitting the 1/12 \
factor).\\n\"\>", ",", 
        TagBox[
          
          FormBox[\({\[Alpha] + \[Beta] + \[Gamma] + \[Delta] + \[Zeta]\ \
\(cos(\[Tau])\), \[Alpha] + \[Beta] + \[Gamma] + \[Delta] + \[Zeta]\ \(cos(\
\[Tau] + \[Omega])\), \[Alpha] + \[Beta] + \[Gamma] + \[Delta] + \[Zeta]\ \
\(cos(\[Tau] - \[Omega])\), \[Alpha] - \[Beta] + \[Gamma] - \[Delta] + \
\[Zeta]\ \(cos(\[Tau])\), \[Alpha] - \[Beta] + \[Gamma] - \[Delta] + \[Zeta]\ \
\(cos(\[Tau] + \[Omega])\), \[Alpha] - \[Beta] + \[Gamma] - \[Delta] + \
\[Zeta]\ \(cos(\[Tau] - \[Omega])\), \[Alpha] + \[Beta] - \[Gamma] - \[Delta] \
+ \[Zeta]\ \(cos(\[Tau])\), \[Alpha] + \[Beta] - \[Gamma] - \[Delta] + \
\[Zeta]\ \(cos(\[Tau] + \[Omega])\), \[Alpha] + \[Beta] - \[Gamma] - \[Delta] \
+ \[Zeta]\ \(cos(\[Tau] - \[Omega])\), \[Alpha] - \[Beta] - \[Gamma] + \
\[Delta] + \[Zeta]\ \(cos(\[Tau])\), \[Alpha] - \[Beta] - \[Gamma] + \[Delta] \
+ \[Zeta]\ \(cos(\[Tau] + \[Omega])\), \[Alpha] - \[Beta] - \[Gamma] + \
\[Delta] + \[Zeta]\ \(cos(\[Tau] - \[Omega])\)}\),
            "TraditionalForm"],
          TraditionalForm,
          Editable->True]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
\tThe linear terms {\[Alpha], \[Beta], \[Gamma], \[Delta]} are offsets (\
\[Alpha]/12 etc) from zero. Square roots of the quadratic terms appear as \
radii with scaling factors. Each phase occurs four times in a 3-phase dozal \
orbit, with different linear offsets.
\tThe offsets and scaled radii are omitted in later examples.\
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \({"\<Example 23. 3-phase C3C4 Orbit (omitting \[Alpha], \[Beta], & the \
\[Zeta]/12 factor).\>", \ 
      12  C3C4O/\[Zeta] /. {\[Alpha] \[Rule] 0, \[Beta] -> 
              0, \[Epsilon] \[Rule] 0, \[Lambda] \[Rule] 0, \[Eta] \[Rule] 
              0, \[Kappa] \[Rule] 0} // tf}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 23. 3-phase C3C4 Orbit (omitting \[Alpha], \
\[Beta], & the \[Zeta]/12 factor).\"\>", ",", 
        TagBox[
          
          FormBox[\({cos(\[Tau]), cos(\[Tau] + \[Omega]), 
              cos(\[Tau] - \[Omega]), cos(\[Tau]), cos(\[Tau] + \[Omega]), 
              cos(\[Tau] - \[Omega]), cos(\[Tau]), cos(\[Tau] + \[Omega]), 
              cos(\[Tau] - \[Omega]), cos(\[Tau]), cos(\[Tau] + \[Omega]), 
              cos(\[Tau] - \[Omega])}\),
            "TraditionalForm"],
          TraditionalForm,
          Editable->True]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["topol",
    FontSlant->"Italic"],
  " shows that the squared amplitude ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Zeta]/12)\)\^2\)]],
  "is the sum of three squares:-\n",
  Cell[BoxData[
      StyleBox[\(\((\((a - b - d + e + g - h - j + k)\)\^2 + \((\(-a\) + c + \
d - f - g + i + j - l)\)\^2 + \((b - c - e + f + h - i - k + l)\)\^2)\)/72\),
        FontFamily->"Times New Roman",
        FontWeight->"Plain"]], "Input"]
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \({"\<Example 24. 4-phase C3C4 Orbit \n(omitting \[Epsilon]/12 \
factor).\>", \ 
      12  C3C4O/\[Epsilon] /. {\[Alpha] \[Rule] 0, \[Beta] -> 
              0, \[Zeta] \[Rule] 0, \[Lambda] \[Rule] 0, \[Eta] \[Rule] 
              0, \[Kappa] \[Rule] 0} // tf}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 24. 4-phase C3C4 Orbit \\n(omitting \[Epsilon]/12 \
factor).\"\>", ",", 
        TagBox[
          
          FormBox[\({cos(\[Sigma]), cos(\[Sigma]), cos(\[Sigma]), 
              sin(\[Sigma]), sin(\[Sigma]), 
              sin(\[Sigma]), \(-\(cos(\[Sigma])\)\), \(-\(cos(\[Sigma])\)\), \
\(-\(cos(\[Sigma])\)\), \(-\(sin(\[Sigma])\)\), \(-\(sin(\[Sigma])\)\), \
\(-\(sin(\[Sigma])\)\)}\),
            "TraditionalForm"],
          TraditionalForm,
          Editable->True]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Each of the four phases occur three times. ",
  StyleBox["topol",
    FontSlant->"Italic"],
  " shows that the squared amplitude ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Epsilon]/12)\)\^2\)]],
  " is the sum of two squares:-\n",
  Cell[BoxData[
      \(\((\((a + b + c - g - h - i)\)\^2 + \((d + e + f - j - k - l)\)\^2)\)/
        144\)], "Text",
    FontFamily->"Times New Roman"]
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \({"\<Example 25. 6-phase C3K Orbit.\n\>", \ 
      Simplify[12 
               C3KO/\[Eta] /. {\[Alpha] \[Rule] 0, \[Beta] \[Rule] 
                0, \[Gamma] \[Rule] 0, \[Delta] \[Rule] 0, \[Lambda] \[Rule] 
                0, \[Psi] \[Rule] 0, \[Zeta] \[Rule] 0, \[CurlyKappa] \[Rule] 
                0}] // tf}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 25. 6-phase C3K Orbit.\\n\"\>", ",", 
        TagBox[
          
          FormBox[\({cos(\[Chi]), cos(\[Chi] + \[Omega]), 
              cos(\[Chi] - \[Omega]), cos(\[Chi]), cos(\[Chi] + \[Omega]), 
              cos(\[Chi] - \[Omega]), \(-\(cos(\[Chi])\)\), \(-\(cos(\[Chi] + \
\[Omega])\)\), \(-\(cos(\[Chi] - \[Omega])\)\), \(-\(cos(\[Chi])\)\), \
\(-\(cos(\[Chi] + \[Omega])\)\), \(-\(cos(\[Chi] - \[Omega])\)\)}\),
            "TraditionalForm"],
          TraditionalForm,
          Editable->True]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
\tThe linear terms, and the \[Eta]/12 factor, have been omitted. Each phase \
occurs twice, with different offsets. \
\>", "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.6. Particle Interactions.", "Subsubsection",
  PageWidth->WindowWidth],

Cell["\<\
\tAs Dozal elements resemble quantum operators, the addition/splitting and \
multiplication/division of Dozal vectors should resemble particle decays and \
interactions. All sizes are conserved on multiplication using one or more of \
the groups, so different groups could correspond to interactions according to \
specific force laws. C3K and D3C2 conserve the linear sizes {\[Alpha], \
\[Beta], \[Gamma], \[Delta]} and  C3C4 and Q12 conserve {\[Alpha], \[Beta]} \
on addition and subtraction, corresponding to absorption or emission of \
particles. Multiplication, with remainders, conserves overlapping sets of \
sizes for each group. Conjecture - this may correspond to interactions \
subject to the four forces. (What is the role of A4 here?)  Many other \
functions are conserved on multiplication of orbits, rather than general \
vecs. I have not been able to correlate them with conserved particle \
properties. Resonances are an outstanding problem; if hoops are related to \
differential equations (as the multi-phase sinusoidal orbits suggest) there \
should be solutions with multiple frequencies, corresponding to the plethora \
of short-lived particles. \
\>", "Text",
  PageWidth->WindowWidth],

Cell["\<\
The sh12 functions (given in section 2) are conserved quantities in Dozal \
interactions; different hoops conserve different selections, and some are \
only conserved for orbit interactions. This is a rich topic that has yet to \
be explored, but has promise as an explanation of particle properties.\
\>", "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.7. Reciprocal Radii; Three size regimes?", "Subsubsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "The Dozal sizes with ternary symmetry could have three sizes that multiply \
to 1, one corresponding to a Planck area ",
  Cell[BoxData[
      \(TraditionalForm\`P\^2\)]],
  " and the others in a reciprocal relationship, two squared radii ",
  Cell[BoxData[
      \(TraditionalForm\`r\^2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`R\^2\)]],
  " corresponding to the dimensions of \"pseudo-point\" particles and the \
universe. p=r.R gives three size regimes. More work needed."
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.8.  Mass and the Unit Velocity Equation.", "Subsubsection",
  PageWidth->WindowWidth],

Cell["\<\
The basic wave equation in many dimensions gives a unit velocity, which is \
projected onto the different dimensions as velocity components. Massless \
particle waves would be restricted to space-like dimensions, whilst others \
would have velocities in Kaluza-Klein dimensions. Generalizing the \
Schrodinger equation to 12 directions (instead of the 4 implied by using \
\[ImaginaryI]) might lead to a more general description of \"information \
about particles\", and a non-dispersing form (including non-linear terms) \
could describe stable particles.More work needed.\
\>", "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.9.  The 6-vector and Dependent Time.", "Subsubsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "The C3C4 hoop has a conserved quartic ",
  StyleBox["l4s",
    FontSlant->"Italic"],
  " which factorizes into two sums of  squares ",
  StyleBox["l22a",
    FontSlant->"Italic"],
  " & ",
  StyleBox["l22b",
    FontSlant->"Italic"],
  ":- "
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({ab = a - b - g + h, ag = a - b + g - h, bc = b - c - h + i, 
      bh = b - c + h - i, ca = a - c - g + i, ci = a - c + g - i, 
      de = d - e - j + k, dj = d - e + j - k, ef = e - f - k + l, 
      ek = e - f + k - l, fd = d - f - j + l, fl = d - f + j - l, 
      f1 = a - b - g + 
          h + \((d + e - 2\ f - j - k + 
                2  l)\)/\@3, \[IndentingNewLine]f2 = \((a + b - 2  c - g - 
                h + 2  i)\)/\@3 - d + e + j - k, \[IndentingNewLine]f3 = 
        a - b - g + 
          h - \((d + e - 2\ f - j - k + 
                2  l)\)/\@3, \[IndentingNewLine]f4 = \((a + b - 2  c - g - 
                h + 2  i)\)/\@3 + d - e - j + 
          k, \[IndentingNewLine]l4s = \n\((ab\^2 + bc\^2 + ca\^2 + de\^2 + 
                ef\^2 + fd\^2)\)/2 - 
          3 \((ab\ ef - bc\ de)\)\^2, \[IndentingNewLine]l4f = 
        9 \((f1\^2 + f2\^2)\) \((f3\^2 + f4\^2)\)/16}\)], "Input",
  PageWidth->WindowWidth],

Cell[TextData[{
  " This may correspond to a 6-vector ",
  Cell[BoxData[
      \(\((ab\^2 + bc\^2 + ca\^2 + de\^2 + ef\^2 + fd\^2)\)/2\)],
    FontFamily->"Times New Roman"],
  " and a dependent \"time\" ",
  Cell[BoxData[
      \(\(-3\) \((ab\ ef - bc\ de)\)\^2\)], "Input",
    FontFamily->"Times New Roman",
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  ". To be investigated."
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4. Outstanding problems.", "Section",
  FontFamily->"Times New Roman"],

Cell["\<\
\tThe author, as an amateur experimental mathematician, who interprets \
Goedels theorem as \"Truth transcends peoof\", has only concerned himself \
with the demonstrability of hoop algebras and their properties. Rigorous \
analysis, based on primal numbers rather than real numbers, is required.

\tThe only general \[OpenCurlyDoubleQuote]proof\[CloseCurlyDoubleQuote] that \
a table is conservative is by demonstration using random vectors. Direct \
factorization is only possible for small tables. Frobenius\[CloseCurlyQuote]s \
proof has not been extended to folded tables; it does not apply to general \
Moufang loops.
\t
\tOrbits are related to the interpretation of hoops as banded sets of \
differential equations with cyclic solutions; resonances at multiples of the \
fundamental frequency may account for the resonances of particle physics.
\t
\tConservation and orbits are \[OpenCurlyDoubleQuote]emergent properties\
\[CloseCurlyDoubleQuote]; others can be expected when techniques are \
developed to find the shapes of larger hoops. Higher-order sizes may lead to \
new emergent properties. They may be difficult to identify - C3 & C4 have \
duals with only a single angle each, but several years of effort were needed \
before \[OpenCurlyDoubleQuote]L4\[CloseCurlyDoubleQuote], a quartic size of \
C3C4, could be factorized and shown to define two orbits. A4 has one linear \
size, one quadratic size (giving an orbit) and a repeated cubic size that \
appears to discriminate between other types of Dozal orbit. Quartic sizes are \
common; if (like \[OpenCurlyDoubleQuote]L4\[CloseCurlyDoubleQuote]) they have \
a minimum of zero, they may be factorizable. \
\>", "Text"],

Cell[TextData[{
  "\tSome non-abelian hoops have \"pseudo-roots\" that may introduce \
uncertainty because their angles do not add on hoop multiplication. They have \
repeated quadratic roots that release extra degrees of freedom. D3 is the \
smallest non-commutative group. Figure 7 demonstrates that AB differs from BA \
in the D3 algebra; B & A are recovered by pre-mu;tiplication by the \
appropriate inverse. The \"pseudo-power\" A",
  Cell[BoxData[
      \(TraditionalForm\`\^2\)]],
  " differs from the repeated product, but the \"pseudo-root\" recovers A. \
(There may be some new mathematics to discover here!)"
}], "Text"],

Cell[TextData[{
  "Figure 7.",
  StyleBox[" Using D3,  Division & Polar-Vector interconversions are OK, but \
repeated prodcts AA differ from pseudo-powers ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["A",
            FontWeight->"Plain",
            FontSlant->"Plain"], "2"], TraditionalForm]]],
  "."
}], "Text",
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Use["\<D3\>"]; 
    Chop[{Flatten[{"\<If  A=\>", 
              A = {2. , 3. , \(-3. \), 0. , \(-2. \), 1. }, "\<polarA=\>", 
              topol /. as[A]}], 
          Flatten[{"\<Vec(pol(A))=\>", 
              tovec /. as[
                  topol /. as[
                      A]], "\<OK, =A\>", "\<\>", "\<\>", "\<\>", "\<\>", \
"\<\>", "\<\>"}], \[IndentingNewLine]Flatten[{"\<If  B=\>", 
              B = {1. , \(-5. \), 3. , \(-1. \), 2. , 2. }, "\<polarB=\>", 
              topol /. as[B]}], \[IndentingNewLine]Flatten[{"\<AB=\>", 
              AB = hoopTimes[A, B], "\<polarAB=\>", 
              topol /. as[AB]}], \[IndentingNewLine]Flatten[{"\<Ai.AB=\>", 
              ABA = hoopTimes[hoopInverse[A], 
                  AB], "\<OK, =B\>", "\<\>", "\<\>", "\<\>", "\<\>", "\<\>", \
"\<\>"}], \[IndentingNewLine]Flatten[{"\<BA=\>", 
              BA = hoopTimes[B, A], "\<polarBA=\>", 
              topol /. as[BA]}], \[IndentingNewLine]Flatten[{"\<Bi.BA=\>", 
              BAB = hoopTimes[hoopInverse[B], 
                  BA], "\<OK, =A\>", "\<\>", "\<\>", "\<\>", "\<\>", "\<\>", \
"\<\>"}], 
          Flatten[{"\<AA=\>", AA = hoopTimes[A, A], "\<polarAA=\>", 
              topol /. as[AA]}], 
          Flatten[{\*"\"\<\!\(A\^2\)=\>\"", 
              A2 = hoopPower[A, 2], \*"\"\<\!\(polarA\^2\)=\>\"", 
              topol /. as[A2]}], 
          Flatten[{\*"\"\<(\!\(A\^2\)\!\(\()\^\(1/2\)\)\)=\>\"", 
              RA2 = hoopPower[A2, 1/2], "\<polar=\>", topol /. as[RA2]}]}] // 
      tf\)], "Input",
  CellOpen->False],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"If  A=\"\>", "2.`", "3.`", \(-3.`\), "0", \(-2.`\), 
              "1.`", "\<\"polarA=\"\>", "1.`", \(-7.`\), "14.`", 
              "0.19012560334646675`", "21.`", "0.3334731722518321`"},
            {"\<\"Vec(pol(A))=\"\>", "2.`", "3.`", \(-2.9999999999999987`\), 
              "0", \(-1.9999999999999993`\), 
              "1.0000000000000002`", "\<\"OK, =A\"\>", "\<\"\"\>", \
"\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
            {"\<\"If  B=\"\>", "1.`", \(-5.`\), "3.`", \(-1.`\), "2.`", 
              "2.`", "\<\"polarB=\"\>", "2.`", 
              "10.`", \(-34.`\), \(-2.6179938779914944`\), "3.`", 
              "2.700286221232442`"},
            {"\<\"AB=\"\>", \(-23.`\), \(-9.`\), "4.`", "18.`", \(-15.`\), 
              "27.`", "\<\"polarAB=\"\>", 
              "2.`", \(-70.`\), \(-476.`\), \(-2.3869764961206146`\), "577.`",
               "2.899028779494308`"},
            {"\<\"Ai.AB=\"\>", "1.`", \(-4.999999999999998`\), 
              "2.9999999999999987`", \(-1.0000000000000002`\), 
              "1.9999999999999993`", 
              "2.0000000000000018`", "\<\"OK, =B\"\>", "\<\"\"\>", \
"\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
            {"\<\"BA=\"\>", \(-23.`\), \(-5.`\), \(-9.`\), "13.`", \(-2.`\), 
              "28.`", "\<\"polarBA=\"\>", "2.`", \(-70.`\), \(-476.`\), 
              "2.808119481337961`", "343.`", "2.6704321487405127`"},
            {"\<\"Bi.BA=\"\>", "2.`", 
              "2.999999999999999`", \(-3.0000000000000004`\), 
              "0", \(-1.9999999999999993`\), 
              "0.9999999999999991`", "\<\"OK, =A\"\>", "\<\"\"\>", \
"\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
            {"\<\"AA=\"\>", "26.`", "7.`", \(-5.`\), \(-20.`\), 
              "4.`", \(-11.`\), "\<\"polarAA=\"\>", "1.`", "49.`", "196.`", 
              "0.2860552964471535`", "763.`", "0.3334731722518321`"},
            {"\<\"\\!\\(A\\^2\\)=\"\>", "5.`", 
              "16.532249250832564`", \(-18.999999999999996`\), \
\(-1.3562945691657533`\), \(-9.999999999999996`\), 
              "9.824045318333194`", "\<\"\\!\\(polarA\\^2\\)=\"\>", 
              "1.0000000000000124`", \(-49.`\), "195.99999999999977`", 
              "0.38025120669293355`", "440.99999999999983`", 
              "0.6669463445036641`"},
            {"\<\"(\\!\\(A\\^2\\)\\!\\(\\()\\^\\(1/2\\)\\)\\)=\"\>", 
              "2.000000000000001`", 
              "3.0000000000000018`", \(-2.9999999999999982`\), 
              "0", \(-1.9999999999999984`\), 
              "1.0000000000000013`", "\<\"polar=\"\>", 
              "1.0000000000000082`", \(-7.`\), "13.99999999999999`", 
              "0.19012560334646675`", "20.999999999999993`", 
              "0.3334731722518321`"}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
  FontSize->9]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5. References.", "Section",
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "[1] H.-D Ebbinghaus et al, Numbers, Springer-Verlag N.Y. 1991 p22.",
  "\n",
  "[2] ",
  " ",
  ButtonBox["http://library.wolfram.com/infocenter/MathSource/4894/",
    ButtonData:>{
      URL[ "http://library.wolfram.com/infocenter/MathSource/4894/"], None},
    ButtonStyle->"Hyperlink"],
  "  R.H.Beresford 2003-6.",
  "\n",
  "[3] J.D.H. Smith, A.B. Romanowska, Post-Modern Algebra, Wiley Interscience \
1999.",
  "\n",
  "[4] ",
  "J.J.Hamilton, Hypercomplex numbers and the description of spin states, \
J.Math.Phys. ",
  StyleBox["38",
    FontWeight->"Bold"],
  "(10) Oct. 1997. pp4914-4928.",
  "\n",
  "[5] P. Lounesto, Clifford Algebras & Spinors 2nd ed., Cambridge University \
Press 2001."
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 887}},
AutoGeneratedPackage->None,
WindowToolbars->"EditBar",
WindowSize->{1050, 682},
WindowMargins->{{65, Automatic}, {Automatic, 39}},
PrintingCopies->1,
PrintingPageRange->{1, 1},
PageHeaders->{{Inherited, Inherited, Inherited}, {None, Inherited, None}},
PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Cell[ 
        TextData[ "21/2/07"]], Cell[ 
        TextData[ "Hoop Algebras."]]}},
Magnification->1.5
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 69, 1, 141, "Title"],
Cell[1848, 56, 547, 20, 115, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2420, 80, 93, 2, 109, "Section"],
Cell[2516, 84, 1586, 29, 333, "Text"],
Cell[4105, 115, 829, 25, 125, "Text"],
Cell[4937, 142, 39, 1, 42, "Input"],
Cell[4979, 145, 74, 2, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5090, 152, 69, 1, 109, "Section"],
Cell[5162, 155, 1286, 17, 307, "Text"],
Cell[6451, 174, 7803, 204, 984, "Text"],
Cell[14257, 380, 8469, 331, 464, "Text"],
Cell[22729, 713, 706, 14, 125, "Text"],
Cell[23438, 729, 9013, 330, 530, "Text"],
Cell[32454, 1061, 2250, 56, 333, "Text"],
Cell[34707, 1119, 119, 4, 47, "Text"],

Cell[CellGroupData[{
Cell[34851, 1127, 416, 7, 28, "Input",
  CellOpen->False],
Cell[35270, 1136, 1052, 23, 371, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36359, 1164, 579, 11, 28, "Input",
  CellOpen->False],
Cell[36941, 1177, 548, 10, 130, "Output"]
}, Open  ]],
Cell[37504, 1190, 385, 6, 99, "Text"],
Cell[37892, 1198, 186, 5, 73, "Text"],

Cell[CellGroupData[{
Cell[38103, 1207, 935, 16, 28, "Input",
  CellOpen->False],
Cell[39041, 1225, 807, 14, 190, "Output"]
}, Open  ]],
Cell[39863, 1242, 821, 12, 203, "Text"],
Cell[40687, 1256, 1543, 33, 255, "Text"],
Cell[42233, 1291, 74, 0, 47, "Text"],

Cell[CellGroupData[{
Cell[42332, 1295, 1688, 35, 28, "Input",
  CellOpen->False],
Cell[44023, 1332, 44, 1, 41, "Output"],
Cell[44070, 1335, 171, 3, 57, "Output"],
Cell[44244, 1340, 45, 1, 41, "Output"],
Cell[44292, 1343, 180, 3, 57, "Output"],
Cell[44475, 1348, 837, 14, 144, "Output"],
Cell[45315, 1364, 44, 1, 41, "Output"],
Cell[45362, 1367, 126, 2, 43, "Output"],
Cell[45491, 1371, 45, 1, 41, "Output"],
Cell[45539, 1374, 192, 3, 101, "Output"],
Cell[45734, 1379, 1124, 21, 144, "Output"]
}, Open  ]],
Cell[46873, 1403, 2922, 49, 593, "Text"],
Cell[49798, 1454, 81, 1, 47, "Text"],
Cell[49882, 1457, 1398, 21, 338, "Input"],
Cell[51283, 1480, 2310, 32, 257, "Input"],
Cell[53596, 1514, 282, 5, 99, "Text"],
Cell[53881, 1521, 7839, 127, 1242, "Input",
  PageBreakWithin->Automatic],
Cell[61723, 1650, 1065, 19, 229, "Text"],
Cell[62791, 1671, 1391, 31, 255, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[64219, 1707, 89, 1, 109, "Section"],
Cell[64311, 1710, 490, 10, 151, "Text"],

Cell[CellGroupData[{
Cell[64826, 1724, 139, 6, 56, "Subsection"],
Cell[64968, 1732, 1636, 45, 255, "Text"],

Cell[CellGroupData[{
Cell[66629, 1781, 2383, 49, 28, "Input",
  CellOpen->False],
Cell[69015, 1832, 4871, 116, 949, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[73935, 1954, 87, 1, 56, "Subsection"],
Cell[74025, 1957, 2634, 73, 359, "Text"],

Cell[CellGroupData[{
Cell[76684, 2034, 756, 14, 28, "Input",
  CellOpen->False],
Cell[77443, 2050, 1320, 26, 443, "Output"]
}, Open  ]],
Cell[78778, 2079, 384, 8, 99, "Text"],

Cell[CellGroupData[{
Cell[79187, 2091, 447, 9, 28, "Input",
  CellOpen->False],
Cell[79637, 2102, 378, 7, 274, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[80064, 2115, 82, 1, 56, "Subsection"],
Cell[80149, 2118, 2153, 66, 335, "Text"],

Cell[CellGroupData[{
Cell[82327, 2188, 3152, 57, 28, "Input",
  CellOpen->False],
Cell[85482, 2247, 4137, 78, 648, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[89668, 2331, 90, 1, 56, "Subsection"],
Cell[89761, 2334, 567, 18, 99, "Text"],

Cell[CellGroupData[{
Cell[90353, 2356, 2741, 51, 28, "Input",
  CellOpen->False],
Cell[93097, 2409, 3549, 62, 516, "Output"]
}, Open  ]],
Cell[96661, 2474, 380, 7, 99, "Text"],

Cell[CellGroupData[{
Cell[97066, 2485, 1974, 39, 28, "Input",
  CellOpen->False],
Cell[99043, 2526, 2393, 39, 316, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[101485, 2571, 84, 1, 56, "Subsection"],
Cell[101572, 2574, 1209, 32, 203, "Text"],

Cell[CellGroupData[{
Cell[102806, 2610, 522, 10, 28, "Input",
  CellOpen->False],
Cell[103331, 2622, 890, 19, 263, "Output"]
}, Open  ]],
Cell[104236, 2644, 209, 5, 73, "Text"],
Cell[104448, 2651, 638, 14, 214, "Output"],

Cell[CellGroupData[{
Cell[105111, 2669, 418, 8, 28, "Input",
  CellOpen->False],
Cell[105532, 2679, 1009, 22, 292, "Output"]
}, Open  ]],
Cell[106556, 2704, 346, 8, 73, "Text"],

Cell[CellGroupData[{
Cell[106927, 2716, 429, 8, 28, "Input",
  CellOpen->False],
Cell[107359, 2726, 2049, 40, 448, "Output"]
}, Open  ]],
Cell[109423, 2769, 419, 16, 73, "Text"],
Cell[109845, 2787, 843, 19, 238, "Input",
  Evaluatable->False],
Cell[110691, 2808, 295, 12, 47, "Text"],

Cell[CellGroupData[{
Cell[111011, 2824, 505, 9, 28, "Input",
  CellOpen->False],
Cell[111519, 2835, 1920, 33, 503, "Output"]
}, Open  ]],
Cell[113454, 2871, 498, 16, 73, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[113989, 2892, 93, 1, 56, "Subsection"],
Cell[114085, 2895, 470, 10, 125, "Text"],

Cell[CellGroupData[{
Cell[114580, 2909, 1233, 21, 28, "Input",
  CellOpen->False],
Cell[115816, 2932, 2956, 56, 853, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[118821, 2994, 76, 1, 56, "Subsection"],
Cell[118900, 2997, 570, 9, 151, "Text"],

Cell[CellGroupData[{
Cell[119495, 3010, 621, 12, 28, "Input",
  CellOpen->False],
Cell[120119, 3024, 570, 9, 191, "Output"]
}, Open  ]],
Cell[120704, 3036, 1298, 34, 151, "Text"],
Cell[122005, 3072, 1401, 34, 229, "Text"],

Cell[CellGroupData[{
Cell[123431, 3110, 1231, 25, 28, "Input",
  CellOpen->False],
Cell[124665, 3137, 1287, 20, 241, "Output"]
}, Open  ]],
Cell[125967, 3160, 253, 5, 99, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[126257, 3170, 84, 1, 56, "Subsection"],
Cell[126344, 3173, 399, 9, 99, "Text"],

Cell[CellGroupData[{
Cell[126768, 3186, 584, 11, 28, "Input",
  CellOpen->False],
Cell[127355, 3199, 1157, 24, 348, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[128549, 3228, 596, 11, 28, "Input",
  CellOpen->False],
Cell[129148, 3241, 1656, 33, 495, "Output"]
}, Open  ]],
Cell[130819, 3277, 427, 8, 125, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[131283, 3290, 120, 3, 56, "Subsection"],
Cell[131406, 3295, 2991, 73, 489, "Text"],

Cell[CellGroupData[{
Cell[134422, 3372, 954, 16, 28, "Input",
  CellOpen->False],
Cell[135379, 3390, 3752, 65, 878, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[139180, 3461, 120, 3, 56, "Subsection"],
Cell[139303, 3466, 1395, 28, 255, "Text"],

Cell[CellGroupData[{
Cell[140723, 3498, 1158, 21, 28, "Input",
  CellOpen->False],
Cell[141884, 3521, 3918, 69, 833, "Output"]
}, Open  ]],
Cell[145817, 3593, 1078, 28, 151, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[146932, 3626, 94, 1, 56, "Subsection"],
Cell[147029, 3629, 1717, 28, 333, "Text"],

Cell[CellGroupData[{
Cell[148771, 3661, 4371, 83, 28, "Input",
  CellOpen->False],
Cell[153145, 3746, 4693, 81, 728, "Output"]
}, Open  ]],
Cell[157853, 3830, 935, 23, 177, "Text"],

Cell[CellGroupData[{
Cell[158813, 3857, 704, 15, 28, "Input",
  CellOpen->False],
Cell[159520, 3874, 765, 13, 421, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[160334, 3893, 89, 1, 56, "Subsection"],
Cell[160426, 3896, 3230, 110, 307, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[163693, 4011, 61, 1, 56, "Subsection"],
Cell[163757, 4014, 1136, 19, 255, "Text"],

Cell[CellGroupData[{
Cell[164918, 4037, 544, 13, 28, "Input",
  CellOpen->False],
Cell[165465, 4052, 590, 9, 277, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[166092, 4066, 1263, 24, 28, "Input",
  CellOpen->False],
Cell[167358, 4092, 1307, 22, 651, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[168726, 4121, 80, 1, 109, "Section"],
Cell[168809, 4124, 953, 13, 307, "Text"],

Cell[CellGroupData[{
Cell[169787, 4141, 72, 1, 40, "Subsubsection"],
Cell[169862, 4144, 481, 8, 125, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[170380, 4157, 90, 1, 40, "Subsubsection"],
Cell[170473, 4160, 599, 21, 73, "Text"],
Cell[171075, 4183, 986, 21, 227, "Input",
  Evaluatable->False],
Cell[172064, 4206, 717, 24, 99, "Text"],
Cell[172784, 4232, 5553, 174, 301, "Input"],
Cell[178340, 4408, 1136, 41, 125, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[179513, 4454, 84, 1, 40, "Subsubsection"],
Cell[179600, 4457, 3342, 96, 438, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[182979, 4558, 147, 4, 40, "Subsubsection"],
Cell[183129, 4564, 279, 5, 73, "Text"],
Cell[183411, 4571, 2365, 33, 277, "Input"],

Cell[CellGroupData[{
Cell[185801, 4608, 73, 2, 28, "Input",
  CellOpen->False],
Cell[185877, 4612, 1378, 21, 331, "Output"]
}, Open  ]],
Cell[187270, 4636, 1074, 25, 151, "Text"],
Cell[188347, 4663, 347, 6, 73, "Text"],
Cell[188697, 4671, 1632, 27, 267, "Input"],
Cell[190332, 4700, 83, 3, 47, "Text"],
Cell[190418, 4705, 3520, 55, 277, "Input"],
Cell[193941, 4762, 1100, 31, 125, "Text"],
Cell[195044, 4795, 1897, 27, 277, "Input"],
Cell[196944, 4824, 301, 6, 73, "Text"],
Cell[197248, 4832, 1834, 26, 277, "Input"],
Cell[199085, 4860, 173, 4, 47, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[199295, 4869, 133, 2, 40, "Subsubsection"],
Cell[199431, 4873, 1092, 22, 203, "Text"],

Cell[CellGroupData[{
Cell[200548, 4899, 276, 8, 28, "Input",
  CellOpen->False],
Cell[200827, 4909, 433, 7, 161, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[201309, 4922, 143, 4, 40, "Subsubsection"],
Cell[201455, 4928, 500, 9, 151, "Text"],

Cell[CellGroupData[{
Cell[201980, 4941, 273, 5, 28, "Input",
  CellOpen->False],
Cell[202256, 4948, 1222, 21, 141, "Output"]
}, Open  ]],
Cell[203493, 4972, 377, 7, 99, "Text"],

Cell[CellGroupData[{
Cell[203895, 4983, 356, 7, 28, "Input",
  CellOpen->False],
Cell[204254, 4992, 611, 13, 91, "Output"]
}, Open  ]],
Cell[204880, 5008, 494, 13, 94, "Text"],

Cell[CellGroupData[{
Cell[205399, 5025, 336, 7, 28, "Input",
  CellOpen->False],
Cell[205738, 5034, 556, 13, 91, "Output"]
}, Open  ]],
Cell[206309, 5050, 447, 13, 94, "Text"],

Cell[CellGroupData[{
Cell[206781, 5067, 392, 8, 28, "Input",
  CellOpen->False],
Cell[207176, 5077, 585, 12, 91, "Output"]
}, Open  ]],
Cell[207776, 5092, 166, 4, 47, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[207979, 5101, 78, 1, 40, "Subsubsection"],
Cell[208060, 5104, 1218, 18, 255, "Text"],
Cell[209281, 5124, 350, 6, 99, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[209668, 5135, 93, 1, 40, "Subsubsection"],
Cell[209764, 5138, 548, 14, 99, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[210349, 5157, 93, 1, 40, "Subsubsection"],
Cell[210445, 5160, 623, 10, 151, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[211105, 5175, 89, 1, 40, "Subsubsection"],
Cell[211197, 5178, 298, 12, 47, "Text"],
Cell[211498, 5192, 953, 17, 292, "Input"],
Cell[212454, 5211, 446, 13, 73, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[212949, 5230, 76, 1, 109, "Section"],
Cell[213028, 5233, 1695, 27, 463, "Text"],
Cell[214726, 5262, 632, 11, 151, "Text"],
Cell[215361, 5275, 395, 13, 73, "Text"],

Cell[CellGroupData[{
Cell[215781, 5292, 1566, 30, 28, "Input",
  CellOpen->False],
Cell[217350, 5324, 2926, 50, 226, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[220325, 5380, 66, 1, 109, "Section"],
Cell[220394, 5383, 758, 24, 151, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

