(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    193789,       4817]*)
(*NotebookOutlinePosition[    194851,       4850]*)
(*  CellTagsIndexPosition[    194807,       4846]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Hoop Algebra Supplement.", "Title",
  PageWidth->WindowWidth],

Cell["R.H.Beresford.  21/2/07.", "Subsubtitle",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell["1. Introduction.", "Section",
  PageWidth->WindowWidth],

Cell[TextData[{
  "This document is supplementary to ",
  StyleBox["\"HoopAlg&Physics.nb\"",
    FontSlant->"Italic"],
  "[in 1]",
  StyleBox[",",
    FontSlant->"Italic"],
  " which is a brief account of Hoop Algebras (also available as ",
  StyleBox["Hoops&Physics.doc",
    FontSlant->"Italic"],
  "[2])."
}], "Text"],

Cell[TextData[{
  "\tHoops are ",
  "defined as ",
  "vector algebras that ",
  StyleBox["conserve the symbolic determinant factors of their Cayley \
multiplication tables as symmetries or \"sizes\". Symmetry conservation \
leads, via Noether's theorem, to forces and to particles",
    PageWidth->WindowWidth],
  ". Consequently, Hoops subsume and unify all the algebras (including Real, \
Complex, Quaternion, Octonion, Clifford and Wedge) relevant to physics. They \
may provide a new paradigm for particle physics, based on vector \
multiplication by finite Moufang loops as well as coordinate transformations \
with continuous groups. Using experimental mathematics the author has found \
many analogies between hoop algebras and particle physics, but (as a 77 yr. \
old chemical engineer) lacks the skills and time to take the subject much \
further.\n\tThe Hoops concept has been implemented in ",
  StyleBox["MathSource/6198/",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  " [1] as a Mathematica package ",
  StyleBox["Hoops.m",
    FontSlant->"Italic"],
  ". This contains over 80 named Hoops (with a few counter-example non-hoop \
Loops), three main procedures ",
  StyleBox["hoopTimes, hoopInverse, hoopPower",
    FontSlant->"Italic"],
  ", and a few subsidiary procedures. Each hoop is defined by a Cayley \
index-table (a preferred isomorph) and its \"shape\" (the distinct factors of \
the inverse symbolic Cayley table). Multiplication, division, and (in many \
cases) inter-conversion between Cartesian vector {a,b,...} and polar {r,\
\[Theta]...} form are provided.\n\tThe figures in this document are \
self-explanatory output from a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session (with results of calculations appearing in ",
  StyleBox["bold-face",
    FontWeight->"Bold"],
  "), comprehensible to readers with no knowledge of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". They use the ",
  StyleBox["Hoops.m",
    FontSlant->"Italic"],
  " package. The input data are usually integer vectors, for clarity.  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " users can test them with different data, by installing ",
  StyleBox["Hoops.nb",
    FontSlant->"Italic"],
  " and running it (to create the ",
  StyleBox["Hoops.m",
    FontSlant->"Italic"],
  " package) in the ",
  StyleBox["Addons\\ExtraPackages",
    FontSlant->"Italic"],
  " directory, and then using the following instructions:-."
}], "Text"],

Cell[BoxData[
    \(Quit[]\)], "Input"],

Cell[BoxData[
    \(<< "\<Hoops`\>"\)], "Input",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Demonstrations.", "Section",
  PageWidth->WindowWidth],

Cell[TextData[{
  "Summary.\n\tExamples demonstrate multiplication and division of vectors in \
different hoop algebras, the \"folding\" of loops to signed algebras with \
conserved sizes and remainders, polar-duals with powers and roots, \
non-Abelian algebras with rotated roots, and the unification of many algebras \
by the Hoop concept. Then ",
  StyleBox["multi-phase sinusoidal ",
    PageWidth->WindowWidth],
  " \"Orbits\" are introduced, as unital dual sub-algebras with relevance to \
physics."
}], "Text",
  PageWidth->WindowWidth,
  FontSlant->"Italic"],

Cell[CellGroupData[{

Cell[TextData[{
  "2.1 ",
  StyleBox["S",
    FontSlant->"Italic"],
  "electing Hoop Algebras."
}], "Subsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tWhen ",
  StyleBox["hoops.m",
    FontSlant->"Italic"],
  " has been activated a specific Hoop is selected by ",
  StyleBox["Use[\"H\"]",
    FontSlant->"Italic"],
  ", where ",
  StyleBox["\"H\"",
    FontSlant->"Italic"],
  " is any Hoop name. This assigns values to the variables {",
  StyleBox["hoopTbl, sh, topol, tovec, mm, nn, gi, gp, plex",
    FontSlant->"Italic"],
  "}. The Cayley table is put into ",
  StyleBox["hoopTbl",
    FontSlant->"Italic"],
  ". ",
  StyleBox["sh",
    FontSlant->"Italic"],
  " is the shape. ",
  StyleBox["topol",
    FontSlant->"Italic"],
  " is the polar form (if known); it defines angles to go with each quadratic \
size in ",
  StyleBox["sh",
    FontSlant->"Italic"],
  ". ",
  StyleBox["tovec",
    FontSlant->"Italic"],
  " is the reversion from polar to vector form. This information allows the \
procedures ",
  StyleBox["hoopTimes, hoopInverse,",
    FontSlant->"Italic"],
  " &",
  StyleBox[" hoopPower",
    FontSlant->"Italic"],
  " to calculate vector products, inverses and (where appropriate) powers, \
and roots. (Vector addition is element-by-element for all hoops with the same \
number of elements.)\n\tExample 1 shows the index table, the symbolic form, \
the shape, the polar form and the vector reversion for the C3, C4 & C2 \
algebras",
  StyleBox[". C2 is unusual, having a \[OpenCurlyDoubleQuote]dual\
\[CloseCurlyDoubleQuote] form that does not involve an angle. ",
    PageWidth->WindowWidth],
  "(Index tables will be shown in later examples if they have not been shown \
previously and are not too large; later input instructions will be hidden in \
\"closed cells\" because they may be incomprehensible to non-",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " users.)  Please ignore the commas that separate explanatory messages and \
the calculated results."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\( (*Example\ 1*) \), 
      RowBox[{"{", 
        RowBox[{\("\<Example 1a\>" // bf\), " ", ",", 
          "\"\<C2 Table and properties.\\nThe C2 index table is\>\"", 
          ",", \(Use["\<C2\>"]; hoopTbl // tf\), ",", 
          "\"\<\\nThe symbolic form is \>\"", 
          ",", \(s = 
            hoopTbl /. 
              Table[ii \[Rule] 
                  alph\[LeftDoubleBracket]ii\[RightDoubleBracket], {ii, mm}]; 
          s // tf\), ",", "\"\<with determinant\>\"", ",", \(Det[s]\), ",", 
          
          RowBox[{\(s =. \), ";", 
            "\"\<\\nthis factorises into the shape \!\(\*
StyleBox[\"sh\",\nFontSlant->\"Italic\"]\)\>\""}], ",", "sh", ",", 
          "\"\<\\ntopol is\>\"", ",", "topol", ",", "\"\<\\ntovec is\>\"", 
          ",", "tovec", ",", 
          "\[IndentingNewLine]", \("\<\nExample 1b\>" // bf\), ",", 
          "\"\< C3 Table and properties.\\nThe C3 index table is\>\"", 
          ",", \(Use["\<C3\>"]; hoopTbl // tf\), ",", 
          "\"\<\\nThe symbolic form is \>\"", 
          ",", \(s = 
            hoopTbl /. 
              Table[ii \[Rule] 
                  alph\[LeftDoubleBracket]ii\[RightDoubleBracket], {ii, mm}]; 
          s // tf\), ",", "\"\<with determinant\>\"", ",", \(Det[s]\), ",", 
          
          RowBox[{\(s =. \), ";", 
            "\"\<\\nthis factorises into the shape \!\(\*
StyleBox[\"sh\",\nFontSlant->\"Italic\"]\)\>\""}], ",", "sh", ",", 
          "\"\<\\ntopol is\>\"", ",", "topol", ",", "\"\<\\ntovec is\>\"", 
          ",", "tovec", ",", 
          "\[IndentingNewLine]", \("\<\nExample 1c\>" // bf\), " ", ",", 
          "\"\< C4 Table and properties.\\nThe C4 index table is\>\"", 
          ",", \(Use["\<C4\>"]; hoopTbl // tf\), ",", 
          "\"\<\\nThe symbolic form is \>\"", 
          ",", \(s = 
            hoopTbl /. 
              Table[ii \[Rule] 
                  alph\[LeftDoubleBracket]ii\[RightDoubleBracket], {ii, mm}]; 
          s // tf\), ",", "\"\<with determinant\>\"", ",", \(Det[s]\), ",", 
          
          RowBox[{\(s =. \), ";", 
            "\"\<\\nthis factorises into the shape \!\(\*
StyleBox[\"sh\",\nFontSlant->\"Italic\"]\)\>\""}], ",", "sh", ",", 
          "\"\<\\ntopol is\>\"", ",", "topol", ",", "\"\<\\ntovec is\>\"", 
          ",", "tovec"}], "}"}]}]], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          StyleBox["\<\"Example 1a\"\>",
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\"C2 Table and properties.\\nThe C2 index table is\"\>", ",", 
        
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2"},
                  {"2", "1"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nThe symbolic form is \"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"a", "b"},
                  {"b", "a"}
                  }], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"with determinant\"\>", 
        ",", \(a\^2 - b\^2\), 
        ",", "\<\"\\nthis factorises into the shape \\!\\(\\* StyleBox[\\\"sh\
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", ",", \({a - b, a + b}\), 
        ",", "\<\"\\ntopol is\"\>", ",", \({a - b, a + b}\), 
        ",", "\<\"\\ntovec is\"\>", 
        ",", \({\(a + b\)\/2, 1\/2\ \((\(-a\) + b)\)}\), ",", 
        TagBox[
          StyleBox["\<\"\\nExample 1b\"\>",
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\" C3 Table and properties.\\nThe C3 index table is\"\>", ",",
         
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3"},
                  {"2", "3", "1"},
                  {"3", "1", "2"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nThe symbolic form is \"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"a", "b", "c"},
                  {"b", "c", "a"},
                  {"c", "a", "b"}
                  }], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"with determinant\"\>", 
        ",", \(\(-a\^3\) - b\^3 + 3\ a\ b\ c - c\^3\), 
        ",", "\<\"\\nthis factorises into the shape \\!\\(\\* StyleBox[\\\"sh\
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
        ",", \({a + b + c, 
          1\/2\ \((\((a - b)\)\^2 + \((b - c)\)\^2 + \((\(-a\) + \
c)\)\^2)\)}\), ",", "\<\"\\ntopol is\"\>", 
        ",", \({a + b + c, 
          1\/2\ \((\((a - b)\)\^2 + \((b - c)\)\^2 + \((\(-a\) + c)\)\^2)\), 
          ArcTan[2\ a - b - c, \(-\@3\)\ \((b - c)\)]}\), 
        ",", "\<\"\\ntovec is\"\>", 
        ",", \({1\/3\ \((a + 2\ \@b\ Cos[c])\), 
          1\/3\ \((a + 2\ \@b\ Cos[c + \(2\ \[Pi]\)\/3])\), 
          1\/3\ \((a + 2\ \@b\ Cos[c - \(2\ \[Pi]\)\/3])\)}\), ",", 
        TagBox[
          StyleBox["\<\"\\nExample 1c\"\>",
            FontWeight->"Bold"],
          (StyleForm[ #, FontWeight -> "Bold"]&)], 
        ",", "\<\" C4 Table and properties.\\nThe C4 index table is\"\>", ",",
         
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4"},
                  {"2", "3", "4", "1"},
                  {"3", "4", "1", "2"},
                  {"4", "1", "2", "3"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nThe symbolic form is \"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"a", "b", "c", "d"},
                  {"b", "c", "d", "a"},
                  {"c", "d", "a", "b"},
                  {"d", "a", "b", "c"}
                  }], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"with determinant\"\>", 
        ",", \(\(-a\^4\) + b\^4 - 4\ a\ b\^2\ c + 2\ a\^2\ c\^2 - c\^4 + 
          4\ a\^2\ b\ d + 4\ b\ c\^2\ d - 2\ b\^2\ d\^2 - 4\ a\ c\ d\^2 + 
          d\^4\), ",", "\<\"\\nthis factorises into the shape \\!\\(\\* \
StyleBox[\\\"sh\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
        ",", \({a + b + c + d, 
          a - b + c - d, \((a - c)\)\^2 + \((b - d)\)\^2}\), 
        ",", "\<\"\\ntopol is\"\>", 
        ",", \({a + b + c + d, 
          a - b + c - d, \((a - c)\)\^2 + \((b - d)\)\^2, 
          ArcTan[a - c, b - d]}\), ",", "\<\"\\ntovec is\"\>", 
        ",", \({1\/4\ \((a + b + 2\ \@c\ Cos[d])\), 
          1\/4\ \((a - b + 2\ \@c\ Sin[d])\), 
          1\/4\ \((a + b - 2\ \@c\ Cos[d])\), 
          1\/4\ \((a - b - 2\ \@c\ Sin[d])\)}\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.2 Vector multiplication and division.", "Subsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tGeneralized vectors (abbreviated to \"vecs\" - they are not vectors in \
some algebras) are lists of ",
  StyleBox["m",
    FontSlant->"Italic"],
  " elements ",
  StyleBox["A=",
    FontSlant->"Italic"],
  "{",
  Cell[BoxData[
      \(TraditionalForm\`\(\(a\_1\)\(,\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`a\_2\)]],
  ",...",
  Cell[BoxData[
      \(TraditionalForm\`a\_m\)]],
  "}. Their components can be numbers (integer, real, complex, or unsigned), \
operators, or symbols; the \"standard form\" uses symbols from a table called \
",
  StyleBox["alph",
    FontSlant->"Italic"],
  ", i.e. A={",
  StyleBox["a,b,c",
    FontSlant->"Italic"],
  "...}. Vectors can also be thought of as summations of coefficients with \
associated dimensions, signs or directions, A = ",
  Cell[BoxData[
      \(TraditionalForm\`a\_1\)]],
  Cell[BoxData[
      \(TraditionalForm\`d\_1\)]],
  " +",
  Cell[BoxData[
      \(TraditionalForm\`a\_2\)]],
  Cell[BoxData[
      \(TraditionalForm\`d\_2\)]],
  " +...+ ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(a\_m\), 
          FormBox[\(d\_m\),
            "TraditionalForm"]}], TraditionalForm]]],
  ".\n\tGeneralized Hoop multiplication is effected by ",
  StyleBox["hoopTimes[A,B]",
    FontSlant->"Italic"],
  ". The elements of the product ",
  StyleBox["AB ",
    FontSlant->"Italic"],
  "are the sum of each ",
  StyleBox["a\[LeftDoubleBracket]k\[RightDoubleBracket] \
b\[LeftDoubleBracket]l\[RightDoubleBracket] Sign[hoopTbl[[k,l]]] ",
    FontSlant->"Italic"],
  "where Table[[k,l]] contains the (possibly signed) index ",
  StyleBox["j",
    FontSlant->"Italic"],
  ".",
  StyleBox[" ",
    FontSlant->"Italic"],
  "The Moufang property ensures that every vec has a multiplicative inverse \
Ai=",
  StyleBox["hoopInverse[A]",
    FontSlant->"Italic"],
  "; division of B by A is ",
  StyleBox["hoopTimes[Ai,B].",
    FontSlant->"Italic"],
  "\n\tHoops are \"conservative\" - the real factors of the symbolic \
determinant are \"size\" functions that are conserved on multiplication, ",
  StyleBox["size[AB] = \[PlusMinus] size[A]size[B]",
    FontSlant->"Italic"],
  ". (Sizes are actually conjugates, but conjugation has no effect in most \
cases.) The sizes are listed in ",
  StyleBox["sh",
    FontSlant->"Italic"],
  ". The inverse has been found by Cramer's method, so the determinant is a \
denominator of the inverse; multiple sizes allow inverses to split into \
partial fractions.\n\tExample 2 demonstrates multiplication and shape \
conservation in the C2 and C3 algebras; both have two sizes. Only the output \
is shown; commas separate a description of the input from the resulting \
output. Note that the sizes of AB are the product of the sizes of A and B. \
(Section 2.8 shows that this is untrue for loops in general.)"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(Use["\<C2\>"]; {"\<Example 2. C2 & C3 multiplication & size \
conservation\>", "\<\nThe C2 table is\>", hoopTbl // tf, "\<with shape\>", 
      sh, "\<\nIf A  = \>", A = {3, 4}, "\<\nand B = \>", 
      B = {x, y}, "\<\nAB = \>", 
      AB = hoopTimes[A, B], "\<\nShape of A  = \>", 
      sh /. \ as[A], "\<\nShape of B  = \>", 
      sh /. \ as[B], "\<\nShape of AB = \>", sh /. \ as[AB], 
      Use["\<C3\>"]; "\<\n\nChange to C3.\nIf A  = \>", 
      A = {3, 4, 1}, "\<\nand B = \>", B = {5, 1, 2}, "\<\nAB = \>", 
      AB = hoopTimes[A, B], "\<\nShape of A  = \>", 
      sh /. \ as[A], "\<\nShape of B  = \>", 
      sh /. \ as[B], "\<\nShape of AB = \>", sh /. \ as[AB]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 2. C2 & C3 multiplication & size conservation\"\>",
         ",", "\<\"\\nThe C2 table is\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2"},
                  {"2", "1"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"with shape\"\>", ",", \({a - b, a + b}\),
         ",", "\<\"\\nIf A  = \"\>", ",", \({3, 4}\), 
        ",", "\<\"\\nand B = \"\>", ",", \({x, y}\), ",", "\<\"\\nAB = \"\>", 
        ",", \({3\ x + 4\ y, 4\ x + 3\ y}\), ",", "\<\"\\nShape of A  = \"\>",
         ",", \({\(-1\), 7}\), ",", "\<\"\\nShape of B  = \"\>", 
        ",", \({x - y, x + y}\), ",", "\<\"\\nShape of AB = \"\>", 
        ",", \({\(-x\) + y, 7\ x + 7\ y}\), 
        ",", "\<\"\\n\\nChange to C3.\\nIf A  = \"\>", ",", \({3, 4, 1}\), 
        ",", "\<\"\\nand B = \"\>", ",", \({5, 1, 2}\), 
        ",", "\<\"\\nAB = \"\>", ",", \({24, 25, 15}\), 
        ",", "\<\"\\nShape of A  = \"\>", ",", \({8, 7}\), 
        ",", "\<\"\\nShape of B  = \"\>", ",", \({8, 13}\), 
        ",", "\<\"\\nShape of AB = \"\>", ",", \({64, 91}\)}], 
      "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Example 3 calculates the inverses of A & B and shows that their sizes are \
inverses of the sizes of A & B. Then ",
  StyleBox["hoopTimes",
    FontSlant->"Italic"],
  " is used to show that Ainverse.AB recovers B, whilst AB.Binverse recovers \
A. (",
  StyleBox["hoopInverse ",
    FontSlant->"Italic"],
  "calculates left-inverses; as C3 is Abelian the distinction is irrelevant \
here.)"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Use["\<C3\>"]; {"\<Example 3. C3 division\>", "\<\nAinverse  = \>", 
      Ai = hoopInverse[A], "\<\nShape of Ainverse  = \>", 
      sh /. \ as[Ai], "\<\nBinverse  = \>", 
      Bi = hoopInverse[B], "\<\nShape of Binverse  = \>", 
      sh /. \ as[Bi], "\<\nAinverse.AB recovers B\>", 
      hoopTimes[Ai, AB], "\<\nAB.Binverse recovers A\>", 
      hoopTimes[AB, Bi]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"Example 3. C3 division", 
      "\nAinverse  = ", {5\/56, \(-\(11\/56\)\), 13\/56}, 
      "\nShape of Ainverse  = ", {1\/8, 1\/7}, 
      "\nBinverse  = ", {23\/104, \(-\(1\/104\)\), \(-\(9\/104\)\)}, 
      "\nShape of Binverse  = ", {1\/8, 1\/13}, 
      "\nAinverse.AB recovers B", {5, 1, 2}, 
      "\nAB.Binverse recovers A", {3, 4, 1}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.3 \"Folding\" Vectors and Loops.", "Subsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tA key concept in Hoop algebra is the \"folding\" of a vector via an \
equivalence relationship \"~\" such as ",
  StyleBox["r[[i]]=a[[i]]-a[[i+m/2]] ~ {a[[i]],a[[i+m/2]]}",
    FontSlant->"Italic"],
  ", which creates a single real number by the \"2-folding\" of pairs of \
unsigned numbers. This introduces the sign \"-\". Similarly,  ",
  StyleBox["t[[i]] ~ a[[i]]+J a[[i+m/3]]+JJ a[[i+2m/3]]",
    FontSlant->"Italic"],
  " folds three unsigned numbers to a \"terplex\" number (with signs ",
  StyleBox["J ",
    FontSlant->"Italic"],
  "& ",
  StyleBox["JJ",
    FontSlant->"Italic"],
  "). One way to fold four unsigned numbers is ",
  StyleBox["c[[i]] ~ a[[i]]+",
    FontSlant->"Italic"],
  StyleBox["i ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["a[[i+m/4]]-a[[i+2m/4]]-",
    FontSlant->"Italic"],
  StyleBox["i ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["a[[i+3m/4]].",
    FontSlant->"Italic"],
  " This creates a complex number and the signs ",
  StyleBox["i ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["&",
    FontSlant->"Italic"],
  " ",
  StyleBox["-",
    FontSlant->"Italic"],
  StyleBox["i",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  ".\n\tFollowing Sir William Hamilton, sets ",
  StyleBox["m",
    FontSlant->"Italic"],
  " of unsigned numbers are \"directors\" with \"",
  StyleBox["m ",
    FontSlant->"Italic"],
  "directions\"; they fold to vectors with \"",
  StyleBox["m/r",
    FontSlant->"Italic"],
  " dimensions\". ",
  StyleBox["The multiplication tables also fold; an ",
    PageWidth->WindowWidth],
  StyleBox["m\[Times]m",
    PageWidth->WindowWidth,
    FontSlant->"Italic"],
  StyleBox[" table with ",
    PageWidth->WindowWidth],
  StyleBox["r",
    PageWidth->WindowWidth,
    FontSlant->"Italic"],
  StyleBox["-fold symmetry can undergo ",
    PageWidth->WindowWidth],
  StyleBox["r",
    PageWidth->WindowWidth,
    FontSlant->"Italic"],
  StyleBox["-folding to an ",
    PageWidth->WindowWidth],
  StyleBox["(m/r)\[Times](m/r)",
    PageWidth->WindowWidth,
    FontSlant->"Italic"],
  StyleBox[" table. ",
    PageWidth->WindowWidth],
  "\n\tExample 4 shows that \"C4\" folds to complex algebra. It demonstrates \
multiplication, division, raising to a power, and extracting a root. In each \
case, the result is shown to fold to the corresponding complex number:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(Use["\<C4\>"]\), ";", 
      RowBox[{"{", 
        RowBox[{
        "\"\<Example 4. C4 folds to Complex algebra.\\nThe table \>\"", 
          ",", \(hoopTbl // tf\), ",", "\"\<can be written as\>\"", 
          ",", \({{1, i, \(-1\), \(-i\)}, {i, \(-1\), \(-i\), 
                1}, {\(-1\), \(-i\), 1, i}, {\(-i\), 1, i, \(-1\)}} // tf\), 
          ",", "\"\<\\nMultiplication using\!\(\*
StyleBox[\" \",\nFontWeight->\"Plain\"]\)\!\(\*
StyleBox[\"hoopTimes\",\nFontWeight->\"Plain\",\n\
FontSlant->\"Italic\"]\):-\\n If A  =\>\"", ",", \(A = {3. , 1. , 1. , 2. }\),
           ",", "\"\<and B =\>\"", ",", \(B = {4. , 7. , 2. , 3. }\), ",", 
          "\"\<\\nmultiplication \!\(\*
StyleBox[\"gives\",\nFontSlant->\"Plain\"]\) \\n AB =\>\"", 
          ",", \(AB = hoopTimes[A, B]\), ",", "\[IndentingNewLine]", 
          "\"\<\\nThis 'folds' to the product of 3-1 + \
(1-2)\[ImaginaryI]\\nand 4-2 + (7-3)\[ImaginaryI] to give 31-23 + (32-26)\
\[ImaginaryI],\\ni.e. (2-\[ImaginaryI])(2+4\[ImaginaryI])=\>\"", " ", 
          ",", \(\((2 - \[ImaginaryI])\) \((2 + 4  \[ImaginaryI])\)\), ",", 
          "\"\<\\n\\nDivision using \!\(\*
StyleBox[\"hoopInverse\",\nFontWeight->\"Plain\",\nFontSlant->\"Italic\"]\):-\
\\nThe inverse of A is\>\"", ",", \(Ainv = hoopInverse[{3, 1, 1, 2}]\), ",", 
          "\"\<\\nAinv.A is the unit\>\"", ",", \(hoopTimes[Ainv, A]\), ",", 
          "\"\<\\nand Ainv.AB recovers B\>\"", 
          ",", \(Simplify[hoopTimes[Ainv, AB]]\), ",", 
          "\"\<\\n\\nPowers and Roots:-\\nhoopPower\!\(\*
StyleBox[\"[\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"A\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"3\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"]\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\"gives\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\"the\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\"cube\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\",\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\) \\nA3=\>\"", 
          ",", \(A3 = hoopPower[A, 3]\), ",", 
          "\"\<which folds to (2-\[ImaginaryI])^3=\>\"", 
          ",", \(\((2 - \[ImaginaryI])\)^3\), ",", "\"\<\\n\!\(\*
StyleBox[\"hoopPower\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"[\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"A3\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"2\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"/\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"3\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"]\",\nFontSlant->\"Italic\"]\) gives the 2/3 power of A3\>\"", 
          ",", \(hoopPower[A3, 2/3]\), ",", 
          "\"\<which folds to 3 - 4i and matches the repeated product AA\>\"",
           ",", \(AA = hoopPower[A, 2]\), ",", 
          "\"\<\\nA^3 is the same as the repeated product AAA\>\"", 
          ",", \(AAA = hoopTimes[A, hoopTimes[A, A]]\), ",", 
          "\"\<\\nhoopTimes[A,hoopTimes[A,A]] (=\!\(A\^3\))\>\"", 
          ",", \(hoopTimes[A, hoopTimes[A, A]]\), 
          ",", \(hoopTimes[A, hoopTimes[A, A]]\), 
          StyleBox[",",
            FontWeight->"Plain"], 
          StyleBox["\[IndentingNewLine]",
            FontWeight->"Plain"], "\!\(\*
StyleBox[\"\\\"\",\nFontWeight->\"Plain\"]\)\\nPolar Form\>\"", 
          ",", \(topol /. as[A]\), ",", "\"\<has\!\(\*
StyleBox[\" \",\nFontWeight->\"Plain\"]\)\!\(r\^2\)=5, \[CurlyPhi]=-.4638 \
OK\>\""}], "}"}]}]], "Input",
  FormatType->TraditionalForm],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 4. C4 folds to Complex algebra.\\nThe table \"\>", 
        ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4"},
                  {"2", "3", "4", "1"},
                  {"3", "4", "1", "2"},
                  {"4", "1", "2", "3"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"can be written as\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "i", \(-1\), \(-i\)},
                  {"i", \(-1\), \(-i\), "1"},
                  {\(-1\), \(-i\), "1", "i"},
                  {\(-i\), "1", "i", \(-1\)}
                  }], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], 
        ",", "\<\"\\nMultiplication using\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontWeight->\\\"Plain\\\"]\\)\\!\\(\\* \
StyleBox[\\\"hoopTimes\\\",\\nFontWeight->\\\"Plain\\\",\\nFontSlant->\\\"\
Italic\\\"]\\):-\\n If A  =\"\>", ",", \({3.`, 1.`, 1.`, 2.`}\), 
        ",", "\<\"and B =\"\>", ",", \({4.`, 7.`, 2.`, 3.`}\), 
        ",", "\<\"\\nmultiplication \\!\\(\\* \
StyleBox[\\\"gives\\\",\\nFontSlant->\\\"Plain\\\"]\\) \\n AB =\"\>", 
        ",", \({31.`, 32.`, 23.`, 26.`}\), 
        ",", "\<\"\\nThis 'folds' to the product of 3-1 + \
(1-2)\[ImaginaryI]\\nand 4-2 + (7-3)\[ImaginaryI] to give 31-23 + (32-26)\
\[ImaginaryI],\\ni.e. (2-\[ImaginaryI])(2+4\[ImaginaryI])=\"\>", 
        ",", \(8 + 6\ \[ImaginaryI]\), 
        ",", "\<\"\\n\\nDivision using \\!\\(\\* \
StyleBox[\\\"hoopInverse\\\",\\nFontWeight->\\\"Plain\\\",\\nFontSlant->\\\"\
Italic\\\"]\\):-\\nThe inverse of A is\"\>", 
        ",", \({17\/35, \(-\(4\/35\)\), 3\/35, \(-\(11\/35\)\)}\), 
        ",", "\<\"\\nAinv.A is the unit\"\>", 
        ",", \({0.9999999999999998`, 0.`, 0.`, 0.`}\), 
        ",", "\<\"\\nand Ainv.AB recovers B\"\>", 
        ",", \({4.`, 6.999999999999999`, 2.`, 3.0000000000000018`}\), 
        ",", "\<\"\\n\\nPowers and Roots:-\\nhoopPower\\!\\(\\* \
StyleBox[\\\"[\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"A\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"3\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"]\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \\\
\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* \
StyleBox[\\\"gives\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* \
StyleBox[\\\"the\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* \
StyleBox[\\\"cube\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* StyleBox[\\\",\
\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\\) \\nA3=\"\>", 
        ",", \({87.`, 80.`, 85.`, 91.`}\), 
        ",", "\<\"which folds to (2-\[ImaginaryI])^3=\"\>", 
        ",", \(2 - 11\ \[ImaginaryI]\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"hoopPower\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"[\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"A3\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"2\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"/\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"3\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"]\\\",\\nFontSlant->\\\"Italic\\\"]\\) gives the 2/3 power of A3\
\"\>", ",", \({13.999999999999996`, 9.999999999999996`, 10.999999999999996`, 
          13.999999999999996`}\), 
        ",", "\<\"which folds to 3 - 4i and matches the repeated product AA\"\
\>", ",", \({14.`, 10.`, 11.`, 14.`}\), 
        ",", "\<\"\\nA^3 is the same as the repeated product AAA\"\>", 
        ",", \({87.`, 80.`, 85.`, 91.`}\), 
        ",", "\<\"\\nhoopTimes[A,hoopTimes[A,A]] (=\\!\\(A\\^3\\))\"\>", 
        ",", \({87.`, 80.`, 85.`, 91.`}\), ",", \({87.`, 80.`, 85.`, 91.`}\), 
        ",", "\<\"\\nPolar Form\"\>", 
        ",", \({7.`, 1.`, 5.`, \(-0.4636476090008061`\)}\), 
        ",", "\<\"has\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontWeight->\\\"Plain\\\"]\\)\\!\\(r\\^2\\)=5, \[CurlyPhi]=-.4638 \
OK\"\>"}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.4 Powers & repeated products may differ.", "Subsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tExample 4 checked whether ",
  Cell[BoxData[
      \(TraditionalForm\`A\^2\)]],
  " = ",
  StyleBox["AA",
    FontSlant->"Italic"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`A\^3\)]],
  " = ",
  StyleBox["AAA",
    FontSlant->"Italic"],
  ". Powers and repeated products may differ for three reasons, negative \
sizes (example 5), \"angle wrap-round\" (example 6), ",
  StyleBox["and non-commutativity (section 2.6)",
    PageWidth->WindowWidth],
  ".\n\tIf a size is negative for A it alternates in sign for repeated \
products but the power is a continuous function of the exponent, as in \
Example 5."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(Use["\<C4\>"]\), ";", 
      RowBox[{"{", 
        RowBox[{
        "\"\<Example 5. C4 with negative size., so AA differs from A^2\\nIf A \
 =\>\"", ",", \(A = {1. , 1. , \(-1. \), 0. }\), ",", "\[IndentingNewLine]", 
          "\"\< with shape \>\"", ",", \(sh /. as[A]\), ",", "\"\<\\n\!\(\*
StyleBox[\"hoopPower\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"[\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"A\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"3\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"]\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\"gives\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\"the\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\"cube\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\",\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\\\ \)]\)A3= \>\"", 
          ",", \(A3 = hoopPower[A, 3]\), ",", 
          "\"\<\\nwhich folds to 2+11i.\\n\!\(\*
StyleBox[\"hoopPower\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"[\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"A3\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"2\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"/\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"3\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"]\",\nFontSlant->\"Italic\"]\) gives the 2/3 power of A3\>\"", 
          ",", \(hoopPower[A3, 2/3]\), ",", 
          "\"\<\\nwhich folds to 3+4i and matches A^2\>\"", 
          ",", \(A2 = hoopPower[A, 2]\), ",", "\[IndentingNewLine]", 
          "\"\<\\nwith shape\>\"", ",", \(sh /. as[A2]\), ",", 
          "\"\<\\nwhilst the repeated product AA\>\"", 
          ",", \(AA = hoopTimes[\ A, A]\), ",", "\[IndentingNewLine]", 
          "\"\<\\nhas the second size positive\>\"", ",", \(sh /. as[AA]\), 
          ",", "\"\<\\nA^3 is the same as the repeated product AAA\>\"", 
          ",", \(AAA = hoopTimes[A, hoopTimes[A, A]]\), ",", 
          "\"\<\\nThe second size of A^2 is negative, of AA is \
positive:-\\nPolar A   =\>\"", ",", \(topol /. \ as[A]\), ",", 
          "\"\<\\nPolar A^2 =\>\"", ",", \(topol /. \ as[A2]\), ",", 
          "\"\<\\nPolar AA  =\>\"", ",", \(topol /. \ as[AA]\), ",", 
          "\"\<\\nPolar AAA =\>\"", ",", \(topol /. \ as[A3]\), ",", 
          "\"\<\\n\\n  A^1.99\>\"", ",", \(hoopPower[A, 1.99]\), ",", 
          "\"\<\\n& A^2.01\>\"", ",", \(hoopPower[A, 2.01]\), ",", 
          "\"\<\\n  bracket A^2\\nwhilst AA =\>\"", ",", "AA"}], 
        "}"}]}]], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 5. C4 with negative size., so AA differs from \
A^2\\nIf A  =\"\>", ",", \({1.`, 1.`, \(-1.`\), 0.`}\), 
        ",", "\<\" with shape \"\>", ",", \({1.`, \(-1.`\), 5.`}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"hoopPower\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"[\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"A\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"3\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"]\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \\\
\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* \
StyleBox[\\\"gives\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* \
StyleBox[\\\"the\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* \
StyleBox[\\\"cube\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* StyleBox[\\\",\
\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* StyleBox[\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\\\\ \\)]\\)A3= \"\>", 
        ",", \({1.0000000000000007`, 
          6.`, \(-1.0000000000000007`\), \(-5.`\)}\), 
        ",", "\<\"\\nwhich folds to 2+11i.\\n\\!\\(\\* StyleBox[\\\"hoopPower\
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"[\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"A3\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"2\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"/\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"3\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"]\\\",\\nFontSlant->\\\"Italic\\\"]\\) gives the 2/3 power of A3\
\"\>", ",", \({1.5`, 
          2.4999999999999996`, \(-1.5`\), \(-1.4999999999999996`\)}\), 
        ",", "\<\"\\nwhich folds to 3+4i and matches A^2\"\>", 
        ",", \({1.5000000000000002`, 
          2.5`, \(-1.5000000000000002`\), \(-1.4999999999999998`\)}\), 
        ",", "\<\"\\nwith shape\"\>", 
        ",", \({1.0000000000000002`, \(-1.0000000000000002`\), 
          25.000000000000004`}\), 
        ",", "\<\"\\nwhilst the repeated product AA\"\>", 
        ",", \({2.`, 2.`, \(-1.`\), \(-2.`\)}\), 
        ",", "\<\"\\nhas the second size positive\"\>", 
        ",", \({1.`, 1.`, 25.`}\), 
        ",", "\<\"\\nA^3 is the same as the repeated product AAA\"\>", 
        ",", \({1.`, 6.`, \(-1.`\), \(-5.`\)}\), 
        ",", "\<\"\\nThe second size of A^2 is negative, of AA is \
positive:-\\nPolar A   =\"\>", 
        ",", \({1.`, \(-1.`\), 5.`, 0.4636476090008061`}\), 
        ",", "\<\"\\nPolar A^2 =\"\>", 
        ",", \({1.0000000000000002`, \(-1.0000000000000002`\), 
          25.000000000000004`, 0.9272952180016122`}\), 
        ",", "\<\"\\nPolar AA  =\"\>", 
        ",", \({1.`, 1.`, 25.`, 0.9272952180016122`}\), 
        ",", "\<\"\\nPolar AAA =\"\>", 
        ",", \({1.`, \(-1.`\), 125.`, 1.3909428270024182`}\), 
        ",", "\<\"\\n\\n  A^1.99\"\>", 
        ",", \({1.4971602576129839`, 
          2.4770499321073896`, \(-1.4971602576129839`\), \
\(-1.4770499321073898`\)}\), ",", "\<\"\\n& A^2.01\"\>", 
        ",", \({1.5027553889648462`, 
          2.5231485205881197`, \(-1.5027553889648462`\), \
\(-1.5231485205881197`\)}\), ",", "\<\"\\n  bracket A^2\\nwhilst AA =\"\>", 
        ",", \({2.`, 2.`, \(-1.`\), \(-2.`\)}\)}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
\tExample 6 shows that if a polar-form angle parameter is large, raising to a \
power (which multiplies the angle by the exponent) may give an angle greater \
than 2\[Pi]. This will become a negative angle and the roots will be rotated. \
Their sizes will be correct. (Taking roots makes the angle parameter smaller, \
and so cannot cause wrap-round.)\
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(Use["\<C4\>"]\), ";", 
      RowBox[{"{", 
        RowBox[{
        "\"\<Example 6. C4 with large angle. (A^3)^(1/3) differs from A.\\nIf \
A  =\>\"", ",", \(A = {2. , 2. , 1. , 0. }\), ",", 
          "\"\<which folds to 1+2i\\n\!\(\*
StyleBox[\"hoopPower\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"[\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"A\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"3\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"]\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\"gives\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\"the\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\"cube\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\",\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\) A3= \>\"", 
          ",", \(A3 = hoopPower[A, 3]\), ",", 
          "\"\<\\nwhich folds to -11-2i\\n\!\(\*
StyleBox[\"hoopPower\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"[\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"A3\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"1\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"/\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"3\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"]\",\nFontSlant->\"Italic\"]\) gives rA3, the 1/3 power of A3\>\"",
           ",", \(rA3 = hoopPower[A3, 1/3]\), ",", 
          "\"\<\\nwhich folds to 1.232-1.866i (which cubes correctly)\\nrA3 \
differs from A, but has the same sizes\>\"", ",", 
          "\"\<\\nThe angle of A^3 exceeds 2Pi and so is negated:-\\nPolar A  \
 =\>\"", ",", \(topol /. \ as[A]\), ",", "\"\<\\nPolar AAA =\>\"", 
          ",", \(topol /. \ as[A3]\), ",", "\"\<\\nPolar rA3 =\>\"", 
          ",", \(topol /. \ as[rA3]\)}], "}"}]}]], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 6. C4 with large angle. (A^3)^(1/3) differs from \
A.\\nIf A  =\"\>", ",", \({2.`, 2.`, 1.`, 0.`}\), 
        ",", "\<\"which folds to 1+2i\\n\\!\\(\\* StyleBox[\\\"hoopPower\\\",\
\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"[\\\",\\nFontSlant->\\\
\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"A\\\",\\nFontSlant->\\\"Italic\\\"]\\)\
\\!\\(\\* StyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"3\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"]\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* \
StyleBox[\\\"gives\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* \
StyleBox[\\\"the\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* \
StyleBox[\\\"cube\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* StyleBox[\\\",\
\\\",\\nFontSlant->\\\"Plain\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Plain\\\"]\\) A3= \"\>", 
        ",", \({26.`, 30.`, 37.`, 32.`}\), 
        ",", "\<\"\\nwhich folds to -11-2i\\n\\!\\(\\* StyleBox[\\\"hoopPower\
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"[\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"A3\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"1\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"/\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"3\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"]\\\",\\nFontSlant->\\\"Italic\\\"]\\) gives rA3, the 1/3 power \
of A3\"\>", 
        ",", \({2.1160254037844384`, 0.0669872981077807`, 
          0.8839745962155612`, 1.9330127018922187`}\), 
        ",", "\<\"\\nwhich folds to 1.232-1.866i (which cubes \
correctly)\\nrA3 differs from A, but has the same sizes\"\>", 
        ",", "\<\"\\nThe angle of A^3 exceeds 2Pi and so is negated:-\\nPolar \
A   =\"\>", ",", \({5.`, 1.`, 5.`, 1.1071487177940904`}\), 
        ",", "\<\"\\nPolar AAA =\"\>", 
        ",", \({125.`, 1.`, 125.`, \(-2.961739153797315`\)}\), 
        ",", "\<\"\\nPolar rA3 =\"\>", 
        ",", \({4.999999999999999`, 1.`, 
          4.9999999999999964`, \(-0.9872463845991049`\)}\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.5 Signed Tables, Generalized Signs.", "Subsection",
  PageWidth->PaperWidth],

Cell[TextData[{
  "\tMany Hoops are \"signed tables\" with signed products in the body of the \
multiplication table, but the elements are unsigned (unlike the second table \
in Example 4, where two elements are \"labeled\" -1 & -i). As these products \
are not members of the defining set, such tables are not loops. Signed tables \
are equivalence relations, folded from unsigned Moufang loops with ",
  StyleBox["r",
    FontSlant->"Italic"],
  "-fold symmetry. The commonest cases involve negation, where ",
  StyleBox["r",
    FontSlant->"Italic"],
  " = 2 and the signed table is obtained from the top left quarter of the \
Moufang loop. Complex algebra is the \"C4c\" hoop, folded from C4. Compare \
the following table with the 2\[Cross]2 quarter-tables in Example 4. Index 3 \
becomes -1, corresponding to index 2 becoming ",
  StyleBox["i",
    FontWeight->"Bold"],
  " with ",
  StyleBox["i.i =",
    FontWeight->"Bold"],
  "-1. Example 7 is equivalent to the complex multiplication (3+1 ",
  StyleBox["i",
    FontWeight->"Bold"],
  ")(x+y ",
  StyleBox["i",
    FontWeight->"Bold"],
  ") = (3x-y)+",
  StyleBox["i",
    FontWeight->"Bold"],
  "(x+3y). ",
  StyleBox["(C4c is demonstrated in more detail later, in Figure S1.)",
    PageWidth->WindowWidth]
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(Use["\<C4c\>"]; {"\<Example 7. C4c multiplication & division is Complex \
Algebra\>", "\<\nThe table is\>", hoopTbl // tf, "\<\nA  = \>", 
      A = {3, 1}, "\<\nB  = \>", B = {x, y}, "\<\nAB = \>", 
      AB = hoopTimes[A, B], "\<\nAinv = \>", 
      Ainv = hoopInverse[A], "\<\nAinv.AB = B \>", 
      Simplify[hoopTimes[hoopInverse[A], 
          AB]], "\<\nComplex AB (3+\[ImaginaryI])(x+\[ImaginaryI]y) = (3x-y) \
+ \[ImaginaryI](x+3y)\>"}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 7. C4c multiplication & division is Complex \
Algebra\"\>", ",", "\<\"\\nThe table is\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2"},
                  {"2", \(-1\)}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nA  = \"\>", ",", \({3, 1}\), 
        ",", "\<\"\\nB  = \"\>", ",", \({x, y}\), ",", "\<\"\\nAB = \"\>", 
        ",", \({3\ x - y, x + 3\ y}\), ",", "\<\"\\nAinv = \"\>", 
        ",", \({3\/10, \(-\(1\/10\)\)}\), ",", "\<\"\\nAinv.AB = B \"\>", 
        ",", \({x, y}\), 
        ",", "\<\"\\nComplex AB (3+\[ImaginaryI])(x+\[ImaginaryI]y) = (3x-y) \
+ \[ImaginaryI](x+3y)\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tThe Davenport Algebra is another signed table. It is folded from the \
following C4C2 isomorph, with 5\[RightArrow]-1, 6\[RightArrow]-2, 7\
\[RightArrow]-3",
  StyleBox[", and gives two copies of the complex field, with only the origin \
in common. It has application in binocular vision.",
    PageWidth->WindowWidth]
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "2", "3", "4", "5", "6", "7", "8"},
            {"2", "5", "4", "7", "6", "1", "8", "3"},
            {"3", "4", "5", "6", "7", "8", "1", "2"},
            {"4", "7", "6", "1", "8", "3", "2", "5"},
            {"5", "6", "7", "8", "1", "2", "3", "4"},
            {"6", "1", "8", "3", "2", "5", "4", "7"},
            {"7", "8", "1", "2", "3", "4", "5", "6"},
            {"8", "3", "2", "5", "4", "7", "6", "1"}
            },
          ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(Use["\<Dav\>"]; {"\<Example 8.  Dav division\>", "\<\nThe table is \>", 
      hoopTbl // tf, "\<\nA=  \>", A = {3, 4, 6, 1}, "\<\nB=  \>", 
      B = {w, x, y, z}, "\<\nAB =\>", 
      AB = hoopTimes[A, B], "\<\nAinv = \>", \[IndentingNewLine]hoopInverse[
        A], "\<\nAinv.AB = B \>", \n
      Simplify[hoopTimes[hoopInverse[A], AB]]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 8.  Dav division\"\>", 
        ",", "\<\"\\nThe table is \"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4"},
                  {"2", \(-1\), "4", \(-3\)},
                  {"3", "4", \(-1\), \(-2\)},
                  {"4", \(-3\), \(-2\), "1"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nA=  \"\>", ",", \({3, 4, 6, 1}\), 
        ",", "\<\"\\nB=  \"\>", ",", \({w, x, y, z}\), ",", "\<\"\\nAB =\"\>",
         ",", \({3\ w - 4\ x - 6\ y + z, 4\ w + 3\ x - y - 6\ z, 
          6\ w - x + 3\ y - 4\ z, w + 6\ x + 4\ y + 3\ z}\), 
        ",", "\<\"\\nAinv = \"\>", 
        ",", \({57\/520, 1\/520, \(-\(51\/520\)\), 47\/520}\), 
        ",", "\<\"\\nAinv.AB = B \"\>", ",", \({w, x, y, z}\)}], 
      "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tSome hoops have complex products, with ",
  StyleBox["i",
    FontWeight->"Bold"],
  " occurring in the body of the multiplication table. The g2401c algebra has \
6 elements; it is \"4-folded\" from the group g2401, i.e. the first group \
with 24 elements in the GAP Group Atlas (not shown):-"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(Use["\<g2401c\>"]; {"\<Example 9. g2401c division\n\>", "\<The table is \
\>", hoopTbl // tf, "\<\nA= \>", A = {3, 4, 6, 1, 2, 7}, "\<\nB= \>", 
      B = {u, v, w, x, y, z}, "\<\nAB = \>", 
      AB = hoopTimes[A, B], "\<\nAinv = \>", \[IndentingNewLine]hoopInverse[
        A], "\<\nAinv.AB = B \>", \n
      Simplify[hoopTimes[hoopInverse[A], AB]]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 9. g2401c division\\n\"\>", 
        ",", "\<\"The table is \"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4", "5", "6"},
                  {"2", "3", "1", "6", "4", "5"},
                  {"3", "1", "2", "5", "6", "4"},
                  {"4", "5", "6", 
                    "\[ImaginaryI]", \(2\ \[ImaginaryI]\), \(3\ \[ImaginaryI]\
\)},
                  {"5", "6", "4", \(3\ \[ImaginaryI]\), 
                    "\[ImaginaryI]", \(2\ \[ImaginaryI]\)},
                  {"6", "4", "5", \(2\ \[ImaginaryI]\), \(3\ \[ImaginaryI]\), 
                    "\[ImaginaryI]"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nA= \"\>", ",", \({3, 4, 6, 1, 2, 7}\),
         ",", "\<\"\\nB= \"\>", ",", \({u, v, w, x, y, z}\), 
        ",", "\<\"\\nAB = \"\>", 
        ",", \({3\ u + 6\ v + 4\ w + \[ImaginaryI]\ x + 2\ \[ImaginaryI]\ y + 
            7\ \[ImaginaryI]\ z, 
          4\ u + 3\ v + 6\ w + 7\ \[ImaginaryI]\ x + \[ImaginaryI]\ y + 
            2\ \[ImaginaryI]\ z, 
          6\ u + 4\ v + 3\ w + 2\ \[ImaginaryI]\ x + 
            7\ \[ImaginaryI]\ y + \[ImaginaryI]\ z, 
          u + 7\ v + 2\ w + 3\ x + 4\ y + 6\ z, 
          2\ u + v + 7\ w + 6\ x + 3\ y + 4\ z, 
          7\ u + 2\ v + w + 4\ x + 6\ y + 3\ z}\), ",", "\<\"\\nAinv = \"\>", 
        ",", \({189877\/19473305 - \(578094\ \[ImaginaryI]\)\/19473305, 
          237907\/7789322 + \(485997\ \[ImaginaryI]\)\/7789322, 
          649681\/38946610 + \(39203\ \[ImaginaryI]\)\/38946610, 
          60863\/38946610 + \(2452579\ \[ImaginaryI]\)\/38946610, \(-\(104532\
\/19473305\)\) + \(628594\ \[ImaginaryI]\)\/19473305, \
\(-\(1558699\/38946610\)\) - \(4719767\ \[ImaginaryI]\)\/38946610}\), 
        ",", "\<\"\\nAinv.AB = B \"\>", ",", \({u, v, w, x, y, z}\)}], 
      "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "A few hoops have ",
  StyleBox["J ",
    FontSlant->"Italic"],
  "& ",
  Cell[BoxData[
      \(TraditionalForm\`J\^2\)]],
  " (primitive cube roots of +1) as signs. \"C9J\" is 3-folded from the \
following C9 isomorph by 9\[RightArrow]",
  Cell[BoxData[
      \(TraditionalForm\`J\^2\)]],
  "3, 5\[RightArrow] ",
  StyleBox["J",
    FontSlant->"Italic"],
  " 2:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "2", "3", "4", "5", "6", "7", "8", "9"},
            {"2", "9", "1", "5", "3", "4", "8", "6", "7"},
            {"3", "1", "5", "6", "4", "8", "9", "7", "2"},
            {"4", "5", "6", "7", "8", "9", "1", "2", "3"},
            {"5", "3", "4", "8", "6", "7", "2", "9", "1"},
            {"6", "4", "8", "9", "7", "2", "3", "1", "5"},
            {"7", "8", "9", "1", "2", "3", "4", "5", "6"},
            {"8", "6", "7", "2", "9", "1", "5", "3", "4"},
            {"9", "7", "2", "3", "1", "5", "6", "4", "8"}
            },
          ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Input",
  Editable->False,
  PageWidth->PaperWidth,
  Evaluatable->False,
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],

Cell[TextData[{
  "Results need extensive simplification, using the rule ",
  StyleBox["js",
    FontSlant->"Italic"],
  ", i.e. ",
  StyleBox["J",
    FontSlant->"Italic"],
  "^any_\[RightArrow]",
  StyleBox["J",
    FontSlant->"Italic"],
  "^Mod[any,3]:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(Use["\<C9j\>"]; {"\<Example 10. C9j division.\n\>", "\<The table is \
\>", hoopTbl // tf, "\<\n A= \>", A = {3, 4, 6}, "\<\n B= \>", 
      B = {x, y, z}, "\<\nAB =\>", 
      AB = hoopTimes[A, B], "\<\nAinv = \>", \[IndentingNewLine]hoopInverse[
        A], "\<\nAinv.AB unsimplified \>", 
      hoopTimes[hoopInverse[A], AB], "\<\nSimplified Ainv.AB = B \>", \n
      Simplify[Simplify[hoopTimes[hoopInverse[A], AB]] //. js]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 10. C9j division.\\n\"\>", 
        ",", "\<\"The table is \"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3"},
                  {"2", \(3\ J\^2\), "1"},
                  {"3", "1", \(2\ J\)}
                  }], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\n A= \"\>", ",", \({3, 4, 6}\), 
        ",", "\<\"\\n B= \"\>", ",", \({x, y, z}\), ",", "\<\"\\nAB =\"\>", 
        ",", \({3\ x + 6\ y + 4\ z, 4\ x + 3\ y + 6\ J\ z, 
          6\ x + 4\ J\^2\ y + 3\ z}\), ",", "\<\"\\nAinv = \"\>", 
        ",", \({\(-\(15\/\(\(-189\) + 216\ J + 
                  64\ J\^2\)\)\), \(12\ \((\(-1\) + 3\ J)\)\)\/\(\(-189\) + \
216\ J + 64\ J\^2\), \(2\ \((\(-9\) + 8\ J\^2)\)\)\/\(\(-189\) + 216\ J + 64\ \
J\^2\)}\), ",", "\<\"\\nAinv.AB unsimplified \"\>", 
        ",", \({\(12\ \((\(-1\) + 3\ J)\)\ \((6\ x + 4\ J\^2\ y + 3\ z)\)\)\/\
\(\(-189\) + 216\ J + 64\ J\^2\) - \(15\ \((3\ x + 6\ y + 4\ z)\)\)\/\(\(-189\
\) + 216\ J + 64\ J\^2\) + \(2\ \((\(-9\) + 8\ J\^2)\)\ \((4\ x + 3\ y + 6\ J\
\ z)\)\)\/\(\(-189\) + 216\ J + 64\ J\^2\), \(2\ J\ \((\(-9\) + 8\ J\^2)\)\ \
\((6\ x + 4\ J\^2\ y + 3\ z)\)\)\/\(\(-189\) + 216\ J + 64\ J\^2\) + \(12\ \
\((\(-1\) + 3\ J)\)\ \((3\ x + 6\ y + 4\ z)\)\)\/\(\(-189\) + 216\ J + 64\ \
J\^2\) - \(15\ \((4\ x + 3\ y + 6\ J\ z)\)\)\/\(\(-189\) + 216\ J + 64\ \
J\^2\), \(-\(\(15\ \((6\ x + 4\ J\^2\ y + 3\ z)\)\)\/\(\(-189\) + 216\ J + 
                    64\ J\^2\)\)\) + \(2\ \((\(-9\) + 8\ J\^2)\)\ \((3\ x + 6\
\ y + 4\ z)\)\)\/\(\(-189\) + 216\ J + 64\ J\^2\) + \(12\ J\^2\ \((\(-1\) + 3\
\ J)\)\ \((4\ x + 3\ y + 6\ J\ z)\)\)\/\(\(-189\) + 216\ J + 64\ J\^2\)}\), 
        ",", "\<\"\\nSimplified Ainv.AB = B \"\>", ",", \({x, y, z}\)}], 
      "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "\t",
  StyleBox["J",
    FontSlant->"Italic"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`J\^2\)]],
  " are the only \"generalized signs\" used in this document; the ",
  StyleBox["Hoops' ",
    FontSlant->"Italic"],
  "package includes instructions that make ",
  StyleBox["J",
    FontSlant->"Italic"],
  " behave as a sign. Other generalized signs are developed in a similar way \
in [4], as powers of primitive roots of unity."
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.6 Non-Abelian Hoops, Left & Right Inverses.", "Subsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tSo far all the examples (except g2401c) have used Abelian (commutative) \
hoops. ",
  StyleBox["Example 11 demonstrates the non-Abelian (AB differs from BA) D3 \
algebra and Clifford(2,1) algebra. ",
    PageWidth->WindowWidth],
  "\n\t",
  StyleBox["hoopInverse",
    FontSlant->"Italic"],
  " calculates a left inverse, so Ai.AB divides AB by A, recovering B. \
Similarly Bi.BA recovers A, whilst BA.Ai recovers B because A is the left \
inverse of Ai. ",
  StyleBox["(Examples 16 & 18 also use D3.)",
    PageWidth->WindowWidth]
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \({"\<Example 11. D3 & CL21 Left and Right division\n\>", 
      Use["\<D3\>"]; "\<The D3 table is\>", hoopTbl // tf, "\<\nA= \>", 
      A = {3, 4, 6, 1, 2, 7}, "\<\nB= \>", 
      B = {4, \(-1\), 2, 2, 5, 3}, "\<\nAB = \>", 
      AB = hoopTimes[A, B], "\<\nAinv = \>", \[IndentingNewLine]Ainv = 
        hoopInverse[A], "\<\nAinv.AB = B \>", \n
      Simplify[hoopTimes[Ainv, AB]], \[IndentingNewLine]"\<\nBA = \>", 
      BA = hoopTimes[B, A], "\<\nBinv.BA = A \>", \n
      Simplify[hoopTimes[hoopInverse[B], BA]], "\<\nBA.Ainv = B \>", \n
      Simplify[hoopTimes[BA, Ainv, 
          AB]], \[IndentingNewLine]Use["\<CL21\>"]; "\<The CL21 table is\>", 
      hoopTbl // tf, "\<\nA= \>", A = {3, 4, 6, 1, 2, 7, 2, 1}, "\<\nB= \>", 
      B = {4, \(-1\), 2, 2, 5, 3, 2, \(-3\)}, "\<\nAB = \>", 
      AB = hoopTimes[A, B], "\<\nAinv = \>", \[IndentingNewLine]Ainv = 
        hoopInverse[A], "\<\nAinv.AB = B \>", \n
      Simplify[hoopTimes[Ainv, AB]], \[IndentingNewLine]"\<\nBA = \>", 
      BA = hoopTimes[B, A], "\<\nBinv.BA = A \>", \n
      Simplify[hoopTimes[hoopInverse[B], BA]], "\<\nBA.Ainv = B \>", \n
      Simplify[hoopTimes[BA, Ainv, AB]]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 11. D3 & CL21 Left and Right division\\n\"\>", 
        ",", "\<\"The D3 table is\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4", "5", "6"},
                  {"2", "1", "6", "5", "4", "3"},
                  {"3", "4", "5", "6", "1", "2"},
                  {"4", "3", "2", "1", "6", "5"},
                  {"5", "6", "1", "2", "3", "4"},
                  {"6", "5", "4", "3", "2", "1"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nA= \"\>", ",", \({3, 4, 6, 1, 2, 7}\),
         ",", "\<\"\\nB= \"\>", ",", \({4, \(-1\), 2, 2, 5, 3}\), 
        ",", "\<\"\\nAB = \"\>", ",", \({65, 72, 65, 44, 39, 60}\), 
        ",", "\<\"\\nAinv = \"\>", 
        ",", \({\(-\(18\/161\)\), 
          4\/23, \(-\(13\/322\)\), \(-\(13\/322\)\), \(-\(15\/46\)\), 
          125\/322}\), ",", "\<\"\\nAinv.AB = B \"\>", 
        ",", \({4, \(-1\), 2, 2, 5, 3}\), ",", "\<\"\\nBA = \"\>", 
        ",", \({65, 50, 44, 69, 60, 57}\), ",", "\<\"\\nBinv.BA = A \"\>", 
        ",", \({3, 4, 6, 1, 2, 7}\), ",", "\<\"\\nBA.Ainv = B \"\>", 
        ",", \({4, \(-1\), 2, 2, 5, 3}\), ",", "\<\"The CL21 table is\"\>", 
        ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4", "5", "6", "7", "8"},
                  {"2", \(-1\), "4", \(-3\), "6", \(-5\), "8", \(-7\)},
                  {"3", \(-4\), "1", \(-2\), "7", \(-8\), "5", \(-6\)},
                  {"4", "3", "2", "1", "8", "7", "6", "5"},
                  {"5", \(-6\), \(-7\), "8", "1", \(-2\), \(-3\), "4"},
                  {"6", "5", \(-8\), \(-7\), "2", "1", \(-4\), \(-3\)},
                  {"7", "8", \(-5\), \(-6\), "3", "4", \(-1\), \(-2\)},
                  {"8", \(-7\), \(-6\), "5", "4", \(-3\), \(-2\), "1"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nA= \"\>", 
        ",", \({3, 4, 6, 1, 2, 7, 2, 1}\), ",", "\<\"\\nB= \"\>", 
        ",", \({4, \(-1\), 2, 2, 5, 3, 2, \(-3\)}\), ",", "\<\"\\nAB = \"\>", 
        ",", \({54, 36, 45, 15, 11, 73, 42, \(-22\)}\), 
        ",", "\<\"\\nAinv = \"\>", 
        ",", \({5\/26, \(-\(1\/13\)\), 
          1\/10, \(-\(2\/13\)\), \(-\(19\/130\)\), 0, 8\/65, 27\/130}\), 
        ",", "\<\"\\nAinv.AB = B \"\>", 
        ",", \({4, \(-1\), 2, 2, 5, 3, 2, \(-3\)}\), ",", "\<\"\\nBA = \"\>", 
        ",", \({54, \(-2\), 51, 3, 33, 33, 12, \(-22\)}\), 
        ",", "\<\"\\nBinv.BA = A \"\>", ",", \({3, 4, 6, 1, 2, 7, 2, 1}\), 
        ",", "\<\"\\nBA.Ainv = B \"\>", 
        ",", \({4, \(-1\), 2, 2, 5, 3, 2, \(-3\)}\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.7 Many Algebras are Hoops.", "Subsection",
  PageWidth->WindowWidth],

Cell["\<\
\tExample 12 shows that traditional vector dot & cross products are hoop \
multiplications where only the \"univectors\" are multiplied i.e. the scalar \
and multivector elements of the multiplicands are kept at zero. (I use \
\"univectors\" where many authors confusingly use \"basis vectors\", \
\"vectors\" or \"scalars\" for single element generators. Their products are \
bivectors, trivectors, etc.) The symbols are chosen to match those in [3, \
p11] for quaternions (Qr) and CL2, and to match [3, p37] for octonions (Octr) \
and CL3.\
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`{Use["\<Qr\>"]; \*"\"\<Example 12. Dot & Cross \
products with Qr & \
Octr.\\n{0,\!\(e\_1\),\!\(e\_2\),0}\[Times]{0,\!\(u\_1\),\!\(u\_2\),0} \
gives\\n   Qr Scalar       & Dot products\\n\>\"", 
      hoopTimes[{0, e\_1, e\_2, 0}, {0, u\_1, u\_2, 
          0}], \[IndentingNewLine]Use["\<Octr\>"]; \*"\"\<\\n\\nOctr  \
{0,\!\(a\_1\),\!\(a\_2\),0,\!\(a\_3\),0,0,0}\[Times]{0,\!\(b\_1\),\!\(b\_2\),\
0,\!\(b\_3\),0,0,0}=\>\"", \ 
      hoopTimes[{0, a\_1, a\_2, 0, a\_3, 0, 0, 0}, {0, b\_1, b\_2, 0, b\_3, 
          0, 0, 0}]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"Example 12. Dot & Cross products with Qr & Octr.\n{0,\!\(e\_1\),\!\(e\
\_2\),0}\[Times]{0,\!\(u\_1\),\!\(u\_2\),0} gives\n   Qr Scalar       & Dot \
products\n", {\(-e\_1\)\ u\_1 - e\_2\ u\_2, 0, 
        0, \(-e\_2\)\ u\_1 + e\_1\ u\_2}, 
      "\n\nOctr  {0,\!\(a\_1\),\!\(a\_2\),0,\!\(a\_3\),0,0,0}\[Times]{0,\!\(b\
\_1\),\!\(b\_2\),0,\!\(b\_3\),0,0,0}=", {\(-a\_1\)\ b\_1 - a\_2\ b\_2 - 
          a\_3\ b\_3, 0, 0, \(-a\_2\)\ b\_1 + a\_1\ b\_2, 
        0, \(-a\_3\)\ b\_1 + a\_1\ b\_3, \(-a\_3\)\ b\_2 + a\_2\ b\_3, 
        0}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tIn both cases the first element of the result is the scalar product (up \
to a sign), whilst the univectors (and octonion trivector) in the product are \
zero. The Qr trivector element ",
  Cell[BoxData[
      \(TraditionalForm\`\(e\_2\) u\_1 - \(e\_1\) u\_2\)]],
  " is the 2D cross product, and Octc gives the (negated) 3D scalar product \
",
  Cell[BoxData[
      StyleBox[\(a\_1\ b\_1 + a\_2\ b\_2 + a\_3\ b\_3\),
        FontSlant->"Italic"]]],
  " together with elements that add to give the vector cross product  {",
  Cell[BoxData[
      \(TraditionalForm\`\((\(-a\_2\)\ b\_1 + a\_1\ b\_2)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(e\_1\) e\_2\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\((\(-a\_3\)\ b\_1 + a\_1\ b\_3)\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(e\_1\) e\_3\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(-a\_3\)\ b\_2 + a\_2\ b\_3)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(e\_2\) e\_3\)]],
  "}. \n(The bivector ",
  Cell[BoxData[
      \(TraditionalForm\`\(e\_1\) e\_2\)]],
  " is the 4th direction, having coefficient 0 in the multiplicands). "
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tAll Clifford algebras are hoops. Their tables are created by using the \
",
  StyleBox["GroupLoopHoop ",
    FontSlant->"Italic"],
  "procedure ",
  StyleBox["cl",
    FontSlant->"Italic"],
  " or by folding a specific group isomorph. Wedge (exterior) algebras are \
the bivector part of the Clifford product [3 p.10]. They multiply univectors \
using Clifford algebra rules; the scalars and multivectors are kept at zero \
in the multiplicands so various products are zero (i.e. these are Grassmann \
algebras). Multiplying univectors ",
  Cell[BoxData[
      \(TraditionalForm\`u\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`u\_2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`v\_2\)]],
  " in CL2 gives a scalar ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_1\) v\_1 - \(u\_2\) v\_2\)]],
  " and a bivector ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_1\) v\_2 - \(u\_2\) v\_1\)]],
  "; the univectors in the product are zero. CL3 gives the wedge product of \
three univectors when the scalar and multivector terms are zero in the \
multiplicands. CL2 and CL3 univector products only differ from the quaternion \
and octonion univector products in the sign of the first term.\n\tDifferent \
16-element Clifford algebras multiply 4 univectors to give scalars and three \
bivectors with assorted signs:- "
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{\(Use["\<CL2\>"]; "\<Example 13. Wedge Products, Exterior \
Algebras. Clifford Algebras.\nCL2\>"\), 
          ",", \(hoopTimes[{0, u\_1, u\_2, 0}, {0, v\_1, v\_2, 0}]\), ",", 
          "\[IndentingNewLine]", \(Use["\<CL3\>"]; "\<\nCL3\>"\), 
          ",", \(hoopTimes[{0, u\_1, u\_2, 0, u\_3, 0, 0, 0}, {0, v\_1, v\_2, 
              0, v\_3, 0, 0, 0}]\), ",", 
          "\[IndentingNewLine]", \(Use["\<CL4\>"]; "\<\nCL4\>"\), ",", 
          
          FormBox[\(hoopTimes[{0, e\_1, e\_2, 0, e\_3, 0, 0, e\_4}, {0, u\_1, 
                u\_2, 0, u\_3, 0, 0, u\_4}]\),
            "TraditionalForm"], ",", "\n", \(Use["\<CL04\>"]; "\<\nCL04\>"\), 
          ",", 
          
          FormBox[\(hoopTimes[{0, e\_1, e\_2, 0, e\_3, 0, 0, e\_4}, {0, u\_1, 
                u\_2, 0, u\_3, 0, 0, u\_4}]\),
            "TraditionalForm"], ",", 
          "\[IndentingNewLine]", \(Use["\<CL31\>"]; "\<\nCL31\>"\), ",", 
          
          FormBox[\(hoopTimes[{0, e\_1, e\_2, 0, e\_3, 0, 0, e\_4}, {0, u\_1, 
                u\_2, 0, u\_3, 0, 0, u\_4}]\),
            "TraditionalForm"]}], "}"}], TraditionalForm]], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"Example 13. Wedge Products, Exterior Algebras. Clifford Algebras.\n\
CL2", {u\_1\ v\_1 - u\_2\ v\_2, 0, 0, \(-u\_2\)\ v\_1 + u\_1\ v\_2}, 
      "\nCL3", {u\_1\ v\_1 + u\_2\ v\_2 + u\_3\ v\_3, 0, 
        0, \(-u\_2\)\ v\_1 + u\_1\ v\_2, 
        0, \(-u\_3\)\ v\_1 + u\_1\ v\_3, \(-u\_3\)\ v\_2 + u\_2\ v\_3, 0}, 
      "\nCL4", {e\_1\ u\_1 + e\_2\ u\_2 + e\_3\ u\_3 - e\_4\ u\_4, 0, 
        0, \(-e\_2\)\ u\_1 + e\_1\ u\_2 + e\_4\ u\_3 + e\_3\ u\_4, 
        0, \(-e\_3\)\ u\_1 - e\_4\ u\_2 + e\_1\ u\_3 - e\_2\ u\_4, 
        e\_4\ u\_1 - e\_3\ u\_2 + e\_2\ u\_3 + e\_1\ u\_4, 0, 0, 0, 0, 0, 0, 
        0, 0, 0}, 
      "\nCL04", {\(-e\_1\)\ u\_1 - e\_2\ u\_2 - e\_3\ u\_3 + e\_4\ u\_4, 0, 
        0, \(-e\_2\)\ u\_1 + e\_1\ u\_2 - e\_4\ u\_3 - e\_3\ u\_4, 
        0, \(-e\_3\)\ u\_1 + e\_4\ u\_2 + e\_1\ u\_3 + 
          e\_2\ u\_4, \(-e\_4\)\ u\_1 - e\_3\ u\_2 + e\_2\ u\_3 - e\_1\ u\_4, 
        0, 0, 0, 0, 0, 0, 0, 0, 0}, 
      "\nCL31", {\(-e\_1\)\ u\_1 + e\_2\ u\_2 + e\_3\ u\_3 + e\_4\ u\_4, 0, 
        0, \(-e\_2\)\ u\_1 + e\_1\ u\_2 + e\_4\ u\_3 + e\_3\ u\_4, 
        0, \(-e\_3\)\ u\_1 - e\_4\ u\_2 + e\_1\ u\_3 - 
          e\_2\ u\_4, \(-e\_4\)\ u\_1 - e\_3\ u\_2 + e\_2\ u\_3 - e\_1\ u\_4, 
        0, 0, 0, 0, 0, 0, 0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tFinite Lie algebras appear to be Clifford hoops for which the real \
(scalar) elements have been zeroed. This has yet to be explored.\n\tMany \
algebras, some of which appear to be new",
  StyleBox[", are defined by other hoops",
    PageWidth->WindowWidth]
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.8 Most loops are not conservative.", "Subsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tThe majority of loops (quasigroups used as multiplication tables) are \
not conservative. The data contains a few non-conservative loops as examples, \
identified by names ending in ",
  StyleBox["n",
    FontSlant->"Italic"],
  ". The determinants of \"Q4n\" and \"C6n\" factorise nicely, but their \
quadratic factors are not conserved:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(Use["\<Q4n\>"]; {"\<Example 14. Q4n is not conservative.\n\>", "\<Q4n \
Table\>", hoopTbl // tf, "\<\nDet factors\>", 
      sh, \[IndentingNewLine]"\<\nA =   \>", 
      A = {4, 2, 3, 5}, \[IndentingNewLine]"\<\nB =   \>", 
      B = {1, 6, 2, 2}, \[IndentingNewLine]"\<\nAB=   \>", 
      AB = hoopTimes[A, B], "\<\nDet factors of A    sa =\>", 
      sa = sh /. \ as[A], "\<\nDet factors of B    sb =\>", 
      sb = sh /. \ as[B], "\<\nDet factors of AB   sab=\>", \ 
      sh /. \ as[AB], "\<\nThis is not sa*sb      =\>", sa\ sb}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 14. Q4n is not conservative.\\n\"\>", 
        ",", "\<\"Q4n Table\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4"},
                  {"2", "1", "4", \(-3\)},
                  {"3", \(-4\), "1", "2"},
                  {"4", "3", \(-2\), "1"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nDet factors\"\>", 
        ",", \({a\^2 - b\^2 - c\^2 - d\^2, a\^2 + b\^2 + c\^2 + d\^2}\), 
        ",", "\<\"\\nA =   \"\>", ",", \({4, 2, 3, 5}\), 
        ",", "\<\"\\nB =   \"\>", ",", \({1, 6, 2, 2}\), 
        ",", "\<\"\\nAB=   \"\>", ",", \({32, 22, 37, \(-1\)}\), 
        ",", "\<\"\\nDet factors of A    sa =\"\>", ",", \({\(-22\), 54}\), 
        ",", "\<\"\\nDet factors of B    sb =\"\>", ",", \({\(-43\), 45}\), 
        ",", "\<\"\\nDet factors of AB   sab=\"\>", ",", \({\(-830\), 2878}\),
         ",", "\<\"\\nThis is not sa*sb      =\"\>", ",", \({946, 2430}\)}], 
      "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Use["\<C6n\>"];\)\), "\[IndentingNewLine]", 
    \({"\<Example 14a. C6n only conserves the linear factors.\n\>", "\<C6n \
Table\>", hoopTbl // tf, "\<\nDet factors\>", sh, "\<\n A =\>", 
      A = {4, 2, 3, 5, 1, 6}, "\<\n B =\>", 
      B = {0, 6, 2, 4, 3, 2}, "\<\nAB =              \>", 
      AB = hoopTimes[A, B], "\<\nDet factors of A  sa =  \>", 
      sa = sh /. \ as[A], "\<\nDet factors of B  sb =  \>", 
      sb = sh /. \ as[B], "\<\nDet factors of AB sab=  \>", 
      sab = sh /. \ as[AB], "\<\nThis is not sa*sb       \>", 
      sa\ sb}\)}], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 14a. C6n only conserves the linear \
factors.\\n\"\>", ",", "\<\"C6n Table\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4", "5", "6"},
                  {"2", "3", "1", "6", "4", "5"},
                  {"3", "1", "2", "5", "6", "4"},
                  {"4", "5", "6", "2", "1", "3"},
                  {"5", "6", "4", "1", "3", "2"},
                  {"6", "4", "5", "3", "2", "1"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nDet factors\"\>", 
        ",", \({a + b + c - d - e - f, a + b + c + d + e + f, 
          1\/2\ \((\((a - b)\)\^2 + \((b - c)\)\^2 + \((\(-a\) + c)\)\^2 - \
\((d - e)\)\^2 - \((e - f)\)\^2 - \((\(-d\) + f)\)\^2)\), 
          1\/2\ \((\((a - b)\)\^2 + \((b - c)\)\^2 + \((\(-a\) + c)\)\^2 + \
\((d - e)\)\^2 + \((e - f)\)\^2 + \((\(-d\) + f)\)\^2)\)}\), 
        ",", "\<\"\\n A =\"\>", ",", \({4, 2, 3, 5, 1, 6}\), 
        ",", "\<\"\\n B =\"\>", ",", \({0, 6, 2, 4, 3, 2}\), 
        ",", "\<\"\\nAB =              \"\>", 
        ",", \({53, 70, 57, 66, 70, 41}\), 
        ",", "\<\"\\nDet factors of A  sa =  \"\>", 
        ",", \({\(-3\), 21, \(-18\), 24}\), 
        ",", "\<\"\\nDet factors of B  sb =  \"\>", 
        ",", \({\(-1\), 17, 25, 31}\), 
        ",", "\<\"\\nDet factors of AB sab=  \"\>", 
        ",", \({3, 357, \(-504\), 978}\), 
        ",", "\<\"\\nThis is not sa*sb       \"\>", 
        ",", \({3, 357, \(-450\), 744}\)}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tMany non-conservative loops, with various properties, have been ",
  StyleBox["tested by multiplying random vectors and comparing the \
determinants. (No necessary and sufficient loop property has been found for \
conservation.) ",
    PageWidth->WindowWidth],
  " The only conservative tables appear to be groups, a few non-commutative \
Moufang Loops [5] (including octonions and split-octonions), their direct \
composition with abelian groups, and tables folded from conservative loops. \
All known conservative tables have the Moufang property."
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2.9 Quadratic sizes, Abelian Polar-Vector Duals, Roots & Powers.\
\>", "Subsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tReal quadratic hoop determinant factors are conserved functions (though \
their complex-conjugate-pair factors are not conserved). They are symmetric \
real polynomials that can often be \"fragmented\", i.e. split into signed \
sums of smaller squared terms or \"fragments\". A generalisation (the \
\"PolyHelix Identity\") of ",
  Cell[BoxData[
      \(TraditionalForm\`Cos\^2\)]],
  "[\[Theta]]+",
  Cell[BoxData[
      \(TraditionalForm\`Sin\^2\)]],
  "[\[Theta]]=1 then leads to \"polar-dual\" formulations. E.g. C3 conserves \
",
  Cell[BoxData[
      \(TraditionalForm\`r\^2\)]],
  " =",
  Cell[BoxData[
      \(TraditionalForm\`a\^2\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`b\^2\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`c\^2\)]],
  StyleBox["- a b - b c - c a",
    FontSlant->"Italic"],
  " which fragments into",
  StyleBox[" ",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(TraditionalForm\`\((a - b)\)\^2\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`\((b - c)\)\^2\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`\((c - a)\)\^2\)]],
  ")/2. The associated angle is ",
  StyleBox["ArcTan[2a-b-c,-",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\@3\)],
    FontSlant->"Italic"],
  StyleBox["(b-c)]",
    FontSlant->"Italic"],
  ". (see Example 1.) Note that",
  StyleBox[", in sizes, ",
    PageWidth->WindowWidth],
  "the \"-\" sign always occurs in squared terms so it corresponds to a \
\"symmetric difference\" that does not imply negation or subtraction, which \
only arise in hoops after 2-folding.\n\tIn effect, each conserved quadratic \
size releases a degree of freedom, which is taken up by an angle. Angles are \
\"hidden variables\" for cartesian vectors. Polar-duals are the \
generalization of the {r,\[Theta]} formulation of the complex plane (or \
Argand-Wessel diagram) to other algebras. Linear sizes provide \"offsets\" \
for polar forms; these are extra degrees of freedom that are missing from \
complex algebra.\n\tAs angles add on abelian hoop multiplication, powers and \
roots can be obtained by raising sizes to the exponent and multiplying angles \
by the exponent. This is implemented by ",
  StyleBox["hoopPower",
    FontSlant->"Italic"],
  ", which converts a cartesian vector to the polar form, applies the \
exponent, and then reverts to cartesian form. It has been demonstrated in \
previous examples. Example 16 demonstrates a \"Hexal\" algebra, C3C4c, which \
is \"supersymmetric\" (see section 3) to one of the \"Dozal\" algebras, C3C4. \
These two algebras are unusual - they have sizes that involve ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\@3\)\(.\)\)\)]],
  " Note the \"If\" statements that handle specific cases in the angle \
calculations. These are essential when dealing with orbits (section 2.13); \
they are omitted (for simplicity) in most ",
  StyleBox["topol",
    FontSlant->"Italic"],
  " definitions in the data. ([4] supplies the complete versions.)"
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(Use["\<C3C4c\>"]; {"\<Example 16. C3C4c Polar form and square root\nThe \
table is\>", hoopTbl // tf, "\<\nThe polar form is\>", 
      topol, "\<\nA simplified cartesian form, in terms of radii \[Epsilon],\
\[Eta],\[Kappa] and angles \[Sigma],\[Chi],\[Psi] is\n\>", \(tovec /. \ 
          as[{\[Epsilon]\^2, \[Sigma], \[Eta]\^2, \[Chi] - \[Pi]/
                  6, \[Kappa]\^2, \[Psi] - \[Pi]/6}]\) /. \@any_\^2 \[Rule] 
          6  any, "\<\nWhen A  = \>", 
      A = {6. , 2. , 4. , 3. , 1. , 1. }, "\<\nthe shape of A is \>", 
      sh /. \ as[A], "\<\nthe polar form is \>", 
      pA = topol /. \ as[A], \[IndentingNewLine]"\<tovec recovers  A \>", 
      tovec /. \ as[pA], \[IndentingNewLine]"\<\nThe square root is\>", 
      rootA = hoopPower[A], "\<\nwith polar form   \>", 
      topol /. \ as[rootA], "\<\nrootA.rootA = A   \>", 
      hoopTimes[rootA, rootA]}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 16. C3C4c Polar form and square root\\nThe table \
is\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4", "5", "6"},
                  {"2", "3", "1", "5", "6", "4"},
                  {"3", "1", "2", "6", "4", "5"},
                  {"4", "5", "6", \(-1\), \(-2\), \(-3\)},
                  {"5", "6", "4", \(-2\), \(-3\), \(-1\)},
                  {"6", "4", "5", \(-3\), \(-1\), \(-2\)}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True], ",", "\<\"\\nThe polar form is\"\>", 
        ",", \({\((a + b + c)\)\^2 + \((d + e + f)\)\^2, 
          If[d + e + f \[Equal] 0, If[a + b + c < 0, \[Pi], 0], 
            ArcTan[a + b + c, d + e + f]], 
          3\/4\ \((\((\(a + b - 2\ c\)\/\@3 - d + e)\)\^2 + \((a - b + \(d + \
e - 2\ f\)\/\@3)\)\^2)\), \(-\(\[Pi]\/6\)\) + 
            If[\(a + b - 2\ c\)\/\@3 - d + e \[Equal] 0, 
              If[a - b + \(d + e - 2\ f\)\/\@3 < 0, \[Pi], 0], 
              ArcTan[a - b + \(d + e - 2\ f\)\/\@3, \(a + b - 2\ c\)\/\@3 - 
                  d + e]], 
          3\/4\ \((\((\(a + b - 2\ c\)\/\@3 + d - e)\)\^2 + \((a - b - \(d + \
e - 2\ f\)\/\@3)\)\^2)\), \(-\(\[Pi]\/6\)\) + 
            If[\(a + b - 2\ c\)\/\@3 + d - e \[Equal] 0, 
              If[a - b - \(d + e - 2\ f\)\/\@3 < 0, \[Pi], 0], 
              ArcTan[a - b - \(d + e - 2\ f\)\/\@3, \(a + b - 2\ c\)\/\@3 + 
                  d - e]]}\), 
        ",", "\<\"\\nA simplified cartesian form, in terms of radii \
\[Epsilon],\[Eta],\[Kappa] and angles \[Sigma],\[Chi],\[Psi] is\\n\"\>", 
        ",", \({2\ \[Epsilon]\ Cos[\[Sigma]] + \@3\ \[Eta]\ Cos[\[Chi]] + \@3\
\ \[Kappa]\ Cos[\[Psi]] + \[Eta]\ Sin[\[Chi]] + \[Kappa]\ Sin[\[Psi]], 
          2\ \[Epsilon]\ Cos[\[Sigma]] - \@3\ \[Eta]\ Cos[\[Chi]] - \@3\ \
\[Kappa]\ Cos[\[Psi]] + \[Eta]\ Sin[\[Chi]] + \[Kappa]\ Sin[\[Psi]], 
          2\ \[Epsilon]\ Cos[\[Sigma]] - 2\ \[Eta]\ Sin[\[Chi]] - 
            2\ \[Kappa]\ Sin[\[Psi]], \[Eta]\ Cos[\[Chi]] - \[Kappa]\ Cos[\
\[Psi]] + 
            2\ \[Epsilon]\ Sin[\[Sigma]] - \@3\ \[Eta]\ Sin[\[Chi]] + \@3\ \
\[Kappa]\ Sin[\[Psi]], \[Eta]\ Cos[\[Chi]] - \[Kappa]\ Cos[\[Psi]] + 
            2\ \[Epsilon]\ Sin[\[Sigma]] + \@3\ \[Eta]\ Sin[\[Chi]] - \@3\ \
\[Kappa]\ Sin[\[Psi]], \(-2\)\ \[Eta]\ Cos[\[Chi]] + 
            2\ \[Kappa]\ Cos[\[Psi]] + 2\ \[Epsilon]\ Sin[\[Sigma]]}\), 
        ",", "\<\"\\nWhen A  = \"\>", ",", \({6.`, 2.`, 4.`, 3.`, 1.`, 1.`}\),
         ",", "\<\"\\nthe shape of A is \"\>", 
        ",", \({169.`, 22.928203230275507`, 9.071796769724491`}\), 
        ",", "\<\"\\nthe polar form is \"\>", 
        ",", \({169.`, 0.3947911196997615`, 
          22.928203230275507`, \(-0.8937137001742207`\), 9.071796769724491`, 
          0.08908002307310836`}\), ",", "\<\"tovec recovers  A \"\>", 
        ",", \({6.`, 2.`, 4.`, 2.9999999999999996`, 0.9999999999999998`, 
          1.`}\), ",", "\<\"\\nThe square root is\"\>", 
        ",", \({2.414224259011073`, 0.3099888766376571`, 0.8113207702840068`, 
          0.576661967608032`, 
          0.13438651755665915`, \(-0.0039417039781438346`\)}\), 
        ",", "\<\"\\nwith polar form   \"\>", 
        ",", \({12.999999999999995`, 0.19739555984988075`, 
          4.788340341942652`, \(-0.4468568500871104`\), 3.01194235830045`, 
          0.04454001153655429`}\), ",", "\<\"\\nrootA.rootA = A   \"\>", 
        ",", \({5.9999999999999964`, 1.9999999999999991`, 
          3.9999999999999982`, 2.999999999999999`, 0.9999999999999994`, 
          0.9999999999999996`}\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2.10 Non-Abelian Polar-Vector Duals, Rotated-roots, Uncertainty?\
\>", "Subsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tNon-abelian hoops have repeated determinant factors. They do not have \
ordinary polar forms because the repeated sizes release extra degrees of \
freedom. (As the tables are non-abelian, the determinant should possibly be \
found and factorised by noncommutative procedures. No progress has been made \
with this topic.) Non-abelian quadratic sizes often have more than three \
fragments, and do not fit the patterns that give abelian polar forms. \
Splitting them into sets of two or three fragments allows the formulation of \
invertible \"pseudo-polar-powers\" with ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            FormBox[\(A\^\(1/p\)\),
              "TraditionalForm"], ")"}], "p"], TraditionalForm]]],
  "=A, but as the angles are not additive this gives \"pseudo-roots\" that do \
not multiply to recover the original vector i.e. ",
  Cell[BoxData[
      \(TraditionalForm\`A\^\(1/2\)\)]],
  ".",
  Cell[BoxData[
      \(TraditionalForm\`A\^\(1/2\)\)]],
  "\[NotEqual]A; the product has the correct sizes but the other elements of \
the polar form are modified in a non-obvious way. The angles are rotated. \
Conjecture - powers and roots may be associated with the introduction of \
uncertainty on making an observation of a quantum system.\n\tPseudo-roots are \
demonstrated for D3:- "
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  StyleBox["Example 16",
    FontWeight->"Bold"],
  StyleBox[". Using D3, Division and Polar-Vector interconversions work, but \
repeated products AA differ from pseudo-powers ",
    FontFamily->"Courier New"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["A",
            FontSlant->"Plain"], "2"], TraditionalForm]],
    FontFamily->"Courier New"]
}], "Text",
  FontSize->9],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Use["\<D3\>"]; {"\<The D3 table is\>", \[IndentingNewLine]hoopTbl // 
        tf}\), "\[IndentingNewLine]", 
    \(Chop[{Flatten[{"\<If  A=\>", 
              A = {2. , 3. , \(-3. \), 0. , \(-2. \), 1. }, "\<polarA=\>", 
              topol /. as[A]}], 
          Flatten[{"\<Vec(pol(A))=\>", 
              tovec /. as[
                  topol /. as[
                      A]], "\<OK, =A\>", "\<\>", "\<\>", "\<\>", "\<\>", \
"\<\>", "\<\>"}], \[IndentingNewLine]Flatten[{"\<and  B=\>", 
              B = {1. , \(-5. \), 3. , \(-1. \), 2. , 2. }, "\<polarB=\>", 
              topol /. as[B]}], \[IndentingNewLine]Flatten[{"\<AB=\>", 
              AB = hoopTimes[A, B], "\<polarAB=\>", 
              topol /. as[AB]}], \[IndentingNewLine]Flatten[{"\<Ai.AB=\>", 
              ABA = hoopTimes[hoopInverse[A], 
                  AB], "\<OK, =B\>", "\<\>", "\<\>", "\<\>", "\<\>", "\<\>", \
"\<\>"}], \[IndentingNewLine]Flatten[{"\<BA=\>", 
              BA = hoopTimes[B, A], "\<polarBA=\>", 
              topol /. as[BA]}], \[IndentingNewLine]Flatten[{"\<Bi.BA=\>", 
              BAB = hoopTimes[hoopInverse[B], 
                  BA], "\<OK, =A\>", "\<\>", "\<\>", "\<\>", "\<\>", "\<\>", \
"\<\>"}], 
          Flatten[{"\<AA=\>", AA = hoopTimes[A, A], "\<polarAA=\>", 
              topol /. as[AA]}], 
          Flatten[{\*"\"\<\!\(A\^2\)=\>\"", 
              A2 = hoopPower[A, 2], \*"\"\<\!\(polarA\^2\)=\>\"", 
              topol /. as[A2]}], 
          Flatten[{\*"\"\<(\!\(A\^2\)\!\(\()\^\(1/2\)\)\)=\>\"", 
              RA2 = hoopPower[A2, 1/2], "\<polar=\>", topol /. as[RA2]}]}] // 
      tf\)}], "Input",
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"The D3 table is\"\>", ",", 
        TagBox[
          FormBox[
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"1", "2", "3", "4", "5", "6"},
                  {"2", "1", "6", "5", "4", "3"},
                  {"3", "4", "5", "6", "1", "2"},
                  {"4", "3", "2", "1", "6", "5"},
                  {"5", "6", "1", "2", "3", "4"},
                  {"6", "5", "4", "3", "2", "1"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
            "TraditionalForm"],
          TraditionalForm,
          Editable->True]}], "}"}]], "Output"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"\<\"If  A=\"\>", "2.`", "3.`", \(-3.`\), "0", \(-2.`\), 
              "1.`", "\<\"polarA=\"\>", "1.`", \(-7.`\), "14.`", 
              "0.19012560334646675`", "21.`", "0.3334731722518321`"},
            {"\<\"Vec(pol(A))=\"\>", "2.`", "3.`", \(-2.9999999999999987`\), 
              "0", \(-1.9999999999999993`\), 
              "1.0000000000000002`", "\<\"OK, =A\"\>", "\<\"\"\>", \
"\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
            {"\<\"and  B=\"\>", "1.`", \(-5.`\), "3.`", \(-1.`\), "2.`", 
              "2.`", "\<\"polarB=\"\>", "2.`", 
              "10.`", \(-34.`\), \(-2.6179938779914944`\), "3.`", 
              "2.700286221232442`"},
            {"\<\"AB=\"\>", \(-23.`\), \(-9.`\), "4.`", "18.`", \(-15.`\), 
              "27.`", "\<\"polarAB=\"\>", 
              "2.`", \(-70.`\), \(-476.`\), \(-2.3869764961206146`\), "577.`",
               "2.899028779494308`"},
            {"\<\"Ai.AB=\"\>", "1.`", \(-4.999999999999998`\), 
              "2.9999999999999987`", \(-1.0000000000000002`\), 
              "1.9999999999999993`", 
              "2.0000000000000018`", "\<\"OK, =B\"\>", "\<\"\"\>", \
"\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
            {"\<\"BA=\"\>", \(-23.`\), \(-5.`\), \(-9.`\), "13.`", \(-2.`\), 
              "28.`", "\<\"polarBA=\"\>", "2.`", \(-70.`\), \(-476.`\), 
              "2.808119481337961`", "343.`", "2.6704321487405127`"},
            {"\<\"Bi.BA=\"\>", "2.`", 
              "2.999999999999999`", \(-3.0000000000000004`\), 
              "0", \(-1.9999999999999993`\), 
              "0.9999999999999991`", "\<\"OK, =A\"\>", "\<\"\"\>", \
"\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
            {"\<\"AA=\"\>", "26.`", "7.`", \(-5.`\), \(-20.`\), 
              "4.`", \(-11.`\), "\<\"polarAA=\"\>", "1.`", "49.`", "196.`", 
              "0.2860552964471535`", "763.`", "0.3334731722518321`"},
            {"\<\"\\!\\(A\\^2\\)=\"\>", "5.`", 
              "16.532249250832564`", \(-18.999999999999996`\), \
\(-1.3562945691657533`\), \(-9.999999999999996`\), 
              "9.824045318333194`", "\<\"\\!\\(polarA\\^2\\)=\"\>", 
              "1.0000000000000124`", \(-49.`\), "195.99999999999977`", 
              "0.38025120669293355`", "440.99999999999983`", 
              "0.6669463445036641`"},
            {"\<\"(\\!\\(A\\^2\\)\\!\\(\\()\\^\\(1/2\\)\\)\\)=\"\>", 
              "2.000000000000001`", 
              "3.0000000000000018`", \(-2.9999999999999982`\), 
              "0", \(-1.9999999999999984`\), 
              "1.0000000000000013`", "\<\"polar=\"\>", 
              "1.0000000000000082`", \(-7.`\), "13.99999999999999`", 
              "0.19012560334646675`", "20.999999999999993`", 
              "0.3334731722518321`"}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
  FontSize->9]
}, Open  ]],

Cell[TextData[{
  "The repeated quadratic factor of D3, (",
  Cell[BoxData[
      \(TraditionalForm\`a\^2 - b\^2 + c\^2 - d\^2 + e\^2 - f\^2 - c\ a - 
        e\ a\)]],
  Cell[BoxData[
      \(TraditionalForm\`+\)],
    PageWidth->PaperWidth,
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`b\ d\)]],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`\(-c\)\ \ e + b\ f + d\ f\)]],
  ")/2, has been handled as two sets of sums of three squares ",
  Cell[BoxData[
      \(TraditionalForm\`\((\((e - a)\)\^2 + \((a - c)\)\^2 + \((c - e)\)\^2)\
\)/2\)],
    PageWidth->PaperWidth,
    FontFamily->"Times New Roman"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\((\((f - b)\)\^2 + \((b - d)\)\^2 + \((d - f)\)\^2)\
\)/2\)]],
  " to allow the formulation of a pseudo-polar dual. The angles do not add, \
nor are the squared radii conserved. (The conserved length is their \
difference.) I have sought (without success) a reformulation with additive \
angles, using the distinction between left and right multiplication."
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.11 Vectors with some zero sizes, Remainders.", "Subsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tSizes provide the denominators of the partial-fraction formulation of \
the multiplicative inverse (because it is found by Cramer's method). Vectors \
can have coefficients that make one or more size zero in a particular \
algebra; these algebras have \"divisors of zero\". Most mathematicians choose \
to restrict their work to the \"algebras without real divisors of zero\", \
i.e. \[DoubleStruckCapitalR], \[DoubleStruckCapitalC], \
\[DoubleStruckCapitalH] (Quaternions), and \[DoubleStruckCapitalO] \
(Octonions). A determinant is zero if it has one or more zero factor, but it \
may still have non-zero factors. Hoop algebras overcome division-by-zero via \
two innovations, ",
  StyleBox["projection",
    FontSlant->"Italic"],
  " into sub-algebras and ",
  StyleBox["ejection",
    FontSlant->"Italic"],
  " of remainders. Zeroed sizes correspond to operations in sub-algebras with \
these sizes constrained to be zero; inverses are in the same sub-algebras, \
and also have these zeroes. In effect, zeroes are \"factored out\". \
Conservation is maintained by ejecting left and right remainders A/B = C +Rl \
+Rr; sizes that are zero in C but not in A go into the left remainder; sizes \
that are zero in C but not in B go into the right remainder. This is a \
generalization of integer division. As ",
  StyleBox["hoopTimes",
    FontSlant->"Italic"],
  " implements both division and multiplication, remainders also extend to \
multiplication A*B=P+Rl+Rr so that P/A+Rr=B and P/B+Rl=A. Example 17 sets up \
two vectors with C4 shapes {6,2,0} & {0,10,10}; their product has shape \
{0,20,0}; Rl conserves the 6 from A0; Rr conserves the second 10 from B0. \
Dividing AB by A does not recover B until Rr is added; dividing AB by B does \
not recover A until Rl is added.  "
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(Use["\<C4\>"]\), ";", 
      RowBox[{"Chop", "[", 
        RowBox[{"{", 
          RowBox[{
          "\"\<Example 17. C4 multiplication with remainders\>\"", ",", 
            "\"\<\\n         A0 = \>\"", ",", \(A0 = {2, 1, 2, 1}\), ",", 
            "\[IndentingNewLine]", "\"\<\\n\!\(\*
StyleBox[\"shape\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)A0 = \>\"", 
            ",", \(sA0 = sh /. \ as[A0]\), ",", "\[IndentingNewLine]", 
            "\"\<\\n         B0 = \>\"", ",", \(B0 = {3, \(-1\), 2, \(-4\)}\),
             ",", "\[IndentingNewLine]", "\"\<\\n\!\(\*
StyleBox[\"shape\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",\nFontSlant->\"Italic\"]\) B0 = \>\"", 
            ",", \(sh /. \ as[B0]\), ",", "\[IndentingNewLine]", 
            "\"\<\\n         AB = \>\"", ",", \(AB = hoopTimes[A0, B0]\), ",",
             "\[IndentingNewLine]", "\"\<\\n\!\(\*
StyleBox[\"shape\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"of\",\nFontSlant->\"Italic\"]\) AB = \>\"", 
            ",", \(sh /. \ as[AB]\), ",", "\[IndentingNewLine]", 
            "\"\<\\n\!\(\*
StyleBox[\"Note\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"that\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"sizes\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"  \",\nFontSlant->\"Italic\"]\)\[UpArrow]     \[UpArrow]\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"have\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"become\",\nFontSlant->\"Italic\"]\) 0\>\"", ",", 
            "\[IndentingNewLine]", "\"\<\\n\!\(\*
StyleBox[\"Remainder\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"Rl\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"=\",\nFontSlant->\"Italic\"]\)\>\"", ",", \(RA = Rl\), ",", 
            "\"\<\\n\!\(\*
StyleBox[\"has\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"a\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"shape\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"     \",\nFontSlant->\"Italic\"]\) \>\"", ",", \(sh /. \ as[Rl]\), 
            ",", "\"\<\\n\!\(\*
StyleBox[\"Remainder\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"Rr\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"=\",\nFontSlant->\"Italic\"]\)\>\"", ",", \(RB = Rr\), ",", 
            "\"\<\\n\!\(\*
StyleBox[\"has\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"a\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"shape\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"   \",\nFontSlant->\"Italic\"]\)\>\"", ",", \(sh /. \ as[Rr]\), 
            ",", "\"\<\\n\!\(\*
StyleBox[\"Ainverse\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"    \",\nFontSlant->\"Italic\"]\)= \>\"", 
            ",", \(Ainv = hoopInverse[A0]\), ",", "\"\<\\nwith shape    \>\"",
             ",", \(sh /. \ as[Ainv]\), ",", "\"\<\\nAB/A0       = \>\"", 
            ",", \(ABoA = hoopTimes[Ainv, AB]\), ",", 
            "\"\<\\nwith shape    \>\"", ",", \(sh /. \ as[ABoA]\), ",", 
            "\"\<\\nAdding Rr recovers B0\>\"", ",", \(ABoA + RB\), ",", 
            "\[IndentingNewLine]", "\"\<\\n\!\(\*
StyleBox[\"Binverse\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"    \",\nFontSlant->\"Italic\"]\)= \>\"", 
            ",", \(Binv = hoopInverse[B0]\), ",", "\"\<\\nwith shape    \>\"",
             ",", \(sh /. \ as[Binv]\), ",", "\"\<\\nAB/B0       = \>\"", 
            ",", \(ABoB = hoopTimes[AB, Binv]\), ",", 
            "\"\<\\nwith shape    \>\"", ",", \(sh /. \ as[ABoB]\), ",", 
            "\"\<\\nAdding Rl recovers A0  \>\"", ",", \(ABoB + RA\)}], 
          StyleBox["}",
            FontSlant->"Italic"]}], "]"}]}]], "Input",
  PageWidth->WindowWidth,
  CellOpen->False,
  FontFamily->"Courier New",
  FontSize->10],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 17. C4 multiplication with remainders\"\>", 
        ",", "\<\"\\n         A0 = \"\>", ",", \({2, 1, 2, 1}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"shape\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)A0 = \"\>", ",", \({6, 2, 0}\), 
        ",", "\<\"\\n         B0 = \"\>", ",", \({3, \(-1\), 2, \(-4\)}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"shape\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\\) B0 = \"\>", 
        ",", \({0, 10, 10}\), ",", "\<\"\\n         AB = \"\>", 
        ",", \({5, \(-5\), 5, \(-5\)}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"shape\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"of\\\",\\nFontSlant->\\\"Italic\\\"]\\) AB = \"\>", 
        ",", \({0, 20, 0}\), 
        ",", "\<\"\\n\\!\\(\\* StyleBox[\\\"Note\\\",\\nFontSlant->\\\"Italic\
\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"that\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"sizes\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"  \\\",\\nFontSlant->\\\"Italic\\\"]\\)\[UpArrow]     \[UpArrow]\
\\!\\(\\* StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"have\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"become\\\",\\nFontSlant->\\\"Italic\\\"]\\) 0\"\>", 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"Remainder\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"Rl\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"=\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
        ",", \({3\/2, 3\/2, 3\/2, 3\/2}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"has\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"a\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"shape\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"     \\\",\\nFontSlant->\\\"Italic\\\"]\\) \"\>", 
        ",", \({6, 0, 0}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"Remainder\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"Rr\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"=\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
        ",", \({1\/2, 3\/2, \(-\(1\/2\)\), \(-\(3\/2\)\)}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"has\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"a\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\" \\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"shape\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"   \\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", 
        ",", \({0, 0, 10}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"Ainverse\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\
\\\"    \\\",\\nFontSlant->\\\"Italic\\\"]\\)= \"\>", 
        ",", \({1\/6, \(-\(1\/12\)\), 1\/6, \(-\(1\/12\)\)}\), 
        ",", "\<\"\\nwith shape    \"\>", ",", \({1\/6, 1\/2, 0}\), 
        ",", "\<\"\\nAB/A0       = \"\>", 
        ",", \({5\/2, \(-\(5\/2\)\), 5\/2, \(-\(5\/2\)\)}\), 
        ",", "\<\"\\nwith shape    \"\>", ",", \({0, 10, 0}\), 
        ",", "\<\"\\nAdding Rr recovers B0\"\>", 
        ",", \({3, \(-1\), 2, \(-4\)}\), 
        ",", "\<\"\\n\\!\\(\\* \
StyleBox[\\\"Binverse\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\
\\\"    \\\",\\nFontSlant->\\\"Italic\\\"]\\)= \"\>", 
        ",", \({3\/40, \(-\(7\/40\)\), \(-\(1\/40\)\), 1\/8}\), 
        ",", "\<\"\\nwith shape    \"\>", ",", \({0, 1\/10, 1\/10}\), 
        ",", "\<\"\\nAB/B0       = \"\>", 
        ",", \({1\/2, \(-\(1\/2\)\), 1\/2, \(-\(1\/2\)\)}\), 
        ",", "\<\"\\nwith shape    \"\>", ",", \({0, 2, 0}\), 
        ",", "\<\"\\nAdding Rl recovers A0  \"\>", ",", \({2, 1, 2, 1}\)}], 
      "}"}]], "Output",
  FontSize->9]
}, Open  ]],

Cell[TextData[{
  "\t\[DoubleStruckCapitalC], \[DoubleStruckCapitalH], and \
\[DoubleStruckCapitalO] can have divisors of zero if their coefficients are \
complex.The hoop algebras defined by the Pauli-\[Sigma] matrices (P4, P8, \
P16) conserve variations on the Minkowski metric ",
  Cell[BoxData[
      \(TraditionalForm\`t\^2\)]],
  "-",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  "-",
  Cell[BoxData[
      \(TraditionalForm\`y\^2\)]],
  "-",
  Cell[BoxData[
      \(TraditionalForm\`z\^2\)]],
  " and can have real divisors of zero. The \"light cone\" is a zero \
sub-space.\n\tSome algebras can have \"annihilators\", real vectors with all \
sizes zero. Operations with them give results with all sizes zero (but with \
non-zero coefficients), so one remainder will be the other operand, \
unchanged. Example 18 shows this for left and right multiplication by a D3 \
annihilator A0."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(Use["\<D3\>"]; 
    Chop[{"\<Example 18. D3 annihilator\>", "\<\nD3 has shape\>", 
        sh, "\<\nA0 =  \>", 
        A0 = {2, 0, \(-2\), \(-2\), 0, 
            2}, \[IndentingNewLine]"\<\nA0 shape\>", 
        sh /. \ as[A0], "\<\nB  =  \>", 
        B = {2, 3, \(-4\), \(-1\), 5, 
            2}, \[IndentingNewLine]"\<\nB shape \>", 
        sh /. \ as[B], "\<\nAB  = \>", 
        AB = hoopTimes[A0, B], "\<\nAB shape\>", 
        sh /. \ as[AB], "\<\nRl =  \>", Rl, "\<\nRr = B\>", 
        Rr, "\<\nBA  = \>", BA = hoopTimes[B, A0], "\<\nBA shape\>", 
        sh /. \ as[BA], "\<\nRl = B\>", Rl, "\<\nRr =  \>", Rr}]\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"Example 18. D3 annihilator", 
      "\nD3 has shape", {a + b + c + d + e + f, a - b + c - d + e - f, 
        1\/2\ \((\((a - c)\)\^2 - \((b - d)\)\^2 + \((c - e)\)\^2 + \((\(-a\) \
+ e)\)\^2 - \((d - f)\)\^2 - \((\(-b\) + f)\)\^2)\)}, 
      "\nA0 =  ", {2, 0, \(-2\), \(-2\), 0, 2}, "\nA0 shape", {0, 0, 0}, 
      "\nB  =  ", {2, 3, \(-4\), \(-1\), 5, 2}, 
      "\nB shape ", {7, \(-1\), 50}, 
      "\nAB  = ", {0, 20, \(-20\), \(-20\), 20, 0}, "\nAB shape", {0, 0, 0}, 
      "\nRl =  ", {0, 0, 0, 0, 0, 0}, 
      "\nRr = B", {2, 3, \(-4\), \(-1\), 5, 2}, 
      "\nBA  = ", {0, \(-10\), \(-10\), 0, 10, 10}, "\nBA shape", {0, 0, 0}, 
      "\nRl = B", {2, 3, \(-4\), \(-1\), 5, 2}, 
      "\nRr =  ", {0, 0, 0, 0, 0, 0}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.12 Subtraction is Additive Elimination.", "Subsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tNegation \"-a\" and subtraction \"b-a\" are conflated and treated as a \
single fundamental process by most mathematicians, but [5] requires over a \
hundred pages of \"Post-Modern Algebra\" before subtraction can be tackled. \
In hoops, negation is the result of a fold with ",
  StyleBox["r",
    FontSlant->"Italic"],
  "=2. This equivalences {",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + m/2\)\)]],
  "} to a real number ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["a",
            FontWeight->"Bold"], "i"], TraditionalForm]]],
  ", with {",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i + m/2\)\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  "} ~ -",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["a",
            FontWeight->"Bold"], "i"], TraditionalForm]]],
  " and {",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  "} ~ ",
  StyleBox["0",
    FontWeight->"Bold"],
  ". The first size, \[Sum]",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  ", is destroyed, as it equivalences to zero. Subtraction can now be seen as \
\"additive elimination\", adding a set of coefficients that make all the \
terms of an un-folded vector identical, so that they equivalence to zero: \
{a,b}+{b,a} ={a+b,a+b} ~ ",
  StyleBox["0",
    FontWeight->"Bold"],
  ". (The commutative property of addition is inherited from the natural \
numbers.)\n\tWhen ",
  StyleBox["r",
    FontSlant->"Italic"],
  " is 3, the equivalence relationship is ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["t",
            FontWeight->"Bold"], "j"], TraditionalForm]]],
  "~{",
  Cell[BoxData[
      \(TraditionalForm\`a\_j\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(j + m/3\)\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(j + 2  m/3\)\)]],
  "} ~{",
  Cell[BoxData[
      \(TraditionalForm\`b\_j\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`b\_\(j + m/3\)\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`b\_\(j + 2  m/3\)\)]],
  "} iff (",
  Cell[BoxData[
      \(TraditionalForm\`a\_j\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`b\_\(j + m/3\)\)]],
  ") = (",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(j + m/3\)\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`b\_\(j + 2  m/3\)\)]],
  ") = (",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(j + 2  m/3\)\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`b\_j\)]],
  "). The \"terplex number\" {a,b,c} has a left negation (or rotation), \
{b,c,a} and a right negation {c,a,b}, with {a,b,c} +{b,c,a} +{c,a,b} ={a+b+c, \
a+b+c, a+b+c} ~ ",
  StyleBox["0",
    FontWeight->"Bold"],
  ". A number is eliminated by adding the two rotations of its vector form. \
This extends to other ",
  StyleBox["r",
    FontSlant->"Italic"],
  " values; a number is eliminated by adding the ",
  StyleBox["r",
    FontSlant->"Italic"],
  "-1 rotations of a primal form. Simultaneous equations can be solved in \
this way in hoop algebras, but this is not demonstrated here."
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.13. Orbits.", "Subsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tI define a \"unital\" sub-algebra by the restriction that \"the product \
of non-zero sizes is unity\". The name \"orbit\" is appropriate to polar \
forms of unital sub-algebras because the coefficients are restricted to \
circles in ",
  StyleBox["m",
    FontSlant->"Italic"],
  "-dimensional space, and the group orbits are points on these circles. \
Multiplying one orbit by another (using the same hoop) gives another orbit, \
and any remainders will also be orbits. If some sizes are zero, operations \
are restricted to a sub-algebra in which these sizes remain at zero, by \
conservation. This generates sub-orbits that have analogies with particles - \
discussed in section 3.\n \tI use the convention that orbit polar forms have \
names OHijk, with vector forms VHijk, where H is the hoop name and ijk... \
gives the sizes. Linear sizes provide \"offsets\", displacing the orbit \
origin from zero. This may be a new concept; it introduces additive \
properties to orbits. The squared radius is a multiplicative property for \
abelian radius/angle formulations."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Use["\<C3\>"]; {"\<Example 19. C3 Orbits\>", "\<\nOC301 is {0,1,a} with \
vector form\>", 
      OC301 = tovec /. \ 
          as[{0, 1, a}], "\<\nOC311 is {1,1,b} with vector form\>", 
      OC311 = tovec /. \ 
          as[{1, 1, 
              b}], "\<\nProducts are orbits with added angles; the polar form \
of the product of OC301 & OC311 is\>", 
      Simplify[topol /. \ 
          as[hoopTimes[OC301, OC311]]], "\<\nand the remainders are\>", Rl, 
      Rr}\), "\[IndentingNewLine]", 
    \(Use["\<C4\>"]; {"\<Example 20b. C4 Orbits\>", "\<\nOC4001 is \>", 
      OC4001 = {0, 0, 1, a}, "\<\n with vector form\>", 
      VC4001 = tovec /. \ as[OC4001], "\<\nOC4011 is\>", 
      OC4011 = {0, 1, 1, b}, "\<\n with vector form\>"\ , 
      VC4011 = tovec /. \ as[OC4011], "\<\nOC4101 =\>", 
      OC4101\  = \ {1, 0, 1, c}, "\<\n with vector form\>", 
      VC4101 = tovec /. \ as[OC4101], "\<\nOC4111 is\>", 
      OC4111\  = \ {1, 1, 1, d}, "\<\nwith vector form\>", 
      VC4111 = tovec /. \ 
          as[OC4111], "\<\n\n\>", \[IndentingNewLine]Simplify[{"\<OC4001\
\[Times]OC4001 has the 001 shape\>", 
          sh /. \ as[
              hoopTimes[VC4001, 
                VC4001]], "\<\nOC4101\[Times]OC4011 also has the 001 shape\n\
as the two offsets disappear   \>", 
          sh /. \ as[hoopTimes[VC4101, VC4011]], "\<\nwith remainders \>", 
          Rl, Rr, "\<\nOC4101\[Times]OC4111 has the 101 shape\>", \
\[IndentingNewLine]sh /. \ 
            as[hoopTimes[VC4101, VC4111]], "\<\nwith remainders \>", Rl, 
          Rr, "\<\nOC4111\[Times]OC4111 has the 111 shape\>", 
          sh /. \ as[hoopTimes[VC4111, VC4111]]}], "\<\nwith remainders \>", 
      Rl, Rr}\)}], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    \({"Example 19. C3 Orbits", 
      "\nOC301 is {0,1,a} with vector form", {\(2\ Cos[a]\)\/3, 
        2\/3\ Cos[a + \(2\ \[Pi]\)\/3], 2\/3\ Cos[a - \(2\ \[Pi]\)\/3]}, 
      "\nOC311 is {1,1,b} with vector form", {1\/3\ \((1 + 2\ Cos[b])\), 
        1\/3\ \((1 + 2\ Cos[b + \(2\ \[Pi]\)\/3])\), 
        1\/3\ \((1 + 2\ Cos[b - \(2\ \[Pi]\)\/3])\)}, 
      "\nProducts are orbits with added angles; the polar form of the product \
of OC301 & OC311 is", {0, 1, ArcTan[Cos[a + b], Sin[a + b]]}, 
      "\nand the remainders are", {0, 0, 0}, {1\/3, 1\/3, 1\/3}}\)], "Output"],

Cell[BoxData[
    \({"Example 20b. C4 Orbits", "\nOC4001 is ", {0, 0, 1, a}, 
      "\n with vector form", {Cos[a]\/2, 
        Sin[a]\/2, \(-\(Cos[a]\/2\)\), \(-\(Sin[a]\/2\)\)}, 
      "\nOC4011 is", {0, 1, 1, b}, 
      "\n with vector form", {1\/4\ \((1 + 2\ Cos[b])\), 
        1\/4\ \((\(-1\) + 2\ Sin[b])\), 1\/4\ \((1 - 2\ Cos[b])\), 
        1\/4\ \((\(-1\) - 2\ Sin[b])\)}, "\nOC4101 =", {1, 0, 1, c}, 
      "\n with vector form", {1\/4\ \((1 + 2\ Cos[c])\), 
        1\/4\ \((1 + 2\ Sin[c])\), 1\/4\ \((1 - 2\ Cos[c])\), 
        1\/4\ \((1 - 2\ Sin[c])\)}, "\nOC4111 is", {1, 1, 1, d}, 
      "\nwith vector form", {1\/4\ \((2 + 2\ Cos[d])\), Sin[d]\/2, 
        1\/4\ \((2 - 2\ Cos[d])\), \(-\(Sin[d]\/2\)\)}, 
      "\n\n", {"OC4001\[Times]OC4001 has the 001 shape", {0, 0, 1}, 
        "\nOC4101\[Times]OC4011 also has the 001 shape\nas the two offsets \
disappear   ", {0, 0, 1}, 
        "\nwith remainders ", {1\/4, 1\/4, 1\/4, 1\/4}, {1\/4, \(-\(1\/4\)\), 
          1\/4, \(-\(1\/4\)\)}, 
        "\nOC4101\[Times]OC4111 has the 101 shape", {1, 0, 1}, 
        "\nwith remainders ", {0, 0, 0, 0}, {1\/4, \(-\(1\/4\)\), 
          1\/4, \(-\(1\/4\)\)}, 
        "\nOC4111\[Times]OC4111 has the 111 shape", {1, 1, 1}}, 
      "\nwith remainders ", {0, 0, 0, 0}, {0, 0, 0, 0}}\)], "Output",
  FontSize->9]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. Analogies with Particles.", "Section",
  PageWidth->WindowWidth],

Cell[TextData[{
  StyleBox["Summary\n\tThe \"Dozal\" algebras based on 12-element groups have \
elements that act as half-spin (fermionic) and unit-spin (bosonic) quantum \
operators. Their orbits have analogies with fundamental particles. This leads \
to the possibility that hoop algebras may provide a new paradigm for physics. \
The following conjectures, which the author cannot develop further, are \
outlined:- \n\tDozal interactions, with remainders conserving different \
properties, resemble particle interactions and decay. Four hoops ",
    FontSlant->"Italic"],
  StyleBox["{C3K, C4C4, D3C2, Q12} possibly ",
    PageWidth->WindowWidth,
    FontSlant->"Italic"],
  StyleBox["correspond to four forces - they conserve different but \
overlapping sets of properties. The non-Abelian hoops may introduce \
uncertainty. Linear sizes are additive properties.\n\tOrbits resemble \
multi-phase deBroglie waves, and quadratic sizes resemble Planck areas. Wave \
packets in stable orbits",
    FontSlant->"Italic"],
  StyleBox[" with 3, 6 or 12 phases ",
    PageWidth->WindowWidth,
    FontSlant->"Italic"],
  StyleBox["may relate to quarks whilst 4-phase orbits may relate to leptons. \
Resonant orbits, at integer multiples of the fundamental frequency, may \
relate to particles resonances.\n\t",
    FontSlant->"Italic"],
  StyleBox["Bosonic \"hexal\" ",
    PageWidth->WindowWidth,
    FontSlant->"Italic"],
  StyleBox["elements are supersymmetric to (but fewer than) ",
    FontSlant->"Italic"],
  StyleBox["fermionic",
    PageWidth->WindowWidth,
    FontSlant->"Italic"],
  StyleBox[" dozal",
    FontSlant->"Italic"],
  StyleBox[" elements. Bosons",
    PageWidth->WindowWidth,
    FontSlant->"Italic"],
  StyleBox[" are not subject to the Pauli exlusion principle because they are \
equivalence relations. ",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["3.1. Dozal and Hexal.", "Subsubsection",
  PageWidth->WindowWidth],

Cell["\<\
\tDozal and Hexal algebras, with 12 and 6 elements, have many analogies with \
fundamental particles. They may lead to a new paradigm for physics, based on \
finite Moufang Loop symmetries (together withLie group symmetries). Sporadic \
discoveries, spread over fifteen years of research, have repeatedly related \
different physical phenomena to newly discovered aspects of hoop algebra, \
encouraging the conjecture that these algebras are \"physical \
mathematics\".\
\>", "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.2. Dozal elements act as Quantum Operators.", "Subsubsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tJ. J. Hamilton [6] developed a \"hypercomplex arithmetic\", with \
half-spin \"non-real, non-complex\" quantum operators {",
  StyleBox["a",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(a\^*\)\)],
    PageWidth->WindowWidth,
    Evaluatable->False],
  ",",
  StyleBox["b ",
    FontSlant->"Italic"],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`\(b\^*\)\)],
    PageWidth->WindowWidth,
    Evaluatable->False],
  "} as well as integer-spin quantum operators, having the following \
multiplication table:-"
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox["Example",
          FormatType->TraditionalForm,
          FontSize->10], 
        StyleBox[" ",
          FormatType->TraditionalForm,
          FontSize->10], 
        StyleBox["21.",
          FormatType->TraditionalForm,
          FontSize->10], 
        StyleBox[" ",
          FormatType->TraditionalForm,
          FontSize->10], 
        RowBox[{
          StyleBox["J",
            FormatType->TraditionalForm,
            FontSize->10,
            FontWeight->"Plain",
            FontSlant->"Plain"], 
          StyleBox[".",
            FormatType->TraditionalForm,
            FontSize->10,
            FontWeight->"Plain",
            FontSlant->"Plain"], 
          StyleBox["J",
            FormatType->TraditionalForm,
            FontSize->10,
            FontWeight->"Plain",
            FontSlant->"Plain"], 
          StyleBox[".",
            FormatType->TraditionalForm,
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox[\(Hamilton'\),
            FormatType->TraditionalForm,
            FontSize->10,
            FontWeight->"Plain"]}], 
        StyleBox["s",
          FormatType->TraditionalForm,
          FontSize->10,
          FontWeight->"Plain",
          FontSlant->"Plain"], 
        StyleBox[" ",
          FormatType->TraditionalForm,
          FontSize->10,
          FontWeight->"Plain"], 
        StyleBox["Table",
          FormatType->TraditionalForm,
          FontSize->10,
          FontWeight->"Plain"], 
        StyleBox[" ",
          FormatType->TraditionalForm,
          FontSize->10,
          FontWeight->"Plain"], 
        StyleBox[\(\(II\)\(.\)\),
          FormatType->TraditionalForm,
          FontSize->10,
          FontWeight->"Plain"]}], TraditionalForm]], "Input"],

Cell[BoxData[
    RowBox[{"     ", 
      FormBox[GridBox[{
            {
              " ", \(E\_0\), \(E\_1\), \(E\_2\), \(E\_3\), \(E\_4\), \
\(E\_5\), \(E\_6\), \(E\_7\)},
            {\(E\_0\), "1", "i", "h", "k", "a", \(b\^*\), \(a\^*\), "b"},
            {\(E\_1\), "i", \(-1\), "k", \(-h\), \(b\^*\), \(-a\), 
              "b", \(-\(a\^*\)\)},
            {\(E\_2\), "h", "k", "1", "i", \(a\^*\), "b", "a", \(b\^*\)},
            {\(E\_3\), "k", \(-h\), "i", \(-1\), 
              "b", \(-\(a\^*\)\), \(b\^*\), \(-a\)},
            {\(E\_4\), "a", \(b\^*\), \(a\^*\), "b", "1", "i", "h", "k"},
            {\(E\_5\), \(b\^*\), \(-a\), "b", \(-\(a\^*\)\), "i", \(-1\), 
              "k", \(-h\)},
            {\(E\_6\), \(a\^*\), "b", "a", \(b\^*\), "h", "k", "1", "i"},
            {\(E\_7\), "b", \(-\(a\^*\)\), \(b\^*\), \(-a\), "k", \(-h\), 
              "i", \(-1\)}
            }],
        "TraditionalForm"]}]], "Input",
  PageWidth->WindowWidth,
  Evaluatable->False],

Cell[TextData[{
  StyleBox["\t",
    FontSlant->"Italic"],
  "His",
  StyleBox[" a",
    FontSlant->"Italic"],
  "* and ",
  StyleBox["b",
    FontSlant->"Italic"],
  "* are \"biconjugates\" (my term) with ",
  StyleBox["a",
    FontSlant->"Italic"],
  "**=-",
  StyleBox["a",
    FontSlant->"Italic"],
  ", ",
  StyleBox["b",
    FontSlant->"Italic"],
  "**=-",
  StyleBox["b",
    FontSlant->"Italic"],
  ". The table has four elements that square to -1; Hamilton also introduces \
several other elements and many aliases. Replacing the ambiguous \"-1\" by ii \
and including extra rows and columns that match his multiplication rules \
gives a 12\[Times]12 table with his table embedded (in boldface, with ii in \
place of -1):-"
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox["Example",
          FormatType->TraditionalForm,
          FontSize->10], 
        StyleBox[" ",
          FormatType->TraditionalForm,
          FontSize->10], 
        StyleBox["22.",
          FormatType->TraditionalForm,
          FontSize->10], 
        StyleBox[" ",
          FormatType->TraditionalForm,
          FontSize->10], 
        StyleBox["C3K",
          FormatType->TraditionalForm,
          FontSize->10,
          FontWeight->"Plain"], 
        StyleBox[" ",
          FormatType->TraditionalForm,
          FontSize->10,
          FontWeight->"Plain"], 
        StyleBox["contains",
          FormatType->TraditionalForm,
          FontSize->10,
          FontWeight->"Plain"], 
        StyleBox[" ",
          FormatType->TraditionalForm,
          FontSize->10,
          FontWeight->"Plain"], 
        StyleBox[\(Hamilton'\),
          FormatType->TraditionalForm,
          FontSize->10,
          FontWeight->"Plain"], 
        StyleBox["s",
          FormatType->TraditionalForm,
          FontSize->10,
          FontWeight->"Plain"], 
        StyleBox[" ",
          FormatType->TraditionalForm,
          FontSize->10,
          FontWeight->"Plain"], 
        StyleBox[\(\(table\)\(.\)\),
          FormatType->TraditionalForm,
          FontSize->10,
          FontWeight->"Plain"]}], TraditionalForm]], "Input"],

Cell[BoxData[GridBox[{
        {
          StyleBox["1",
            FontSize->10], 
          StyleBox["i",
            FontSize->10], 
          StyleBox["ii",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["h",
            FontSize->10], 
          StyleBox["k",
            FontSize->10], 
          StyleBox[\(-h\),
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["a",
            FontSize->10], 
          StyleBox[\(b\^*\),
            FontSize->10], 
          StyleBox[\(-a\),
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox[\(a\^*\),
            FontSize->10], 
          StyleBox["b",
            FontSize->10], 
          StyleBox[\(-\(a\^*\)\),
            FontSize->10,
            FontWeight->"Plain"]},
        {
          StyleBox["i",
            FontSize->10], 
          StyleBox["ii",
            FontSize->10], 
          StyleBox["1",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["k",
            FontSize->10], 
          StyleBox[\(-h\),
            FontSize->10], 
          StyleBox["h",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox[\(b\^*\),
            FontSize->10], 
          StyleBox[\(-a\),
            FontSize->10], 
          StyleBox["a",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["b",
            FontSize->10], 
          StyleBox[\(-\(a\^*\)\),
            FontSize->10], 
          StyleBox[\(a\^*\),
            FontSize->10,
            FontWeight->"Plain"]},
        {
          StyleBox["ii",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["1",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["i",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox[\(-h\),
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["h",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["k",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox[\(-a\),
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["a",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox[\(b\^*\),
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox[\(-\(a\^*\)\),
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox[\(a\^*\),
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["b",
            FontSize->10,
            FontWeight->"Plain"]},
        {
          StyleBox["h",
            FontSize->10], 
          StyleBox["k",
            FontSize->10], 
          StyleBox[\(-h\),
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["1",
            FontSize->10], 
          StyleBox["i",
            FontSize->10], 
          StyleBox["ii",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox[\(a\^*\),
            FontSize->10], 
          StyleBox["b",
            FontSize->10], 
          StyleBox[\(-\(a\^*\)\),
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["a",
            FontSize->10], 
          StyleBox[\(b\^*\),
            FontSize->10], 
          StyleBox[\(-a\),
            FontSize->10,
            FontWeight->"Plain"]},
        {
          StyleBox["k",
            FontSize->10], 
          StyleBox[\(-h\),
            FontSize->10], 
          StyleBox["h",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["i",
            FontSize->10], 
          StyleBox["ii",
            FontSize->10], 
          StyleBox["1",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["b",
            FontSize->10], 
          StyleBox[\(-\(a\^*\)\),
            FontSize->10], 
          StyleBox[\(a\^*\),
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox[\(b\^*\),
            FontSize->10], 
          StyleBox[\(-a\),
            FontSize->10], 
          StyleBox["a",
            FontSize->10,
            FontWeight->"Plain"]},
        {
          StyleBox[\(-h\),
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["h",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["k",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["ii",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["1",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["i",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox[\(-\(a\^*\)\),
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox[\(a\^*\),
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["b",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox[\(-a\),
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["a",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox[\(b\^*\),
            FontSize->10,
            FontWeight->"Plain"]},
        {
          StyleBox["a",
            FontSize->10], 
          StyleBox[\(b\^*\),
            FontSize->10], 
          StyleBox[\(-a\),
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox[\(a\^*\),
            FontSize->10], 
          StyleBox["b",
            FontSize->10], 
          StyleBox[\(-\(a\^*\)\),
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["1",
            FontSize->10], 
          StyleBox["i",
            FontSize->10], 
          StyleBox["ii",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["h",
            FontSize->10], 
          StyleBox["k",
            FontSize->10], 
          StyleBox[\(-h\),
            FontSize->10,
            FontWeight->"Plain"]},
        {
          StyleBox[\(b\^*\),
            FontSize->10], 
          StyleBox[\(-a\),
            FontSize->10], 
          StyleBox["a",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["b",
            FontSize->10], 
          StyleBox[\(-\(a\^*\)\),
            FontSize->10], 
          StyleBox[\(a\^*\),
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["i",
            FontSize->10], 
          StyleBox["ii",
            FontSize->10], 
          StyleBox["1",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["k",
            FontSize->10], 
          StyleBox[\(-h\),
            FontSize->10], 
          StyleBox["h",
            FontSize->10,
            FontWeight->"Plain"]},
        {
          StyleBox[\(-a\),
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["a",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox[\(b\^*\),
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox[\(-\(a\^*\)\),
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox[\(a\^*\),
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["b",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["ii",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["1",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["i",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox[\(-h\),
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["h",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["k",
            FontSize->10,
            FontWeight->"Plain"]},
        {
          StyleBox[\(a\^*\),
            FontSize->10], 
          StyleBox["b",
            FontSize->10], 
          StyleBox[\(-\(a\^*\)\),
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["a",
            FontSize->10], 
          StyleBox[\(b\^*\),
            FontSize->10], 
          StyleBox[\(-a\),
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["h",
            FontSize->10], 
          StyleBox["k",
            FontSize->10], 
          StyleBox[\(-h\),
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["1",
            FontSize->10], 
          StyleBox["i",
            FontSize->10], 
          StyleBox["ii",
            FontSize->10,
            FontWeight->"Plain"]},
        {
          StyleBox["b",
            FontSize->10], 
          StyleBox[\(-\(a\^*\)\),
            FontSize->10], 
          StyleBox[\(a\^*\),
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox[\(b\^*\),
            FontSize->10], 
          StyleBox[\(-a\),
            FontSize->10], 
          StyleBox["a",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["k",
            FontSize->10], 
          StyleBox[\(-h\),
            FontSize->10], 
          StyleBox["h",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["i",
            FontSize->10], 
          StyleBox["ii",
            FontSize->10], 
          StyleBox["1",
            FontSize->10,
            FontWeight->"Plain"]},
        {
          StyleBox[\(-\(a\^*\)\),
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox[\(a\^*\),
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["b",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox[\(-a\),
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["a",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox[\(b\^*\),
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox[\(-h\),
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["h",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["k",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["ii",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["1",
            FontSize->10,
            FontWeight->"Plain"], 
          StyleBox["i",
            FontSize->10,
            FontWeight->"Plain"]}
        }]], "Input",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\t",
  StyleBox["The extended table ",
    PageWidth->WindowWidth],
  "is isomorphic to C3K, so ",
  StyleBox["i",
    FontSlant->"Italic"],
  " and ",
  StyleBox["ii",
    FontSlant->"Italic"],
  " are interpreted as a cube roots of 1. His half-spin operators {",
  StyleBox["a, a*, -a\[Congruent]  a**,b, b*, -b\[Congruent] b**\[Congruent] \
-a*",
    FontSlant->"Italic"],
  "} are {",
  StyleBox["a, a h, a i i, a h i, a i , a h i i",
    FontSlant->"Italic"],
  "}; conjugation ",
  StyleBox["a",
    FontSlant->"Italic"],
  "* is multiplication by ",
  StyleBox["h",
    FontSlant->"Italic"],
  " (with ",
  StyleBox["h h",
    FontSlant->"Italic"],
  " =1), but biconjugation ",
  StyleBox["a**",
    FontSlant->"Italic"],
  " becomes multiplication by ",
  StyleBox["i",
    FontSlant->"Italic"],
  " or ",
  StyleBox["ii",
    FontSlant->"Italic"],
  ". His half-spin operators are still valid, but they are now defined in \
terms of two distinct square roots of 1 (",
  StyleBox["h & a",
    FontSlant->"Italic"],
  ") and the cube roots (",
  StyleBox["i, ii",
    FontSlant->"Italic"],
  ") of 1. Complex numbers are not involved."
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.2. Half-spin and Dozal algebra.", "Subsubsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tBanded sets of differential equations generate multi-phase sinusoids \
(just as ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(x\_1\)\)\& . \)]],
  StyleBox[" = a ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`x\_\(\(2\)\(,\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(\(\ \)\(x\_2\)\)\& . \)\)\)]],
  StyleBox["= -a",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  ", equivalent to ",
  Cell[BoxData[
      \(TraditionalForm\`x\&\[DoubleDot]\)]],
  " = -",
  Cell[BoxData[
      \(TraditionalForm\`a\^2\)]],
  "x, generates ordinary sinusoids). A relevant simple set is the ",
  StyleBox["m",
    FontSlant->"Italic"],
  " equations (with ",
  StyleBox["m",
    FontSlant->"Italic"],
  "-1 being independent):-\n ",
  StyleBox["Example 23.",
    PageWidth->WindowWidth,
    CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
    FontSize->10,
    FontWeight->"Bold"],
  StyleBox[" Banded Differential Equations and Multi-phase Sinusoids",
    PageWidth->WindowWidth,
    CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
    FontSize->10],
  "\n",
  StyleBox["     ",
    FontSize->10],
  Cell[BoxData[
      StyleBox[\(D[x\_j, t] = \(c'\)[t] + 
            a \((x\_\(Mod[j + k, m]\) - x\_\(Mod[j - k, m]\))\), 
        j = \(0.  .. \)\ m - 1, k < m/2. \),
        FontFamily->"Times New Roman",
        FontWeight->"Plain"]], "Input",
    FontSize->10],
  StyleBox["\nSubstituting the trial function ",
    FontSize->10],
  Cell[BoxData[
      \(x\_j = c[t] + \(c\_1\) Sin[c\_2\ t + \[Phi] + 2  j\ k\ \[Pi]/m]\)],
    FontFamily->"Times New Roman",
    FontSize->10],
  StyleBox[" leads to          ",
    FontSize->10],
  Cell[BoxData[
      \(\(\(\ \ \ \ \ \ \ \ \)\(x\_j = 
        c[t] + \[Sum]\_p\( c\_p\) 
              Sin[2  a\ Sin[2  k\ \[Pi]\ f\_p/m]\ t + \[Phi]\_p + 
                    2  j\ k\ \[Pi]/m]/f\_p\)\)\)], "Input",
    FontFamily->"Times New Roman",
    FontSize->10,
    FontWeight->"Plain"],
  StyleBox[".\n",
    FontSize->10],
  "\n\t",
  StyleBox["j",
    FontSlant->"Italic"],
  " is one of the ",
  StyleBox["m",
    FontSlant->"Italic"],
  " phases; c[t] gives freedom from the origin;",
  StyleBox[" ",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(c\_p\)],
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(f\_p\)], "Input",
    FontFamily->"Times New Roman",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  " and ",
  Cell[BoxData[
      StyleBox[\(\[Phi]\_p\),
        FontFamily->"Times New Roman"]],
    FontSlant->"Italic"],
  " are phase amplitude, resonant multiplier and phase offset constants which \
have to be subscripted because independent sets can arise; ",
  StyleBox["k",
    FontSlant->"Italic"],
  " is a phase step. ",
  StyleBox["Sin[2k \[Pi]/m]",
    FontSlant->"Italic"],
  " is a constant that determines the frequency & period. When ",
  StyleBox["m",
    FontSlant->"Italic"],
  "=4, ",
  StyleBox["k",
    FontSlant->"Italic"],
  " must be 1; folding then removes the c[t] term and reproduces the ordinary \
sinusoid equation-pair with doubled amplitude. Other values of ",
  StyleBox["m",
    FontSlant->"Italic"],
  " and ",
  StyleBox["k",
    FontSlant->"Italic"],
  " give a frequency reduction.\n\tThe period is ",
  StyleBox["2\[Pi]",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(f\_p\)],
    FontFamily->"Times New Roman",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["/Sin[2k \[Pi]/m]",
    FontSlant->"Italic"],
  ", and the function is non-sinusoidal (constant) if 2/m is integral.\n\t",
  StyleBox["The Dozal C3C4 loop gives half-spin ",
    PageWidth->WindowWidth,
    CellMargins->{{Inherited, 0}, {Inherited, Inherited}}],
  "with a period of 4\[Pi] when ",
  StyleBox["m",
    FontSlant->"Italic"],
  "=12, k=1, ",
  Cell[BoxData[
      \(f\_p\)],
    FontFamily->"Times New Roman",
    FontWeight->"Plain"],
  "=1. The twelve components are elements of the C12 hoop.However, C3C4 is \
the preferred isomorph because it has sizes in common with the other Dozal \
hoops C3K, Q12, D3C2, and A4.\n\t A lot more research is needed here. The \
differential equations need to be related to hoops; the resonances (orbits \
with frequencies that are integer multiples of the fundamental frequency) \
need study; what is the relationship between hoops and the theory of strings \
and branes, etc.? ",
  StyleBox["Before folding, the sinusoids are \[OpenCurlyDoubleQuote]free\
\[CloseCurlyDoubleQuote]; they do not have a zero mean because they include \
constants of integration c[t]. This may relate to position in space.",
    PageWidth->WindowWidth,
    CellMargins->{{Inherited, 0}, {Inherited, Inherited}}]
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3.3. Sizes and Orbits as Planck Areas & deBroglie Waves with polarization & \
chirality.\
\>", "Subsubsection",
  PageWidth->WindowWidth],

Cell["\<\
\tC3K has a polar dual that can be expressed as {\[Alpha], \[Beta], \[Gamma], \
\[Delta], \[Zeta]\[Zeta], \[Tau], \[Lambda]\[Lambda], \[Phi], \[Eta]\[Eta], \
\[Chi], \[Kappa]\[Kappa], \[Psi]} and reverted to a vector as follows:-\
\>", "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox["Example",
          FormatType->TraditionalForm], 
        StyleBox[" ",
          FormatType->TraditionalForm], 
        StyleBox["24.",
          FormatType->TraditionalForm], 
        StyleBox[" ",
          FormatType->TraditionalForm], 
        StyleBox["C3K",
          FormatType->TraditionalForm,
          FontWeight->"Plain"], 
        StyleBox[" ",
          FormatType->TraditionalForm,
          FontWeight->"Plain"], 
        StyleBox["Polar",
          FormatType->TraditionalForm,
          FontWeight->"Plain"], 
        StyleBox[" ",
          FormatType->TraditionalForm,
          FontWeight->"Plain"], 
        StyleBox["form",
          FormatType->TraditionalForm,
          FontWeight->"Plain"], 
        StyleBox[" ",
          FormatType->TraditionalForm,
          FontWeight->"Plain"], 
        StyleBox["and",
          FormatType->TraditionalForm,
          FontWeight->"Plain"], 
        StyleBox[" ",
          FormatType->TraditionalForm,
          FontWeight->"Plain"], 
        StyleBox["reversion",
          FormatType->TraditionalForm,
          FontWeight->"Plain"], 
        StyleBox[" ",
          FormatType->TraditionalForm,
          FontWeight->"Plain"], 
        StyleBox["to",
          FormatType->TraditionalForm,
          FontWeight->"Plain"], 
        StyleBox[" ",
          FormatType->TraditionalForm,
          FontWeight->"Plain"], 
        StyleBox["Cartesian",
          FormatType->TraditionalForm,
          FontWeight->"Plain"], 
        StyleBox[" ",
          FormatType->TraditionalForm,
          FontWeight->"Plain"], 
        StyleBox[\(\(form\)\(.\)\),
          FormatType->TraditionalForm,
          FontWeight->"Plain"]}], TraditionalForm]], "Input"],

Cell[BoxData[
    \(\(\(\ \ \ \)\(C3KO = {\[IndentingNewLine]\[Alpha] + \[Beta] + \[Gamma] \
+ \[Delta] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  + \[Lambda]\ Cos[\[Phi]]\ \ \ \ \
\ \  + \[Eta]\ Cos[\[Chi]]\ \ \ \ \ \  + \[Kappa]\ Cos[\[Psi]], \[Alpha] + \
\[Beta] + \[Gamma] + \[Delta] + \[Zeta]\ Cos[\[Tau] + \[Omega]] + \[Lambda]\ \
Cos[\[Phi] + \[Omega]] + \[Eta]\ Cos[\[Chi] + \[Omega]] + \[Kappa]\ \
Cos[\[Psi] + \[Omega]], \ \[IndentingNewLine]\[Alpha] + \[Beta] + \[Gamma] + \
\[Delta] + \[Zeta]\ Cos[\[Tau] - \[Omega]] + \[Lambda]\ Cos[\[Phi] - \
\[Omega]] + \[Eta]\ Cos[\[Chi] - \[Omega]] + \[Kappa]\ Cos[\[Psi] - \
\[Omega]], \[IndentingNewLine]\[Alpha] - \[Beta] + \[Gamma] - \[Delta] + \
\[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  - \[Lambda]\ Cos[\[Phi]]\ \ \ \ \ \  + \
\[Eta]\ Cos[\[Chi]]\ \ \ \ \ \  - \[Kappa]\ Cos[\[Psi]], \ \[Alpha] - \[Beta] \
+ \[Gamma] - \[Delta] + \[Zeta]\ Cos[\[Tau] + \[Omega]] - \[Lambda]\ Cos[\
\[Phi] + \[Omega]] + \[Eta]\ Cos[\[Chi] + \[Omega]] - \[Kappa]\ Cos[\[Psi] + \
\[Omega]], \ \[Alpha] - \[Beta] + \[Gamma] - \[Delta] + \[Zeta]\ Cos[\[Tau] - \
\[Omega]] - \[Lambda]\ Cos[\[Phi] - \[Omega]] + \[Eta]\ Cos[\[Chi] - \
\[Omega]] - \[Kappa]\ Cos[\[Psi] - \[Omega]], \ \[Alpha] + \[Beta] - \[Gamma] \
- \[Delta] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  + \[Lambda]\ Cos[\[Phi]]\ \ \ \ \
\ \  - \[Eta]\ Cos[\[Chi]]\ \ \ \ \ \  - \[Kappa]\ Cos[\[Psi]], \ \[Alpha] + \
\[Beta] - \[Gamma] - \[Delta] + \[Zeta]\ Cos[\[Tau] + \[Omega]] + \[Lambda]\ \
Cos[\[Phi] + \[Omega]] - \[Eta]\ Cos[\[Chi] + \[Omega]] - \[Kappa]\ \
Cos[\[Psi] + \[Omega]], \ \[Alpha] + \[Beta] - \[Gamma] - \[Delta] + \[Zeta]\ \
Cos[\[Tau] - \[Omega]] + \[Lambda]\ Cos[\[Phi] - \[Omega]] - \[Eta]\ Cos[\
\[Chi] - \[Omega]] - \[Kappa]\ Cos[\[Psi] - \[Omega]], \ \[Alpha] - \[Beta] - \
\[Gamma] + \[Delta] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  - \[Lambda]\ \
Cos[\[Phi]]\ \ \ \ \ \  - \[Eta]\ Cos[\[Chi]]\ \ \ \ \ \  + \[Kappa]\ Cos[\
\[Psi]], \ \[Alpha] - \[Beta] - \[Gamma] + \[Delta] + \[Zeta]\ Cos[\[Tau] + \
\[Omega]] - \[Lambda]\ Cos[\[Phi] + \[Omega]] - \[Eta]\ Cos[\[Chi] + \
\[Omega]] + \[Kappa]\ Cos[\[Psi] + \[Omega]], \ \[Alpha] - \[Beta] - \[Gamma] \
+ \[Delta] + \[Zeta]\ Cos[\[Tau] - \[Omega]] - \[Lambda]\ Cos[\[Phi] - \
\[Omega]] - \[Eta]\ Cos[\[Chi] - \[Omega]] + \[Kappa]\ Cos[\[Psi] - \
\[Omega]]}/12;\)\)\)], "Input",
  FormatType->TraditionalForm,
  FontSize->9],

Cell[CellGroupData[{

Cell[BoxData[
    \(Use["\<C3K\>"]; topol\)], "Input"],

Cell[BoxData[
    \({a + b + c + d + e + f + g + h + i + j + k + l, 
      a + b + c - d - e - f + g + h + i - j - k - l, 
      a + b + c + d + e + f - g - h - i - j - k - l, 
      a + b + c - d - e - f - g - h - i + j + k + l, 
      1\/2\ \((\((a - b + d - e + g - h + j - k)\)\^2 + \((b - c + e - f + h \
- i + k - l)\)\^2 + \((\(-a\) + c - d + f - g + i - j + l)\)\^2)\), 
      ArcTan[2\ a - b - c + 2\ d - e - f + 2\ g - h - i + 2\ j - k - 
          l, \(-\@3\)\ \((b - c + e - f + h - i + k - l)\)], 
      1\/2\ \((\((a - b - d + e + g - h - j + k)\)\^2 + \((\(-a\) + c + d - f \
- g + i + j - l)\)\^2 + \((b - c - e + f + h - i - k + l)\)\^2)\), 
      ArcTan[2\ a - b - c - 2\ d + e + f + 2\ g - h - i - 2\ j + k + 
          l, \(-\@3\)\ \((b - c - e + f + h - i - k + l)\)], 
      1\/2\ \((\((a - b + d - e - g + h - j + k)\)\^2 + \((\(-a\) + c - d + f \
+ g - i + j - l)\)\^2 + \((b - c + e - f - h + i - k + l)\)\^2)\), 
      ArcTan[2\ a - b - c + 2\ d - e - f - 2\ g + h + i - 2\ j + k + 
          l, \(-\@3\)\ \((b - c + e - f - h + i - k + l)\)], 
      1\/2\ \((\((a - b - d + e - g + h + j - k)\)\^2 + \((b - c - e + f - h \
+ i + k - l)\)\^2 + \((\(-a\) + c + d - f + g - i - j + l)\)\^2)\), 
      ArcTan[2\ a - b - c - 2\ d + e + f - 2\ g + h + i + 2\ j - k - 
          l, \(-\@3\)\ \((b - c - e + f - h + i + k - l)\)]}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tHere the substitutions \[Zeta]=2",
  Cell[BoxData[
      \(TraditionalForm\`\@\[Zeta]\[Zeta]\)]],
  ", \[Lambda]=2",
  Cell[BoxData[
      \(TraditionalForm\`\@\[Lambda]\[Lambda]\)]],
  ", \[Eta]=2",
  Cell[BoxData[
      \(TraditionalForm\`\@\[Eta]\[Eta]\)]],
  ", \[Kappa]=2",
  Cell[BoxData[
      \(TraditionalForm\`\@\[Kappa]\[Kappa]\)]],
  " have been made, to give a compact expression. Note that \[Zeta]\[Zeta], \
\[Lambda]\[Lambda], \[Eta]\[Eta], & \[Kappa]\[Kappa] represent quadratic \
sizes that are expressible as a sums of squares, so they are positive for \
real elements. I conjecture that they correspond to Planck areas, and provide \
a fundamental scale; their square roots provide radii (2",
  Cell[BoxData[
      \(TraditionalForm\`\@\[Zeta]\[Zeta]\)]],
  "/12 etc) for multiphase deBroglie-like sinusoids. The angles \[Tau], \
\[Phi], \[Chi], & \[Psi] are \"hidden variables\" in the vector form. PROBLEM \
- how do these relate to space-time?"
}], "Text",
  PageWidth->WindowWidth],

Cell["\<\
\tC3C4 has a polar dual that can be expressed as {\[Alpha], \[Beta], \
\[Epsilon]\[Epsilon], \[Sigma], \[Zeta]\[Zeta], \[Tau], \[Lambda]\[Lambda], \
\[Phi], \[Eta]\[Eta], \[Chi], \[Kappa]\[Kappa], \[Psi]} (with {\[Alpha], \
\[Beta], \[Zeta]\[Zeta], \[Tau], \[Lambda]\[Lambda], \[Phi]} in common with \
C3K) and reverted as follows:-\
\>", "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  StyleBox["Example 25.",
    FontWeight->"Bold"],
  " C3C4 Full Polar form and Orbits."
}], "Text"],

Cell[BoxData[
    \(Use["\<C3C4\>"]; sh\)], "Input",
  CellOpen->False],

Cell[BoxData[
    \(\(\(\ \ \)\(C3C4O = {\[IndentingNewLine]\[Alpha] + \[Beta] + \
\[Epsilon]\ \ Cos[\[Sigma]] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  + \[Lambda]\ \
Cos[\[Phi]]\ \ \ \ \ \ \ \ \ \  + \[Eta]\ Cos[x] + \[Eta]\ r3\ Sin[
                  x] + \[Kappa]\ Cos[y] + \[Kappa]\ r3\ Sin[
                  y], \[IndentingNewLine]\[Alpha] + \[Beta] + \
\[Epsilon]\ \ Cos[\[Sigma]] + \[Zeta]\ Cos[\[Tau] + \[Omega]] + \[Lambda]\ \
Cos[\[Phi] + \[Omega]]\ \ \ \ \  - \[Eta]\ Cos[x] + \[Eta]\ r3\ Sin[
                  x] - \[Kappa]\ Cos[y] + \[Kappa]\ r3\ Sin[
                  y], \ \[IndentingNewLine]\[Alpha] + \[Beta] + \
\[Epsilon]\ \ Cos[\[Sigma]] + \[Zeta]\ Cos[\[Tau] - \[Omega]] + \[Lambda]\ \
Cos[\[Phi] - \[Omega]] - \[Eta]\ r6\ Sin[
                  x]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \  - \[Kappa]\ r6\ Sin[
                  y], \[IndentingNewLine]\[Alpha] - \[Beta] + \
\[Epsilon]\ \ Sin[\[Sigma]] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \  - \[Lambda]\ \
Cos[\[Phi]]\ \ \ \ \ \  + \[Eta]\ r3\ Cos[x]\ \ \ \ \  - \[Eta]\ Sin[
                  x] - \[Kappa]\ r3\ Cos[y] + \[Kappa]\ Sin[
                  y], \[IndentingNewLine]\[Alpha] - \[Beta] + \
\[Epsilon]\ \ Sin[\[Sigma]] + \[Zeta]\ Cos[\[Tau] + \[Omega]] - \[Lambda]\ \
Cos[\[Phi] + \[Omega]] + \[Eta]\ r3\ Cos[x]\ \ \ \ \  + \[Eta]\ Sin[
                  x] - \[Kappa]\ r3\ Cos[y] - \[Kappa]\ Sin[
                  y], \[IndentingNewLine]\[Alpha] - \[Beta] + \
\[Epsilon]\ \ Sin[\[Sigma]] + \[Zeta]\ Cos[\[Tau] - \[Omega]] - \[Lambda]\ \
Cos[\[Phi] - \[Omega]] - \[Eta]\ r6\ Cos[
                  x]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \  + \[Kappa]\ r6\ Cos[
                  y], \[IndentingNewLine]\[Alpha] + \[Beta] - \
\[Epsilon]\ \ Cos[\[Sigma]] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \  + \[Lambda]\ \
Cos[\[Phi]]\ \ \ \ \ \ \ \ \ \ \  - \[Eta]\ Cos[x] - \[Eta]\ r3\ Sin[
                  x] - \[Kappa]\ Cos[y] - \[Kappa]\ r3\ Sin[
                  y]\ , \[IndentingNewLine]\[Alpha] + \[Beta] - \
\[Epsilon]\ \ Cos[\[Sigma]] + \[Zeta]\ Cos[\[Tau] + \[Omega]] + \[Lambda]\ \
Cos[\[Phi] + \[Omega]]\ \ \ \ \  + \[Eta]\ Cos[x] - \[Eta]\ r3\ Sin[
                  x] + \[Kappa]\ Cos[y] - \[Kappa]\ r3\ Sin[
                  y], \ \[IndentingNewLine]\[Alpha] + \[Beta] - \
\[Epsilon]\ \ Cos[\[Sigma]] + \[Zeta]\ Cos[\[Tau] - \[Omega]] + \[Lambda]\ \
Cos[\[Phi] - \[Omega]] + \[Eta]\ r6\ Sin[
                  x]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \  - \[Kappa]\ r6\ Sin[
                  y], \[IndentingNewLine]\[Alpha] - \[Beta] - \
\[Epsilon]\ \ Sin[\[Sigma]] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \  - \[Lambda]\ \
Cos[\[Phi]]\ \ \ \ \ \  - \[Eta]\ r3\ Cos[x]\ \ \ \ \  + \[Eta]\ Sin[
                  x] + \[Kappa]\ r3\ Cos[y] - \[Kappa]\ Sin[
                  y], \[IndentingNewLine]\[Alpha] - \[Beta] - \
\[Epsilon]\ \ Sin[\[Sigma]] + \[Zeta]\ Cos[\[Tau] + \[Omega]] - \[Lambda]\ \
Cos[\[Phi] + \[Omega]] - \[Eta]\ r3\ Cos[x]\ \ \ \ \  - \[Eta]\ Sin[
                  x] + \[Kappa]\ r3\ Cos[y] + \[Kappa]\ Sin[
                  y], \[IndentingNewLine]\[Alpha] - \[Beta] - \
\[Epsilon]\ \ Sin[\[Sigma]] + \[Zeta]\ Cos[\[Tau] - \[Omega]] - \[Lambda]\ \
Cos[\[Phi] - \[Omega]] + \[Eta]\ r6\ Cos[
                  x]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  + \[Kappa]\
\ r6\ Cos[y]}/12;\)\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  FontSize->9],

Cell[TextData[{
  "Here \[Epsilon]=2",
  Cell[BoxData[
      \(TraditionalForm\`\@\[Epsilon]\[Epsilon]\)]],
  ", \[Zeta]=2",
  Cell[BoxData[
      \(TraditionalForm\`\@\[Zeta]\[Zeta]\)]],
  ", \[Lambda]=2",
  Cell[BoxData[
      \(TraditionalForm\`\@\[Lambda]\[Lambda]\)]],
  ", \[Eta]=",
  Cell[BoxData[
      \(TraditionalForm\`\@\(3  \[Eta]\[Eta]\)\)]],
  ", \[Kappa]=",
  Cell[BoxData[
      \(TraditionalForm\`\@\(3  \[Kappa]\[Kappa]\)\)]],
  ",  x=\[Chi]+\[Pi]/6, y=\[Psi]+\[Pi]/6, \[Omega]=2\[Pi]/3, r3=",
  Cell[BoxData[
      \(TraditionalForm\`\@3\)]],
  ", r6=2",
  Cell[BoxData[
      \(TraditionalForm\`\@3\)]],
  StyleBox["to give a compact expression.",
    PageWidth->WindowWidth],
  "\n\tOrbits are obtained by setting some of the parameters {\[Alpha], \
\[Beta], \[Gamma], \[Delta], \[Epsilon]\[Epsilon], \[Zeta]\[Zeta] ,\[Lambda]\
\[Lambda] , ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\[Eta]\)]],
  ", \[Kappa]\[Kappa]} to zero or 1 and constraining the product of the \
remainder to be 1. Each set of angles involving \[Omega]=2\[Pi]/3 gives a \
chiral orbit; the chirality is reversed if the angle is negated. \n\tSimilar, \
but simpler, expressions give Q12 & D3C2 orbits. Their parameters are related \
to those for C3K and C3C4. A 12-phase system arises if \[Psi]=\[Chi]+\[Pi]/6. \
",
  StyleBox["Problem - non-commutativity prevents angle additivity in these \
orbits",
    PageWidth->WindowWidth],
  StyleBox[". Does this introduce uncertainty?",
    PageWidth->WindowWidth,
    FontFamily->"Times New Roman"]
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\(Q12O = \[IndentingNewLine]{\ \ \((\[Alpha] + \[Beta] + \[Epsilon]\ \
Cos[\[Sigma]] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  + \[Eta]\ Cos[\[Chi]])\), \
\[IndentingNewLine]\((\[Alpha] + \[Beta] + \[Epsilon]\ Cos[\[Sigma]] + \
\[Zeta]\ Cos[\[Tau] + \[Omega]] + \[Eta]\ Cos[\[Chi] + \[Omega]])\), \
\[IndentingNewLine]\((\[Alpha] + \[Beta] + \[Epsilon]\ Cos[\[Sigma]] + \
\[Zeta]\ Cos[\[Tau] - \[Omega]] + \[Eta]\ Cos[\[Chi] - \[Omega]])\), \
\[IndentingNewLine]\((\[Alpha] - \[Beta] + \[Epsilon]\ Sin[\[Sigma]]\ \ \ \ \ \
 + \[Lambda]\ Cos[\[Phi]]\ \ \ \ \ \  + \[CurlyKappa]\ Cos[\[Psi]])\), \
\[IndentingNewLine]\((\[Alpha] - \[Beta] + \[Epsilon]\ Sin[\[Sigma]]\ \ \ \ \ \
 + \[Lambda]\ Cos[\[Phi] + \[Omega]] + \[CurlyKappa]\ Cos[\[Psi] + \[Omega]])\
\), \[IndentingNewLine]\((\[Alpha] - \[Beta] + \[Epsilon]\ Sin[\[Sigma]]\ \ \ \
\ \  + \[Lambda]\ Cos[\[Phi] - \[Omega]] + \[CurlyKappa]\ Cos[\[Psi] - \
\[Omega]])\), \[IndentingNewLine]\((\[Alpha] + \[Beta] - \[Epsilon]\ Cos[\
\[Sigma]] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  - \[Eta]\ Cos[\[Chi]])\), \
\[IndentingNewLine]\((\[Alpha] + \[Beta] - \[Epsilon]\ Cos[\[Sigma]] + \
\[Zeta]\ Cos[\[Tau] + \[Omega]] - \[Eta]\ Cos[\[Chi] + \[Omega]])\), \
\[IndentingNewLine]\((\[Alpha] + \[Beta] - \[Epsilon]\ Cos[\[Sigma]] + \
\[Zeta]\ Cos[\[Tau] - \[Omega]] - \[Eta]\ Cos[\[Chi] - \[Omega]])\), \
\[IndentingNewLine]\((\[Alpha] - \[Beta] - \[Epsilon]\ Sin[\[Sigma]]\ \ \ \ \ \
\  + \[Lambda]\ Cos[\[Phi]]\ \ \ \ \  - \[CurlyKappa]\ Cos[\[Psi]])\), \
\[IndentingNewLine]\((\[Alpha] - \[Beta] - \[Epsilon]\ Sin[\[Sigma]]\ \ \ \ \ \
\  + \[Lambda]\ Cos[\[Phi] - \[Omega]] - \[CurlyKappa]\ Cos[\[Psi] + \
\[Omega]])\), \[IndentingNewLine]\((\[Alpha] - \[Beta] - \[Epsilon]\ Sin[\
\[Sigma]]\ \ \ \ \ \  + \[Lambda]\ Cos[\[Phi] - \[Omega]] - \[CurlyKappa]\ \
Cos[\[Psi] - \[Omega]])\)}/12;\)\)], "Input",
  PageWidth->WindowWidth,
  FontSize->9],

Cell["\<\
This (and D3C2O, below) gives a 12-phase system if \[Psi]=\[Chi]\[PlusMinus]\
\[Pi]/6 & \[Chi]=\[Eta]. A polarised 3-phase system (with polarisation angle \
\[CurlyPhi]) is given by \[Phi]=\[Tau] & \[Lambda]=\[PlusMinus]\[Zeta].\
\>", "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\(D3C2O = \[IndentingNewLine]{\ \ \((\[Alpha] + \[Beta] + \[Gamma] + \
\[Delta] + \[Zeta]\ Cos[\[Tau]]\ \ \ \ \ \  + \[Eta]\ Cos[\[Chi]])\), \
\[IndentingNewLine]\((\[Alpha] + \[Beta] + \[Gamma] + \[Delta] + \[Zeta]\ \
Cos[\[Tau] + \[Omega]] + \[Eta]\ Cos[\[Chi] + \[Omega]])\), \
\[IndentingNewLine]\((\[Alpha] + \[Beta] + \[Gamma] + \[Delta] + \[Zeta]\ \
Cos[\[Tau] - \[Omega]] + \[Eta]\ Cos[\[Chi] - \[Omega]])\), \
\[IndentingNewLine]\((\[Alpha] - \[Beta] + \[Gamma] - \[Delta]\ \ \ \ \ \  - \
\[Lambda]\ Cos[\[Phi]]\ \ \ \ \ \  - \[CurlyKappa]\ Cos[\[Psi]])\), \
\[IndentingNewLine]\((\[Alpha] - \[Beta] + \[Gamma] - \[Delta]\ \ \ \ \ \  - \
\[Lambda]\ Cos[\[Phi] + \[Omega]] - \[CurlyKappa]\ Cos[\[Psi] + \[Omega]])\), \
\[IndentingNewLine]\((\[Alpha] - \[Beta] + \[Gamma] - \[Delta]\ \ \ \ \ \  - \
\[Lambda]\ Cos[\[Phi] - \[Omega]] - \[CurlyKappa]\ Cos[\[Psi] - \[Omega]])\), \
\[IndentingNewLine]\((\[Alpha] + \[Beta] - \[Gamma] - \[Delta] + \[Zeta]\ \
Cos[\[Tau]]\ \ \ \ \ \  - \[Eta]\ Cos[\[Chi]])\), \[IndentingNewLine]\((\
\[Alpha] + \[Beta] - \[Gamma] - \[Delta] + \[Zeta]\ Cos[\[Tau] + \[Omega]] - \
\[Eta]\ Cos[\[Chi] + \[Omega]])\), \[IndentingNewLine]\((\[Alpha] + \[Beta] - \
\[Gamma] - \[Delta] + \[Zeta]\ Cos[\[Tau] - \[Omega]] - \[Eta]\ Cos[\[Chi] - \
\[Omega]])\), \[IndentingNewLine]\((\[Alpha] - \[Beta] - \[Gamma] + \[Delta]\ \
\ \ \ \ \  - \[Lambda]\ Cos[\[Phi]]\ \ \ \ \ \  + \[CurlyKappa]\ Cos[\[Psi]])\
\), \[IndentingNewLine]\((\[Alpha] - \[Beta] - \[Gamma] + \[Delta]\ \ \ \ \ \ \
 - \[Lambda]\ Cos[\[Phi] + \[Omega]] + \[CurlyKappa]\ Cos[\[Psi] + \[Omega]])\
\), \[IndentingNewLine]\((\[Alpha] - \[Beta] - \[Gamma] + \[Delta]\ \ \ \ \ \ \
 - \[Lambda]\ Cos[\[Phi] - \[Omega]] + \[CurlyKappa]\ Cos[\[Psi] - \[Omega]])\
\)}/12;\)\)], "Input",
  PageWidth->WindowWidth,
  FontSize->9],

Cell["\<\
\tFor these orbits to represent particles, the product of the non-zero \
quadratic sizes should define a fundamental size - a Planck Area. Section 3.7 \
explores this topic. The product of the non-zero linear sizes {\[Alpha], \
\[Beta], \[Gamma], \[Delta]} should be 1; some quantization process may \
constrain them to be \[PlusMinus]1. The orbits may represent multi-phase \
deBroglie waves. \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.4. C5, C7 & C8 Orbits have unstable amplitudes.", "Subsubsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tThe orbits of C3 have a squared radius of magnitude 2/3, with offsets \
{0,0,0} or {1/3, 1/3, 1/3).  Those of C4 have squared radii (or ulnae) of \
magnitude 1/2, and offsets {0,..} or {\[PlusMinus]1/4,..}. Orbits of C5, C7, \
Cp (p prime>3) etc can be developed, with p sinusoidal phases, but their \
radii are unconstrained, though their offsets are 0 or 1/p. Example 21 shows \
that OC5dr, a five-phase orbit with a displacement d and radius ",
  StyleBox["r",
    FontSlant->"Italic"],
  ", has a quartic size of zero and so is unconstrained. The angle, linear L1 \
and quartic parameters only use 3 of the 5 degrees of freedom. Similarly, a \
seven-phase orbit with radius ",
  StyleBox["r",
    FontSlant->"Italic"],
  " has a zero size in C7 (I have not found a polar expression for this \
group) and an eight-phase orbit with radius ",
  StyleBox["r",
    FontSlant->"Italic"],
  " has a zero size in C8. These orbits also appear to be unstable - \
numerical integration of the relevant differential-equation sets is unstable. \
Orbit instability ",
  StyleBox["is a vague concept. ",
    PageWidth->WindowWidth],
  "It may be related to the occurrence of determinant factors that are larger \
than quadratic."
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["\<\
{Use[\"C5\"];\"Example 26.  Zero-sized C5 orbit.\\nOC5dr is\",OC5dr = 
    tovec/. as[{d, r, \[Sigma]}], 
  \"\\nThe radius disappears from the shape\", 
  Simplify[sh/. as[OC5dr]]}\
\>", "Input",
  PageWidth->WindowWidth,
  FontFamily->"Courier"],

Cell[BoxData[
    \({"Example 26.  Zero-sized C5 orbit.\nOC5dr is", {1\/5\ \((d + 
              r\ Sin[\[Sigma]])\), 
        1\/5\ \((d + r\ Sin[\(2\ \[Pi]\)\/5 + \[Sigma]])\), 
        1\/5\ \((d + r\ Sin[\(4\ \[Pi]\)\/5 + \[Sigma]])\), 
        1\/5\ \((d + r\ Sin[\(6\ \[Pi]\)\/5 + \[Sigma]])\), 
        1\/5\ \((d + r\ Sin[\(8\ \[Pi]\)\/5 + \[Sigma]])\)}, 
      "\nThe radius disappears from the shape", {d, 0}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3.5. The limited number of stable orbits may limit the number of stable \
particles.\
\>", "Subsubsection",
  PageWidth->WindowWidth],

Cell["\<\
\tI surmise that stable orbits represent stable particles, and that the \
number of stable particles is determined by the limited number of stable \
particles. 
\tStable, finite amplitude, orbits with 3, 4, 6 & 12 phases have been found, \
some with polarization and chirality. The following examples are restrictions \
(with various radii and offsets set to zero) of the tables in section 3.3.\
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \({"\<Example 27. 3-phase C3K Orbit (Omitting the 1/12 factor).\n\>", \ 
      12  C3KO /. {\[Lambda] \[Rule] 0, \[Eta] \[Rule] 0, \[Kappa] \[Rule] 
              0, \[CurlyKappa] \[Rule] 0} // tf}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 27. 3-phase C3K Orbit (Omitting the 1/12 \
factor).\\n\"\>", ",", 
        TagBox[
          
          FormBox[\({\[Alpha] + \[Beta] + \[Gamma] + \[Delta] + \[Zeta]\ \
\(cos(\[Tau])\), \[Alpha] + \[Beta] + \[Gamma] + \[Delta] + \[Zeta]\ \(cos(\
\[Tau] + \[Omega])\), \[Alpha] + \[Beta] + \[Gamma] + \[Delta] + \[Zeta]\ \
\(cos(\[Tau] - \[Omega])\), \[Alpha] - \[Beta] + \[Gamma] - \[Delta] + \
\[Zeta]\ \(cos(\[Tau])\), \[Alpha] - \[Beta] + \[Gamma] - \[Delta] + \[Zeta]\ \
\(cos(\[Tau] + \[Omega])\), \[Alpha] - \[Beta] + \[Gamma] - \[Delta] + \
\[Zeta]\ \(cos(\[Tau] - \[Omega])\), \[Alpha] + \[Beta] - \[Gamma] - \[Delta] \
+ \[Zeta]\ \(cos(\[Tau])\), \[Alpha] + \[Beta] - \[Gamma] - \[Delta] + \
\[Zeta]\ \(cos(\[Tau] + \[Omega])\), \[Alpha] + \[Beta] - \[Gamma] - \[Delta] \
+ \[Zeta]\ \(cos(\[Tau] - \[Omega])\), \[Alpha] - \[Beta] - \[Gamma] + \
\[Delta] + \[Zeta]\ \(cos(\[Tau])\), \[Alpha] - \[Beta] - \[Gamma] + \[Delta] \
+ \[Zeta]\ \(cos(\[Tau] + \[Omega])\), \[Alpha] - \[Beta] - \[Gamma] + \
\[Delta] + \[Zeta]\ \(cos(\[Tau] - \[Omega])\)}\),
            "TraditionalForm"],
          TraditionalForm,
          Editable->True]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
\tThe linear terms {\[Alpha], \[Beta], \[Gamma], \[Delta]} define offsets (\
\[Alpha]/12 etc) from zero. Scaled square roots of the quadratic terms appear \
as radii. Each phase occurs four times in a 3-phase dozal orbit, with \
different linear offsets.\
\>", "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  StyleBox["\ttopol",
    FontSlant->"Italic"],
  " shows that the squared amplitude ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Zeta]/12)\)\^2\)]],
  "is the sum of three squares:- \n",
  StyleBox["((a-b-d+e+g-h-j+k)",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\^2\)],
    FontSlant->"Italic"],
  StyleBox["+(-a+c+d-f-g+i+j-l)",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\^2\)],
    FontSlant->"Italic"],
  StyleBox["+(b-c-e+f+h-i-k+l)",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\^2\)],
    FontSlant->"Italic"],
  StyleBox[")/72",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \({"\<Example 28. 4-phase C3C4 Orbit \n(omitting \[Epsilon]/12 \
factor).\>", \ 
      12  C3C4O/\[Epsilon] /. {\[Alpha] \[Rule] 0, \[Beta] -> 
              0, \[Zeta] \[Rule] 0, \[Lambda] \[Rule] 0, \[Eta] \[Rule] 
              0, \[Kappa] \[Rule] 0} // tf}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"Example 28. 4-phase C3C4 Orbit \\n(omitting \[Epsilon]/12 \
factor).\"\>", ",", 
        TagBox[
          
          FormBox[\({cos(\[Sigma]), cos(\[Sigma]), cos(\[Sigma]), 
              sin(\[Sigma]), sin(\[Sigma]), 
              sin(\[Sigma]), \(-\(cos(\[Sigma])\)\), \(-\(cos(\[Sigma])\)\), \
\(-\(cos(\[Sigma])\)\), \(-\(sin(\[Sigma])\)\), \(-\(sin(\[Sigma])\)\), \
\(-\(sin(\[Sigma])\)\)}\),
            "TraditionalForm"],
          TraditionalForm,
          Editable->True]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Each of the four phases occur three times. ",
  StyleBox["topol",
    FontSlant->"Italic"],
  " shows that the squared amplitude ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Epsilon]/12)\)\^2\)]],
  " is the sum of two squares  ",
  Cell[BoxData[
      StyleBox[\(\((\((a + b + c - g - h - i)\)\^2 + \((d + e + f - j - k - \
l)\)\^2)\)/144\),
        FontSlant->"Italic"]], "Text",
    FontFamily->"Times New Roman"],
  "."
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    \({"\<Example 29. 6-phase C3K Orbit.\n\>", \ 
      Simplify[C3KO /. {\[Psi] \[Rule] 0, \[Zeta] \[Rule] 
                0, \[CurlyKappa] \[Rule] 0}] // tf}\)], "Input",
  PageWidth->WindowWidth,
  CellOpen->False],

Cell[BoxData[
    StyleBox[
      RowBox[{\(Example\ 29. \ 6\), "-", 
        RowBox[{"phase", " ", "C3K", " ", 
          RowBox[{
            RowBox[{"Orbit", ".", 
              TagBox[
                
                FormBox[\(\(\[IndentingNewLine]\)\({\[Alpha] + \[Beta] + \
\[Gamma] + \[Delta] + \[Kappa]\ \ \ \ \ \  + \[Lambda]\ \(cos(\[Phi])\)\ \ \ \
\ \ \ \  + \[Eta]\ \(cos(\[Chi])\), \[Alpha] + \[Beta] + \[Gamma] + \[Delta] \
- \[Kappa]/
                        2 + \[Lambda]\ \(cos(\[Phi] + \[Omega])\) + \[Eta]\ \
\(cos(\[Chi] + \[Omega])\), \[Alpha] + \[Beta] + \[Gamma] + \[Delta] - \
\[Kappa]\ /
                        2 + \[Lambda]\ \(cos(\[Phi] - \[Omega])\) + \[Eta]\ \
\(cos(\[Chi] - \[Omega])\), \[Alpha] - \[Beta] + \[Gamma] - \[Delta] - \
\[Kappa]\ \ \ \ \ \ \  - \[Lambda]\ \(cos(\[Phi])\)\ \ \ \ \ \  + \[Eta]\ \
\(cos(\[Chi])\), \[Alpha] - \[Beta] + \[Gamma] - \[Delta] + \[Kappa]\ /
                        2 - \[Lambda]\ \(cos(\[Phi] + \[Omega])\) + \[Eta]\ \
\(cos(\[Chi] + \[Omega])\), \[Alpha] - \[Beta] + \[Gamma] - \[Delta] + \
\[Kappa]\ /
                        2 - \[Lambda]\ \(cos(\[Phi] - \[Omega])\) + \[Eta]\ \
\(cos(\[Chi] - \[Omega])\), \[Alpha] + \[Beta] - \[Gamma] - \[Delta] - \
\[Kappa]\ \ \ \ \ \ \  + \[Lambda]\ \(cos(\[Phi])\)\ \ \ \ \ \  - \[Eta]\ \
\(cos(\[Chi])\), \[Alpha] + \[Beta] - \[Gamma] - \[Delta] + \[Kappa]\ /
                        2 + \[Lambda]\ \(cos(\[Phi] + \[Omega])\) - \[Eta]\ \
\(cos(\[Chi] + \[Omega])\), \[Alpha] + \[Beta] - \[Gamma] - \[Delta] + \
\[Kappa]\ /
                        2 + \[Lambda]\ \(cos(\[Phi] - \[Omega])\) - \[Eta]\ \
\(cos(\[Chi] - \[Omega])\), \[Alpha] - \[Beta] - \[Gamma] + \[Delta] + \
\[Kappa]\ \ \ \ \ \ \  - \[Lambda]\ \(cos(\[Phi])\)\ \ \ \ \ \  - \[Eta]\ \
\(cos(\[Chi])\), \[Alpha] - \[Beta] - \[Gamma] + \[Delta] - \[Kappa]/
                        2 - \[Lambda]\ \(cos(\[Phi] + \[Omega])\) - \[Eta]\ \
\(cos(\[Chi] + \[Omega])\), \[Alpha] - \[Beta] - \[Gamma] + \[Delta] - \
\[Kappa]/2 - \[Lambda]\ \(cos(\[Phi] - \[Omega])\) - \[Eta]\ \(cos(\[Chi] - \
\[Omega])\)}\)\),
                  "TraditionalForm"],
                TraditionalForm,
                Editable->True]}], "/", "12"}]}]}],
      FontWeight->"Plain"]], "Input"],

Cell["\<\
\tThe linear terms have been omitted. Each phase occurs twice, with different \
offsets. \
\>", "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.6. Particle Interactions.", "Subsubsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tAs Dozal elements resemble quantum operators, the addition/splitting and \
multiplication/division of Dozal vectors should resemble particle decays and \
interactions. C3K and D3C2 conserve the linear sizes {\[Alpha], \[Beta], \
\[Gamma], \[Delta]} and  C3C4 and Q12 conserve {\[Alpha], \[Beta]} on \
addition and subtraction, corresponding to additive particle properies. \
Multiplication, with remainders, conserves overlapping sets of sizes for each \
group. Conjecture - this may correspond to interactions subject to the four \
forces. (What is the role of A4 here?",
  StyleBox[" It appears to discriminate between different classes of orbit.",
    PageWidth->WindowWidth],
  ") Many other functions are conserved on multiplication of orbits, rather \
than of general vectors. Example 30 lists the known conserved functions, \
together with two {L4Q,L4\[Sigma]} conserved by two signed tables related to \
quaternions and Pauli-\[Sigma] hoops.\n\tI have not been able to correlate \
these functions with conserved particle properties. Resonances are an \
outstanding problem; if hoops are related to differential equations (as the \
multi-phase sinusoidal orbits suggest) there should be solutions with \
multiple frequencies, corresponding to the plethora of short-lived particles. \
"
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox["Example",
          FormatType->TraditionalForm,
          FontFamily->"Times New Roman"], 
        StyleBox[" ",
          FormatType->TraditionalForm,
          FontFamily->"Times New Roman"], 
        StyleBox["30.",
          FormatType->TraditionalForm,
          FontFamily->"Times New Roman"], 
        StyleBox[" ",
          FormatType->TraditionalForm,
          FontFamily->"Times New Roman",
          FontWeight->"Plain"], 
        StyleBox["Functions",
          FormatType->TraditionalForm,
          FontFamily->"Times New Roman",
          FontWeight->"Plain"], 
        StyleBox[" ",
          FormatType->TraditionalForm,
          FontFamily->"Times New Roman",
          FontWeight->"Plain"], 
        StyleBox["conserved",
          FormatType->TraditionalForm,
          FontFamily->"Times New Roman",
          FontWeight->"Plain"], 
        StyleBox[" ",
          FormatType->TraditionalForm,
          FontFamily->"Times New Roman",
          FontWeight->"Plain"], 
        StyleBox["in",
          FormatType->TraditionalForm,
          FontFamily->"Times New Roman",
          FontWeight->"Plain"], 
        StyleBox[" ",
          FormatType->TraditionalForm,
          FontFamily->"Times New Roman",
          FontWeight->"Plain"], 
        StyleBox["Dozal",
          FormatType->TraditionalForm,
          FontFamily->"Times New Roman",
          FontWeight->"Plain"], 
        StyleBox[" ",
          FormatType->TraditionalForm,
          FontFamily->"Times New Roman",
          FontWeight->"Plain"], 
        StyleBox[\(\(interactions\)\(.\)\),
          FormatType->TraditionalForm,
          FontFamily->"Times New Roman",
          FontWeight->"Plain"]}], TraditionalForm]], "Input"],

Cell[BoxData[
    \(\(sh12[{a_, b_, c_, d_, e_, f_, g_, h_, i_, j_, k_, l_}] := 
        Module[{ab = a - b - g + h, ag = a - b + g - h, bc = b - c - h + i, 
            bh = b - c + h - i, \[IndentingNewLine]ca = a - c - g + i, 
            ci = a - c + g - i, de = d - e - j + k, 
            dj = d - e + j - k, \[IndentingNewLine]ef = e - f - k + l, 
            ek = e - f + k - l, fd = d - f - j + l, fl = d - f + j - l, 
            f1 = a - b - g + 
                h + \((d + e - 2\ f - j - k + 
                      2  l)\)/\@3, \[IndentingNewLine]f2 = \((a + b - 2  c - 
                      g - h + 2  i)\)/\@3 - d + e + j - 
                k, \[IndentingNewLine]f3 = 
              a - b - g + 
                h - \((d + e - 2\ f - j - k + 
                      2  l)\)/\@3, \[IndentingNewLine]f4 = \((a + b - 2  c - 
                      g - h + 2  i)\)/\@3 + d - e - j + k, abef, 
            agek}, \[IndentingNewLine]abef = 3 \((ab\ ef - bc\ de)\)\^2; 
          agek = 3 \((ag\ ek - bh\ dj)\)\^2; \[IndentingNewLine]{o1 = 
              a + b + c + d + e + f + g + h + i + j + k + l, 
            o2 = a + b + c - d - e - f + g + h + i - j - k - 
                l, \[IndentingNewLine]o3 = 
              a + b + c + d + e + f - g - h - i - j - k - l, 
            o4 = a + b + c - d - e - f - g - h - i + j + k + 
                l, \[IndentingNewLine] (*5*) l22a = 
              3 \((f1\^2 + f2\^2)\)/4,  (*6*) l22b = 
              3 \((f3\^2 + f4\^2)\)/4, \[IndentingNewLine] (*7*) 
              p22 = \((a + b + c + g + h + i)\)\^2 + \((d + e + f + j + k + \
l)\)\^2,  (*8*) 
              q22 = \((a + b + c - g - h - i)\)\^2 + \((d + e + f - j - k - \
l)\)\^2,  (*9*) 
              r22 = \((a + b + c + g + h + i)\)\^2 - \((d + e + f + j + k + \
l)\)\^2,  (*10*) 
              s22 = \((a + b + c - g - h - i)\)\^2 - \((d + e + f - j - k - \
l)\)\^2, \[IndentingNewLine] (*11*) 
              p23 = \((\((ag + dj)\)\^2 + \((bh + ek)\)\^2 + \((ci + \
fl)\)\^2)\)/2,  (*12*) 
              q23 = \((\((ag - dj)\)\^2 + \((bh - ek)\)\^2 + \((ci - \
fl)\)\^2)\)/2, \[IndentingNewLine] (*13*) 
              r23 = \((\((ab + de)\)\^2 + \((bc + ef)\)\^2 + \((ca + \
fd)\)\^2)\)/2,  (*14*) 
              s23 = \((\((ab - de)\)\^2 + \((bc - ef)\)\^2 + \((ca - \
fd)\)\^2)\)/2, \[IndentingNewLine] (*15*) 
              q24 = \((a + b + c)\)\^2 + \((d + e + f)\)\^2 + \((g + h + i)\)\
\^2 + \((j + k + l)\)\^2, \[IndentingNewLine] (*16*) 
              s24 = \((a + b + c)\)\^2 - \((d + e + f)\)\^2 - \((g + h + i)\)\
\^2 - \((j + k + l)\)\^2, \[IndentingNewLine] (*17*) 
              p26 = \((ag\^2 + bh\^2 + ci\^2 - dj\^2 - fl\^2 - ek\^2)\)/
                2,  (*18*) 
              q26 = \((ab\^2 + bc\^2 + ca\^2 - de\^2 - ef\^2 - fd\^2)\)/
                2, \[IndentingNewLine] (*19*) 
              r26 = \((ag\^2 + bh\^2 + ci\^2 + dj\^2 + fl\^2 + ek\^2)\)/
                2,  (*20*) 
              s26 = \((ab\^2 + bc\^2 + ca\^2 + de\^2 + ef\^2 + fd\^2)\)/
                2, \n\ \ \ \ \ \ \ \  (*21*) \ 
            l3 = \((a + d - g - j)\)\ \((a - d + g - j)\)\ \((a - d - g + 
                      j)\) + \((b + e - h - k)\)\ \((b - e + h - k)\)\ \((b - 
                      e - h + k)\) + \[IndentingNewLine]\((c + f - \ i\  - 
                      l)\)\ \((c - f + \ i\  - l)\)\ \((c - f - \ i\  + 
                      l)\) - \((a - d + g - j)\)\ \((b - e - h + k)\)\ \((c + 
                      f - \ i\  - l)\) - \[IndentingNewLine]\((a - d - g + 
                      j)\)\ \((b + e - h - k)\)\ \((c - f + i - l)\) - \((a + 
                      d - g - j)\)\ \((b - e + h - k)\)\ \((c - f - \ i\  + 
                      l)\), \[IndentingNewLine] (*22*) l4p = 
              p26\^2 + agek, \[IndentingNewLine] (*23*) l4q = 
              q26\^2 + abef, \[IndentingNewLine] (*24*) l4r = 
              r26\^2 - 3  agek, \[IndentingNewLine] (*25*) l4s = 
              l22a\ l22b (*\ \(=\)\(\ \)\(s26\^2 - abef\)*) ,  (*26*) 
              L4Q = \((\((a - b)\)\^2 + \((b - c)\)\^2 + \((a - c)\)\^2 + \
\((d - e)\)\^2 + \((e - f)\)\^2 + \((d - f)\)\^2 + \((g - h)\)\^2 + \
\[IndentingNewLine]\((h - i)\)\^2 + \((g - i)\)\^2 + \((j - k)\)\^2 + \((k - \
l)\)\^2 + \((j - l)\)\^2)\)^2/4 - 
                3\ \((\((a\ \((f - e)\) + b\ \((d - f)\) + c\ \((e - \
d)\))\)\^2 + \((a\ \((i - h)\) + b\ \((g - i)\) + c\ \((h - g)\))\)\^2 + \((d\
\ \((h - i)\) + e\ \((i - g)\) + f\ \((g - h)\))\)\^2 + \((g\ \((k - l)\) + h\
\ \((l - j)\) + i\ \((j - k)\))\)\^2 + \[IndentingNewLine]\((\((b - c)\)\^2 + \
\((e - f)\)\^2)\)\ j\^2 + \((\((a - c)\)\^2 + \((d - f)\)\^2)\)\ k\^2 + \
\((\((a - b)\)\^2 + \((d - e)\)\^2)\)\ l\^2)\) + \[IndentingNewLine]6\ \((\((\
\((c - a)\)\ \((c - b)\) + \((f - d)\)\ \((f - e)\))\)\ j\ k + \((\((b - 
                        
                                a)\)\ \((b - c)\) + \((e - d)\)\ \((e - 
                                  f)\))\)\ j\ l + \[IndentingNewLine]\((\((a \
- b)\)\ \((a - c)\) + \((d - e)\)\ \((d - 
                                  f)\))\)\ k\ l)\), \[IndentingNewLine] (*27*) 
              L4\[Sigma] = \ \((\((a - b)\)\^2 + \((b - c)\)\^2 + \((c - a)\)\
\^2 - \((d - e)\)\^2 - \((e - f)\)\^2 - \((f - d)\)\^2 - \((g - h)\)\^2 - \
\((h - i)\)\^2 - \((i - g)\)\^2 - \((j - k)\)\^2 - \((k - l)\)\^2 - \((l - j)\
\)\^2)\)^2/4 + 
                3\ \((\((b\ d - c\ d - a\ e + c\ e + a\ f - b\ f)\)\^2 + \((b\
\ g - c\ g - a\ h + c\ h + a\ i - b\ i)\)\^2 - \((e\ g - f\ g - d\ h + f\ h + \
d\ i - e\ i)\)\^2 + \((b\ j - c\ j - a\ k + c\ k + a\ l - b\ l)\)\^2 - \
\((\(-e\)\ j + f\ j + d\ k - f\ k - d\ l + e\ l)\)\^2 - \((h\ j - i\ j - g\ k \
+ i\ k + g\ l - h\ l)\)\^2)\), \[IndentingNewLine] (*28*) 
              L4a3 = \((\((ag + dj)\)\^2 + \((bh + ek)\)\^2 + \((ci + \
fl)\)\^2)\)\^2/4 + agek,  (*29*) 
              L4b3 = \((\((ag - dj)\)\^2 + \((bh - ek)\)\^2 + \((ci - \
fl)\)\^2)\)\^2/4 + agek,  (*30*) 
              L4c3 = \((\((ab + de)\)\^2 + \((bc + ef)\)\^2 + \((ca + \
fd)\)\^2)\)\^2/4 - abef,  (*31*) 
              L4d3 = \((\((ab - de)\)\^2 + \((bc - ef)\)\^2 + \((ca - \
fd)\)\^2)\)\^2/4 - abef,  (*32*) 
              L4a6 = \((ag\^2 + bh\^2 + ci\^2 - dj\^2 - fl\^2 - ek\^2)\)\^2/
                  4 + agek,  (*33*) 
              L4b6 = \((ab\^2 + bc\^2 + ca\^2 - de\^2 - ef\^2 - fd\^2)\)\^2/
                  4 + abef,  (*34*) 
              L4c6 = \((ab\^2 + bc\^2 + ca\^2 - de\^2 - ef\^2 - fd\^2)\)\^2/
                  4 - abef, \n\t (*35*) 
              L4d6 = \ \((ag\^2 + bh\^2 + ci\^2 + dj\^2 + fl\^2 + ek\^2)\)\^2/
                  4 - agek, \[IndentingNewLine] (*36*) 
              L49 = \((\((ab\^2 - de\^2)\)\^2 + \((ab\^2 - ef\^2)\)\^2 + \
\((ab\^2 - fd\^2)\)\^2 + \((bc\^2 - de\^2)\)\^2 + \((bc\^2 - ef\^2)\)\^2 + \
\((bc\^2 - fd\^2)\)\^2 + \((ca\^2 - de\^2)\)\^2 + \((ca\^2 - ef\^2)\)\^2 + \
\((ca\^2 - fd\^2)\)\^2)\), \[IndentingNewLine] (*37*) 
              L49a = \((\((ag\^2 - dj\^2)\)\^2 + \((ag\^2 - ek\^2)\)\^2 + \
\((ag\^2 - fl\^2)\)\^2 + \((bh\^2 - dj\^2)\)\^2 + \((bh\^2 - ek\^2)\)\^2 + \
\((bh\^2 - fl\^2)\)\^2 + \((ci\^2 - dj\^2)\)\^2 + \((ci\^2 - ek\^2)\)\^2 + \
\((ci\^2 - fl\^2)\)\^2)\), \[IndentingNewLine] (*38*) 
              L49b = \((\((ab\^2 - dj\^2)\)\^2 + \((ab\^2 - ek\^2)\)\^2 + \
\((ab\^2 - fl\^2)\)\^2 + \((bc\^2 - dj\^2)\)\^2 + \((bc\^2 - ek\^2)\)\^2 + \
\((bc\^2 - fl\^2)\)\^2 + \((ca\^2 - dj\^2)\)\^2 + \((ca\^2 - ek\^2)\)\^2 + \
\((ca\^2 - fl\^2)\)\^2)\), \[IndentingNewLine] (*39*) 
              L49c = \((\((ag\^2 - de\^2)\)\^2 + \((ag\^2 - ef\^2)\)\^2 + \
\((ag\^2 - fd\^2)\)\^2 + \((bh\^2 - de\^2)\)\^2 + \((bh\^2 - ef\^2)\)\^2 + \
\((bh\^2 - fd\^2)\)\^2 + \((ci\^2 - de\^2)\)\^2 + \((ci\^2 - ef\^2)\)\^2 + \
\((ci\^2 - fd\^2)\)\^2)\)}];\)\)], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  PageBreakWithin->Automatic,
  FontSize->9],

Cell[TextData[{
  "\tThese ",
  StyleBox["sh12",
    FontSlant->"Italic"],
  " functions are conserved quantities in some Dozal interactions; different \
hoops conserve different selections, and some are only conserved for orbit \
interactions. This is a rich topic that has yet to be explored, but has \
promise as an explanation of particle properties."
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3.7. Reciprocal Radii; Three size regimes? The \"Large numbers \
hypothesis\"?\
\>", "Subsubsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tThe Dozal ",
  StyleBox["quadratic",
    PageWidth->WindowWidth],
  " sizes,{\[Zeta], \[Lambda], \[Eta], \[Kappa]}, must multiply to 1 ",
  StyleBox["(excluding any zeroes) in any orbits. ",
    PageWidth->WindowWidth],
  "\[Zeta]",
  StyleBox[" has (leptonic?) 4-fold symmetry.",
    PageWidth->WindowWidth],
  " The three with ternary (hadronic?) symmetry could have one (\[Lambda]) \
corresponding to a Planck area ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["p",
            FontSlant->"Plain"], "2"], TraditionalForm]]],
  " and the other two (\[Eta], \[Kappa]) in a reciprocal relationship, two \
squared radii ",
  Cell[BoxData[
      \(TraditionalForm\`r\^2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`R\^2\)]],
  " corresponding to the dimensions of \"pseudo-point\" particles and the \
universe. p=r.R then gives three size regimes. There is an analogy here with \
the \"T-duality\" of M-theory, where equivalent theories are created by \
exchanging a large dimension and a small dimension. ",
  StyleBox["The \"Dirac large numbers hypothesis\" ",
    PageWidth->WindowWidth],
  "could be a result of this possible reciprocal relationship between two \
sizes",
  StyleBox[", with size ratios being powers of ",
    PageWidth->WindowWidth],
  Cell[BoxData[
      \(TraditionalForm\`10\^40\)]],
  StyleBox[" approximately. ",
    PageWidth->WindowWidth],
  " More work is needed."
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.8.  Mass and the Unit Velocity Equation.", "Subsubsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tThe basic wave equation in many directions, ",
  Cell[BoxData[
      \(TraditionalForm\`d\^2\)],
    FontSlant->"Italic"],
  StyleBox["G/d",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`t\^2\)],
    FontSlant->"Italic"],
  "-\[Sum][",
  Cell[BoxData[
      \(TraditionalForm\`d\^2\)],
    FontSlant->"Italic"],
  StyleBox["G/d",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)],
    FontSlant->"Italic"],
  "]=0, ",
  StyleBox["has an infinite number of planar wave solutions, each with a unit \
velocity. These project onto ",
    PageWidth->WindowWidth],
  "the different directions as velocity components. ",
  StyleBox["This is proved in Example 31, which ",
    PageWidth->WindowWidth],
  "sums the second differentials of a general travelling wave G[-t+x lx+y \
ly+z lz] with three space directions."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  StyleBox["Example 31.",
    FontWeight->"Bold"],
  " Unit Velocity Equation with 3 space directions."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[\[PartialD]\_{t, 2}G[\(-t\) + x\ lx + y\ ly + 
              z\ lz] - \[IndentingNewLine]\[PartialD]\_{x, 2}G[\(-t\) + 
              x\ lx + y\ ly + 
              z\ lz] - \[IndentingNewLine]\ \[PartialD]\_{y, 2}G[\(-t\) + 
              x\ lx + y\ ly + z\ lz] - \[PartialD]\_{z, 2}G[\(-t\) + x\ lx + 
              y\ ly + z\ lz]]\)], "Input",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman",
  FontSize->12,
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[BoxData[
    RowBox[{\(-\((\(-1\) + lx\^2 + ly\^2 + lz\^2)\)\), " ", 
      RowBox[{
        SuperscriptBox["G", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", \(\(-t\) + lx\ x + ly\ y + lz\ z\), 
        "]"}]}]], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[TextData[{
  "\tThe result is zero if the ",
  StyleBox["lx",
    FontSlant->"Italic"],
  " are direction sines so that their squares sum to 1. (Direction sines are \
used because the angles are measured towards the x direction and the lx \
contribution disappears in sub-algebras where this angle is zero.). This \
generalises to any number of space directions. Each additional space \
direction adds the square of its direction sine. The partial differential \
equation is therefore satisfied by any unit velocity function moving forward \
in any number of directions. This gives a light-like limiting velocity in two \
possible ways:-\n1. If pairs of directions fold to single dimensions, the \
disturbance travels at a speed that is less than unity unless there is a zero \
velocity in one of each of the folded pairs.\n2. If all but 3 space \
directions are curled-up (Kaluza-Klein) directions, KK velocities reduce the \
velocity in the spatial directions; light-like disturbances have no velocity \
in the KK directions. KK \"orbital\" velocities give mass to the \
disturbances. Massless particle waves would be restricted to space-like \
dimensions, whilst others would have velocities in Kaluza-Klein dimensions. \
This relates to the reciprocal radii conjecture. Constant orbital frequencies \
in small dimensions would contribute less mass than the same in larger \
dimensions."
}], "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tAn article [7] on Huygen's principle develops both the linear and the \
spherical wave versions for n spatial dimensions. n=3 gives sinusoidal waves \
with the square law of decay, amplitude=A/",
  Cell[BoxData[
      \(TraditionalForm\`r\^\(n - 2\)\)]],
  ". n=2 gives Bessel function solutions. [8] applies the spherical wave \
versions to spaces with more than 3 space dimensions. Odd n's  give expanding \
spherical waves that decay according to r^[n-2]; the square law decay is \
restricted to 3 spatial dimensions."
}], "Text",
  PageWidth->WindowWidth],

Cell["\<\
\tThe  Schrodinger equation provides \"information about particles\" as wave \
packets which disperse with the passage of time. As dispersion arises when \
the velocity is frequency-dependent, the unit velocity equation describes \
non-dispersing wave packets. Generalizing the Schrodinger equation to 12 \
directions (instead of the 4 implied by using \[ImaginaryI]) might lead to a \
more general description of non-dispersing particles. \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.9.  The 6-vectors and Dependent Time.", "Subsubsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tThe C3C4 hoop has a conserved quartic ",
  StyleBox["l4s",
    FontSlant->"Italic"],
  " which factorizes into two sums of  squares ",
  StyleBox["l22a",
    FontSlant->"Italic"],
  " & ",
  StyleBox["l22b",
    FontSlant->"Italic"],
  " and can be expressed as ",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  StyleBox["s26\.b2-abef =",
    PageWidth->WindowWidth,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  Cell[BoxData[
      StyleBox[\(\((\((ab\^2 + bc\^2 + ca\^2 + de\^2 + ef\^2 + fd\^2)\)/
                2)\)\^2\),
        FontSlant->"Italic"]],
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"-", 
          StyleBox["3",
            FontSlant->"Italic"]}], 
        StyleBox[\(\((ab\ ef - bc\ de)\)\^2\),
          FontSlant->"Italic"]}]], "Input",
    FontFamily->"Times New Roman",
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  ". This may correspond to a Kaluza-Klein 6-vector ",
  Cell[BoxData[
      StyleBox[\(\((ab\^2 + bc\^2 + ca\^2 + de\^2 + ef\^2 + fd\^2)\)/2\),
        FontSlant->"Italic"]],
    FontFamily->"Times New Roman"],
  " (with 3 spce dimensions and 3 KK dimensions) and a dependent \"time\" ",
  Cell[BoxData[
      StyleBox[\(\(-3\) \((ab\ ef - bc\ de)\)\),
        FontSlant->"Italic"]], "Input",
    FontFamily->"Times New Roman",
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  ". Other conserved quartics provide a variety of conserved sums or \
differences of squares; ",
  StyleBox["l4r",
    FontSlant->"Italic"],
  " = ",
  StyleBox["r26\.b2-3agek",
    PageWidth->WindowWidth,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" is also ",
    PageWidth->WindowWidth,
    FontFamily->"Times New Roman"],
  "the difference between the squared sum of six squares and another squared \
term. These functions provide possible extensions of the Minkowski metric to \
Kaluza-Klein spaces where \"time\" is dependent on the particle velocity. ",
  StyleBox["Four functions consisting of the sum of nine squared terms are \
also defined in Example 30. Their significance is unknown.",
    PageWidth->WindowWidth]
}], "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.10.  Hyperbolic orbits.", "Subsubsection",
  PageWidth->WindowWidth],

Cell[TextData[{
  "\tHyperbolic orbits exist when hoops have sizes that can be expressed as \
the difference of two squared fragments, corresponding to ",
  Cell[BoxData[
      \(TraditionalForm\`Cosh[x]\^2\)]],
  "-",
  Cell[BoxData[
      \(TraditionalForm\`Sinh[x]\^2\)]],
  "=1. They are not implemented in the ",
  StyleBox["hoops.m",
    FontSlant->"Italic"],
  " package, but are included in ",
  StyleBox["MathSource",
    FontSlant->"Italic"],
  "/4894. They occur in non-Abelian hoops, and can be created in Abelian \
hoops if the product of two linear sizes can be expressed as the difference \
of two squares. The ",
  StyleBox["GroupLoopHoop.m",
    FontSlant->"Italic"],
  " package includes nine examples. Example 29 in ",
  StyleBox["GroupLoopDemo.nb ",
    FontSlant->"Italic"],
  "(reproduced below as ",
  StyleBox["Example 32",
    FontWeight->"Bold"],
  ") multiplies two complex vectors, using the Klein group K. This conserves \
{a+b+c+d, a-b+c-d, a-b-c+d, a+b-c-d}, so it also conserves ",
  Cell[BoxData[
      \(TraditionalForm\`\((a + c)\)\^2\)]],
  "-",
  Cell[BoxData[
      \(TraditionalForm\`\((b + d)\)\^2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\((a - c)\)\^2\)]],
  "-",
  Cell[BoxData[
      \(TraditionalForm\`\((b - d)\)\^2\)]],
  ". The example shows that sizes multiply, (complex) angles add, and \
hyperbolic forms revert correctly to Cartesian vectors. Figure 32 includes a \
skeleton implementation of the relevant procedures. The hyperbolic tangent \
function has to be extended to handle two complex arguments {x,y}. The \
results depend on the quadrants in which x & y occur (details omitted); ",
  StyleBox["arcTanh[-x,-y]",
    FontSlant->"Italic"],
  " differs from ",
  StyleBox["arcTanh[x,y] ",
    FontSlant->"Italic"],
  "although",
  StyleBox[" arcTanh[-x/(-y)]=arcTanh[x/y]",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox["Example",
            FontWeight->"Bold"], 
          StyleBox[" ",
            FontWeight->"Bold"], 
          StyleBox["32.",
            FontWeight->"Bold"], 
          StyleBox["Implementation",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["of",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["the",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["\"\<K\>\"",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["Hyperbolic",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["Dual",
            FontWeight->"Plain"]}], 
        StyleBox[";",
          FontWeight->"Plain"]}], TraditionalForm]], "Input"],

Cell[BoxData[{
    FormBox[
      StyleBox[\(arcTanh[x, y] := Log[\((x + y)\)/\@\(x\^2 - y\^2\)]\),
        FontWeight->"Plain"], TraditionalForm], "\n", 
    FormBox[
      StyleBox[\(tohyPol[{a, b, c, 
              d}, "\<K\>"] := {u^2 = \((a + c)\)^2 - \((b + d)\)^2, \[Phi] = 
              arcTanh[a + c, 
                b + d], \[IndentingNewLine]v^2 = \((a - c)\)^2 - \((b - 
                      d)\)^2, \[Psi] = arcTanh[a - c, b - d]}\),
        FontWeight->"Plain"], TraditionalForm], "\n", 
    FormBox[
      StyleBox[\(tohyVec[{u, \[Phi], 
              v, \[Psi]}, "\<K\>"] := \[IndentingNewLine]\ \ {\ 
              u*Cosh[\[Phi]]\  + v*Cosh[\[Psi]], \ \ u*Sinh[\[Phi]] + 
                v*Sinh[\[Psi]], \[IndentingNewLine]\(-u\)*Sinh[\[Phi]] - 
                v*Cosh[\[Psi]], \(-u\)*Sinh[\[Phi]] - v*Cosh[\[Psi]]}/2\),
        FontWeight->"Plain"], TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{
        StyleBox[\(If\ A\),
          FontWeight->"Plain"], 
        StyleBox["=",
          FontWeight->"Plain"], 
        RowBox[{
          
          StyleBox[\({3.  - 2  \[ImaginaryI], 5. , \(-2\), 
                2.  + \[ImaginaryI]} with\ hyperbolic\ form\ hA\),
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox["\[IndentingNewLine]",
            
            FontWeight->"Plain"], \({\(-51\) - 
              18\ \[ImaginaryI],  .0919\[InvisibleSpace] + 
              1.2768\ \[ImaginaryI], 
            13\[InvisibleSpace] - 
              14\ \[ImaginaryI],  .67026 +  .0524\ \[ImaginaryI]}\)}]}], 
      TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{
        StyleBox[\(and\ B\),
          FontWeight->"Plain"], 
        StyleBox["=",
          FontWeight->"Plain"], 
        RowBox[{
          
          StyleBox[\({5.  + \[ImaginaryI], 
                3.  - 2  \[ImaginaryI], \(-2. \) - 3  \[ImaginaryI], 4. } 
              with\ hyperbolic\ form\ hB\),
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          "\[IndentingNewLine]", \({\(-40\) + 
              16\ \[ImaginaryI],  .49525\[InvisibleSpace] - 
              1.761\ \[ImaginaryI], 
            36\[InvisibleSpace] + 
              52\ \[ImaginaryI], \(- .2291\) -  .1609\ \[ImaginaryI]}\)}]}], 
      TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{
        StyleBox["AB",
          FontWeight->"Plain"], 
        StyleBox["=",
          FontWeight->"Plain"], 
        RowBox[{
          
          RowBox[{\({44\[InvisibleSpace] - 7\ \[ImaginaryI], 
              21\[InvisibleSpace] - 15\ \[ImaginaryI], 
              6\[InvisibleSpace] - 8\ \[ImaginaryI], 
              5\[InvisibleSpace] - 12\ \[ImaginaryI]}\), 
            StyleBox["with",
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            StyleBox["hyperbolic",
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            StyleBox["form",
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            StyleBox["hAB",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            
            FontWeight->"Plain"], \({2328\[InvisibleSpace] - 
              96\ \[ImaginaryI],  .5872\[InvisibleSpace] -  .4843\ \
\[ImaginaryI], 
            1196\[InvisibleSpace] + 
              172\ \[ImaginaryI],  .4412\[InvisibleSpace] -  .1084\ \
\[ImaginaryI]}\)}]}], TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{
        StyleBox[\(sizes\ multiply\),
          FontWeight->"Plain"], 
        StyleBox[",",
          FontWeight->"Plain"], 
        StyleBox[" ",
          FontWeight->"Plain"], 
        RowBox[{
          StyleBox[\(hA\ hB - hAB\),
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[\({0, 1.7068 +  .955  I, 0, \(- .586\) -  .01  I}\),
            FontWeight->"Bold"]}]}], TraditionalForm], "\[IndentingNewLine]", 
  
    FormBox[
      RowBox[{
        StyleBox[\(hyperangles\ add\),
          FontWeight->"Plain"], 
        StyleBox[",",
          FontWeight->"Plain"], 
        RowBox[{
          StyleBox[\(hA + hB - hAB\),
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[\({\(-2419\) + 94  I, 0, \(-1147\) - 134  I, 0}\),
            FontWeight->"Bold"]}]}], TraditionalForm]}], "Input",
  FontFamily->"Courier New"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  StyleBox["4. Conclusions.",
    FontSize->14,
    FontWeight->"Bold"],
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->14],
  StyleBox["\n",
    FontSize->14],
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->14,
    FontWeight->"Plain"],
  StyleBox["Hoop Algebras unify many algebras with applications in physics. \
Complex algebra is a hoop, but is degenerate because it only conserves one \
size. This reduces Hoop properties to special cases.\n",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain"]
}], "Section"],

Cell[CellGroupData[{

Cell["References.", "Section"],

Cell[TextData[{
  "[1]",
  StyleBox[" MathSource",
    FontSlant->"Italic"],
  "/6198/\n[2] Hoops&Physics.doc\n[3] P. Louenesto, Clifford Algebras & \
Spinors 2nd ed., Cambridge University Press 2001\n[4]",
  StyleBox[" MathSource",
    FontSlant->"Italic"],
  "/4894/\n[5] J.D.H.Smith, A.B.Romanowska, Post-Modern Algebra,Wiley \
Interscience 1999.\n[6] J.J.Hamilton, Hypercomplex numbers and the \
description of spin states, J.Math.Phys.",
  StyleBox["38",
    FontWeight->"Bold"],
  "(10) Oct. 1997. pp4914-4928\n[7] \
http://www.mathpages.com/home/kmath242/kmath242.htm\n[8] \
http://www.mathpages.com/home/kmath614/kmath614.htm"
}], "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 887}},
WindowToolbars->"EditBar",
WindowSize->{1043, 677},
WindowMargins->{{103, Automatic}, {Automatic, 83}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Inherited, Inherited, Inherited}, {None, Inherited, None}},
PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}]], Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Cell[ 
        TextData[ "21/02/2007"]]}},
Magnification->1.5
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 67, 1, 141, "Title"],
Cell[1846, 56, 72, 1, 44, "Subsubtitle"],

Cell[CellGroupData[{
Cell[1943, 61, 61, 1, 109, "Section"],
Cell[2007, 64, 320, 11, 73, "Text"],
Cell[2330, 77, 2504, 56, 463, "Text"],
Cell[4837, 135, 39, 1, 42, "Input"],
Cell[4879, 138, 74, 2, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4990, 145, 63, 1, 109, "Section"],
Cell[5056, 148, 566, 12, 151, "Text"],

Cell[CellGroupData[{
Cell[5647, 164, 139, 6, 56, "Subsection"],
Cell[5789, 172, 1898, 52, 307, "Text"],

Cell[CellGroupData[{
Cell[7712, 228, 2383, 49, 28, "Input",
  CellOpen->False],
Cell[10098, 279, 4871, 116, 993, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[15018, 401, 87, 1, 56, "Subsection"],
Cell[15108, 404, 2856, 80, 385, "Text"],

Cell[CellGroupData[{
Cell[17989, 488, 756, 14, 28, "Input",
  CellOpen->False],
Cell[18748, 504, 1320, 26, 443, "Output"]
}, Open  ]],
Cell[20083, 533, 421, 11, 99, "Text"],

Cell[CellGroupData[{
Cell[20529, 548, 447, 9, 28, "Input",
  CellOpen->False],
Cell[20979, 559, 378, 7, 274, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[21406, 572, 82, 1, 56, "Subsection"],
Cell[21491, 575, 2437, 76, 283, "Text"],

Cell[CellGroupData[{
Cell[23953, 655, 3661, 67, 510, "Input"],
Cell[27617, 724, 4523, 85, 725, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[32189, 815, 90, 1, 56, "Subsection"],
Cell[32282, 818, 673, 21, 125, "Text"],

Cell[CellGroupData[{
Cell[32980, 843, 2741, 51, 28, "Input",
  CellOpen->False],
Cell[35724, 896, 3549, 62, 516, "Output"]
}, Open  ]],
Cell[39288, 961, 401, 7, 99, "Text"],

Cell[CellGroupData[{
Cell[39714, 972, 1974, 39, 28, "Input",
  CellOpen->False],
Cell[41691, 1013, 2393, 39, 316, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[44133, 1058, 84, 1, 56, "Subsection"],
Cell[44220, 1061, 1305, 33, 229, "Text"],

Cell[CellGroupData[{
Cell[45550, 1098, 522, 10, 28, "Input",
  CellOpen->False],
Cell[46075, 1110, 890, 19, 263, "Output"]
}, Open  ]],
Cell[46980, 1132, 377, 8, 73, "Text"],
Cell[47360, 1142, 638, 14, 214, "Output"],

Cell[CellGroupData[{
Cell[48023, 1160, 418, 8, 28, "Input",
  CellOpen->False],
Cell[48444, 1170, 1009, 22, 292, "Output"]
}, Open  ]],
Cell[49468, 1195, 352, 8, 99, "Text"],

Cell[CellGroupData[{
Cell[49845, 1207, 429, 8, 28, "Input",
  CellOpen->False],
Cell[50277, 1217, 2049, 40, 448, "Output"]
}, Open  ]],
Cell[52341, 1260, 420, 16, 73, "Text"],
Cell[52764, 1278, 843, 19, 238, "Input",
  Evaluatable->False],
Cell[53610, 1299, 295, 12, 47, "Text"],

Cell[CellGroupData[{
Cell[53930, 1315, 505, 9, 28, "Input",
  CellOpen->False],
Cell[54438, 1326, 1920, 33, 503, "Output"]
}, Open  ]],
Cell[56373, 1362, 497, 16, 73, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[56907, 1383, 93, 1, 56, "Subsection"],
Cell[57003, 1386, 590, 15, 125, "Text"],

Cell[CellGroupData[{
Cell[57618, 1405, 1233, 21, 28, "Input",
  CellOpen->False],
Cell[58854, 1428, 2956, 56, 853, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[61859, 1490, 76, 1, 56, "Subsection"],
Cell[61938, 1493, 591, 10, 151, "Text"],

Cell[CellGroupData[{
Cell[62554, 1507, 621, 12, 28, "Input",
  CellOpen->False],
Cell[63178, 1521, 570, 9, 191, "Output"]
}, Open  ]],
Cell[63763, 1533, 1187, 31, 151, "Text"],
Cell[64953, 1566, 1453, 37, 229, "Text"],

Cell[CellGroupData[{
Cell[66431, 1607, 1231, 25, 28, "Input",
  CellOpen->False],
Cell[67665, 1634, 1287, 20, 241, "Output"]
}, Open  ]],
Cell[68967, 1657, 316, 7, 99, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[69320, 1669, 84, 1, 56, "Subsection"],
Cell[69407, 1672, 399, 9, 99, "Text"],

Cell[CellGroupData[{
Cell[69831, 1685, 613, 11, 28, "Input",
  CellOpen->False],
Cell[70447, 1698, 1186, 24, 348, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[71670, 1727, 634, 12, 28, "Input",
  CellOpen->False],
Cell[72307, 1741, 1689, 34, 495, "Output"]
}, Open  ]],
Cell[74011, 1778, 609, 11, 151, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[74657, 1794, 120, 3, 56, "Subsection"],
Cell[74780, 1799, 3051, 76, 489, "Text"],

Cell[CellGroupData[{
Cell[77856, 1879, 954, 16, 28, "Input",
  CellOpen->False],
Cell[78813, 1897, 3752, 65, 878, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[82614, 1968, 120, 3, 56, "Subsection"],
Cell[82737, 1973, 1400, 28, 255, "Text"],
Cell[84140, 2003, 421, 13, 68, "Text"],

Cell[CellGroupData[{
Cell[84586, 2020, 1664, 31, 28, "Input",
  CellOpen->False],
Cell[86253, 2053, 655, 16, 146, "Output"],
Cell[86911, 2071, 2927, 50, 245, "Output"]
}, Open  ]],
Cell[89853, 2124, 1090, 29, 151, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[90980, 2158, 94, 1, 56, "Subsection"],
Cell[91077, 2161, 1841, 32, 359, "Text"],

Cell[CellGroupData[{
Cell[92943, 2197, 4371, 83, 28, "Input",
  CellOpen->False],
Cell[97317, 2282, 4708, 82, 657, "Output"]
}, Open  ]],
Cell[102040, 2367, 937, 23, 177, "Text"],

Cell[CellGroupData[{
Cell[103002, 2394, 703, 15, 28, "Input",
  CellOpen->False],
Cell[103708, 2411, 764, 13, 421, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[104521, 2430, 89, 1, 56, "Subsection"],
Cell[104613, 2433, 3238, 110, 307, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[107888, 2548, 61, 1, 56, "Subsection"],
Cell[107952, 2551, 1131, 19, 229, "Text"],

Cell[CellGroupData[{
Cell[109108, 2574, 1766, 35, 28, "Input",
  CellOpen->False],
Cell[110877, 2611, 590, 9, 277, "Output"],
Cell[111470, 2622, 1323, 23, 551, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[112854, 2652, 73, 1, 109, "Section"],
Cell[112930, 2655, 1886, 42, 359, "Text"],

Cell[CellGroupData[{
Cell[114841, 2701, 72, 1, 40, "Subsubsection"],
Cell[114916, 2704, 519, 9, 125, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[115472, 2718, 96, 1, 40, "Subsubsection"],
Cell[115571, 2721, 599, 21, 73, "Text"],
Cell[116173, 2744, 1817, 59, 41, "Input"],
Cell[117993, 2805, 986, 21, 227, "Input",
  Evaluatable->False],
Cell[118982, 2828, 770, 27, 125, "Text"],
Cell[119755, 2857, 1404, 46, 41, "Input"],
Cell[121162, 2905, 10641, 382, 277, "Input"],
Cell[131806, 3289, 1200, 44, 151, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[133043, 3338, 84, 1, 40, "Subsubsection"],
Cell[133130, 3341, 4907, 148, 485, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[138074, 3494, 147, 4, 40, "Subsubsection"],
Cell[138224, 3500, 279, 5, 73, "Text"],
Cell[138506, 3507, 1782, 55, 41, "Input"],
Cell[140291, 3564, 2371, 33, 277, "Input"],

Cell[CellGroupData[{
Cell[142687, 3601, 54, 1, 42, "Input"],
Cell[142744, 3604, 1363, 20, 473, "Output"]
}, Open  ]],
Cell[144122, 3627, 1025, 24, 151, "Text"],
Cell[145150, 3653, 382, 7, 73, "Text"],
Cell[145535, 3662, 116, 4, 47, "Text"],
Cell[145654, 3668, 71, 2, 28, "Input",
  CellOpen->False],
Cell[145728, 3672, 3520, 55, 277, "Input"],
Cell[149251, 3729, 1581, 42, 229, "Text"],
Cell[150835, 3773, 1899, 27, 277, "Input"],
Cell[152737, 3802, 278, 5, 73, "Text"],
Cell[153018, 3809, 1834, 26, 277, "Input"],
Cell[154855, 3837, 418, 7, 99, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[155310, 3849, 133, 2, 40, "Subsubsection"],
Cell[155446, 3853, 1277, 26, 255, "Text"],

Cell[CellGroupData[{
Cell[156748, 3883, 257, 7, 110, "Input"],
Cell[157008, 3892, 433, 7, 161, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[157490, 3905, 143, 4, 40, "Subsubsection"],
Cell[157636, 3911, 444, 8, 125, "Text"],

Cell[CellGroupData[{
Cell[158105, 3923, 273, 5, 28, "Input",
  CellOpen->False],
Cell[158381, 3930, 1222, 21, 141, "Output"]
}, Open  ]],
Cell[159618, 3954, 304, 6, 73, "Text"],
Cell[159925, 3962, 692, 25, 73, "Text"],

Cell[CellGroupData[{
Cell[160642, 3991, 336, 7, 28, "Input",
  CellOpen->False],
Cell[160981, 4000, 556, 13, 91, "Output"]
}, Open  ]],
Cell[161552, 4016, 484, 15, 73, "Text"],
Cell[162039, 4033, 232, 5, 28, "Input",
  CellOpen->False],
Cell[162274, 4040, 2242, 40, 341, "Input"],
Cell[164519, 4082, 139, 4, 47, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[164695, 4091, 78, 1, 40, "Subsubsection"],
Cell[164776, 4094, 1351, 21, 281, "Text"],
Cell[166130, 4117, 1783, 51, 41, "Input"],
Cell[167916, 4170, 7856, 127, 1269, "Input",
  PageBreakWithin->Automatic],
Cell[175775, 4299, 393, 9, 99, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[176205, 4313, 137, 4, 40, "Subsubsection"],
Cell[176345, 4319, 1493, 40, 203, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[177875, 4364, 93, 1, 40, "Subsubsection"],
Cell[177971, 4367, 913, 29, 99, "Text"],
Cell[178887, 4398, 131, 4, 47, "Text"],

Cell[CellGroupData[{
Cell[179043, 4406, 631, 16, 100, "Input"],
Cell[179677, 4424, 269, 6, 43, "Output"]
}, Open  ]],
Cell[179961, 4433, 1433, 23, 333, "Text"],
Cell[181397, 4458, 580, 11, 125, "Text"],
Cell[181980, 4471, 464, 7, 125, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[182481, 4483, 90, 1, 40, "Subsubsection"],
Cell[182574, 4486, 2246, 63, 229, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[184857, 4554, 76, 1, 40, "Subsubsection"],
Cell[184936, 4557, 1890, 52, 281, "Text"],
Cell[186829, 4611, 1011, 33, 41, "Input"],
Cell[187843, 4646, 4591, 122, 413, "Input"]
}, Open  ]]
}, Open  ]],
Cell[192461, 4772, 596, 19, 173, "Section"],

Cell[CellGroupData[{
Cell[193082, 4795, 30, 0, 109, "Section"],
Cell[193115, 4797, 646, 16, 229, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

