(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    162833,       3369]*)
(*NotebookOutlinePosition[    163881,       3401]*)
(*  CellTagsIndexPosition[    163837,       3397]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Hoops Package Creation", "Title",
  PageWidth->WindowWidth],

Cell["R.H.Beresford 21/02/2007.", "Subsubtitle",
  PageWidth->WindowWidth],

Cell["Quit[] (* prevents shadowing *)", "Input"],

Cell["\<\
Off[General::spell, General::spell1, Syntax::com]
tf = TraditionalForm; \
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[CellGroupData[{

Cell["1. Version, Copyright notice.", "Subsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, -104.188}, {Inherited, Inherited}},
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "Version 1c. 21/02/07.\n\[Copyright] Copyright 2006,2007",
  StyleBox[" Roger Herbert Beresford, 30, Brook Rd., Woodhouse Eaves, \
Loughborough, Leics, LE12 8RS, England",
    FontSlant->"Italic"],
  ". \nConsiderable effort has gone into checking this work, but some errors \
probably persist. No responsibility will be accepted for any problems arising \
from its use. Permission is granted to distribute this file for any purpose \
except for inclusion in commercial software or program collections. This \
copyright notice must remain intact.\nPlease send any comments to me at ",
  StyleBox["rhberesford@btinternet.com",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{808, Inherited}]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Revisions.", "Subsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, -104.188}, {Inherited, Inherited}},
  FontFamily->"Times New Roman"],

Cell["\<\
Version 1 20/04/06.
Version 1a. 07/05/06. Minor edits. Introduced BoldFace by \"//bf\".
Version 1b. 23/09/06. Minor edits. Exra hoops added, from latest \
GroupLoopHoop.m.
Version 1c. 21/02/07. Minor edits.  Extended \"as[A_,B_]\"; hoopNames global.\
\
\>", "Text",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. Keywords.", "Subsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, -54.375}, {Inherited, Inherited}},
  FontFamily->"Times New Roman"],

Cell["\<\
\tAlgebras, Clifford algebras, conservative loops & algebras, \
Frobenius-conservation, generalized signs, Hoops, Hoop shapes & Hoop sizes, \
Moufang Loops, plex-conjugate, partial-division-by-zero, remainders,  roots \
of unity, symmetries, zero-vectors.\
\>", "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  CellSize->{490, Inherited}]
}, Closed]],

Cell[CellGroupData[{

Cell["4. Warnings.", "Subsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, -54.375}, {Inherited, Inherited}},
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "This package is incompatible with GroupLoopHoop.m in ",
  StyleBox["MathSource",
    FontSlant->"Italic"],
  " 4894."
}], "Text",
  PageWidth->WindowWidth]
}, Closed]],

Cell[CellGroupData[{

Cell["5. Limitations.", "Subsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, -54.375}, {Inherited, Inherited}},
  FontFamily->"Times New Roman"],

Cell["Many hoops lack polar forms.", "Text",
  PageWidth->WindowWidth]
}, Closed]],

Cell[CellGroupData[{

Cell["6. Note on Implementation.", "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "\tData on each hoop is stored as ",
  StyleBox["Hoop[\"H\"]",
    FontSlant->"Italic"],
  "; ",
  StyleBox["Use[H]",
    FontSlant->"Italic"],
  " puts this data into the set of variables used by the procedures ",
  StyleBox["hoopTimes, hoopInverse, hoopPower",
    FontSlant->"Italic"],
  " that implement the Hoop algebra for the \"active\" hoop. ",
  StyleBox["hoopNames",
    FontSlant->"Italic"],
  " lists all the names.",
  "\n\tFor each hoop ",
  StyleBox["H",
    FontSlant->"Italic"],
  ", the first two elements of ",
  StyleBox["Hoop[\"H\"] ",
    FontSlant->"Italic"],
  "are ",
  StyleBox["mm & nn,",
    FontSlant->"Italic"],
  " i.e. the length of the hoop ",
  StyleBox["mm",
    FontSlant->"Italic"],
  " and its position ",
  StyleBox["nn",
    FontSlant->"Italic"],
  " in the GAP Atlas, as extended in the ",
  StyleBox["GroupLoopHoop.m",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  " package to include hoops and some other small loops. (This is adapted \
from ([GAP99] The Gap Group. GAP --- Groups, Algorithms,  and Programming, \
Version 4.2; Aachen, St Andrews, 1999. http://www-gap. dcs.st-and. \
ac.uk/~gap).\n\tNext is the index table \"protoloop\", i.e. the Cayley table \
isomorph used to define the hoop. This is a list of lists giving the product \
index, ",
  StyleBox["i.j=k",
    FontSlant->"Italic"],
  " in the ",
  StyleBox["i",
    FontSlant->"Italic"],
  "'th row and ",
  StyleBox["j",
    FontSlant->"Italic"],
  "'th column. Tables have {1,2...,mm} in the first row and column, and every \
index occurs (possibly with a sign) once in every row and column. Hoop tables \
have the Moufang division property x(yz) = (xy)z (for all elements x,y,z in \
the table, allowing for signs). By definition, they have the Frobenius \
conservation property Det[A] Det[B] = Det[AB], up to a sign, for the \
multiplication of vectors A & B. (Five tables without the conservation \
property are appended to provide counter-examples. Their names end in ",
  StyleBox["n",
    FontSlant->"Italic"],
  ")\n\tNext comes the factorized determinant for a Cartesian form {a,b,..",
  StyleBox["m",
    FontSlant->"Italic"],
  "}, followed, where known, by the closely related Polar form which includes \
angles that take up the degrees of freedom released by quadratic sizes. (A \
null entry means that the polar form has not been developed. More may be \
available in later versions of ",
  StyleBox["MathSource",
    FontSlant->"Italic"],
  "/4894).\n\tIf it is known, the Polar-Cartesian reversion will come next. \
This gives the Cartesian form for a polar form {a,b,..",
  StyleBox["m",
    FontSlant->"Italic"],
  "}.\n\tTwo lists, ",
  StyleBox["gi, gp",
    FontSlant->"Italic"],
  ", follow. These summarize information about the hoop, needed by the ",
  StyleBox["hoopInverse, topol",
    FontSlant->"Italic"],
  " and ",
  StyleBox["tovec ",
    FontSlant->"Italic"],
  "routines. Finally, a ",
  StyleBox["Plex",
    FontSlant->"Italic"],
  " involution may be supplied. This is the Complex Conjugate for hoops C4c \
(complex), Qr (quaternion) and Oct (octonion) and is an equivalent of the \
Complex Conjugate for some other algebras."
}], "Text",
  PageWidth->WindowWidth]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["7. Set up the Hoops.m package, usage",
    FontFamily->"Times New Roman"],
  "."
}], "Subsection",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[TextData[{
  "7.1 Begin, ",
  StyleBox["Hoops",
    FontFamily->"Times New Roman"],
  " Usage."
}], "Subsubsection",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[TextData[{
  "BeginPackage[",
  StyleBox["\"",
    FontFamily->"Courier New"],
  StyleBox["Hoops",
    FontFamily->"Times New Roman"],
  StyleBox["`\"",
    FontFamily->"Courier New"],
  "];"
}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[TextData[{
  "Hoops::usage = \"",
  StyleBox["Hoops",
    FontFamily->"Times New Roman"],
  ".m is a package that creates a database of over 80 hoops \
(symmetry-conserving partial-fraction division algebras) or counter-examples \
as index-Tables (Cayley tables with signed indices as elements). It provides \
Hoop procedures for multiplication & division, powers & roots, & some \
polar-dual formulations, of generalized vectors.\";"
}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 2}, {Inherited, Inherited}},
  InitializationCell->True,
  FontFamily->"Courier New"]
}, Closed]],

Cell[CellGroupData[{

Cell["7.2 Alphabetic list of Usage for functions and procedures.", \
"Subsubsection",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(a::usage = "\<Symbol in HoopTbl etc.\>"; b::usage = "\<\>"; 
    c::usage = "\<\>"; d::usage = "\<\>"; e::usage = "\<\>"; 
    f::usage = "\<\>"; g::usage = "\<\>"; h::usage = "\<\>"; 
    i::usage = "\<\>"; j::usage = "\<\>"; k::usage = "\<\>"; 
    l::usage = "\<\>"; m::usage = "\<\>"; o::usage = "\<\>"; 
    p::usage = "\<\>"; q::usage = "\<\>"; r::usage = "\<\>"; 
    s::usage = "\<\>"; t::usage = "\<\>"; u::usage = "\<\>"; 
    v::usage = "\<\>"; w::usage = "\<\>"; x::usage = "\<\>"; 
    y::usage = "\<\>";\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
alph::usage=\"A list of 24 symbols, {a,b,...,x} used as symbolic elements of \
Cayley Tables.\";\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True,
  FontFamily->"Courier New"],

Cell[BoxData[
    \(\(arcTanh::usage = "\<Quadrant sensitive Hyperbolc Tangent\>";\)\)], \
"Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(as::usage\), "=", 
          "\"\<as[w_] sets up a substitution table to replace \!\(\*
StyleBox[\"alph\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\"symbols\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\"by\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\"elements\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\"of\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\"the\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\"vector\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\"w\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\)to convert symbolic functions to \
specific cases.\n Extended so that /.as[v_,w_] replaces elements of v by \
elements of w.\>\""}], ";"}], TraditionalForm]], "Input",
  InitializationCell->True,
  FontFamily->"Courier New"],

Cell[BoxData[
    \(\(bf::usage = "\<BoldFormat. xx//bf will print in bold\>";\)\)], "Input",\

  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{\(hoopInverse::usage\), "=", "\"\<\!\(\*
StyleBox[\"hoopInverse\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\"[\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\"A_\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\"]\",\nFontSlant->\"Plain\"]\)\!\(\*
StyleBox[\" \",\nFontSlant->\"Plain\"]\)finds the multiplicative left inverse \
Ainv of A. hoopTimes[Ainv,B] divides B by A and creates remainders Rl & Rr to \
conserve any sizes that are lost from A or B\>\""}], ";"}]], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    StyleBox[\(hoopPower::usage = \*"\"\<hoopPower[A_, r_:1/2] calculates \
\!\(A\^r\) if the active loop has a polar form.\>\"";\),
      ShowStringCharacters->True,
      NumberMarks->True,
      FontSlant->"Plain"]], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True,
  FontFamily->"Courier New"],

Cell[BoxData[
    StyleBox[\(hoopTimes::usage\  = \ "\<hoopTimes[A,B] uses the active loop \
to multiply the vectors 'A' & 'B' to give a product 'P'. Remainders Rl & Rr \
are created, so that A=P/B+Rl, B=P/A+Rr, maintaining size conservation.\>";\),
      
      FontSlant->"Plain"]], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True,
  FontFamily->"Courier New"],

Cell[BoxData[
    \(\(gi::usage = "\<Indices used by hoopTimes.\>";\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(gp::usage = "\<Powers used by hoopTimes.\>";\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(hoopNames::usage = "\<A list of strings naming each loop.\>";\)\)], \
"Input",
  PageWidth->WindowWidth,
  InitializationCell->True,
  FontFamily->"Courier New"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(hoopTbl::usage\), "=", "\"\<Set by \!\(\*
StyleBox[\"us\",\nFontSlant->\"Italic\"]\)e as the indexTable of the active \
hoop.\>\""}], ";"}]], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True,
  FontFamily->"Courier New"],

Cell[BoxData[
    \(\(genCos::usage = "\<Multiphase Sinusoid\>";\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(genSin::usage = "\<Multiphase Sinusoid\>";\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(hmin::usage = "\<hmin is arbitrarily set at 4$MachineEpsilon as the \
criterion for 'hoopInverse' to ignore (renormalize) partial fractions with \
near-zero denominators.\>";\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True,
  FontFamily->"Courier New"],

Cell[BoxData[
    \(\(J::usage = "\<J^3=1. \>";\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(JJ::usage = "\<J J with J^3=1.\>";\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(js::usage = "\<re-write rule to make J & JJ act as signs with J^3=1. \
\>";\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(mm::usage = "\<The length of the active hoop\>";\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(nn::usage = "\<The position of the active hoop in loop[[mm]] of \
groupLoopHoop.nb\>";\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(plex::usage = "\<The Hoop-plex conjugate; duplicates the complex \
conjugates where they exist.\>";\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(r3::usage = "\<Sqrt[3.]\>";\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(r6::usage = "\<2 Sqrt[3.]\>";\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Rl::usage = "\<Left remainder\>";\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Rr::usage = "\<Right remainder\>";\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(sh::usage = "\<Symbolic shape (list of conserved sizes) for the \
active hoop\>";\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(topol::usage = "\<Symbolic polar form for the active hoop\>";\)\)], \
"Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(tovec::usage = "\<Vector form for the Symbolic polar form of the \
active hoop\>";\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Use::usage = "\<After Use[hoopname_] other instructions employ this \
hoop as the active hoop.\>";\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["8. Start Private definitions.  Create Database.",
  FontFamily->"Times New Roman"]], "Subsection",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["8",
    FontFamily->"Times New Roman"],
  ".1 Begin Private."
}], "Subsubsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(\(Begin["\<`Private`\>"];\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Unprotect[NumberQ, Positive, Abs, Sign, Re, Im];\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["8",
    FontFamily->"Times New Roman"],
  ".2 Data File,",
  StyleBox[" ",
    FontWeight->"Plain"],
  StyleBox["alph, hoopNames, Hoop[name].",
    FontSlant->"Italic"]
}], "Subsubsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 1}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(\(alph =  (*\ 
          Dummy\ variables\ used\ in\ all\ symbolic\ tables\ and\ functions*) \
{a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t, u, v, w, 
          x};\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["Data is supplied for the following Hoops:-", "Text",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(hoopNames = {"\<C2\>", "\<C4c\>", "\<C3\>", "\<C3C2c\>", "\<C4C3c\>", \
"\<C9j\>", "\<C3i\>", "\<C12c\>", "\<K\>", "\<C4\>", "\<Qr\>", "\<Dav\>", \
"\<P4\>", "\<P16c\>", "\<O2\>", "\<CL2\>", "\<C4C2r\>", "\<C8c\>", "\<C5\>", \
"\<D3\>", "\<C3C2\>", "\<Q12c\>", "\<Q12r\>", "\<D6r\>", "\<KC3c\>", \
"\<C3Kr\>", "\<C3C4c\>", "\<D3C2c\>", "\<Clm3r\>", "\<Cl3r\>", "\<g2401c\>", \
"\<C8\>", "\<C4C2\>", "\<D4\>", "\<Q8\>", "\<KC2\>", "\<C4C4c\>", \
"\<KiC4c\>", "\<C4iC4c\>", "\<QC2r\>", "\<Q8C2r\>", "\<O4\>", "\<P8\>", \
"\<C2D4r\>", "\<CL3\>", "\<Octr\>", "\<KiC4r\>", "\<CL21\>", "\<CL03\>", \
"\<Octi\>", "\<C3C3\>", "\<Q12\>", "\<C3C4\>", "\<A4\>", "\<D3C2\>", \
"\<C3K\>", "\<C3Qr\>", "\<C3P4\>", "\<C3KC2r\>", "\<C6Kr\>", "\<Q12C2c\>", \
"\<C4C4\>", "\<KiC4\>", "\<C4iC4\>", "\<D8\>", "\<Q16\>", "\<C4K\>", \
"\<D4C2\>", "\<Q8C2\>", "\<P16\>", "\<KK\>", "\<Oct\>", "\<r31r\>", \
"\<CL4\>", "\<CL31\>", "\<CL22\>", "\<CL13\>", "\<CL04\>", "\<O8\>", \
"\<Q8M2\>", "\<C3C4C2\>", "\<Q4n\>", "\<C6n\>", "\<Q8n\>", "\<Alt8n\>", \
"\<D3Mn\>"};\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Many more hoops are listed in [3], but not included here because they do not \
have known polar forms or are too closely related to those that are included \
to be of interest.\
\>", "Text",
  PageWidth->WindowWidth],

Cell[TextData[{
  "Nomenclature.\nC",
  StyleBox["n",
    FontSlant->"Italic"],
  " is a cyclic group; C",
  StyleBox["n",
    FontSlant->"Italic"],
  "C",
  StyleBox["m",
    FontSlant->"Italic"],
  " (etc.) are direct compositions; C",
  StyleBox["n",
    FontSlant->"Italic"],
  "iC",
  StyleBox["m",
    FontSlant->"Italic"],
  " are indirect compositions; D",
  StyleBox["n",
    FontSlant->"Italic"],
  " is the dihedral group with 2",
  StyleBox["n",
    FontSlant->"Italic"],
  " elements; Q",
  StyleBox["n ",
    FontSlant->"Italic"],
  "is the generalazed quaternion group with ",
  StyleBox["n",
    FontSlant->"Italic"],
  " elements; Dav, O4 & O8 are tables with 2, 4 & 8 complex planes; P",
  StyleBox["n",
    FontSlant->"Italic"],
  " are tables created from Pauli-\[Sigma] matrices; CL",
  StyleBox["m",
    FontSlant->"Italic"],
  " are Clifford algebras. Names ending in ",
  StyleBox["r, j, c",
    FontSlant->"Italic"],
  " are signed tables obtained from hoops by 2, 3, or 4-fold collapse. D3Mn \
and Q8M2 are nonassociative Moufang loops; the first is not conservative; the \
second is Chein-doubled Q8 and folds to split-octonion algebra Octi."
}], "Text",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Hoop["\<C2\>"] = {2, 
          1, {{1, 2}, {2, 1}}, {a - b, a + b}, {a - b, 
            a + b}, {\((a + b)\)/2, \((\(-a\) + b)\)/2}, {1, 2, 1, 1}, {1, 
            1}, {a, \(-b\)}};\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Hoop["\<C4c\>"] = {2, 
          2, {{1, 2}, {2, \(-1\)}}, {\(-a\^2\) - b\^2}, {a\^2 + b\^2, 
            ArcTan[a, b]}, {Sqrt[a] Cos[b], Sqrt[a] Sin[b]}, {1, \(-2\), 
            1}, {1, 0. }, {a, \(-b\)}};\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"C3\"]={3,1,{{1,2,3},{2,3,1},{3,1,2}},{a+b+c,(1/2)*((a-b)^2+(b-c)^2+(-a+\
c)^2)},{a+b+c,(1/2)*((a-b)^2+(b-c)^2+(-a+c)^2),ArcTan[2*a-b-c,(-Sqrt[3])*(b-c)\
]},{(1/3)*(a+2*Sqrt[b]*Cos[c]),(1/3)*(a+2*Sqrt[b]*Cos[c+(2*Pi)/3]),(1/3)*(a+2*\
Sqrt[b]*Cos[c-(2*Pi)/3])},{1,3,2,1,1},{1,1,0.},{a,c,b}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Hoop["\<C3C2c\>"] = {3, 
          2, {{1, 2, 3}, {2, 3, \(-1\)}, {3, \(-1\), \(-2\)}}, {a - b + 
              c, \((1/2)\)*\((\((a + b)\)^2 + \((b + c)\)^2 + \((a - 
                        c)\)^2)\)}, {a - b + 
              c, \((1/2)\)*\((\((a + b)\)^2 + \((b + c)\)^2 + \((a - 
                        c)\)^2)\), 
            ArcTan[2*a + b - 
                c, \((\(-Sqrt[3]\))\)*\((b + c)\)]}, {\((1/3)\)*\((a + 
                  2*Sqrt[b]*Cos[c])\), \((1/3)\)*\((\(-a\) - 
                  2*Sqrt[b]*Cos[c - 2*Pi/3])\), \((1/3)\)*\((a + 
                  2*Sqrt[b]*Cos[c - 2*Pi/3])\)}, {1, \(-3\), \(-2\), 1, 
            1}, {1, 1, 0. }, {a, \(-c\), \(-b\)}};\)\)], "Input",
  PageWidth->WindowWidth],

Cell["\<\
Hoop[\"C4C3c\"]={3,4,{{1,2,3},{2,3*I,-1},{3,-1,2*I}},{a+I*b+I*c,((a-I*b)^2-(b-\
c)^2+(a-I*c)^2)/2},{a-I*b-c,((a+I*b)^2+(I*b-c)^2+(a+c)^2)/2,ArcTan[2*a+I*b+c,\
Sqrt[3]*((-I)*b+c)]},{(a+2*Sqrt[b]*Cos[c])/3,(I/3)*(a+2*Sqrt[b]*Cos[c-(2*Pi)/\
3]),(-a-2*Sqrt[b]*Cos[c+(2*Pi)/3])/3},{1,-3,-2,1,1},{1,1,0.},Null};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"C3C3j\"]={3,5,{{1,2,3},{2,3*J^2,J},{3,J,2*^2}},{(a+b J^2+c J^2),((a-b \
J^2)^2+(b J^2-c J^2)^2+(c J^2-a)^2)/2},,,{1,3J,2J,1},,};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"C9j\"]={3,6,{{1,2,3},{2,3*J^2,1},{3,1,2*J}},{a^3-3*a*b*c+c^3*J+b^3*J^2}\
,,,{1,3,2,1},,};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"C3i\"]={3,9,{{1,2,3},{2,3,I},{3,I,2*I}},{a-I*b-c,((a+I*b)^2+(I*b-c)^2+(\
a+c)^2)/2},{a-I*b-c,((a+I*b)^2+(I*b-c)^2+(a+c)^2)/2,ArcTan[2*a+I*b+c,Sqrt[3]*(\
(-I)*b+c)]},{(a+2*Sqrt[b]*Cos[c])/3,(I/3)*(a+2*Sqrt[b]*Cos[c-(2*Pi)/3]),(-a-2*\
Sqrt[b]*Cos[c+(2*Pi)/3])/3},{1,-3*I,-2*I,1,1},{1,1,0.},,};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"C12c\"]={3,8,{{1,2,3},{2,3,-I},{3,-I,-2*I}},{a+I*b-c,((a-I*b)^2+(a+c)^\
2+(I*b+c)^2)/2},{a+I*b-c,((a-I*b)^2+(a+c)^2+(I*b+c)^2)/2,ArcTan[2*a-I*b+c,\
Sqrt[3]*(I*b+c)]},{(a+2*Sqrt[b]*Cos[c])/3,(-I/3)*(a+2*Sqrt[b]*Cos[c-(2*Pi)/3])\
,(-a-2*Sqrt[b]*Cos[c+(2*Pi)/3])/3},{1,3*I,2*I,1,1},{1,1,0.},};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"K\"]={4,1,{{1,2,3,4},{2,1,4,3},{3,4,1,2},{4,3,2,1}},{a+b-c-d,a-b+c-d,a-\
b-c+d,a+b+c+d},{a+b-c-d,a-b+c-d,a-b-c+d,a+b+c+d},{(a+b+c+d)/4,(a-b-c+d)/4,(-a+\
b-c+d)/4,(-a-b+c+d)/4},{1,2,3,4,1,1,1,1},{1,1,1,1},{a,-b,-c,d}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"C4\"]={4,2,{{1,2,3,4},{2,3,4,1},{3,4,1,2},{4,1,2,3}},{a+b+c+d,a-b+c-d,(\
a-c)^2+(b-d)^2},{a+b+c+d,a-b+c-d,(a-c)^2+(b-d)^2,ArcTan[a-c,b-d]},{(a+b+2*\
Sqrt[c]*Cos[d])/4,(a-b+2*Sqrt[c]*Sin[d])/4,(a+b-2*Sqrt[c]*Cos[d])/4,(a-b-2*\
Sqrt[c]*Sin[d])/4},{1,4,3,2,1,1,1},{1,1,1,0.},{a,-b,c,-d}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"Qr\"]={4,3,{{1,2,3,4},{2,-1,4,-3},{3,-4,-1,2},{4,3,-2,-1}},{a^2+b^2+c^\
2+d^2},
{a^2+b^2+c^2+d^2,ArcTan[a,b],c^2+d^2,ArcTan[c,d]},{Sqrt[a-c]*Cos[b],Sqrt[a-c]*\
Sin[b],Sqrt[c]*Cos[d],Sqrt[c]*Sin[d]},{1,-2,-3,-4,2},{1,0.,1,0.},{a,-b,-c,-d}}\
;\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"Dav\"]={4,6,{{1,2,3,4},{2,-1,4,-3},{3,4,-1,-2},{4,-3,-2,1}},{(b+c)^2+(\
a-d)^2,(b-c)^2+(a+d)^2},{(b+c)^2+(a-d)^2,ArcTan[a-d,b+c],(b-c)^2+(a+d)^2,\
ArcTan[a+d,b-c]},{(Sqrt[a]*Cos[b]+Sqrt[c]*Cos[d])/2,(Sqrt[a]*Sin[b]+Sqrt[c]*\
Sin[d])/2,(Sqrt[a]*Sin[b]-Sqrt[c]*Sin[d])/2,(-(Sqrt[a]*Cos[b])+Sqrt[c]*Cos[d])\
/2},{1,-2,-3,4,1,1},{1,0.,1,0.},{a,-b,-c,d}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"P4\"]={4,8,{{1,2,3,4},{2,1,-4*I,3*I},{3,4*I,1,-2*I},{4,-3*I,2*I,1}},{a^\
2-b^2-c^2-d^2},{Sqrt[(b-c)^2+(c-d)^2+(-b+d)^2]/Sqrt[2],ArcTan[(Sqrt[2]*a)/\
Sqrt[(b-c)^2+(c-d)^2+(-b+d)^2]],(b+c+d)/3,If[c==d,0,ArcTan[2*b-c-d,(-Sqrt[3])*\
(c-d)]]},{a*Tan[b],c+(2*a*Cos[d])/3,c+(2*a*Cos[d+(2*Pi)/3])/3,c+(2*a*Cos[d+(4*\
Pi)/3])/3},{1,2,3,4,2},{1,0.,1,0.},{a,-b,-c,-d}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"P16c\"]={4,13,{{1,2,3,4},{2,-1,-4*I,-3*I},{3,4*I,-1,2*I},{4,3*I,-2*I,1}\
},{a^2+b^2+c^2-d^2},{a^2+b^2,If[b!=0,ArcTan[a,b],0],c^2-d^2,If[d!=0,arcTanh[c,\
d],0]},{Sqrt[a]*Cos[b],Sqrt[a]*Sin[b],Sqrt[c]*Cosh[d],Sqrt[c]*Sinh[d]},{1,-2,-\
3,4,2},{1,0.,1,0.},{a,-b,-c,-d}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"O2\"]={4,5,{{1,2,3,4},{2,-1,4,-3},{3,4,1,2},{4,-3,2,-1}},{(a-c)^2+(b-d)\
^2,(a+c)^2+(b+d)^2},{(a-c)^2+(b-d)^2,ArcTan[a-c,b-d],(a+c)^2+(b+d)^2,ArcTan[a+\
c,b+d]},{(Sqrt[a]*Cos[b]+Sqrt[c]*Cos[d])/2,(Sqrt[a]*Sin[b]+Sqrt[c]*Sin[d])/2,(\
-(Sqrt[a]*Cos[b])+Sqrt[c]*Cos[d])/2,(-(Sqrt[a]*Sin[b])+Sqrt[c]*Sin[d])/2},{1,-\
2,3,-4,1,1},{1,0.,1,0.},{a,-b,-c,-d}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"CL2\"]={4,7,{{1,2,3,4},{2,1,4,3},{3,-4,-1,2},{4,-3,-2,1}},{a^2-b^2+c^2-\
d^2},{a^2-b^2+c^2-d^2,ArcTan[a,c],b^2+d^2,ArcTan[b,d]},{Sqrt[a+c]*Cos[b],Sqrt[\
c]*Cos[d],Sqrt[a+c]*Sin[b],Sqrt[c]*Sin[d]},{1,2,-3,4,2},{1,0.,1,0.},{a,-b,-c,-\
d}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"C4C2r\"]={4,9,{{1,2,3,4},{2,3,-4,-1},{3,-4,1,-2},{4,-1,-2,3}},{a+b+c-d,\
a-b+c+d,(a-c)^2+(b+d)^2},{a+b+c-d,a-b+c+d,(a-c)^2+(b+d)^2,ArcTan[a-c,b+d]},{(\
a+b+2*Sqrt[c]*Cos[d])/4,(a-b+2*Sqrt[c]*Sin[d])/4,(a+b-2*Sqrt[c]*Cos[d])/4,(-a+\
b+2*Sqrt[c]*Sin[d])/4},{1,-4,3,-2,1,1,1},{1,1,1,0.},{a,-b,c,-d}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"C3C4j\"]={4,10,
{{1,2,3,4},{2,-3,4,-1},{3,4,1,2},{4,-1,2,-3}},{a+b-c-d,a-b-c+d,(a+c)^2+(b+d)^\
2},{a+b-c-d,a-b-c+d,(a+c)^2+(b+d)^2,ArcTan[a+c,b+d]},{(a+b+2*Sqrt[c]*Cos[d])/\
4,(a-b+2*Sqrt[c]*Sin[d])/4,(-a-b+2*Sqrt[c]*Cos[d])/4,(-a+b+2*Sqrt[c]*Sin[d])/\
4},{1,-4,3,-2,1,1,1},{1,1,1,0.},{a,-b,c,-d}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"C8c\"]={4,11,{{1,2,3,4},{2,3,4,-1},{3,4,-1,-2},{4,-1,-2,-3}},{a^2+b^2+\
c^2+d^2+Sqrt[2]*(a*b+b*c-a*d+c*d),a^2+b^2+c^2+d^2-Sqrt[2]*(a*b+b*c-a*d+c*d)},,\
,{1,-4,-3,-2,1,1},{11,1,0.},{a,-b,c,-d}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"C5\"]={5,1,{{1,2,3,4,5},{2,3,4,5,1},{3,4,5,1,2},{4,5,1,2,3},{5,1,2,3,4}\
},{a+b+c+d+e,(-(5/4))*(a*b-a*c+b*c-a*d-b*d+c*d+a*e-b*e-c*e+d*e)^2+(1/16)*((a-\
b)^2+(a-c)^2+(b-c)^2+(b-d)^2+(c-d)^2+(-a+d)^2+(c-e)^2+(d-e)^2+(-a+e)^2+(-b+e)^\
2)^2},,{a+b*Sin[c],a+b*Sin[c+2\[Pi]/5],a+b*Sin[c+4\[Pi]/5],a+b*
Sin[c+6\[Pi]/5],a+b*Sin[c+8\[Pi]/5]}/5 ,{1,5,4,3,2,1,1},,};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"D3\"]={6,1,{{1,2,3,4,5,6},{2,1,6,5,4,3},{3,4,5,6,1,2},{4,3,2,1,6,5},{5,\
6,1,2,3,4},{6,5,4,3,2,1}},{a+b+c+d+e+f,a-b+c-d+e-f,((a-c)^2-(b-d)^2+(c-e)^2+(-\
a+e)^2-(d-f)^2-(-b+f)^2)/2},{a+b+c+d+e+f,a-b+c-d+e-f,((a-c)^2+(c-e)^2+(-a+e)^\
2-(b-d)^2-(d-f)^2-(-b+f)^2)/2,ArcTan[2*a-c-e,Sqrt[3]*(-c+e)],((a-c)^2+(c-e)^2+\
(-a+e)^2)/2,ArcTan[2*b-d-f,Sqrt[3]*(-d+f)]},{(a+b+4*Sqrt[e]*Cos[d])/6,(a-b+4*\
Sqrt[-c+e]*Cos[f])/6,(a+b+4*Sqrt[e]*Cos[d+(2*Pi)/3])/6,(a-b+4*Sqrt[-c+e]*Cos[\
f+(2*Pi)/3])/6,(a+b+4*Sqrt[e]*Cos[d-(2*Pi)/3])/6,(a-b+4*Sqrt[-c+e]*Cos[f-(2*\
Pi)/3])/6},{1,2,5,4,3,6,1,1,2},{1,1,1,0.,1,0.},,{(a+c+e)^2-(b+d+f)^2,arcTanh[\
a+c+e,b+d+e],((a-c)^2+(c-e)^2+(-a+e)^2)/2,ArcTan[2*a-c-e,Sqrt[3]*(e-c)],((b-d)\
^2+(d-f)^2+(-b+f)^2)/2,ArcTan[2*a-c-e,Sqrt[3]*(c-e)]+ArcTan[2*b-d-f,Sqrt[3]*(\
f-d)]},{2*Sqrt[c]*Cos[d]+Sqrt[a]*Cosh[b],2*Sqrt[e]*Cos[d+f]+Sqrt[a]*Sinh[b],2*\
Sqrt[c]*Cos[d+2*Pi/3]+Sqrt[a]*Cosh[b],2*Sqrt[e]*Cos[d+f+2*Pi/3]+Sqrt[a]*Sinh[\
b],2*Sqrt[c]*Cos[d-2*Pi/3]+Sqrt[a]*Cosh[b],2*Sqrt[e]*Cos[d+f-2*Pi/3]+Sqrt[a]*\
Sinh[b]}/3};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"C3C2\"]={6,2,{{1,2,3,4,5,6},{2,3,1,5,6,4},{3,1,2,6,4,5},{4,5,6,1,2,3},{\
5,6,4,2,3,1},{6,4,5,3,1,2}},{a+b+c+d+e+f,a+b+c-d-e-f,((a-b+d-e)^2+(a-c+d-f)^2+\
(b-c+e-f)^2)/2,((a-b-d+e)^2+(a-c-d+f)^2+(b-c-e+f)^2)/2},{a+b+c+d+e+f,a+b+c-d-\
e-f,((a-b+d-e)^2+(b-c+e-f)^2+(-a+c-d+f)^2)/2,ArcTan[2*a-b-c+2*d-e-f,Sqrt[3]*(-\
b+c-e+f)],((a-b-d+e)^2+(-a+c+d-f)^2+(b-c-e+f)^2)/2,ArcTan[2*a-b-c-2*d+e+f,\
Sqrt[3]*(-b+c+e-f)]},{(a+b+2*Sqrt[c]*Cos[d]+2*Sqrt[e]*Cos[f])/6,(a+b+2*Sqrt[c]\
*Cos[d+(2*Pi)/3]+2*Sqrt[e]*Cos[f+(2*Pi)/3])/6,(a+b+2*Sqrt[c]*Cos[d-(2*Pi)/3]+\
2*Sqrt[e]*Cos[f-(2*Pi)/3])/6,(a-b+2*Sqrt[c]*Cos[d]-2*Sqrt[e]*Cos[f])/6,(a-b+2*\
Sqrt[c]*Cos[d+(2*Pi)/3]-2*Sqrt[e]*Cos[f+(2*Pi)/3])/6,(a-b+2*Sqrt[c]*Cos[d-(2*\
Pi)/3]-2*Sqrt[e]*Cos[f-(2*Pi)/3])/6},{1,3,2,4,6,5,1,1,1,1},{1,1,1,0.,1,0.},{a,\
c,b,d,f,e}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"Q12c\"]={6,3,{{1,2,3,4,5,6},{2,3,1,6,4,5},{3,1,2,5,6,4},{4,5,6,-1,-2,-\
3},
{5,6,4,-3,-1,-2},{6,4,5,-2,-3,-1}},{(a+b+c)^2+(d+e+f)^2,
((a-b)^2+(a-c)^2+(b-c)^2+(d-e)^2+(d-f)^2+(e-f)^2)/2},
{(a+b+c)^2+(d+e+f)^2,ArcTan[a+b+c,d+e+f],
((a-b)^2+(b-c)^2+(-a+c)^2)/2+((d-e)^2+(e-f)^2+(-d+f)^2)/2,
If[c==b,0,ArcTan[2*a-b-c,Sqrt[3]*(c-b)]],((d-e)^2+(e-f)^2+(-d+f)^2)/2,
If[e==f,0,ArcTan[2*d-e-f,Sqrt[3]*(f-e)]]},
{(Sqrt[a]*Cos[b])/3+(2*Sqrt[c-e]*Cos[d])/3,(Sqrt[a]*Cos[b])/3+
(2*Sqrt[c-e]*Cos[d+(2*Pi)/3])/3,(Sqrt[a]*Cos[b])/3+(2*Sqrt[c-e]*Cos[d-(2*Pi)/\
3])/3,
(2*Sqrt[e]*Cos[f])/3+(Sqrt[a]*Sin[b])/3,(2*Sqrt[e]*Cos[f+(2*Pi)/3])/3+(Sqrt[a]\
*Sin[b])/3,
(2*Sqrt[e]*Cos[f-(2*Pi)/3])/3+(Sqrt[a]*Sin[b])/3},{1,3,2,-4,-5,-6,1,2},
{1,2,1,0.,1,0.},{a,c,b,-d,-e,-f}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"Q12r\"]={6,4,{{1,2,3,4,5,6},{2,-1,4,-3,6,-5},{3,-6,5,2,-1,4},{4,5,6,-1,\
-2,-3},{5,-4,-1,-6,-3,2},{6,3,-2,5,-4,-1}},{(a-c+e)^2+(b-d+f)^2,((a+c)^2+(b+d)\
^2+(a-e)^2+(c+e)^2+(b-f)^2+(d+f)^2)/2},{(a-c+e)^2+(b-d+f)^2,If[b+f==d,0,\
ArcTan[a-c+e,b-d+f]],((a+c)^2+(a-e)^2+(c+e)^2)/2+((b+d)^2+(b-f)^2+(d+f)^2)/2,\
If[c==-e,0,ArcTan[2*a+c-e,Sqrt[3]*(c+e)]],((b+d)^2+(b-f)^2+(d+f)^2)/2,If[d==-\
f,0,ArcTan[2*b+d-f,Sqrt[3]*(d+f)]]},{(Sqrt[a]*Cos[b])/3+(2*Sqrt[c-e]*Cos[d])/\
3,(2*Sqrt[e]*Cos[f])/3+(Sqrt[a]*Sin[b])/3,-(Sqrt[a]*Cos[b])/3-(2*Sqrt[c-e]*\
Cos[d+(2*Pi)/3])/3,(-2*Sqrt[e]*Cos[f+(2*Pi)/3])/3-(Sqrt[a]*Sin[b])/3,(Sqrt[a]*\
Cos[b])/3+(2*Sqrt[c-e]*Cos[d-(2*Pi)/3])/3,(2*Sqrt[e]*Cos[f-(2*Pi)/3])/3+(Sqrt[\
a]*Sin[b])/3},{1,-2,-5,-4,-3,-6,1,2},{1,2,1,0.,1,0.},};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"D6r\"]={6,5,{{1,2,3,4,5,6},{2,1,4,3,6,5},{3,-6,5,2, \
-1,4},{4,-5,6,1,-2,3},{5,-4,-1,-6,-3,2},{6,-3,-2,-5,-4,1}},{a-b-c+d+e-f,a+b-c-\
d+e+f,(1/2)*((a+c)^2-(b+d)^2+(a-e)^2+(c+e)^2-(b-f)^2-(d+f)^2)},,,{1,2,-5,4,-3,\
6,1,1,2},{1, 1,1,0.,1,0.},};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True,
  FontFamily->"Courier New"],

Cell["\<\
Hoop[\"KC3c\"]={6,6,{{1,2,3,4,5,6},{2,3,-1,5,6,-4},{3,-1,-2,6,-4,-5},{4,5,6,1,\
2,3},{5,6,-4,2,3,-1},{6,-4,-5,3,-1,-2}},{a-b+c-d+e-f,a-b+c+d-e+f,((a+b-d-e)^2+\
(b+c-e-f)^2+(a-c-d+f)^2)/2,((a+b+d+e)^2+(a-c+d-f)^2+(b+c+e+f)^2)/2},,,{1,-3,-\
2,4,-6,-5,1,1,1,1},{1,1,1,0.,1,0.},{a,b,c,-d,-e,-f}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"C3Kr\"]={6,7,{{1,2,3,4,5,6},{2,-3,1,5,-6,4},{3,1,-2,6,4,-5},{4,5,6,1,2,\
3},
{5,-6,4,2,-3,1},{6,4,-5,3,1,-2}},{a-b-c-d+e+f,a-b-c+d-e-f,
((a+b-d-e)^2+(a+c-d-f)^2+(b-c-e+f)^2)/2,
((a+b+d+e)^2+(b-c+e-f)^2+(a+c+d+f)^2)/2},,,{1,3,2,4,6,5,1,1,1,1},{1,1,1,0.,1,\
0.},
{a,c,b,-d,-e,-f}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"C3C4c\"]:=(*10/1/6*){6,8,
{{1,2,3,4,5,6},{2,3,1,5,6,4},{3,1,2,6,4,5},{4,5,6,-1,-2,-3},{5,6,4,-2,-3,-1},{\
6,4,5,-3,-1,-2}},
{(a+b+c)^2+(d+e+f)^2,        \
3*((a-b+(d+e-2*f)/Sqrt[3])^2+((a+b-2*c)/Sqrt[3]-d+e)^2)/4,        \
3*((a-b-(d+e-2*f)/Sqrt[3])^2+((a+b-2*c)/Sqrt[3]+d-e)^2)/            \
4(*,((a-b)^2+(b-c)^2+(c-a)^2+(d-e)^2+(e-f)^2+(f-d)^2)^2/
4-3*(c*(d-e)+a*(e-f)+b*(f-d))^2*)},
{(a+b+c)^2+(d+e+f)^2,
If[d+e+f\[Equal]0,If[a+b+c<0,Pi,0],ArcTan[a+b+c,d+e+f]],        \
3*((a-b+(d+e-2*f)/Sqrt[3])^2+((a+b-2*c)/Sqrt[3]-d+e)^2)/4,
If[(a+b-2*c)/Sqrt[3]-d+e\[Equal]0,If[a-b+(d+e-2*f)/Sqrt[3]<0,Pi,0],           \
 ArcTan[a-b+(d+e-2*f)/Sqrt[3],(a+b-2*c)/Sqrt[3]-d+e]]-Pi/6,        \
3*((a-b-(d+e-2*f)/Sqrt[3])^2+((a+b-2*c)/Sqrt[3]+d-e)^2)/4,
If[(a+b-2*c)/Sqrt[3]+d-e\[Equal]0,
If[a-b-(d+e-2*f)/Sqrt[3]<0,Pi,0],            \
ArcTan[a-b-(d+e-2*f)/Sqrt[3],(a+b-2*c)/Sqrt[3]+d-e]]-Pi/6},      \
{Sqrt[a/9]*Cos[b]+Sqrt[c/12]*Cos[d+Pi/6]+Sqrt[c/36]*Sin[d+Pi/6]+Sqrt[e/12]*\
Cos[f+Pi/6]+Sqrt[e/36]*Sin[f+Pi/6],        \
Sqrt[a/9]*Cos[b]-Sqrt[c/12]*Cos[d+Pi/6]+Sqrt[c/36]*Sin[d+Pi/6]-Sqrt[e/12]*Cos[\
f+Pi/6]+Sqrt[e/36]*Sin[f+Pi/6],        \
Sqrt[a/9]*Cos[b]-Sqrt[c/9]*Sin[d+Pi/6]-Sqrt[e/9]*Sin[f+Pi/6],        \
Sqrt[a/9]*Sin[b]+Sqrt[c/36]*Cos[d+Pi/6]-Sqrt[c/12]*Sin[d+Pi/6]-Sqrt[e/36]*Cos[\
f+Pi/6]+Sqrt[e/12]*Sin[f+Pi/6],        \
Sqrt[a/9]*Sin[b]+Sqrt[c/36]*Cos[d+Pi/6]+Sqrt[c/12]*Sin[d+Pi/6]-Sqrt[e/36]*Cos[\
f+Pi/6]-Sqrt[e/12]*Sin[f+Pi/6],        \
Sqrt[a/9]*Sin[b]-Sqrt[c/9]*Cos[d+Pi/6]+Sqrt[e/9]*Cos[f+Pi/6]},
{1,3,2,-4,-6,-5,1,1,1,0},{1,0.,1,0.,1,0.},{a,b,c,-d,-e,-f}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True,
  LineSpacing->{1, 0},
  FontWeight->"Bold"],

Cell[BoxData[
    \(\(Hoop["\<C3C4c\>"] :=  (*\(10/1\)/6*) \[IndentingNewLine]{6, 
          8, {{1, 2, 3, 4, 5, 6}, {2, 3, 1, 5, 6, 4}, {3, 1, 2, 6, 4, 5}, {4, 
              5, 6, \(-1\), \(-2\), \(-3\)}, {5, 6, 
              4, \(-2\), \(-3\), \(-1\)}, {6, 4, 
              5, \(-3\), \(-1\), \(-2\)}}, \[IndentingNewLine]{\((a + b + 
                    c)\)^2 + \((d + e + f)\)^2, 
            3*\((\((a - b + \((d + e - 2*f)\)/
                            Sqrt[3])\)^2 + \((\((a + b - 2*c)\)/Sqrt[3] - d + 
                          e)\)^2)\)/4, 
            3*\((\((a - b - \((d + e - 2*f)\)/
                            Sqrt[3])\)^2 + \((\((a + b - 2*c)\)/Sqrt[3] + d - 
                          e)\)^2)\)/
                4 (*\(,\)\(\((\((a - b)\)^2 + \((b - c)\)^2 + \((c - 
                              a)\)^2 + \((d - e)\)^2 + \((e - f)\)^2 + \((f - 
                              d)\)^2)\)^2/4 - 
                3*\((c*\((d - e)\) + a*\((e - f)\) + 
                        b*\((f - d)\))\)^2\)*) }, {\((a + b + c)\)^2 + \((d + 
                    e + f)\)^2, 
            If[d + e + f \[Equal] 0, If[a + b + c < 0, Pi, 0], 
              ArcTan[a + b + c, d + e + f]], 
            3*\((\((a - b + \((d + e - 2*f)\)/
                            Sqrt[3])\)^2 + \((\((a + b - 2*c)\)/Sqrt[3] - d + 
                          e)\)^2)\)/4, 
            If[\((a + b - 2*c)\)/Sqrt[3] - d + e \[Equal] 0, 
                If[a - b + \((d + e - 2*f)\)/Sqrt[3] < 0, Pi, 0], 
                ArcTan[a - 
                    b + \((d + e - 2*f)\)/Sqrt[3], \((a + b - 2*c)\)/
                      Sqrt[3] - d + e]] - Pi/6, 
            3*\((\((a - b - \((d + e - 2*f)\)/
                            Sqrt[3])\)^2 + \((\((a + b - 2*c)\)/Sqrt[3] + d - 
                          e)\)^2)\)/4, 
            If[\((a + b - 2*c)\)/Sqrt[3] + d - e \[Equal] 0, 
                If[a - b - \((d + e - 2*f)\)/Sqrt[3] < 0, Pi, 0], 
                ArcTan[a - 
                    b - \((d + e - 2*f)\)/Sqrt[3], \((a + b - 2*c)\)/
                      Sqrt[3] + d - e]] - 
              Pi/6}, \[IndentingNewLine]{Sqrt[a/9]*Cos[b] + 
              Sqrt[c/12]*Cos[d + Pi/6] + Sqrt[c/36]*Sin[d + Pi/6] + 
              Sqrt[e/12]*Cos[f + Pi/6] + 
              Sqrt[e/36]*Sin[f + Pi/6], \[IndentingNewLine]Sqrt[a/9]*Cos[b] - 
              Sqrt[c/12]*Cos[d + Pi/6] + Sqrt[c/36]*Sin[d + Pi/6] - 
              Sqrt[e/12]*Cos[f + Pi/6] + 
              Sqrt[e/36]*Sin[f + Pi/6], \[IndentingNewLine]Sqrt[a/9]*Cos[b] - 
              Sqrt[c/9]*Sin[d + Pi/6] - 
              Sqrt[e/9]*Sin[f + Pi/6], \[IndentingNewLine]Sqrt[a/9]*Sin[b] + 
              Sqrt[c/36]*Cos[d + Pi/6] - Sqrt[c/12]*Sin[d + Pi/6] - 
              Sqrt[e/36]*Cos[f + Pi/6] + 
              Sqrt[e/12]*Sin[f + Pi/6], \[IndentingNewLine]Sqrt[a/9]*Sin[b] + 
              Sqrt[c/36]*Cos[d + Pi/6] + Sqrt[c/12]*Sin[d + Pi/6] - 
              Sqrt[e/36]*Cos[f + Pi/6] - 
              Sqrt[e/12]*Sin[f + Pi/6], \[IndentingNewLine]Sqrt[a/9]*Sin[b] - 
              Sqrt[c/9]*Cos[d + Pi/6] + 
              Sqrt[e/9]*Cos[f + Pi/6]}, \[IndentingNewLine]{1, 3, 
            2, \(-4\), \(-6\), \(-5\), 1, 1, 1, 0}, {1, 0. , 1, 0. , 1, 
            0. }, {a, b, c, \(-d\), \(-e\), \(-f\)}};\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True,
  LineSpacing->{1, 0},
  FontWeight->"Bold"],

Cell["\<\
Hoop[\"D3C2c\"]={6,9,{{1,2,3,4,5,6},{2,3,1,5,-6,-4},{3,1,2,-6,4,-5},{4,-6,5,1,\
3,-2},{5,4,-6,2,1,-3},{6,-5,-4,-3,-2,1}},{a+b+c+d+e-f,a+b+c-d-e+f,((a-b)^2+(a-\
c)^2+(b-c)^2-(d-e)^2-(d+f)^2-(e+f)^2)/2},,,{1,3,2,4,5,6,1,1,2},{1,1,1,0.,1,0.}\
,{a,c,b,-d,-e,-f}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"Clm3r\"]={6,10,{{1,2,3,4,5,6},{2,-3,1,5,-6,4},{3,1,-2,6,4,-5},{4,5,6,-\
1,-2,-3},{5,-6,4,-2,3,-1},{6,4,-5,-3,-1,2}},{(a-b-c)^2+(d-e-f)^2,-3*(-b*d+c*d+\
a*e+c*e-a*f-b*f)^2+((a+b)^2+(b-c)^2+(a+c)^2+(d+e)^2+(e-f)^2+(d+f)^2)^2/4},,,{\
1,3,2,-4,-6,-5,1,1},{1,1,1,0.,1,0.},{a,b,c,-d,-e,-f}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"Cl3r\"]={6,11,{{1,2,3,4,5,6},{2,3,-1,5,6,-4},{3,-1,-2,6,-4,-5},{4,5,6,-\
1,-2,-3},{5,6,-4,-2,-3,1},{6,-4,-5,-3,1,2}},{(a-b+c)^2+(d-e+f)^2,-3*(-b*d-c*d+\
a*e-c*e+a*f+b*f)^2+((a+b)^2+(a-c)^2+(b+c)^2+(d+e)^2+(-d+f)^2+(e+f)^2)^2/4},,,{\
1,-3,-2,-4,6,5,1,1},{1,1,1,0.,1,0.},{a,b,c,-d,-e,-f}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"g2401c\"]={6,12,
{{1,2,3,4,5,6},{2,3,1,6,4,5},{3,1,2,5,6,4},{4,5,6,I,2*I,3*I},{5,6,4,3*I,I,2*I}\
,{6,4,5,2*I,3*I,I}},{((a-b)^2+(a-c)^2+(b-c)^2-I*((d-e)^2+(d-f)^2+(e-f)^2))/2,(\
a+b+c)^2-I*(d+e+f)^2},,,{1,3,2,-4*I,-5*I,-6*I,2,1},{1,1,1,0.,1,0.},{a,c,b,-d,-\
e,-f}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"C8\"]={8,1,{{1,2,3,4,5,6,7,8},{2,3,4,5,6,7,8,1},{3,4,5,6,7,8,1,2},
{4,5,6,7,8,1,2,3},{5,6,7,8,1,2,3,4},{6,7,8,1,2,3,4,5},
{7,8,1,2,3,4,5,6},{8,1,2,3,4,5,6,7}},{a-b+c-d+e-f+g-h,
a+b+c+d+e+f+g+h,(a-c+e-g)^2+(b-d+f-h)^2,
((a-e)^2+(c-g)^2)^2+4*((-b+f)*(c-g)+(a-e)*(d-h))*
((a-e)*(b-f)+(c-g)*(d-h))+((b-f)^2+(d-h)^2)^2},,,
{1,8,7,6,5,4,3,2,1,1,1,1},{1,1,1,1,0.,1,0.},{a,-b,c,-d,e,-f,g,-h}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"C4C2\"]={8,2,{{1,2,3,4,5,6,7,8},{2,3,4,1,6,7,8,5},{3,4,1,2,7,8,5,6},
{4,1,2,3,8,5,6,7},{5,6,7,8,1,2,3,4},{6,7,8,5,2,3,4,1},
{7,8,5,6,3,4,1,2},{8,5,6,7,4,1,2,3}},{a+b+c+d-e-f-g-h,
a-b+c-d+e-f+g-h,a-b+c-d-e+f-g+h,a+b+c+d+e+f+g+h,
(a-c-e+g)^2+(b-d-f+h)^2,(a-c+e-g)^2+(b-d+f-h)^2},
{a+b+c+d+e+f+g+h,a-b+c-d+e-f+g-h,a+b+c+d-e-f-g-h,
a-b+c-d-e+f-g+h,(a-c-e+g)^2+(b-d-f+h)^2,
ArcTan[a-c-e+g,b-d-f+h],(a-c+e-g)^2+(b-d+f-h)^2,
ArcTan[a-c+e-g,b-d+f-h]},{(a+b+c+d+2*Sqrt[e]*Cos[f]+2*Sqrt[g]*Cos[h])/8,
(a-b+c-d+2*Sqrt[e]*Sin[f]+2*Sqrt[g]*Sin[h])/8,
(a+b+c+d-2*Sqrt[e]*Cos[f]-2*Sqrt[g]*Cos[h])/8,
(a-b+c-d-2*Sqrt[e]*Sin[f]-2*Sqrt[g]*Sin[h])/8,
(a+b-c-d-2*Sqrt[e]*Cos[f]+2*Sqrt[g]*Cos[h])/8,
(a-b-c+d-2*Sqrt[e]*Sin[f]+2*Sqrt[g]*Sin[h])/8,
(a+b-c-d+2*Sqrt[e]*Cos[f]-2*Sqrt[g]*Cos[h])/8,
(a-b-c+d+2*Sqrt[e]*Sin[f]-2*Sqrt[g]*Sin[h])/8},
{1,4,3,2,5,8,7,6,1,1,1,1,1,1},{1,1,1,1,1,0.,1,0.},
{a,-b,c,-d,e,-f,g,-h}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"D4\"]={8,3,{{1,2,3,4,5,6,7,8},{2,1,8,7,6,5,4,3},{3,4,5,6,7,8,1,2},
{4,3,2,1,8,7,6,5},{5,6,7,8,1,2,3,4},{6,5,4,3,2,1,8,7},
{7,8,1,2,3,4,5,6},{8,7,6,5,4,3,2,1}},{a+b-c-d+e+f-g-h,
a-b+c-d+e-f+g-h,a-b-c+d+e-f-g+h,a+b+c+d+e+f+g+h,
(a-e)^2-(b-f)^2+(c-g)^2-(d-h)^2},{a+b+c+d+e+f+g+h,
a+b-c-d+e+f-g-h,a-b+c-d+e-f+g-h,a-b-c+d+e-f-g+h,
(a-e)^2-(b-f)^2+(c-g)^2-(d-h)^2,ArcTan[a-e,c-g],(b-f)^2+(d-h)^2,ArcTan[b-f,d-\
h]},{(a+b+c+d+4*Sqrt[e+g]*Cos[f]),
(a+b-c-d+4*Sqrt[g]*Cos[h]),(a-b+c-d+4*Sqrt[e+g]*Sin[f]),
(a-b-c+d+4*Sqrt[g]*Sin[h]),(a+b+c+d-4*Sqrt[e+g]*Cos[f]),
(a+b-c-d-4*Sqrt[g]*Cos[h]),(a-b+c-d-4*Sqrt[e+g]*Sin[f]),
(a-b-c+d-4*Sqrt[g]*Sin[h])}/8,{1,2,7,4,5,6,3,8,1,1,1,1,2},{1,1,1,1,1,0.,1,0.},\
};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"Q8\"]={8,4,{{1,2,3,4,5,6,7,8},{2,5,8,3,6,1,4,7},{3,4,5,6,7,8,1,2},
{4,7,2,5,8,3,6,1},{5,6,7,8,1,2,3,4},{6,1,4,7,2,5,8,3},
{7,8,1,2,3,4,5,6},{8,3,6,1,4,7,2,5}},{a+b-c-d+e+f-g-h,
a-b+c-d+e-f+g-h,a-b-c+d+e-f-g+h,a+b+c+d+e+f+g+h,
(a-e)^2+(b-f)^2+(c-g)^2+(d-h)^2},{a+b+c+d+e+f+g+h,
a-b+c-d+e-f+g-h,a-b-c+d+e-f-g+h,a+b-c-d+e+f-g-h,
(a-e)^2+(b-f)^2,ArcTan[a-e,b-f],(c-g)^2+(d-h)^2,ArcTan[c-g,d-h]},
{(a+b+c+d+4*Sqrt[e]*Cos[f]),(a-b-c+d+4*Sqrt[e]*Sin[f]),
(a+b-c-d+4*Sqrt[g]*Cos[h]),(a-b+c-d+4*Sqrt[g]*Sin[h]),
(a+b+c+d-4*Sqrt[e]*Cos[f]),(a-b-c+d-4*Sqrt[e]*Sin[f]),
(a+b-c-d-4*Sqrt[g]*Cos[h]),(a-b+c-d-4*Sqrt[g]*Sin[h])}/8,{1,6,7,8,5,2,3,4,1,1,\
1,1,2},{1,1,1,1,1,0.,1,0.},{a,-b,-c,-d,e,-f,-g,-h}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"KC2\"]={8,5,{{1,2,3,4,5,6,7,8},{2,1,4,3,6,5,8,7},{3,4,1,2,7,8,5,6},
{4,3,2,1,8,7,6,5},{5,6,7,8,1,2,3,4},{6,5,8,7,2,1,4,3},
{7,8,5,6,3,4,1,2},{8,7,6,5,4,3,2,1}},{a+b+c+d-e-f-g-h,
a+b-c-d+e+f-g-h,a-b+c-d+e-f+g-h,a-b-c+d-e+f+g-h,
a-b-c+d+e-f-g+h,a-b+c-d-e+f-g+h,a+b-c-d-e-f+g+h,
a+b+c+d+e+f+g+h},{a+b+c+d-e-f-g-h,a+b-c-d+e+f-g-h,
a-b+c-d+e-f+g-h,a-b-c+d-e+f+g-h,a-b-c+d+e-f-g+h,
a-b+c-d-e+f-g+h,a+b-c-d-e-f+g+h,a+b+c+d+e+f+g+h},
{(a+b+c+d+e+f+g+h)/8,(a+b-c-d-e-f+g+h)/8,
(a-b+c-d-e+f-g+h)/8,(a-b-c+d+e-f-g+h)/8,
(-a+b+c-d+e-f-g+h)/8,(-a+b-c+d-e+f-g+h)/8,
(-a-b+c+d-e-f+g+h)/8,(-a-b-c-d+e+f+g+h)/8},
{1,2,3,4,5,6,7,8,1,1,1,1,1,1,1,1},{1,1,1,1,1,1,1,1},
{a,b,c,d,-e,-f,-g,-h}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"C4C4c\"]={8,8,{{1,2,3,4,5,6,7,8},{2,3,4,1,6,7,8,5},{3,4,1,2,7,8,5,6},{\
4,1,2,3,8,5,6,7},{5,6,7,8,-1,-2,-3,-4},{6,7,8,5,-2,-3,-4,-1},{7,8,5,6,-3,-4,-\
1,-2},{8,5,6,7,-4,-1,-2,-3}},{(b-d+e-g)^2+(a-c-f+h)^2,(b-d-e+g)^2+(a-c+f-h)^2,\
(a-b+c-d)^2+(e-f+g-h)^2,(a+b+c+d)^2+(e+f+g+h)^2},
{(b-d+e-g)^2+(a-c-f+h)^2,Which[b-d+e-g==0,0,aa$66==0,(Pi/2)*Sign[bb$66],True,\
ArcTan[aa$66,bb$66]],(b-d-e+g)^2+(a-c+f-h)^2,Which[b-d-e+g==0,0,aa$66==0,(Pi/\
2)*Sign[bb$66],True,ArcTan[aa$66,bb$66]],(a-b+c-d)^2+(e-f+g-h)^2,Which[e-f+g-\
h==0,0,aa$66==0,(Pi/2)*Sign[bb$66],True,ArcTan[aa$66,bb$66]],(a+b+c+d)^2+(e+f+\
g+h)^2,Which[e+f+g+h==0,0,aa$66==0,(Pi/2)*Sign[bb$66],True,ArcTan[aa$66,bb$66]\
]},
{(Sqrt[a]*Cos[b]+Sqrt[c]*Cos[d]+Sqrt[e]*Cos[f]+Sqrt[g]*Cos[h]),(-(Sqrt[e]*Cos[\
f])+Sqrt[g]*Cos[h]+Sqrt[a]*Sin[b]+Sqrt[c]*Sin[d]),(-(Sqrt[a]*Cos[b])-Sqrt[c]*\
Cos[d]+Sqrt[e]*Cos[f]+Sqrt[g]*Cos[h]),(-(Sqrt[e]*Cos[f])+Sqrt[g]*Cos[h]-Sqrt[\
a]*Sin[b]-Sqrt[c]*Sin[d]),(Sqrt[a]*Sin[b]-Sqrt[c]*Sin[d]+Sqrt[e]*Sin[f]+Sqrt[\
g]*Sin[h]),(-(Sqrt[a]*Cos[b])+Sqrt[c]*Cos[d]-Sqrt[e]*Sin[f]+Sqrt[g]*Sin[h]),(-\
(Sqrt[a]*Sin[b])+Sqrt[c]*Sin[d]+Sqrt[e]*Sin[f]+Sqrt[g]*Sin[h]),(Sqrt[a]*Cos[b]\
-Sqrt[c]*Cos[d]-Sqrt[e]*Sin[f]+Sqrt[g]*Sin[h])}/4,{1,4,3,2,-5,-8,-7,-6,1,1,1,\
1},{1,0.,1,0.,1,0.,1,0.},{a,-b,c,-d,-e,f,-g,h}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"KiC4c\"]={8,9,{{1,2,3,4,5,6,7,8},{2,1,4,3,8,7,6,5},{3,4,1,2,7,8,5,6},{\
4,3,2,1,6,5,8,7},{5,6,7,8,-1,-2,-3,-4},{6,5,8,7,-4,-3,-2,-1},{7,8,5,6,-3,-4,-\
1,-2},{8,7,6,5,-2,-1,-4,-3}},{(a-b+c-d)^2+(e-f+g-h)^2,(a+b+c+d)^2+(e+f+g+h)^2,\
(a-c)^2-(b-d)^2+(e-g)^2-(f-h)^2},{(a-c)^2-(b-d)^2+(e-g)^2-(f-h)^2,If[e==g,0,\
ArcTan[a-c,e-g]],(b-d)^2+(f-h)^2,If[f==h,0,ArcTan[b-d,f-h]],(a-b+c-d)^2+(e-f+\
g-h)^2,If[e+g==f+h,0,ArcTan[a-b+c-d,e-f+g-h]],(a+b+c+d)^2+(e+f+g+h)^2,If[e+f==\
g+h,0,ArcTan[a+b+c+d,e+f+g+h]]},{(Sqrt[a+c]*Cos[b])/2+(Sqrt[e]*Cos[f])/4+(\
Sqrt[g]*Cos[h])/4,(Sqrt[c]*Cos[d])/2-(Sqrt[e]*Cos[f])/4+(Sqrt[g]*Cos[h])/4,-(\
Sqrt[a+c]*Cos[b])/2+(Sqrt[e]*Cos[f])/4+(Sqrt[g]*Cos[h])/4,
-(Sqrt[c]*Cos[d])/2-(Sqrt[e]*Cos[f])/4+(Sqrt[g]*Cos[h])/4,(Sqrt[a+c]*Sin[b])/\
2+(Sqrt[e]*Sin[f])/4+(Sqrt[g]*Sin[h])/4,(Sqrt[c]*Sin[d])/2-(Sqrt[e]*Sin[f])/4+\
(Sqrt[g]*Sin[h])/4,-(Sqrt[a+c]*Sin[b])/2+(Sqrt[e]*Sin[f])/4+(Sqrt[g]*Sin[h])/\
4,-(Sqrt[c]*Sin[d])/2-(Sqrt[e]*Sin[f])/4+(Sqrt[g]*Sin[h])/4},{1,2,3,4,-5,-8,-\
7,-6,1,1,2},{1,0.,1,0.,1,0,1,0.},{a,b,c,d,-e,-f,-g,-h}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"C4iC4c\"]={8,10,{{1,2,3,4,5,6,7,8},{2,3,4,1,8,5,6,7},{3,4,1,2,7,8,5,6},\
{4,1,2,3,6,7,8,5},{5,6,7,8,-1,-2,-3,-4},{6,7,8,5,-4,-1,-2,-3},{7,8,5,6,-3,-4,-\
1,-2},{8,5,6,7,-2,-3,-4,-1}},{(a-c)^2+(b-d)^2+(e-g)^2+(f-h)^2,(a-b+c-d)^2+(e-\
f+g-h)^2,(a+b+c+d)^2+(e+f+g+h)^2},,,{1,4,3,2,-5,-6,-7,-8,2,1,1},{1,1,2,1,0.,1,\
0.},{a,-b,c,-d,-e,-f,-g,-h}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"QC2r\"]={8,11,{{1,2,3,4,5,6,7,8},{2,1,4,3,6,5,8,7},{3,4,-1,-2,-7,-8,5,\
6},{4,3,-2,-1,-8,-7,6,5},{5,6,7,8,-1,-2,-3,-4},{6,5,8,7,-2,-1,-4,-3},{7,8,-5,-\
6,3,4,-1,-2},{8,7,-6,-5,4,3,-2,-1}},{(a-b)^2+(c-d)^2+(e-f)^2+(g-h)^2,(a+b)^2+(\
c+d)^2+(e+f)^2+(g+h)^2},,,{1,2,-3,-4,-5,-6,-7,-8,2,2},{1,1,1,1,0.,1,0.},{a,b,-\
c,-d,-e,-f,-g,-h}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"Q8C2r\"]={8,12,{{1,2,3,4,5,6,7,8},{2,-5,1,8,-3,-4,6,-7},{3,1,-5,-6,-2,\
7,-8,4},
{4,-6,8,-5,7,-3,-1,2},{5,-3,-2,7,1,8,4,6},{6,7,-4,-2,8,-5,3,-1},
{7,-8,6,-1,4,2,-5,-3},{8,4,-7,3,6,-1,-2,-5}},
{a-b-c-d-e-f+g+h,a+b+c-d-e+f+g-h,a+b+c+d-e-f-g+h,
a-b-c+d-e+f-g-h,(b-c)^2+(a+e)^2+(d+g)^2+(f+h)^2},
{a-b-c-d-e-f+g+h,a+b+c-d-e+f+g-h,a+b+c+d-e-f-g+h,
a-b-c+d-e+f-g-h,(b-c)^2+(a+e)^2,ArcTan[a+e,b-c],(d+g)^2+(f+h)^2,ArcTan[d+g,f+\
h]},{(a+b+c+d+4*Sqrt[e]*Cos[f]),
(-a+b+c-d+4*Sqrt[e]*Sin[f]),(-a+b+c-d-4*Sqrt[e]*Sin[f]),
(-a-b+c+d+4*Sqrt[g]*Cos[h]),(-a-b-c-d+4*Sqrt[e]*Cos[f]),
(-a+b-c+d+4*Sqrt[g]*Sin[h]),(a+b-c-d+4*Sqrt[g]*Cos[h]),
(a-b+c-d+4*Sqrt[g]*Sin[h])}/8,{1,3,2,-7,5,-8,-4,-6,1,1,1,1,2},{1,1,1,1,1,0.,1,\
0.},{a,-b,-c,-d,e,-f,-g,-h}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"O4\"]={8,13,{{1,2,3,4,5,6,7,8},{2,1,4,3,6,5,8,7},{3,4,1,2,7,8,5,6},{4,\
3,2,1,8,7,6,5},{5,6,7,8,-1,-2,-3,-4},{6,5,8,7,-2,-1,-4,-3},{7,8,5,6,-3,-4,-1,-\
2},{8,7,6,5,-4,-3,-2,-1}},{(a-b-c+d)^2+(e-f-g+h)^2,(a-b+c-d)^2+(e-f+g-h)^2,(a+\
b-c-d)^2+(e+f-g-h)^2,(a+b+c+d)^2+(e+f+g+h)^2},
{(a-b-c+d)^2+(e-f-g+h)^2,If[e+h==f+g,0,ArcTan[a-b-c+d,e-f-g+h]],(a-b+c-d)^2+(\
e-f+g-h)^2,If[e+g==f+h,0,ArcTan[a-b+c-d,e-f+g-h]],(a+b-c-d)^2+(e+f-g-h)^2,If[\
e+f==g+h,0,ArcTan[a+b-c-d,e+f-g-h]],(a+b+c+d)^2+(e+f+g+h)^2,If[e+f+g+h==0,0,\
ArcTan[a+b+c+d,e+f+g+h]]},{(Sqrt[a]*Cos[b]+Sqrt[c]*Cos[d]+Sqrt[e]*Cos[f]+Sqrt[\
g]*Cos[h])/4,(-(Sqrt[a]*Cos[b])-Sqrt[c]*Cos[d]+Sqrt[e]*Cos[f]+Sqrt[g]*Cos[h])/\
4,(-(Sqrt[a]*Cos[b])+Sqrt[c]*Cos[d]-Sqrt[e]*Cos[f]+Sqrt[g]*Cos[h])/4,(Sqrt[a]*\
Cos[b]-Sqrt[c]*Cos[d]-Sqrt[e]*Cos[f]+Sqrt[g]*Cos[h])/4,(Sqrt[a]*Sin[b]+Sqrt[c]\
*Sin[d]+Sqrt[e]*Sin[f]+Sqrt[g]*Sin[h])/4,(-(Sqrt[a]*Sin[b])-Sqrt[c]*Sin[d]+\
Sqrt[e]*Sin[f]+Sqrt[g]*Sin[h])/4,(-(Sqrt[a]*Sin[b])+Sqrt[c]*Sin[d]-Sqrt[e]*\
Sin[f]+Sqrt[g]*Sin[h])/4,(Sqrt[a]*Sin[b]-Sqrt[c]*Sin[d]-Sqrt[e]*Sin[f]+Sqrt[g]\
*Sin[h])/4},{1,2,3,4,-5,-6,-7,-8,1,1,1,1},{1,0.,1,0.,1,0.,1,0.},{a,b,c,d,-e,-\
f,-g,-h}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"P8\"]={8,16,{{1,2,3,4,5,6,7,8},{2,1,-4*I,3*I,6,5,-8*I,7*I},{3,4*I,1,-2*\
I,7,8*I,5,-6*I},{4,-3*I,2*I,1,8,-7*I,6*I,5},{5,6,7,8,1,2,3,4},{6,5,-8*I,7*I,2,\
1,-4*I,3*I},{7,8*I,5,-6*I,3,4*I,1,-2*I},{8,-7*I,6*I,5,4,-3*I,2*I,1}},{(a+e)^2-\
(b+f)^2-(c+g)^2-(d+h)^2,(a-e)^2-(b-f)^2-(c-g)^2-(d-h)^2},{(a+e)^2-(b+f)^2,\
arcTanh[a+e,b+f],(c+g)^2+(d+h)^2,ArcTan[c+g,d+h],(a-e)^2-(b-f)^2,arcTanh[a-e,\
b-f],(c-g)^2+(d-h)^2,ArcTan[c-g,d-h]},{(Sqrt[a]*Cosh[b]+Sqrt[e]*Cosh[f])/2,(\
Sqrt[a]*Sinh[b]+Sqrt[e]*Sinh[f])/2,(Sqrt[c]*Cos[d]+Sqrt[g]*Cos[h])/2,(Sqrt[c]*\
Sin[d]+Sqrt[g]*Sin[h])/2,(Sqrt[a]*Cosh[b]-Sqrt[e]*Cosh[f])/2,(Sqrt[a]*Sinh[b]-\
Sqrt[e]*Sinh[f])/2,(Sqrt[c]*Cos[d]-Sqrt[g]*Cos[h])/2,(Sqrt[c]*Sin[d]-Sqrt[g]*\
Sin[h])/2},{1,2,3,4,5,6,7,8,2,2},{1,0.,1,0.,1,0.,1,0.},{a,-b,-c,-d,e,-f,-g,-h}\
};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"C2D4r\"]={8,18,{{1,2,3,4,5,6,7,8},{2,1,4,3,6,5,8,7},{3,4,1,2,-7,-8,-5,-\
6},{4,3,2,1,-8,-7,-6,-5},{5,6,7,8,-1,-2,-3,-4},{6,5,8,7,-2,-1,-4,-3},{7,8,5,6,\
3,4,1,2},{8,7,6,5,4,3,2,1}},{(a+b)^2-(c+d)^2+(e+f)^2-(g+h)^2,(a-b)^2-(c-d)^2+(\
e-f)^2-(g-h)^2},{(a+b)^2+(e+f)^2,If[e==-f,0,ArcTan[a+b,e+f]],(c+d)^2+(g+h)^2,\
If[g==-h,0,ArcTan[c+d,g+h]],(a-b)^2+(e-f)^2,If[e==f,0,ArcTan[a-b,e-f]],(c-d)^\
2+(g-h)^2,If[g==h,0,ArcTan[c-d,g-h]]},{(Sqrt[a]*Cos[b]+Sqrt[e]*Cos[f])/2,(\
Sqrt[a]*Cos[b]-Sqrt[e]*Cos[f])/2,(Sqrt[c]*Cos[d]+Sqrt[g]*Cos[h])/2,(Sqrt[c]*\
Cos[d]-Sqrt[g]*Cos[h])/2,(Sqrt[a]*Sin[b]+Sqrt[e]*Sin[f])/2,(Sqrt[a]*Sin[b]-\
Sqrt[e]*Sin[f])/2,(Sqrt[c]*Sin[d]+Sqrt[g]*Sin[h])/2,(Sqrt[c]*Sin[d]-Sqrt[g]*\
Sin[h])/2},{1,2,3,4,-5,-6,7,8,2,2},{1,0.,1,0.,1,0.,1,0.},{a,b,-c,-d,-e,-f,-g,-\
h}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"CL3\"]={8,19,{{1,2,3,4,5,6,7,8},{2,1,4,3,6,5,8,7},{3,-4,1,-2,7,-8,5,-6}\
,{4,-3,2,-1,8,-7,6,-5},{5,-6,-7,8,1,-2,-3,4},{6,-5,-8,7,2,-1,-4,3},{7,8,-5,-6,\
3,4,-1,-2},{8,7,-6,-5,4,3,-2,-1}},{4*(-(d*e)+c*f-b*g+a*h)^2+(a^2-b^2-c^2+d^2-\
e^2+f^2+g^2-h^2)^2},,,{1,2,3,-4,5,-6,-7,-8,2},{2,1,0.,1,0.},{a,-b,-c,-d,-e,-f,\
-g,h}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"Octr\"]=(*Octonion Algebra*)
{8,21,{{1,2,3,4,5,6,7,8},{2,-1,4,-3,6,-5,-8,7},{3,-4,-1,2,7,8,-5,-6},{4,3,-2,-\
1,8,-7,6,-5},{5,-6,-7,-8,-1,2,3,4},{6,5,-8,7,-2,-1,-4,3},{7,8,5,-6,-3,4,-1,-2}\
,{8,-7,6,5,-4,-3,2,-1}},{a^2+b^2+c^2+d^2+e^2+f^2+g^2+h^2},{a^2+b^2+c^2+d^2+e^\
2+f^2+g^2+h^2,ArcTan[a,b],c^2+d^2,ArcTan[c,d],e^2+f^2,ArcTan[e,f],g^2+h^2,\
ArcTan[g,h]},{Sqrt[a-c-e-g]*Cos[b],Sqrt[a-c-e-g]*Sin[b],Sqrt[c]*Cos[d],Sqrt[c]\
*Sin[d],Sqrt[e]*Cos[f],Sqrt[e]*Sin[f],Sqrt[g]*Cos[h],Sqrt[g]*Sin[h]},{1,-2,-3,\
-4,-5,-6,-7,-8,4},{1,0.,1,0.,1,0.,1,0.},{a,-b,-c,-d,-e,-f,-g,-h}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"KiC4r\"]={8,22,{{1,2,3,4,5,6,7,8},{2,1,-8,-7,6,5,-4,-3},{3,-4,-1,2,7,-\
8,-5,6},{4,-3,6,-5,8,-7,2,-1},{5,6,7,8,1,2,3,4},{6,5,-4,-3,2,1,-8,-7},{7,-8,-\
5,6,3,-4,-1,2},{8,-7,2,-1,4,-3,6,-5}},{(a-e)^2-(b-f)^2+(c-g)^2-(d-h)^2,(a+b+e+\
f)^2+(c-d+g-h)^2,(a-b+e-f)^2+(c+d+g+h)^2},,,{1,2,-3,-8,5,6,-7,-4,2,1,1},{1,1,\
1,1,0.,1,0.},{a,-b,-c,-d,e,-f,-g,-h}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"CL21\"]={8,27,{{1,2,3,4,5,6,7,8},{2,-1,4,-3,6,-5,8,-7},{3,-4,1,-2,7,-8,\
5,-6},{4,3,2,1,8,7,6,5},{5,-6,-7,8,1,-2,-3,4},{6,5,-8,-7,2,1,-4,-3},{7,8,-5,-\
6,3,4,-1,-2},{8,-7,-6,5,4,-3,-2,1}},{-(d-e)^2-(c+f)^2+(b+g)^2+(a-h)^2,-(d+e)^\
2-(c-f)^2+(b-g)^2+(a+h)^2},{(b+g)^2+(a-h)^2,ArcTan[a-h,b+g],(d-e)^2+(c+f)^2,\
ArcTan[c+f,d-e],(b-g)^2+(a+h)^2,ArcTan[a+h,b-g],(d+e)^2+(c-f)^2,ArcTan[c-f,d+\
e]},{(Sqrt[a]*Cos[b]+Sqrt[e]*Cos[f])/2,(Sqrt[a]*Sin[b]+Sqrt[e]*Sin[f])/2,(\
Sqrt[c]*Cos[d]+Sqrt[g]*Cos[h])/2,(Sqrt[c]*Sin[d]+Sqrt[g]*Sin[h])/2,(-(Sqrt[c]*\
Sin[d])+Sqrt[g]*Sin[h])/2,(Sqrt[c]*Cos[d]-Sqrt[g]*Cos[h])/2,(Sqrt[a]*Sin[b]-\
Sqrt[e]*Sin[f])/2,(-(Sqrt[a]*Cos[b])+Sqrt[e]*Cos[f])/2},{1,-2,3,4,5,6,-7,8,2,\
2},{1,0.,1,0.,1,0.,1,0.},{a,-b,-c,-d,-e,-f,-g,h}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"CL03\"]={8,28,{{1,2,3,4,5,6,7,8},{2,-1,4,-3,6,-5,8,-7},{3,-4,-1,2,7,-8,\
-5,6},{4,3,-2,-1,8,7,-6,-5},{5,-6,-7,8,-1,2,3,-4},{6,5,-8,-7,-2,-1,4,3},{7,8,\
5,6,-3,-4,-1,-2},{8,-7,6,-5,-4,3,-2,1}},{(d+e)^2+(c-f)^2+(b+g)^2+(a-h)^2,(d-e)\
^2+(c+f)^2+(b-g)^2+(a+h)^2},{(b+g)^2+(a-h)^2,ArcTan[a-h,b+g],(d+e)^2+(c-f)^2,\
ArcTan[c-f,d+e],(b-g)^2+(a+h)^2,ArcTan[a+h,b-g],(d-e)^2+(c+f)^2,ArcTan[c+f,d-\
e]},{(Sqrt[a]*Cos[b]+Sqrt[e]*Cos[f])/2,(Sqrt[a]*Sin[b]+Sqrt[e]*Sin[f])/2,(\
Sqrt[c]*Cos[d]+Sqrt[g]*Cos[h])/2,(Sqrt[c]*Sin[d]+Sqrt[g]*Sin[h])/2,(Sqrt[c]*\
Sin[d]-Sqrt[g]*Sin[h])/2,(-(Sqrt[c]*Cos[d])+Sqrt[g]*Cos[h])/2,(Sqrt[a]*Sin[b]-\
Sqrt[e]*Sin[f])/2,(-(Sqrt[a]*Cos[b])+Sqrt[e]*Cos[f])/2},{1,-2,-3,-4,-5,-6,-7,\
8,2,2},{1,0.,1,0.,1,0.,1,0.},{a,-b,-c,-d,-e,-f,-g,h}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"Octi\"]=(*Split-Octonion*){8,30,{{1,2,3,4,5,6,7,8},{2,1,4,3,6,5,-8,-7},\
{3,-4,-1,2,7,8,-5,-6},{4,-3,-2,1,8,7,6,5},{5,-6,-7,-8,-1,2,3,4},{6,-5,-8,-7,-\
2,1,-4,-3},{7,8,5,-6,-3,4,-1,-2},{8,7,6,-5,-4,3,2,1}},{a^2-b^2+c^2-d^2+e^2-f^\
2+g^2-h^2},{a^2+c^2,ArcTan[a,c],b^2+d^2,ArcTan[b,d],e^2+g^2,
ArcTan[e,g],f^2+h^2,ArcTan[f,h]},{Sqrt[a]*Cos[b],Sqrt[c]*Cos[d],Sqrt[a]*Sin[b]\
,Sqrt[c]*Sin[d],Sqrt[e]*Cos[f],Sqrt[g]*Cos[h],Sqrt[e]*Sin[f],Sqrt[g]*Sin[h]},{\
1,2,-3,4,-5,6,-7,8,4},{1,0.,1,0.,1,0.,1,0.},{a,-b,-c,-d,-e,-f,-g,-h}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"C3C3\"]={9,2,{{1,2,3,4,5,6,7,8,9},{2,3,1,5,6,4,8,9,7},{3,1,2,6,4,5,9,7,\
8},{4,5,6,7,8,9,1,2,3},{5,6,4,8,9,7,2,3,1},{6,4,5,9,7,8,3,1,2},{7,8,9,1,2,3,4,\
5,6},{8,9,7,2,3,1,5,6,4},{9,7,8,3,1,2,6,4,5}},{a+b+c+d+e+f+g+h+i,((-a+c+e-f+g-\
h)^2+(a-b-d+f+h-i)^2+(b-c+d-e-g+i)^2)/2,((b-c-d+f+g-h)^2+(a-b+e-f-g+i)^2+(a-c-\
d+e-h+i)^2)/2,((a-b+d-e+g-h)^2+(b-c+e-f+h-i)^2+(-a+c-d+f-g+i)^2)/2,((a+b+c-d-\
e-f)^2+(a+b+c-g-h-i)^2+(d+e+f-g-h-i)^2)/2},{a+b+c+d+e+f+g+h+i,((-a+c+e-f+g-h)^\
2+(a-b-d+f+h-i)^2+(b-c+d-e-g+i)^2)/2,ArcTan[2*a-b-c-d-e+2*f-g+2*h-i,-(Sqrt[3]*\
(b-c+d-e-g+i))],((b-c-d+f+g-h)^2+(a-b+e-f-g+i)^2+(a-c-d+e-h+i)^2)/2,ArcTan[2*\
a-b-c-d+2*e-f-g-h+2*i,-(Sqrt[3]*(b-c-d+f+g-h))],((a-b+d-e+g-h)^2+(b-c+e-f+h-i)\
^2+(-a+c-d+f-g+i)^2)/2,ArcTan[2*a-b-c+2*d-e-f+2*g-h-i,-(Sqrt[3]*(b-c+e-f+h-i))\
],((a+b+c-d-e-f)^2+(a+b+c-g-h-i)^2+(d+e+f-g-h-i)^2)/2,ArcTan[2*a+2*b+2*c-d-e-\
f-g-h-i,-(Sqrt[3]*(d+e+f-g-h-i))]},{(a+2*Sqrt[b]*Cos[c]+2*Sqrt[d]*Cos[e]+2*\
Sqrt[f]*Cos[g]+2*Sqrt[h]*Cos[i])/9,(a+2*Sqrt[h]*Cos[i]+2*Sqrt[b]*Cos[c+(2*Pi)/\
3]+2*Sqrt[d]*Cos[e+(2*Pi)/3]+2*Sqrt[f]*Cos[g+(2*Pi)/3])/9,(a+2*Sqrt[h]*Cos[i]+\
2*Sqrt[b]*Cos[c+(4*Pi)/3]+2*Sqrt[d]*Cos[e+(4*Pi)/3]+2*Sqrt[f]*Cos[g+(4*Pi)/3])\
/9,(a+2*Sqrt[f]*Cos[g]+2*Sqrt[b]*Cos[c+(2*Pi)/3]+2*Sqrt[h]*Cos[i+(2*Pi)/3]+2*\
Sqrt[d]*Cos[e+(4*Pi)/3])/9,(a+2*Sqrt[d]*Cos[e]+2*Sqrt[f]*Cos[g+(2*Pi)/3]+2*\
Sqrt[h]*Cos[i+(2*Pi)/3]+2*Sqrt[b]*Cos[c+(4*Pi)/3])/9,(a+2*Sqrt[b]*Cos[c]+2*\
Sqrt[d]*Cos[e+(2*Pi)/3]+2*Sqrt[h]*Cos[i+(2*Pi)/3]+2*Sqrt[f]*Cos[g+(4*Pi)/3])/\
9,(a+2*Sqrt[f]*Cos[g]+2*Sqrt[d]*Cos[e+(2*Pi)/3]+2*Sqrt[b]*Cos[c+(4*Pi)/3]+2*\
Sqrt[h]*Cos[i+(4*Pi)/3])/9,(a+2*Sqrt[b]*Cos[c]+2*Sqrt[f]*Cos[g+(2*Pi)/3]+2*\
Sqrt[d]*Cos[e+(4*Pi)/3]+2*Sqrt[h]*Cos[i+(4*Pi)/3])/9,(a+2*Sqrt[d]*Cos[e]+2*\
Sqrt[b]*Cos[c+(2*Pi)/3]+2*Sqrt[f]*Cos[g+(4*Pi)/3]+2*Sqrt[h]*Cos[i+(4*Pi)/3])/\
9},{1,3,2,7,9,8,4,6,5,1,1,1,1,1},{1,1,0.,1,0.,1,0.,1,0.},{a,c,b,g,i,h,d,f,e}};\
\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Hoop["\<Q12\>"] = {12, 
          1, {{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {2, 3, 1, 5, 6, 4, 8, 
              9, 7, 11, 12, 10}, {3, 1, 2, 6, 4, 5, 9, 7, 8, 12, 10, 11}, {4, 
              6, 5, 7, 9, 8, 10, 12, 11, 1, 3, 2}, {5, 4, 6, 8, 7, 9, 11, 10, 
              12, 2, 1, 3}, {6, 5, 4, 9, 8, 7, 12, 11, 10, 3, 2, 1}, {7, 8, 
              9, 10, 11, 12, 1, 2, 3, 4, 5, 6}, {8, 9, 7, 11, 12, 10, 2, 3, 
              1, 5, 6, 4}, {9, 7, 8, 12, 10, 11, 3, 1, 2, 6, 4, 5}, {10, 12, 
              11, 1, 3, 2, 4, 6, 5, 7, 9, 8}, {11, 10, 12, 2, 1, 3, 5, 4, 6, 
              8, 7, 9}, {12, 11, 10, 3, 2, 1, 6, 5, 4, 9, 8, 7}}, {a + b + 
              c + d + e + f + g + h + i + j + k + l, 
            a + b + c - d - e - f + g + h + i - j - k - 
              l, \((a + b + c - g - h - i)\)\^2 + \((d + e + f - j - k - l)\)\
\^2, \ \((\((a - b + g - h)\)\^2 + \((a - c + g - i)\)\^2 + \((\(-b\) + c - h \
+ i)\)\^2 - \((d - e + j - k)\)\^2 - \((d - f + j - l)\)\^2 - \((\(-e\) + f - \
k + l)\)\^2)\)/
              2, \ \((\((a - b - g + h)\)\^2 + \((\(-b\) + c + h - i)\)\^2 + \
\((a - c - g + i)\)\^2 + \((d - e - j + k)\)\^2 + \((\(-e\) + f + k - l)\)\^2 \
+ \((d - f - j + l)\)\^2)\)/2}, {a + b + c + d + e + f + g + h + i + j + k + 
              l, a + b + c - d - e - f + g + h + i - j - k - 
              l, \((a + b + c - g - h - i)\)\^2 + \((d + e + f - j - k - l)\)\
\^2, ArcTan[a + b + c - g - h - i, 
              d + e + f - j - k - 
                l], \ \((\((a - b + g - h)\)\^2 + \((b - c + h - i)\)\^2 + \
\((\(-a\) + c - g + i)\)\^2)\)/2, 
            ArcTan[2\ a - b - c + 2\ g - h - 
                i, \(-\@3\)\ \((b - c + h - 
                    i)\)], \ \((\((d - e + j - k)\)\^2 + \((e - f + k - \
l)\)\^2 + \((\(-d\) + f - j + l)\)\^2)\)/2, 
            ArcTan[2\ d - e - f + 2\ j - k - 
                l, \(-\@3\)\ \((e - f + k - 
                    l)\)], \((\((a - b - g + h)\)\^2 + \((\(-a\) + c + g - i)\
\)\^2 + \((b - c - h + i)\)\^2)\)/2, 
            ArcTan[2\ a - b - c - 2\ g + h + 
                i, \(-\@3\)\ \((b - c - h + 
                    i)\)], \ \((\((d - e - j + k)\)\^2 + \((\(-d\) + f + j - \
l)\)\^2 + \((e - f - k + l)\)\^2)\)/2, 
            ArcTan[2\ d - e - f - 2\ j + k + 
                l, \(-\@3\)\ \((e - f - k + l)\)]}, {\ \((a + b + 
                    2\ \@c\ Cos[d] + 4\ \@e\ Cos[f] + 4\ \@i\ Cos[j])\)/
                2, \ \((a + b + 2\ \@c\ Cos[d] + 
                  4\ \@e\ Cos[f + \(2\ \[Pi]\)\/3] + 
                  4\ \@i\ Cos[j + \(2\ \[Pi]\)\/3])\), \ \((a + b + 
                  2\ \@c\ Cos[d] + 4\ \@e\ Cos[f - \(2\ \[Pi]\)\/3] + 
                  4\ \@i\ Cos[j - \(2\ \[Pi]\)\/3])\), \ \((a - b + 
                  4\ \@g\ Cos[h] + 4\ \@k\ Cos[l] + 
                  2\ \@c\ Sin[d])\), \ \((a - b + 
                  4\ \@g\ Cos[h + \(2\ \[Pi]\)\/3] + 
                  4\ \@k\ Cos[l + \(2\ \[Pi]\)\/3] + 
                  2\ \@c\ Sin[d])\), \ \((a - b + 
                  4\ \@g\ Cos[h - \(2\ \[Pi]\)\/3] + 
                  4\ \@k\ Cos[l - \(2\ \[Pi]\)\/3] + 
                  2\ \@c\ Sin[d])\), \ \((a + b - 2\ \@c\ Cos[d] + 
                  4\ \@e\ Cos[f] - 4\ \@i\ Cos[j])\), \ \((a + b - 
                  2\ \@c\ Cos[d] + 4\ \@e\ Cos[f + \(2\ \[Pi]\)\/3] - 
                  4\ \@i\ Cos[j + \(2\ \[Pi]\)\/3])\), \ \((a + b - 
                  2\ \@c\ Cos[d] + 4\ \@e\ Cos[f - \(2\ \[Pi]\)\/3] - 
                  4\ \@i\ Cos[j - \(2\ \[Pi]\)\/3])\), \ \((a - b + 
                  4\ \@g\ Cos[h] - 4\ \@k\ Cos[l] - 
                  2\ \@c\ Sin[d])\), \ \((a - b + 
                  4\ \@g\ Cos[h + \(2\ \[Pi]\)\/3] - 
                  4\ \@k\ Cos[l + \(2\ \[Pi]\)\/3] - 
                  2\ \@c\ Sin[d])\), \ \((a - b + 
                  4\ \@g\ Cos[h - \(2\ \[Pi]\)\/3] - 
                  4\ \@k\ Cos[l - \(2\ \[Pi]\)\/3] - 2\ \@c\ Sin[d])\)}/
            12, {1, 3, 2, 10, 11, 12, 7, 9, 8, 4, 5, 6, 1, 1, 1, 2, 2}, {1, 
            1, 1, 0. , 1, 0. , 1, 0. , 1, 0. , 1, 0. }, };\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Hoop["\<C3C4\>"] = {12, 
          2, {{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {2, 3, 1, 5, 6, 4, 8, 
              9, 7, 11, 12, 10}, {3, 1, 2, 6, 4, 5, 9, 7, 8, 12, 10, 11}, {4, 
              5, 6, 7, 8, 9, 10, 11, 12, 1, 2, 3}, {5, 6, 4, 8, 9, 7, 11, 12, 
              10, 2, 3, 1}, {6, 4, 5, 9, 7, 8, 12, 10, 11, 3, 1, 2}, {7, 8, 
              9, 10, 11, 12, 1, 2, 3, 4, 5, 6}, {8, 9, 7, 11, 12, 10, 2, 3, 
              1, 5, 6, 4}, {9, 7, 8, 12, 10, 11, 3, 1, 2, 6, 4, 5}, {10, 11, 
              12, 1, 2, 3, 4, 5, 6, 7, 8, 9}, {11, 12, 10, 2, 3, 1, 5, 6, 4, 
              8, 9, 7}, {12, 10, 11, 3, 1, 2, 6, 4, 5, 9, 7, 8}}, {a + b + 
              c + d + e + f + g + h + i + j + k + l, 
            a + b + c - d - e - f + g + h + i - j - k - 
              l, \((a + b + c - g - h - i)\)\^2 + \((d + e + f - j - k - l)\)\
\^2, \((\((a - b + d - e + g - h + j - k)\)\^2 + \((b - c + e - f + h - i + k \
- l)\)\^2 + \((\(-a\) + c - d + f - g + i - j + l)\)\^2)\)/
              2, \((\((a - b - d + e + g - h - j + k)\)\^2 + \((\(-a\) + c + \
d - f - g + i + j - l)\)\^2 + \((b - c - e + f + h - i - k + l)\)\^2)\)/
              2, \((a - b - g + h)\)\^2 + \((a - b - g + h)\)\ \((b - c - h + 
                    i)\) + \((b - c - h + i)\)\^2 + \((d - e - j + k)\)\^2 + \
\((d - e - j + k)\)\ \((e - f - k + 
                    l)\) + \((e - f - k + l)\)\^2 + \@3\ \((\((b - c - h + 
                          i)\)\ \((d - e - j + k)\) - \((a - b - g + 
                          h)\)\ \((e - f - k + 
                          l)\))\), \((a - b - g + h)\)\^2 + \((a - b - g + 
                    h)\)\ \((b - c - h + 
                    i)\) + \((b - c - h + i)\)\^2 + \((d - e - j + k)\)\^2 + \
\((d - e - j + k)\)\ \((e - f - k + 
                    l)\) + \((e - f - k + l)\)\^2 - \@3\ \((\((b - c - h + 
                          i)\)\ \((d - e - j + k)\) - \((a - b - g + 
                          h)\)\ \((e - f - k + l)\))\)}, {a + b + c + d + e + 
              f + g + h + i + j + k + l, 
            a + b + c - d - e - f + g + h + i - j - k - 
              l, \((a + b + c - g - h - i)\)\^2 + \((d + e + f - j - k - l)\)\
\^2, ArcTan[a + b + c - g - h - i, 
              d + e + f - j - k - 
                l], \((\((a - b + d - e + g - h + j - k)\)\^2 + \((b - c + e \
- f + h - i + k - l)\)\^2 + \((\(-a\) + c - d + f - g + i - j + l)\)\^2)\)/2, 
            ArcTan[
              2\ a - b - c + 2\ d - e - f + 2\ g - h - i + 2\ j - k - 
                l, \(-\@3\)\ \((b - c + e - f + h - i + k - 
                    l)\)], \((\((a - b - d + e + g - h - j + k)\)\^2 + \
\((\(-a\) + c + d - f - g + i + j - l)\)\^2 + \((b - c - e + f + h - i - k + \
l)\)\^2)\)/2, 
            ArcTan[2\ a - b - c - 2\ d + e + f + 2\ g - h - i - 2\ j + k + 
                l, \(-\@3\)\ \((b - c - e + f + h - i - k + 
                    l)\)], \((\((a - b + d - e - g + h - j + k)\)\^2 + \
\((\(-a\) + c - d + f + g - i + j - l)\)\^2 + \((b - c + e - f - h + i - k + \
l)\)\^2)\)/2, 
            ArcTan[2\ a - b - c + 2\ d - e - f - 2\ g + h + i - 2\ j + k + 
                l, \(-\@3\)\ \((b - c + e - f - h + i - k + 
                    l)\)], \((\((a - b - d + e - g + h + j - k)\)\^2 + \((b - \
c - e + f - h + i + k - l)\)\^2 + \((\(-a\) + c + d - f + g - i - j + \
l)\)\^2)\)/2, 
            ArcTan[2\ a - b - c - 2\ d + e + f - 2\ g + h + i + 2\ j - k - 
                l, \(-\@3\)\ \((b - c - e + f - h + i + k - l)\)]}, {\ \((a + 
                  b + 2\ \@c\ Cos[d] + 2\ \@e\ Cos[f] + 2\ \@g\ Cos[h] + 
                  2\ \@i\ Cos[j] + 2\ \@k\ Cos[l])\), \ \((a + b + 
                  2\ \@c\ Cos[d] + 2\ \@e\ Cos[f + \(2\ \[Pi]\)\/3] + 
                  2\ \@g\ Cos[h + \(2\ \[Pi]\)\/3] + 
                  2\ \@i\ Cos[j + \(2\ \[Pi]\)\/3] + 
                  2\ \@k\ Cos[l + \(2\ \[Pi]\)\/3])\), \ \((a + b + 
                  2\ \@c\ Cos[d] + 2\ \@e\ Cos[f - \(2\ \[Pi]\)\/3] + 
                  2\ \@g\ Cos[h - \(2\ \[Pi]\)\/3] + 
                  2\ \@i\ Cos[j - \(2\ \[Pi]\)\/3] + 
                  2\ \@k\ Cos[l - \(2\ \[Pi]\)\/3])\), \ \((a - b + 
                  2\ \@e\ Cos[f] - 2\ \@g\ Cos[h] + 2\ \@i\ Cos[j] - 
                  2\ \@k\ Cos[l] + 2\ \@c\ Sin[d])\), \ \((a - b + 
                  2\ \@e\ Cos[f + \(2\ \[Pi]\)\/3] - 
                  2\ \@g\ Cos[h + \(2\ \[Pi]\)\/3] + 
                  2\ \@i\ Cos[j + \(2\ \[Pi]\)\/3] - 
                  2\ \@k\ Cos[l + \(2\ \[Pi]\)\/3] + 
                  2\ \@c\ Sin[d])\), \ \((a - b + 
                  2\ \@e\ Cos[f - \(2\ \[Pi]\)\/3] - 
                  2\ \@g\ Cos[h - \(2\ \[Pi]\)\/3] + 
                  2\ \@i\ Cos[j - \(2\ \[Pi]\)\/3] - 
                  2\ \@k\ Cos[l - \(2\ \[Pi]\)\/3] + 
                  2\ \@c\ Sin[d])\), \ \((a + b - 2\ \@c\ Cos[d] + 
                  2\ \@e\ Cos[f] + 2\ \@g\ Cos[h] - 2\ \@i\ Cos[j] - 
                  2\ \@k\ Cos[l])\), \ \((a + b - 2\ \@c\ Cos[d] + 
                  2\ \@e\ Cos[f + \(2\ \[Pi]\)\/3] + 
                  2\ \@g\ Cos[h + \(2\ \[Pi]\)\/3] - 
                  2\ \@i\ Cos[j + \(2\ \[Pi]\)\/3] - 
                  2\ \@k\ Cos[l + \(2\ \[Pi]\)\/3])\), \ \((a + b - 
                  2\ \@c\ Cos[d] + 2\ \@e\ Cos[f - \(2\ \[Pi]\)\/3] + 
                  2\ \@g\ Cos[h - \(2\ \[Pi]\)\/3] - 
                  2\ \@i\ Cos[j - \(2\ \[Pi]\)\/3] - 
                  2\ \@k\ Cos[l - \(2\ \[Pi]\)\/3])\), \((a - b + 
                  2\ \@e\ Cos[f] - 2\ \@g\ Cos[h] - 2\ \@i\ Cos[j] + 
                  2\ \@k\ Cos[l] - 2\ \@c\ Sin[d])\), \ \((a - b + 
                  2\ \@e\ Cos[f + \(2\ \[Pi]\)\/3] - 
                  2\ \@g\ Cos[h + \(2\ \[Pi]\)\/3] - 
                  2\ \@i\ Cos[j + \(2\ \[Pi]\)\/3] + 
                  2\ \@k\ Cos[l + \(2\ \[Pi]\)\/3] - 
                  2\ \@c\ Sin[d])\), \((a - b + 
                  2\ \@e\ Cos[f - \(2\ \[Pi]\)\/3] - 
                  2\ \@g\ Cos[h - \(2\ \[Pi]\)\/3] - 
                  2\ \@i\ Cos[j - \(2\ \[Pi]\)\/3] + 
                  2\ \@k\ Cos[l - \(2\ \[Pi]\)\/3] - 2\ \@c\ Sin[d])\)}/
            12, {1, 3, 2, 10, 12, 11, 7, 9, 8, 4, 6, 5, 1, 1, 1, 1, 1, 1, 1, 
            1}, {1, 1, 1, 0. , 1, 0. , 1, 0. , 1, 0. , 1, 0. }, {a, c, b, d, 
            f, e, g, i, h, j, l, k}};\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Hoop["\<A4\>"] = {12, 
          3, {{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {2, 3, 1, 5, 6, 4, 8, 
              9, 7, 11, 12, 10}, {3, 1, 2, 6, 4, 5, 9, 7, 8, 12, 10, 11}, {4, 
              11, 9, 1, 8, 12, 10, 5, 3, 7, 2, 6}, {5, 12, 7, 2, 9, 10, 11, 
              6, 1, 8, 3, 4}, {6, 10, 8, 3, 7, 11, 12, 4, 2, 9, 1, 5}, {7, 5, 
              12, 10, 2, 9, 1, 11, 6, 4, 8, 3}, {8, 6, 10, 11, 3, 7, 2, 12, 
              4, 5, 9, 1}, {9, 4, 11, 12, 1, 8, 3, 10, 5, 6, 7, 2}, {10, 8, 
              6, 7, 11, 3, 4, 2, 12, 1, 5, 9}, {11, 9, 4, 8, 12, 1, 5, 3, 10, 
              2, 6, 7}, {12, 7, 5, 9, 10, 2, 6, 1, 11, 3, 4, 8}}, {a + b + 
              c + d + e + f + g + h + i + j + k + 
              l, \ \((\((a - b + d - e + g - h + j - k)\)\^2 + \((b - c + e - \
f + h - i + k - l)\)\^2 + \((\(-a\) + c - d + f - g + i - j + l)\)\^2)\)/
              2, \((a + d - g - j)\)\ \((a - d + g - j)\)\ \((a - d - g + 
                    j)\) + \((b + e - h - k)\)\ \((b - e + h - k)\)\ \((b - 
                    e - h + k)\) - \((a - d + g - j)\)\ \((b - e - h + 
                    k)\)\ \((c + f - i - l)\) - \((a - d - g + j)\)\ \((b + 
                    e - h - k)\)\ \((c - f + i - l)\) - \((a + d - g - 
                    j)\)\ \((b - e + h - k)\)\ \((c - f - i + l)\) + \((c + 
                    f - i - l)\)\ \((c - f + i - l)\)\ \((c - f - i + 
                    l)\)}, , , {1, 3, 2, 4, 9, 11, 7, 12, 5, 10, 6, 8, 1, 1, 
            3}, , };\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Hoop["\<D3C2\>"] = {12, 
          4, \[IndentingNewLine]{{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {2, 
              3, 1, 5, 6, 4, 8, 9, 7, 11, 12, 10}, {3, 1, 2, 6, 4, 5, 9, 7, 
              8, 12, 10, 11}, {4, 6, 5, 1, 3, 2, 10, 12, 11, 7, 9, 8}, {5, 4, 
              6, 2, 1, 3, 11, 10, 12, 8, 7, 9}, {6, 5, 4, 3, 2, 1, 12, 11, 
              10, 9, 8, 7}, {7, 8, 9, 10, 11, 12, 1, 2, 3, 4, 5, 6}, {8, 9, 
              7, 11, 12, 10, 2, 3, 1, 5, 6, 4}, {9, 7, 8, 12, 10, 11, 3, 1, 
              2, 6, 4, 5}, {10, 12, 11, 7, 9, 8, 4, 6, 5, 1, 3, 2}, {11, 10, 
              12, 8, 7, 9, 5, 4, 6, 2, 1, 3}, {12, 11, 10, 9, 8, 7, 6, 5, 4, 
              3, 2, 1}}, {a + b + c + d + e + f + g + h + i + j + k + l, 
            a + b + c - d - e - f + g + h + i - j - k - l, 
            a + b + c + d + e + f - g - h - i - j - k - l, 
            a + b + c - d - e - f - g - h - i + j + k + 
              l, \((\((a - b + g - h)\)\^2 + \((b - c + h - i)\)\^2 + \((\(-a\
\) + c - g + i)\)\^2 - \((\(-d\) + e - j + k)\)\^2 - \((d - f + j - l)\)\^2 - \
\((\(-e\) + f - k + l)\)\^2)\)/
              2, \((\((a - b - g + h)\)\^2 + \((\(-a\) + c + g - i)\)\^2 + \
\((b - c - h + i)\)\^2 - \((\(-d\) + e + j - k)\)\^2 - \((\(-e\) + f + k - l)\
\)\^2 - \((d - f - j + l)\)\^2)\)/2}, {a + b + c + d + e + f + g + h + i + 
              j + k + l, a + b + c - d - e - f + g + h + i - j - k - l, 
            a + b + c + d + e + f - g - h - i - j - k - l, 
            a + b + c - d - e - f - g - h - i + j + k + 
              l, \((\((a - b + g - h)\)\^2 + \((b - c + h - i)\)\^2 + \((\(-a\
\) + c - g + i)\)\^2)\)/2, 
            ArcTan[2\ a - b - c + 2\ g - h - 
                i, \(-\@3\)\ \((b - c + h - 
                    i)\)], \((\((\(-d\) + e - j + k)\)\^2 + \((d - f + j - l)\
\)\^2 + \((\(-e\) + f - k + l)\)\^2)\)/2, 
            ArcTan[\(-2\)\ d + e + f - 2\ j + k + 
                l, \(-\@3\)\ \((\(-e\) + f - k + 
                    l)\)], \((\((a - b - g + h)\)\^2 + \((\(-a\) + c + g - i)\
\)\^2 + \((b - c - h + i)\)\^2)\)/2, 
            ArcTan[2\ a - b - c - 2\ g + h + 
                i, \(-\@3\)\ \((b - c - h + 
                    i)\)], \((\((\(-d\) + e + j - k)\)\^2 + \((\(-e\) + f + k \
- l)\)\^2 + \((d - f - j + l)\)\^2)\)/2, 
            ArcTan[\(-2\)\ d + e + f + 2\ j - k - 
                l, \(-\@3\)\ \((\(-e\) + f + k - l)\)]}, {\ \((a + b + c + 
                  d + 4\ \@e\ Cos[f] + 4\ \@i\ Cos[j])\), \ \((a + b + c + 
                  d + 4\ \@e\ Cos[f + \(2\ \[Pi]\)\/3] + 
                  4\ \@i\ Cos[j + \(2\ \[Pi]\)\/3])\), \ \((a + b + c + d + 
                  4\ \@e\ Cos[f - \(2\ \[Pi]\)\/3] + 
                  4\ \@i\ Cos[j - \(2\ \[Pi]\)\/3])\), \ \((a - b + c - d - 
                  4\ \@g\ Cos[h] - 4\ \@k\ Cos[l])\), \ \((a - b + c - d - 
                  4\ \@g\ Cos[h + \(2\ \[Pi]\)\/3] - 
                  4\ \@k\ Cos[l + \(2\ \[Pi]\)\/3])\), \ \((a - b + c - d - 
                  4\ \@g\ Cos[h - \(2\ \[Pi]\)\/3] - 
                  4\ \@k\ Cos[l - \(2\ \[Pi]\)\/3])\), \ \((a + b - c - d + 
                  4\ \@e\ Cos[f] - 4\ \@i\ Cos[j])\), \ \((a + b - c - d + 
                  4\ \@e\ Cos[f + \(2\ \[Pi]\)\/3] - 
                  4\ \@i\ Cos[j + \(2\ \[Pi]\)\/3])\), \ \((a + b - c - d + 
                  4\ \@e\ Cos[f - \(2\ \[Pi]\)\/3] - 
                  4\ \@i\ Cos[j - \(2\ \[Pi]\)\/3])\), \ \((a - b - c + d - 
                  4\ \@g\ Cos[h] + 4\ \@k\ Cos[l])\), \ \((a - b - c + d - 
                  4\ \@g\ Cos[h + \(2\ \[Pi]\)\/3] + 
                  4\ \@k\ Cos[l + \(2\ \[Pi]\)\/3])\), \ \((a - b - c + d - 
                  4\ \@g\ Cos[h - \(2\ \[Pi]\)\/3] + 
                  4\ \@k\ Cos[l - \(2\ \[Pi]\)\/3])\)}/12, {1, 3, 2, 4, 5, 6, 
            7, 9, 8, 10, 11, 12, 1, 1, 1, 1, 2, 2}, {1, 1, 1, 1, 1, 0. , 1, 
            0. , 1, 0. , 1, 0. }, };\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Hoop["\<C3K\>"] = {12, 
          5, {{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {2, 3, 1, 5, 6, 4, 8, 
              9, 7, 11, 12, 10}, {3, 1, 2, 6, 4, 5, 9, 7, 8, 12, 10, 11}, {4, 
              5, 6, 1, 2, 3, 10, 11, 12, 7, 8, 9}, {5, 6, 4, 2, 3, 1, 11, 12, 
              10, 8, 9, 7}, {6, 4, 5, 3, 1, 2, 12, 10, 11, 9, 7, 8}, {7, 8, 
              9, 10, 11, 12, 1, 2, 3, 4, 5, 6}, {8, 9, 7, 11, 12, 10, 2, 3, 
              1, 5, 6, 4}, {9, 7, 8, 12, 10, 11, 3, 1, 2, 6, 4, 5}, {10, 11, 
              12, 7, 8, 9, 4, 5, 6, 1, 2, 3}, {11, 12, 10, 8, 9, 7, 5, 6, 4, 
              2, 3, 1}, {12, 10, 11, 9, 7, 8, 6, 4, 5, 3, 1, 2}}, {a + b + 
              c + d + e + f + g + h + i + j + k + l, 
            a + b + c - d - e - f + g + h + i - j - k - l, 
            a + b + c + d + e + f - g - h - i - j - k - l, 
            a + b + c - d - e - f - g - h - i + j + k + 
              l, \((\((a - b + d - e + g - h + j - k)\)\^2 + \((b - c + e - f \
+ h - i + k - l)\)\^2 + \((\(-a\) + c - d + f - g + i - j + l)\)\^2)\)/
              2, \ \((\((a - b - d + e + g - h - j + k)\)\^2 + \((\(-a\) + c \
+ d - f - g + i + j - l)\)\^2 + \((b - c - e + f + h - i - k + l)\)\^2)\)/
              2, \((\((a - b + d - e - g + h - j + k)\)\^2 + \((\(-a\) + c - \
d + f + g - i + j - l)\)\^2 + \((b - c + e - f - h + i - k + l)\)\^2)\)/
              2, \((\((a - b - d + e - g + h + j - k)\)\^2 + \((b - c - e + f \
- h + i + k - l)\)\^2 + \((\(-a\) + c + d - f + g - i - j + l)\)\^2)\)/
              2}, {a + b + c + d + e + f + g + h + i + j + k + l, 
            a + b + c - d - e - f + g + h + i - j - k - l, 
            a + b + c + d + e + f - g - h - i - j - k - l, 
            a + b + c - d - e - f - g - h - i + j + k + 
              l, \((\((a - b + d - e + g - h + j - k)\)\^2 + \((b - c + e - f \
+ h - i + k - l)\)\^2 + \((\(-a\) + c - d + f - g + i - j + l)\)\^2)\)/2, 
            ArcTan[2\ a - b - c + 2\ d - e - f + 2\ g - h - i + 2\ j - k - 
                l, \(-\@3\)\ \((b - c + e - f + h - i + k - 
                    l)\)], \((\((a - b - d + e + g - h - j + k)\)\^2 + \
\((\(-a\) + c + d - f - g + i + j - l)\)\^2 + \((b - c - e + f + h - i - k + \
l)\)\^2)\)/2, 
            ArcTan[2\ a - b - c - 2\ d + e + f + 2\ g - h - i - 2\ j + k + 
                l, \(-\@3\)\ \((b - c - e + f + h - i - k + 
                    l)\)], \((\((a - b + d - e - g + h - j + k)\)\^2 + \
\((\(-a\) + c - d + f + g - i + j - l)\)\^2 + \((b - c + e - f - h + i - k + \
l)\)\^2)\)/2, 
            ArcTan[2\ a - b - c + 2\ d - e - f - 2\ g + h + i - 2\ j + k + 
                l, \(-\@3\)\ \((b - c + e - f - h + i - k + 
                    l)\)], \((\((a - b - d + e - g + h + j - k)\)\^2 + \((b - \
c - e + f - h + i + k - l)\)\^2 + \((\(-a\) + c + d - f + g - i - j + \
l)\)\^2)\)/2, 
            ArcTan[2\ a - b - c - 2\ d + e + f - 2\ g + h + i + 2\ j - k - 
                l, \(-\@3\)\ \((b - c - e + f - h + i + k - l)\)]}, {\((a + 
                  b + c + d + 2\ \@e\ Cos[f] + 2\ \@g\ Cos[h] + 
                  2\ \@i\ Cos[j] + 2\ \@k\ Cos[l])\), \ \((a + b + c + d + 
                  2\ \@e\ Cos[f + \(2\ \[Pi]\)\/3] + 
                  2\ \@g\ Cos[h + \(2\ \[Pi]\)\/3] + 
                  2\ \@i\ Cos[j + \(2\ \[Pi]\)\/3] + 
                  2\ \@k\ Cos[l + \(2\ \[Pi]\)\/3])\), \ \((a + b + c + d + 
                  2\ \@e\ Cos[f - \(2\ \[Pi]\)\/3] + 
                  2\ \@g\ Cos[h - \(2\ \[Pi]\)\/3] + 
                  2\ \@i\ Cos[j - \(2\ \[Pi]\)\/3] + 
                  2\ \@k\ Cos[l - \(2\ \[Pi]\)\/3])\), \ \((a - b + c - d + 
                  2\ \@e\ Cos[f] - 2\ \@g\ Cos[h] + 2\ \@i\ Cos[j] - 
                  2\ \@k\ Cos[l])\), \ \((a - b + c - d + 
                  2\ \@e\ Cos[f + \(2\ \[Pi]\)\/3] - 
                  2\ \@g\ Cos[h + \(2\ \[Pi]\)\/3] + 
                  2\ \@i\ Cos[j + \(2\ \[Pi]\)\/3] - 
                  2\ \@k\ Cos[l + \(2\ \[Pi]\)\/3])\), \ \((a - b + c - d + 
                  2\ \@e\ Cos[f - \(2\ \[Pi]\)\/3] - 
                  2\ \@g\ Cos[h - \(2\ \[Pi]\)\/3] + 
                  2\ \@i\ Cos[j - \(2\ \[Pi]\)\/3] - 
                  2\ \@k\ Cos[l - \(2\ \[Pi]\)\/3])\), \ \((a + b - c - d + 
                  2\ \@e\ Cos[f] + 2\ \@g\ Cos[h] - 2\ \@i\ Cos[j] - 
                  2\ \@k\ Cos[l])\), \ \((a + b - c - d + 
                  2\ \@e\ Cos[f + \(2\ \[Pi]\)\/3] + 
                  2\ \@g\ Cos[h + \(2\ \[Pi]\)\/3] - 
                  2\ \@i\ Cos[j + \(2\ \[Pi]\)\/3] - 
                  2\ \@k\ Cos[l + \(2\ \[Pi]\)\/3])\), \ \((a + b - c - d + 
                  2\ \@e\ Cos[f - \(2\ \[Pi]\)\/3] + 
                  2\ \@g\ Cos[h - \(2\ \[Pi]\)\/3] - 
                  2\ \@i\ Cos[j - \(2\ \[Pi]\)\/3] - 
                  2\ \@k\ Cos[l - \(2\ \[Pi]\)\/3])\), \ \((a - b - c + d + 
                  2\ \@e\ Cos[f] - 2\ \@g\ Cos[h] - 2\ \@i\ Cos[j] + 
                  2\ \@k\ Cos[l])\), \ \((a - b - c + d + 
                  2\ \@e\ Cos[f + \(2\ \[Pi]\)\/3] - 
                  2\ \@g\ Cos[h + \(2\ \[Pi]\)\/3] - 
                  2\ \@i\ Cos[j + \(2\ \[Pi]\)\/3] + 
                  2\ \@k\ Cos[l + \(2\ \[Pi]\)\/3])\), \ \((a - b - c + d + 
                  2\ \@e\ Cos[f - \(2\ \[Pi]\)\/3] - 
                  2\ \@g\ Cos[h - \(2\ \[Pi]\)\/3] - 
                  2\ \@i\ Cos[j - \(2\ \[Pi]\)\/3] + 
                  2\ \@k\ Cos[l - \(2\ \[Pi]\)\/3])\)}/12, {1, 3, 2, 4, 6, 5, 
            7, 9, 8, 10, 12, 11, 1, 1, 1, 1, 1, 1, 1, 1}, {1, 1, 1, 1, 1, 
            0.`, 1, 0.`, 1, 0.`, 1, 0.`}, {a, b, c, \(-d\), \(-e\), \(-f\), 
            g, h, i, \(-j\), \(-k\), \(-l\)}};\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Hoop["\<C3Qr\>"] = {12, 
          7, {{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {2, 3, 1, 5, 6, 4, 8, 
              9, 7, 11, 12, 10}, {3, 1, 2, 6, 4, 5, 9, 7, 8, 12, 10, 11}, {4, 
              5, 6, \(-1\), \(-2\), \(-3\), \(-10\), \(-11\), \(-12\), 7, 8, 
              9}, {5, 6, 
              4, \(-2\), \(-3\), \(-1\), \(-11\), \(-12\), \(-10\), 8, 9, 
              7}, {6, 4, 
              5, \(-3\), \(-1\), \(-2\), \(-12\), \(-10\), \(-11\), 9, 7, 
              8}, {7, 8, 9, 10, 11, 
              12, \(-1\), \(-2\), \(-3\), \(-4\), \(-5\), \(-6\)}, {8, 9, 7, 
              11, 12, 10, \(-2\), \(-3\), \(-1\), \(-5\), \(-6\), \(-4\)}, \
{9, 7, 8, 12, 10, 11, \(-3\), \(-1\), \(-2\), \(-6\), \(-4\), \(-5\)}, {10, 
              11, 12, \(-7\), \(-8\), \(-9\), 4, 5, 
              6, \(-1\), \(-2\), \(-3\)}, {11, 12, 
              10, \(-8\), \(-9\), \(-7\), 5, 6, 
              4, \(-2\), \(-3\), \(-1\)}, {12, 10, 
              11, \(-9\), \(-7\), \(-8\), 6, 4, 
              5, \(-3\), \(-1\), \(-2\)}}, {\((a + b + c)\)\^2 + \((d + e + \
f)\)\^2 + \((g + h + i)\)\^2 + \((j + k + l)\)\^2, \((\((a - b)\)\^2 + \((b - \
c)\)\^2 + \((\(-a\) + c)\)\^2 + \((d - e)\)\^2 + \((e - f)\)\^2 + \((\(-d\) + \
f)\)\^2 + \((g - h)\)\^2 + \((h - i)\)\^2 + \((\(-g\) + i)\)\^2 + \((j - k)\)\
\^2 + \((k - l)\)\^2 + \((\(-j\) + l)\)\^2)\)\^2/4 - 
              3\ \((\((b\ d - c\ d - a\ e + c\ e + a\ f - b\ f)\)\^2 + \((b\ \
g - c\ g - a\ h + c\ h + a\ i - b\ i)\)\^2 + \((e\ g - f\ g - d\ h + f\ h + d\
\ i - e\ i)\)\^2 + \((b\ j - c\ j - a\ k + c\ k + a\ l - b\ l)\)\^2 + \((\(-e\
\)\ j + f\ j + d\ k - f\ k - d\ l + e\ l)\)\^2 + \((h\ j - i\ j - g\ k + i\ k \
+ g\ l - h\ l)\)\^2)\)}, , , {1, 3, 
            2, \(-4\), \(-6\), \(-5\), \(-7\), \(-9\), \(-8\), \(-10\), \(-12\
\), \(-11\), 2, 2}, , {a, c, 
            b, \(-d\), \(-f\), \(-e\), \(-g\), \(-i\), \(-h\), \(-j\), \
\(-l\), \(-k\)}};\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Hoop["\<C3P4\>"] = {12, 
          8, {{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {2, 3, 1, 5, 6, 4, 8, 
              9, 7, 11, 12, 10}, {3, 1, 2, 6, 4, 5, 9, 7, 8, 12, 10, 11}, {4, 
              5, 6, 1, 2, 3, 10\ \[ImaginaryI], 11\ \[ImaginaryI], 
              12\ \[ImaginaryI], \(-7\)\ \[ImaginaryI], \(-8\)\ \
\[ImaginaryI], \(-9\)\ \[ImaginaryI]}, {5, 6, 4, 2, 3, 1, 11\ \[ImaginaryI], 
              12\ \[ImaginaryI], 
              10\ \[ImaginaryI], \(-8\)\ \[ImaginaryI], \(-9\)\ \
\[ImaginaryI], \(-7\)\ \[ImaginaryI]}, {6, 4, 5, 3, 1, 2, 12\ \[ImaginaryI], 
              10\ \[ImaginaryI], 
              11\ \[ImaginaryI], \(-9\)\ \[ImaginaryI], \(-7\)\ \
\[ImaginaryI], \(-8\)\ \[ImaginaryI]}, {7, 8, 
              9, \(-10\)\ \[ImaginaryI], \(-11\)\ \[ImaginaryI], \(-12\)\ \
\[ImaginaryI], 1, 2, 3, 4\ \[ImaginaryI], 5\ \[ImaginaryI], 
              6\ \[ImaginaryI]}, {8, 9, 
              7, \(-11\)\ \[ImaginaryI], \(-12\)\ \[ImaginaryI], \(-10\)\ \
\[ImaginaryI], 2, 3, 1, 5\ \[ImaginaryI], 6\ \[ImaginaryI], 
              4\ \[ImaginaryI]}, {9, 7, 
              8, \(-12\)\ \[ImaginaryI], \(-10\)\ \[ImaginaryI], \(-11\)\ \
\[ImaginaryI], 3, 1, 2, 6\ \[ImaginaryI], 4\ \[ImaginaryI], 
              5\ \[ImaginaryI]}, {10, 11, 12, 7\ \[ImaginaryI], 
              8\ \[ImaginaryI], 
              9\ \[ImaginaryI], \(-4\)\ \[ImaginaryI], \(-5\)\ \[ImaginaryI], \
\(-6\)\ \[ImaginaryI], 1, 2, 3}, {11, 12, 10, 8\ \[ImaginaryI], 
              9\ \[ImaginaryI], 
              7\ \[ImaginaryI], \(-5\)\ \[ImaginaryI], \(-6\)\ \[ImaginaryI], \
\(-4\)\ \[ImaginaryI], 2, 3, 1}, {12, 10, 11, 9\ \[ImaginaryI], 
              7\ \[ImaginaryI], 
              8\ \[ImaginaryI], \(-6\)\ \[ImaginaryI], \(-4\)\ \[ImaginaryI], \
\(-5\)\ \[ImaginaryI], 3, 1, 
              2}}, {\((a + b + c)\)\^2 - \((d + e + f)\)\^2 - \((g + h + i)\)\
\^2 - \((j + k + l)\)\^2, \((\((a - b)\)\^2 + \((b - c)\)\^2 + \((\(-a\) + c)\
\)\^2 - \((d - e)\)\^2 - \((e - f)\)\^2 - \((\(-d\) + f)\)\^2 - \((g - \
h)\)\^2 - \((h - i)\)\^2 - \((\(-g\) + i)\)\^2 - \((j - k)\)\^2 - \((k - l)\)\
\^2 - \((\(-j\) + l)\)\^2)\)\^2/4 + 
              3\ \((\((b\ d - c\ d - a\ e + c\ e + a\ f - b\ f)\)\^2 + \((b\ \
g - c\ g - a\ h + c\ h + a\ i - b\ i)\)\^2 - \((e\ g - f\ g - d\ h + f\ h + d\
\ i - e\ i)\)\^2 + \((b\ j - c\ j - a\ k + c\ k + a\ l - b\ l)\)\^2 - \((\(-e\
\)\ j + f\ j + d\ k - f\ k - d\ l + e\ l)\)\^2 - \((h\ j - i\ j - g\ k + i\ k \
+ g\ l - h\ l)\)\^2)\)}, , , {1, 3, 2, 4, 6, 5, 7, 9, 8, 10, 12, 11, 2, 
            2}, {a, c, 
            b, \(-d\), \(-f\), \(-e\), \(-g\), \(-i\), \(-h\), \(-j\), \
\(-l\), \(-k\)}, };\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Hoop["\<Q12C2c\>"] = {12, 
          14, {{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {2, 3, 4, 5, 6, 1, 
              12, 7, 8, 9, 10, 11}, {3, 4, 5, 6, 1, 2, 11, 12, 7, 8, 9, 
              10}, {4, 5, 6, 1, 2, 3, 10, 11, 12, 7, 8, 9}, {5, 6, 1, 2, 3, 
              4, 9, 10, 11, 12, 7, 8}, {6, 1, 2, 3, 4, 5, 8, 9, 10, 11, 12, 
              7}, {7, 8, 9, 10, 11, 
              12, \(-1\), \(-2\), \(-3\), \(-4\), \(-5\), \(-6\)}, {8, 9, 10, 
              11, 12, 7, \(-6\), \(-1\), \(-2\), \(-3\), \(-4\), \(-5\)}, {9, 
              10, 11, 12, 7, 
              8, \(-5\), \(-6\), \(-1\), \(-2\), \(-3\), \(-4\)}, {10, 11, 
              12, 7, 8, 
              9, \(-4\), \(-5\), \(-6\), \(-1\), \(-2\), \(-3\)}, {11, 12, 7, 
              8, 9, 10, \(-3\), \(-4\), \(-5\), \(-6\), \(-1\), \(-2\)}, {12, 
              7, 8, 9, 10, 
              11, \(-2\), \(-3\), \(-4\), \(-5\), \(-6\), \(-1\)}}, {\((a - b \
+ c - d + e - f)\)\^2 + \((g - h + i - j + k - l)\)\^2, 
            1\/2\ \((\((a - b + d - e)\)\^2 + \((a - c + d - f)\)\^2 + \((b - \
c + e - f)\)\^2 + \((g - h + j - k)\)\^2 + \((g - i + j - l)\)\^2 + \((h - i \
+ k - l)\)\^2)\), 
            1\/2\ \((\((a + b - d - e)\)\^2 + \((b + c - e - f)\)\^2 + \((a - \
c - d + f)\)\^2 + \((g + h - j - k)\)\^2 + \((h + i - k - l)\)\^2 + \((g - i \
- j + l)\)\^2)\), \((a + b + c + d + e + f)\)\^2 + \((g + h + i + j + k + \
l)\)\^2}, , , {1, 6, 5, 4, 3, 
            2, \(-7\), \(-8\), \(-9\), \(-10\), \(-11\), \(-12\), 1, 2, 2, 
            1}, , };\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Hoop["\<C3KC2r\>"] = {12, 
          19, {{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {2, 3, 1, 5, 6, 
              4, \(-8\), 9, \(-7\), 11, 12, 10}, {3, 1, 2, 6, 4, 
              5, \(-9\), \(-7\), 8, 12, 10, 11}, {4, 5, 6, 1, 2, 3, \(-10\), 
              11, 12, \(-7\), 8, 9}, {5, 6, 4, 2, 3, 1, \(-11\), 12, 10, 8, 
              9, \(-7\)}, {6, 4, 5, 3, 1, 2, \(-12\), 10, 11, 9, \(-7\), 
              8}, {7, \(-8\), \(-9\), \(-10\), \(-11\), \(-12\), 
              1, \(-2\), \(-3\), \(-4\), \(-5\), \(-6\)}, {8, 9, \(-7\), 11, 
              12, 10, \(-2\), 3, 1, 5, 6, 4}, {9, \(-7\), 8, 12, 10, 
              11, \(-3\), 1, 2, 6, 4, 5}, {10, 11, 12, \(-7\), 8, 9, \(-4\), 
              5, 6, 1, 2, 3}, {11, 12, 10, 8, 9, \(-7\), \(-5\), 6, 4, 2, 3, 
              1}, {12, 10, 11, 9, \(-7\), 8, \(-6\), 4, 5, 3, 1, 2}}, {a + 
              b + c + d + e + f + g - h - i - j - k - l, 
            a + b + c - d - e - f - g + h + i - j - k - l, 
            a + b + c - d - e - f + g - h - i + j + k + l, 
            a + b + c + d + e + f - g + h + i + j + k + l, 
            1\/2\ \((\((a - b + d - e - g - h + j - k)\)\^2 + \((b - c + e - \
f + h - i + k - l)\)\^2 + \((\(-a\) + c - d + f + g + i - j + l)\)\^2)\), 
            1\/2\ \((\((a - b - d + e + g + h + j - k)\)\^2 + \((b - c - e + \
f - h + i + k - l)\)\^2 + \((\(-a\) + c + d - f - g - i - j + l)\)\^2)\), 
            1\/2\ \((\((a - b - d + e - g - h - j + k)\)\^2 + \((\(-a\) + c + \
d - f + g + i + j - l)\)\^2 + \((b - c - e + f + h - i - k + l)\)\^2)\), 
            1\/2\ \((\((a - b + d - e + g + h - j + k)\)\^2 + \((\(-a\) + c - \
d + f - g - i + j - l)\)\^2 + \((b - c + e - f - h + i - k + l)\)\^2)\)}, , , \
{1, 3, 2, 4, 6, 5, 7, 9, 8, 10, 12, 11, 1, 1, 1, 1, 1, 1, 1, 1}, , {a, c, b, 
            d, f, e, g, i, h, j, l, k}};\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Hoop["\<C6Kr\>"] = {12, 
          20, {{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {2, \(-3\), 1, 
              5, \(-6\), 4, 8, \(-9\), 7, 11, \(-12\), 10}, {3, 1, \(-2\), 6, 
              4, \(-5\), 9, 7, \(-8\), 12, 10, \(-11\)}, {4, 5, 6, 1, 2, 3, 
              10, 11, 12, 7, 8, 9}, {5, \(-6\), 4, 2, \(-3\), 1, 11, \(-12\), 
              10, 8, \(-9\), 7}, {6, 4, \(-5\), 3, 1, \(-2\), 12, 
              10, \(-11\), 9, 7, \(-8\)}, {7, 8, 9, 10, 11, 12, 1, 2, 3, 4, 
              5, 6}, {8, \(-9\), 7, 11, \(-12\), 10, 2, \(-3\), 1, 5, \(-6\), 
              4}, {9, 7, \(-8\), 12, 10, \(-11\), 3, 1, \(-2\), 6, 
              4, \(-5\)}, {10, 11, 12, 7, 8, 9, 4, 5, 6, 1, 2, 
              3}, {11, \(-12\), 10, 8, \(-9\), 7, 5, \(-6\), 4, 2, \(-3\), 
              1}, {12, 10, \(-11\), 9, 7, \(-8\), 6, 4, \(-5\), 3, 
              1, \(-2\)}}, {a - b - c + d - e - f + g - h - i + j - k - l, 
            a - b - c - d + e + f - g + h + i + j - k - l, 
            a - b - c - d + e + f + g - h - i - j + k + l, 
            a - b - c + d - e - f - g + h + i - j + k + l, 
            1\/2\ \((\((a + b - d - e - g - h + j + k)\)\^2 + \((b - c - e + \
f - h + i + k - l)\)\^2 + \((a + c - d - f - g - i + j + l)\)\^2)\), 
            1\/2\ \((\((a + b - d - e + g + h - j - k)\)\^2 + \((a + c - d - \
f + g + i - j - l)\)\^2 + \((b - c - e + f + h - i - k + l)\)\^2)\), 
            1\/2\ \((\((a + b + d + e + g + h + j + k)\)\^2 + \((b - c + e - \
f + h - i + k - l)\)\^2 + \((a + c + d + f + g + i + j + l)\)\^2)\), 
            1\/2\ \((\((a + b + d + e - g - h - j - k)\)\^2 + \((a + c + d + \
f - g - i - j - l)\)\^2 + \((b - c + e - f - h + i - k + l)\)\^2)\)}, , , {1, 
            3, 2, 4, 6, 5, 7, 9, 8, 10, 12, 11, 1, 1, 1, 1, 1, 1, 1, 
            1}, , {a, c, b, d, f, e, g, i, h, j, l, k}};\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Hoop["\<C4C4\>"] = {16, 
          2, {{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16}, {2, 3, 
              4, 1, 6, 7, 8, 5, 10, 11, 12, 9, 14, 15, 16, 13}, {3, 4, 1, 2, 
              7, 8, 5, 6, 11, 12, 9, 10, 15, 16, 13, 14}, {4, 1, 2, 3, 8, 5, 
              6, 7, 12, 9, 10, 11, 16, 13, 14, 15}, {5, 6, 7, 8, 9, 10, 11, 
              12, 13, 14, 15, 16, 1, 2, 3, 4}, {6, 7, 8, 5, 10, 11, 12, 9, 
              14, 15, 16, 13, 2, 3, 4, 1}, {7, 8, 5, 6, 11, 12, 9, 10, 15, 
              16, 13, 14, 3, 4, 1, 2}, {8, 5, 6, 7, 12, 9, 10, 11, 16, 13, 
              14, 15, 4, 1, 2, 3}, {9, 10, 11, 12, 13, 14, 15, 16, 1, 2, 3, 
              4, 5, 6, 7, 8}, {10, 11, 12, 9, 14, 15, 16, 13, 2, 3, 4, 1, 6, 
              7, 8, 5}, {11, 12, 9, 10, 15, 16, 13, 14, 3, 4, 1, 2, 7, 8, 5, 
              6}, {12, 9, 10, 11, 16, 13, 14, 15, 4, 1, 2, 3, 8, 5, 6, 
              7}, {13, 14, 15, 16, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 
              12}, {14, 15, 16, 13, 2, 3, 4, 1, 6, 7, 8, 5, 10, 11, 12, 
              9}, {15, 16, 13, 14, 3, 4, 1, 2, 7, 8, 5, 6, 11, 12, 9, 
              10}, {16, 13, 14, 15, 4, 1, 2, 3, 8, 5, 6, 7, 12, 9, 10, 
              11}}, {a + b + c + d + e + f + g + h + i + j + k + l + m + n + 
              o + p, a - b + c - d - e + f - g + h + i - j + k - l - m + n - 
              o + p, a - b + c - d + e - f + g - h + i - j + k - l + m - n + 
              o - p, a + b + c + d - e - f - g - h + i + j + k + l - m - n - 
              o - p, \((a + b + c + d - i - j - k - l)\)\^2 + \((e + f + g + \
h - m - n - o - p)\)\^2, \((a - b + c - d - i + j - k + l)\)\^2 + \((e - f + \
g - h - m + n - o + p)\)\^2, \((a - c + e - g + i - k + m - o)\)\^2 + \((b - \
d + f - h + j - l + n - p)\)\^2, \((a - c - e + g + i - k - m + o)\)\^2 + \
\((b - d - f + h + j - l - n + p)\)\^2, \((b - d - e + g - j + l + m - \
o)\)\^2 + \((a - c + f - h - i + k - n + p)\)\^2, \((b - d + e - g - j + l - \
m + o)\)\^2 + \((a - c - f + h - i + k + n - p)\)\^2}, , , {1, 4, 3, 2, 13, 
            16, 15, 14, 9, 12, 11, 10, 5, 8, 7, 6, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
            1}, , };\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Hoop["\<KiC4\>"] = {16, 
          3, \[IndentingNewLine]{{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 
              14, 15, 16}, {2, 1, 4, 3, 6, 5, 8, 7, 10, 9, 12, 11, 14, 13, 
              16, 15}, {3, 4, 1, 2, 7, 8, 5, 6, 11, 12, 9, 10, 15, 16, 13, 
              14}, {4, 3, 2, 1, 8, 7, 6, 5, 12, 11, 10, 9, 16, 15, 14, 
              13}, {5, 8, 7, 6, 9, 12, 11, 10, 13, 16, 15, 14, 1, 4, 3, 
              2}, {6, 7, 8, 5, 10, 11, 12, 9, 14, 15, 16, 13, 2, 3, 4, 
              1}, {7, 6, 5, 8, 11, 10, 9, 12, 15, 14, 13, 16, 3, 2, 1, 
              4}, {8, 5, 6, 7, 12, 9, 10, 11, 16, 13, 14, 15, 4, 1, 2, 
              3}, {9, 10, 11, 12, 13, 14, 15, 16, 1, 2, 3, 4, 5, 6, 7, 
              8}, {10, 9, 12, 11, 14, 13, 16, 15, 2, 1, 4, 3, 6, 5, 8, 
              7}, {11, 12, 9, 10, 15, 16, 13, 14, 3, 4, 1, 2, 7, 8, 5, 
              6}, {12, 11, 10, 9, 16, 15, 14, 13, 4, 3, 2, 1, 8, 7, 6, 
              5}, {13, 16, 15, 14, 1, 4, 3, 2, 5, 8, 7, 6, 9, 12, 11, 
              10}, {14, 15, 16, 13, 2, 3, 4, 1, 6, 7, 8, 5, 10, 11, 12, 
              9}, {15, 14, 13, 16, 3, 2, 1, 4, 7, 6, 5, 8, 11, 10, 9, 
              12}, {16, 13, 14, 15, 4, 1, 2, 3, 8, 5, 6, 7, 12, 9, 10, 
              11}}, {a + b + c + d + e + f + g + h + i + j + k + l + m + n + 
              o + p, a - b + c - d - e + f - g + h + i - j + k - l - m + n - 
              o + p, a - b + c - d + e - f + g - h + i - j + k - l + m - n + 
              o - p, a + b + c + d - e - f - g - h + i + j + k + l - m - n - 
              o - p, \((a + b + c + d - i - j - k - l)\)\^2 + \((\(-e\) - f - \
g - h + m + n + o + p)\)\^2, \((a - b + c - d - i + j - k + l)\)\^2 + \((\(-e\
\) + f - g + h + m - n + o - p)\)\^2, \((a - c + i - k)\)\^2 - \((b - d + j - \
l)\)\^2 - \((e - g + m - o)\)\^2 + \((f - h + n - p)\)\^2, \((a - c - i + \
k)\)\^2 - \((b - d - j + l)\)\^2 + \((e - g - m + o)\)\^2 - \((f - h - n + p)\
\)\^2}, , , {1, 2, 3, 4, 13, 16, 15, 14, 9, 10, 11, 12, 5, 8, 7, 6, 1, 1, 1, 
            1, 1, 1, 2, 2}, , };\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Hoop["\<C4iC4\>"] = {16, 
          4, \[IndentingNewLine]{{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 
              14, 15, 16}, {2, 3, 4, 1, 6, 7, 8, 5, 10, 11, 12, 9, 14, 15, 
              16, 13}, {3, 4, 1, 2, 7, 8, 5, 6, 11, 12, 9, 10, 15, 16, 13, 
              14}, {4, 1, 2, 3, 8, 5, 6, 7, 12, 9, 10, 11, 16, 13, 14, 
              15}, {5, 8, 7, 6, 9, 12, 11, 10, 13, 16, 15, 14, 1, 4, 3, 
              2}, {6, 5, 8, 7, 10, 9, 12, 11, 14, 13, 16, 15, 2, 1, 4, 
              3}, {7, 6, 5, 8, 11, 10, 9, 12, 15, 14, 13, 16, 3, 2, 1, 
              4}, {8, 7, 6, 5, 12, 11, 10, 9, 16, 15, 14, 13, 4, 3, 2, 
              1}, {9, 10, 11, 12, 13, 14, 15, 16, 1, 2, 3, 4, 5, 6, 7, 
              8}, {10, 11, 12, 9, 14, 15, 16, 13, 2, 3, 4, 1, 6, 7, 8, 
              5}, {11, 12, 9, 10, 15, 16, 13, 14, 3, 4, 1, 2, 7, 8, 5, 
              6}, {12, 9, 10, 11, 16, 13, 14, 15, 4, 1, 2, 3, 8, 5, 6, 
              7}, {13, 16, 15, 14, 1, 4, 3, 2, 5, 8, 7, 6, 9, 12, 11, 
              10}, {14, 13, 16, 15, 2, 1, 4, 3, 6, 5, 8, 7, 10, 9, 12, 
              11}, {15, 14, 13, 16, 3, 2, 1, 4, 7, 6, 5, 8, 11, 10, 9, 
              12}, {16, 15, 14, 13, 4, 3, 2, 1, 8, 7, 6, 5, 12, 11, 10, 
              9}}, {a + b + c + d + e + f + g + h + i + j + k + l + m + n + 
              o + p, a - b + c - d - e + f - g + h + i - j + k - l - m + n - 
              o + p, a - b + c - d + e - f + g - h + i - j + k - l + m - n + 
              o - p, a + b + c + d - e - f - g - h + i + j + k + l - m - n - 
              o - p, \((a + b + c + d - i - j - k - l)\)\^2 + \((\(-e\) - f - \
g - h + m + n + o + p)\)\^2, \((a - b + c - d - i + j - k + l)\)\^2 + \((\(-e\
\) + f - g + h + m - n + o - p)\)\^2, \((a - c + i - k)\)\^2 + \((b - d + j - \
l)\)\^2 - \((e - g + m - o)\)\^2 - \((f - h + n - p)\)\^2, \((a - c - i + \
k)\)\^2 + \((b - d - j + l)\)\^2 + \((e - g - m + o)\)\^2 + \((f - h - n + p)\
\)\^2}, , , {1, 4, 3, 2, 13, 14, 15, 16, 9, 12, 11, 10, 5, 6, 7, 8, 1, 1, 1, 
            1, 1, 1, 2, 2}, , };\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Hoop["\<D8\>"] = {16, 
          7, {{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16}, {2, 1, 
              16, 15, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 3}, {3, 4, 5, 6, 
              7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 1, 2}, {4, 3, 2, 1, 16, 
              15, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5}, {5, 6, 7, 8, 9, 10, 11, 
              12, 13, 14, 15, 16, 1, 2, 3, 4}, {6, 5, 4, 3, 2, 1, 16, 15, 14, 
              13, 12, 11, 10, 9, 8, 7}, {7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 
              1, 2, 3, 4, 5, 6}, {8, 7, 6, 5, 4, 3, 2, 1, 16, 15, 14, 13, 12, 
              11, 10, 9}, {9, 10, 11, 12, 13, 14, 15, 16, 1, 2, 3, 4, 5, 6, 
              7, 8}, {10, 9, 8, 7, 6, 5, 4, 3, 2, 1, 16, 15, 14, 13, 12, 
              11}, {11, 12, 13, 14, 15, 16, 1, 2, 3, 4, 5, 6, 7, 8, 9, 
              10}, {12, 11, 10, 9, 8, 7, 6, 5, 4, 3, 2, 1, 16, 15, 14, 
              13}, {13, 14, 15, 16, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 
              12}, {14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 3, 2, 1, 16, 
              15}, {15, 16, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 
              14}, {16, 15, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 3, 2, 
              1}}, {a + b + c + d + e + f + g + h + i + j + k + l + m + n + 
              o + p, a - b + c - d + e - f + g - h + i - j + k - l + m - n + 
              o - p, a + b - c - d + e + f - g - h + i + j - k - l + m + n - 
              o - p, a - b - c + d + e - f - g + h + i - j - k + l + m - n - 
              o + p, \((a - e + i - m)\)\^2 - \((b - f + j - n)\)\^2 + \((c - \
g + k - o)\)\^2 - \((d - h + l - p)\)\^2, \(-2\)\ \((\((a - i)\)\ \((c - k)\) \
- \((b - j)\)\ \((d - l)\) + \((c - k)\)\ \((e - m)\) - \((d - l)\)\ \((f - \
n)\) - \((a - i)\)\ \((g - o)\) + \((e - m)\)\ \((g - o)\) + \((b - j)\)\ \
\((h - p)\) - \((f - n)\)\ \((h - p)\))\)\^2 + \((\((a - i)\)\^2 - \((b - \
j)\)\^2 + \((c - k)\)\^2 - \((d - l)\)\^2 + \((e - m)\)\^2 - \((f - n)\)\^2 + \
\((g - o)\)\^2 - \((h - p)\)\^2)\)\^2}, , , {1, 2, 15, 4, 13, 6, 11, 8, 9, 
            10, 7, 12, 5, 14, 3, 16, 1, 1, 1, 1, 2, 2}, gp, };\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Hoop["\<Q16\>"] = {16, 
          9, {{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16}, {2, 9, 
              16, 7, 14, 5, 12, 3, 10, 1, 8, 15, 6, 13, 4, 11}, {3, 4, 5, 6, 
              7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 1, 2}, {4, 11, 2, 9, 16, 
              7, 14, 5, 12, 3, 10, 1, 8, 15, 6, 13}, {5, 6, 7, 8, 9, 10, 11, 
              12, 13, 14, 15, 16, 1, 2, 3, 4}, {6, 13, 4, 11, 2, 9, 16, 7, 
              14, 5, 12, 3, 10, 1, 8, 15}, {7, 8, 9, 10, 11, 12, 13, 14, 15, 
              16, 1, 2, 3, 4, 5, 6}, {8, 15, 6, 13, 4, 11, 2, 9, 16, 7, 14, 
              5, 12, 3, 10, 1}, {9, 10, 11, 12, 13, 14, 15, 16, 1, 2, 3, 4, 
              5, 6, 7, 8}, {10, 1, 8, 15, 6, 13, 4, 11, 2, 9, 16, 7, 14, 5, 
              12, 3}, {11, 12, 13, 14, 15, 16, 1, 2, 3, 4, 5, 6, 7, 8, 9, 
              10}, {12, 3, 10, 1, 8, 15, 6, 13, 4, 11, 2, 9, 16, 7, 14, 
              5}, {13, 14, 15, 16, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 
              12}, {14, 5, 12, 3, 10, 1, 8, 15, 6, 13, 4, 11, 2, 9, 16, 
              7}, {15, 16, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 
              14}, {16, 7, 14, 5, 12, 3, 10, 1, 8, 15, 6, 13, 4, 11, 2, 
              9}}, {a + b + c + d + e + f + g + h + i + j + k + l + m + n + 
              o + p, a - b + c - d + e - f + g - h + i - j + k - l + m - n + 
              o - p, a + b - c - d + e + f - g - h + i + j - k - l + m + n - 
              o - p, a - b - c + d + e - f - g + h + i - j - k + l + m - n - 
              o + p, \((a - e + i - m)\)\^2 - \((b - f + j - n)\)\^2 + \((c - \
g + k - o)\)\^2 - \((d - h + l - p)\)\^2, \((a - i)\)\^4 + 
              2\ \((a - i)\)\^2\ \((b - j)\)\^2 + \((b - j)\)\^4 + 
              2\ \((b - j)\)\^2\ \((c - k)\)\^2 + \((c - k)\)\^4 - 
              4\ \((a - i)\)\ \((b - j)\)\ \((c - k)\)\ \((d - l)\) + 
              2\ \((a - i)\)\^2\ \((d - l)\)\^2 + 
              2\ \((c - k)\)\^2\ \((d - l)\)\^2 + \((d - l)\)\^4 - 
              4\ \((a - i)\)\ \((c - k)\)\^2\ \((e - m)\) - 
              4\ \((b - j)\)\ \((c - k)\)\ \((d - l)\)\ \((e - m)\) + 
              2\ \((a - i)\)\^2\ \((e - m)\)\^2 + 
              2\ \((b - j)\)\^2\ \((e - m)\)\^2 + 
              2\ \((d - l)\)\^2\ \((e - m)\)\^2 + \((e - m)\)\^4 - 
              4\ \((a - i)\)\ \((c - k)\)\ \((d - l)\)\ \((f - n)\) - 
              4\ \((b - j)\)\ \((d - l)\)\^2\ \((f - n)\) - 
              4\ \((c - k)\)\ \((d - l)\)\ \((e - m)\)\ \((f - n)\) + 
              2\ \((a - i)\)\^2\ \((f - n)\)\^2 + 
              2\ \((b - j)\)\^2\ \((f - n)\)\^2 + 
              2\ \((c - k)\)\^2\ \((f - n)\)\^2 + 
              2\ \((e - m)\)\^2\ \((f - n)\)\^2 + \((f - n)\)\^4 + 
              4\ \((a - i)\)\^2\ \((c - k)\)\ \((g - o)\) + 
              4\ \((a - i)\)\ \((b - j)\)\ \((d - l)\)\ \((g - o)\) - 
              4\ \((b - j)\)\ \((d - l)\)\ \((e - m)\)\ \((g - o)\) - 
              4\ \((c - k)\)\ \((e - m)\)\^2\ \((g - o)\) + 
              4\ \((a - i)\)\ \((d - l)\)\ \((f - n)\)\ \((g - o)\) - 
              4\ \((d - l)\)\ \((e - m)\)\ \((f - n)\)\ \((g - o)\) + 
              2\ \((b - j)\)\^2\ \((g - o)\)\^2 + 
              2\ \((c - k)\)\^2\ \((g - o)\)\^2 + 
              2\ \((d - l)\)\^2\ \((g - o)\)\^2 + 
              4\ \((a - i)\)\ \((e - m)\)\ \((g - o)\)\^2 + 
              2\ \((f - n)\)\^2\ \((g - o)\)\^2 + \((g - o)\)\^4 + 
              4\ \((a - i)\)\ \((b - j)\)\ \((c - k)\)\ \((h - p)\) + 
              4\ \((b - j)\)\^2\ \((d - l)\)\ \((h - p)\) + 
              4\ \((b - j)\)\ \((c - k)\)\ \((e - m)\)\ \((h - p)\) - 
              4\ \((a - i)\)\ \((c - k)\)\ \((f - n)\)\ \((h - p)\) - 
              4\ \((c - k)\)\ \((e - m)\)\ \((f - n)\)\ \((h - p)\) - 
              4\ \((d - l)\)\ \((f - n)\)\^2\ \((h - p)\) - 
              4\ \((a - i)\)\ \((b - j)\)\ \((g - o)\)\ \((h - p)\) + 
              4\ \((b - j)\)\ \((e - m)\)\ \((g - o)\)\ \((h - p)\) + 
              4\ \((a - i)\)\ \((f - n)\)\ \((g - o)\)\ \((h - p)\) - 
              4\ \((e - m)\)\ \((f - n)\)\ \((g - o)\)\ \((h - p)\) + 
              2\ \((a - i)\)\^2\ \((h - p)\)\^2 + 
              2\ \((c - k)\)\^2\ \((h - p)\)\^2 + 
              2\ \((d - l)\)\^2\ \((h - p)\)\^2 + 
              2\ \((e - m)\)\^2\ \((h - p)\)\^2 + 
              4\ \((b - j)\)\ \((f - n)\)\ \((h - p)\)\^2 + 
              2\ \((g - o)\)\^2\ \((h - p)\)\^2 + \((h - p)\)\^4}, , , {1, 
            10, 15, 12, 13, 14, 11, 16, 9, 2, 7, 4, 5, 6, 3, 8, 1, 1, 1, 1, 
            2, 2}, gp, };\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Hoop["\<C4K\>"] = {16, 
          10, \[IndentingNewLine]{{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 
              14, 15, 16}, {2, 3, 4, 1, 6, 7, 8, 5, 10, 11, 12, 9, 14, 15, 
              16, 13}, {3, 4, 1, 2, 7, 8, 5, 6, 11, 12, 9, 10, 15, 16, 13, 
              14}, {4, 1, 2, 3, 8, 5, 6, 7, 12, 9, 10, 11, 16, 13, 14, 
              15}, {5, 6, 7, 8, 1, 2, 3, 4, 13, 14, 15, 16, 9, 10, 11, 
              12}, {6, 7, 8, 5, 2, 3, 4, 1, 14, 15, 16, 13, 10, 11, 12, 
              9}, {7, 8, 5, 6, 3, 4, 1, 2, 15, 16, 13, 14, 11, 12, 9, 
              10}, {8, 5, 6, 7, 4, 1, 2, 3, 16, 13, 14, 15, 12, 9, 10, 
              11}, {9, 10, 11, 12, 13, 14, 15, 16, 1, 2, 3, 4, 5, 6, 7, 
              8}, {10, 11, 12, 9, 14, 15, 16, 13, 2, 3, 4, 1, 6, 7, 8, 
              5}, {11, 12, 9, 10, 15, 16, 13, 14, 3, 4, 1, 2, 7, 8, 5, 
              6}, {12, 9, 10, 11, 16, 13, 14, 15, 4, 1, 2, 3, 8, 5, 6, 
              7}, {13, 14, 15, 16, 9, 10, 11, 12, 5, 6, 7, 8, 1, 2, 3, 
              4}, {14, 15, 16, 13, 10, 11, 12, 9, 6, 7, 8, 5, 2, 3, 4, 
              1}, {15, 16, 13, 14, 11, 12, 9, 10, 7, 8, 5, 6, 3, 4, 1, 
              2}, {16, 13, 14, 15, 12, 9, 10, 11, 8, 5, 6, 7, 4, 1, 2, 
              3}}, {a + b + c + d + e + f + g + h + i + j + k + l + m + n + 
              o + p, a + b + c + d - e - f - g - h - i - j - k - l + m + n + 
              o + p, a - b + c - d + e - f + g - h - i + j - k + l - m + n - 
              o + p, a - b + c - d - e + f - g + h + i - j + k - l - m + n - 
              o + p, a - b + c - d - e + f - g + h - i + j - k + l + m - n + 
              o - p, a - b + c - d + e - f + g - h + i - j + k - l + m - n + 
              o - p, a + b + c + d - e - f - g - h + i + j + k + l - m - n - 
              o - p, a + b + c + d + e + f + g + h - i - j - k - l - m - n - 
              o - p, \((a - c - e + g - i + k + m - o)\)\^2 + \((b - d - f + \
h - j + l + n - p)\)\^2, \((a - c + e - g - i + k - m + o)\)\^2 + \((b - d + \
f - h - j + l - n + p)\)\^2, \((a - c - e + g + i - k - m + o)\)\^2 + \((b - \
d - f + h + j - l - n + p)\)\^2, \((a - c + e - g + i - k + m - o)\)\^2 + \
\((b - d + f - h + j - l + n - p)\)\^2}, {a + b + c + d + e + f + g + h + i + 
              j + k + l + m + n + o + p, 
            a + b + c + d - e - f - g - h - i - j - k - l + m + n + o + p, 
            a - b + c - d + e - f + g - h - i + j - k + l - m + n - o + p, 
            a - b + c - d - e + f - g + h + i - j + k - l - m + n - o + p, 
            a - b + c - d - e + f - g + h - i + j - k + l + m - n + o - p, 
            a - b + c - d + e - f + g - h + i - j + k - l + m - n + o - p, 
            a + b + c + d - e - f - g - h + i + j + k + l - m - n - o - p, 
            a + b + c + d + e + f + g + h - i - j - k - l - m - n - o - 
              p, \[IndentingNewLine] (*ij*) \((a - c - e + g - i + k + m - o)\
\)\^2 + \((b - d - f + h - j + l + n - p)\)\^2, 
            If[b - d - f + h - j + l + n - p \[Equal] 0, 0, 
              ArcTan[a - c - e + g - i + k + m - o, 
                b - d - f + h - j + l + n - 
                  p]], \[IndentingNewLine] (*kl*) \((a - c + e - g - i + k - \
m + o)\)\^2 + \((b - d + f - h - j + l - n + p)\)\^2, 
            If[b - d + f - h - j + l - n + p \[Equal] 0, 0, 
              ArcTan[a - c + e - g - i + k - m + o, 
                b - d + f - h - j + l - n + 
                  p]], \[IndentingNewLine] (*mn*) \((a - c - e + g + i - k - \
m + o)\)\^2 + \((b - d - f + h + j - l - n + p)\)\^2, 
            If[b - d - f + h + j - l - n + p \[Equal] 0, 0, 
              ArcTan[a - c - e + g + i - k - m + o, 
                b - d - f + h + j - l - n + 
                  p]], \[IndentingNewLine] (*op*) \((a - c + e - g + i - k + \
m - o)\)\^2 + \((b - d + f - h + j - l + n - p)\)\^2, 
            If[b - d + f - h + j - l + n - p \[Equal] 0, 0, 
              ArcTan[a - c + e - g + i - k + m - o, 
                b - d + f - h + j - l + n - p]]}, { (*a*) a + b + c + d + e + 
                f + g + h + 2  Sqrt[i]\ Cos[j] + 2  Sqrt[k]\ Cos[l] + 
                2  Sqrt[m]\ Cos[n] + 
                2  Sqrt[o]\ Cos[p], \[IndentingNewLine] (*b*) a + b - c - d - 
                e - f + g + h + 2  Sqrt[i]\ Sin[j] + 2  Sqrt[k]\ Sin[l] + 
                2  Sqrt[m]\ Sin[n] + 
                2  Sqrt[o]\ Sin[p], \[IndentingNewLine] (*c*) a + b + c + d + 
                e + f + g + h - 2  Sqrt[i]\ Cos[j] - 2  Sqrt[k]\ Cos[l] - 
                2  Sqrt[m]\ Cos[n] - 
                2  Sqrt[o]\ Cos[p], \[IndentingNewLine] (*d*) a + b - c - d - 
                e - f + g + h - 2  Sqrt[i]\ Sin[j] - 2  Sqrt[k]\ Sin[l] - 
                2  Sqrt[m]\ Sin[n] - 
                2  Sqrt[o]\ Sin[p], \[IndentingNewLine] (*e*) a - b + c - d - 
                e + f - g + h - 2  Sqrt[i]\ Cos[j] + 2  Sqrt[k]\ Cos[l] - 
                2  Sqrt[m]\ Cos[n] + 
                2  Sqrt[o]\ Cos[p], \[IndentingNewLine] (*f*) a - b - c + d + 
                e - f - g + h - 2  Sqrt[i]\ Sin[j] + 2  Sqrt[k]\ Sin[l] - 
                2  Sqrt[m]\ Sin[n] + 
                2  Sqrt[o]\ Sin[p], \[IndentingNewLine] (*g*) a - b + c - d - 
                e + f - g + h + 2  Sqrt[i]\ Cos[j] - 2  Sqrt[k]\ Cos[l] + 
                2  Sqrt[m]\ Cos[n] - 
                2  Sqrt[o]\ Cos[p], \[IndentingNewLine] (*h*) a - b - c + d + 
                e - f - g + h + 2  Sqrt[i]\ Sin[j] - 2  Sqrt[k]\ Sin[l] + 
                2  Sqrt[m]\ Sin[n] - 
                2  Sqrt[o]\ Sin[p], \[IndentingNewLine] (*i*) a - b - c + d - 
                e + f + g - h - 2  Sqrt[i]\ Cos[j] - 2  Sqrt[k]\ Cos[l] + 
                2  Sqrt[m]\ Cos[n] + 
                2  Sqrt[o]\ Cos[p], \[IndentingNewLine] (*j*) a - b + c - d + 
                e - f + g - h - 2  Sqrt[i]\ Sin[j] - 2  Sqrt[k]\ Sin[l] + 
                2  Sqrt[m]\ Sin[n] + 
                2  Sqrt[o]\ Sin[p], \[IndentingNewLine] (*k*) a - b - c + d - 
                e + f + g - h + 2  Sqrt[i]\ Cos[j] + 2  Sqrt[k]\ Cos[l] - 
                2  Sqrt[m]\ Cos[n] - 
                2  Sqrt[o]\ Cos[p], \[IndentingNewLine] (*l*) a - b + c - d + 
                e - f + g - h + 2  Sqrt[i]\ Sin[j] + 2  Sqrt[k]\ Sin[l] - 
                2  Sqrt[m]\ Sin[n] - 
                2  Sqrt[o]\ Sin[p], \[IndentingNewLine] (*m*) a + b - c - d + 
                e + f - g - h + 2  Sqrt[i]\ Cos[j] - 2  Sqrt[k]\ Cos[l] - 
                2  Sqrt[m]\ Cos[n] + 
                2  Sqrt[o]\ Cos[p], \[IndentingNewLine] (*n*) a + b + c + d - 
                e - f - g - h + 2  Sqrt[i]\ Sin[j] - 2  Sqrt[k]\ Sin[l] - 
                2  Sqrt[m]\ Sin[n] + 
                2  Sqrt[o]\ Sin[p], \[IndentingNewLine] (*o*) a + b - c - d + 
                e + f - g - h - 2  Sqrt[i]\ Cos[j] + 2  Sqrt[k]\ Cos[l] + 
                2  Sqrt[m]\ Cos[n] - 
                2  Sqrt[o]\ Cos[p], \[IndentingNewLine] (*p*) a + b + c + d - 
                e - f - g - h - 2  Sqrt[i]\ Sin[j] + 2  Sqrt[k]\ Sin[l] + 
                2  Sqrt[m]\ Sin[n] - 2  Sqrt[o]\ Sin[p]}/16, {1, 4, 3, 2, 5, 
            8, 7, 6, 9, 12, 11, 10, 13, 16, 15, 14, 1, 1, 1, 1, 1, 1, 1, 1, 
            1, 1, 1, 1}, {1, 1, 1, 1, 1, 1, 1, 1, 1, 0. , 1, 0. , 1, 0. , 1, 
            0. }, };\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Hoop["\<D4C2\>"] = {16, 
          11, \[IndentingNewLine]{{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 
              14, 15, 16}, {2, 1, 4, 3, 6, 5, 8, 7, 10, 9, 12, 11, 14, 13, 
              16, 15}, {3, 8, 5, 2, 7, 4, 1, 6, 11, 16, 13, 10, 15, 12, 9, 
              14}, {4, 7, 6, 1, 8, 3, 2, 5, 12, 15, 14, 9, 16, 11, 10, 
              13}, {5, 6, 7, 8, 1, 2, 3, 4, 13, 14, 15, 16, 9, 10, 11, 
              12}, {6, 5, 8, 7, 2, 1, 4, 3, 14, 13, 16, 15, 10, 9, 12, 
              11}, {7, 4, 1, 6, 3, 8, 5, 2, 15, 12, 9, 14, 11, 16, 13, 
              10}, {8, 3, 2, 5, 4, 7, 6, 1, 16, 11, 10, 13, 12, 15, 14, 
              9}, {9, 10, 11, 12, 13, 14, 15, 16, 1, 2, 3, 4, 5, 6, 7, 
              8}, {10, 9, 12, 11, 14, 13, 16, 15, 2, 1, 4, 3, 6, 5, 8, 
              7}, {11, 16, 13, 10, 15, 12, 9, 14, 3, 8, 5, 2, 7, 4, 1, 
              6}, {12, 15, 14, 9, 16, 11, 10, 13, 4, 7, 6, 1, 8, 3, 2, 
              5}, {13, 14, 15, 16, 9, 10, 11, 12, 5, 6, 7, 8, 1, 2, 3, 
              4}, {14, 13, 16, 15, 10, 9, 12, 11, 6, 5, 8, 7, 2, 1, 4, 
              3}, {15, 12, 9, 14, 11, 16, 13, 10, 7, 4, 1, 6, 3, 8, 5, 
              2}, {16, 11, 10, 13, 12, 15, 14, 9, 8, 3, 2, 5, 4, 7, 6, 
              1}}, {a + b + c + d + e + f + g + h - i - j - k - l - m - n - 
              o - p, a + b - c - d + e + f - g - h + i + j - k - l + m + n - 
              o - p, a - b + c - d + e - f + g - h + i - j + k - l + m - n + 
              o - p, a - b - c + d + e - f - g + h - i + j + k - l - m + n + 
              o - p, a - b - c + d + e - f - g + h + i - j - k + l + m - n - 
              o + p, a - b + c - d + e - f + g - h - i + j - k + l - m + n - 
              o + p, a + b - c - d + e + f - g - h - i - j + k + l - m - n + 
              o + p, a + b + c + d + e + f + g + h + i + j + k + l + m + n + 
              o + p, \((a - e + i - m)\)\^2 - \((b - f + j - n)\)\^2 + \((c - \
g + k - o)\)\^2 - \((d - h + l - p)\)\^2, \((a - e - i + m)\)\^2 - \((b - f - \
j + n)\)\^2 + \((c - g - k + o)\)\^2 - \((d - h - l + p)\)\^2}, , , {1, 2, 7, 
            4, 5, 6, 3, 8, 9, 10, 15, 12, 13, 14, 11, 16, 1, 1, 1, 1, 1, 1, 
            1, 1, 2, 2}, , {a, c, b, d, f, e, g, i, h, j, l, 
            k}};\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Hoop["\<Q8C2\>"] = {16, 
          12, \[IndentingNewLine]{{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 
              14, 15, 16}, {2, 5, 4, 7, 6, 1, 8, 3, 10, 13, 12, 15, 14, 9, 
              16, 11}, {3, 8, 5, 2, 7, 4, 1, 6, 11, 16, 13, 10, 15, 12, 9, 
              14}, {4, 3, 6, 5, 8, 7, 2, 1, 12, 11, 14, 13, 16, 15, 10, 
              9}, {5, 6, 7, 8, 1, 2, 3, 4, 13, 14, 15, 16, 9, 10, 11, 
              12}, {6, 1, 8, 3, 2, 5, 4, 7, 14, 9, 16, 11, 10, 13, 12, 
              15}, {7, 4, 1, 6, 3, 8, 5, 2, 15, 12, 9, 14, 11, 16, 13, 
              10}, {8, 7, 2, 1, 4, 3, 6, 5, 16, 15, 10, 9, 12, 11, 14, 
              13}, {9, 10, 11, 12, 13, 14, 15, 16, 1, 2, 3, 4, 5, 6, 7, 
              8}, {10, 13, 12, 15, 14, 9, 16, 11, 2, 5, 4, 7, 6, 1, 8, 
              3}, {11, 16, 13, 10, 15, 12, 9, 14, 3, 8, 5, 2, 7, 4, 1, 
              6}, {12, 11, 14, 13, 16, 15, 10, 9, 4, 3, 6, 5, 8, 7, 2, 
              1}, {13, 14, 15, 16, 9, 10, 11, 12, 5, 6, 7, 8, 1, 2, 3, 
              4}, {14, 9, 16, 11, 10, 13, 12, 15, 6, 1, 8, 3, 2, 5, 4, 
              7}, {15, 12, 9, 14, 11, 16, 13, 10, 7, 4, 1, 6, 3, 8, 5, 
              2}, {16, 15, 10, 9, 12, 11, 14, 13, 8, 7, 2, 1, 4, 3, 6, 
              5}}, {a + b + c + d + e + f + g + h + i + j + k + l + m + n + 
              o + p, a - b - c + d + e - f - g + h + i - j - k + l + m - n - 
              o + p, a - b + c - d + e - f + g - h + i - j + k - l + m - n + 
              o - p, a + b - c - d + e + f - g - h + i + j - k - l + m + n - 
              o - p, a + b + c + d + e + f + g + h - i - j - k - l - m - n - 
              o - p, a + b - c - d + e + f - g - h - i - j + k + l - m - n + 
              o + p, a - b - c + d + e - f - g + h - i + j + k - l - m + n + 
              o - p, a - b + c - d + e - f + g - h - i + j - k + l - m + n - 
              o + p, \((a - e + i - m)\)\^2 + \((b - f + j - n)\)\^2 + \((c - \
g + k - o)\)\^2 + \((d - h + l - p)\)\^2, \((a - e - i + m)\)\^2 + \((b - f - \
j + n)\)\^2 + \((c - g - k + o)\)\^2 + \((d - h - l + p)\)\^2}, , , {1, 6, 7, 
            8, 5, 2, 3, 4, 9, 14, 15, 16, 13, 10, 11, 12, 1, 1, 1, 1, 1, 1, 
            1, 1, 2, 2}, 
          gp, {a, c, b, d, f, e, g, i, h, j, l, k}};\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"P16\"]={16,13,
{{1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16},{2,1,8,15,6,5,12,3,10,9,16,7,14,13,\
4,11},{3,16,1,6,7,4,5,10,11,8,9,14,15,12,13,2},{4,7,14,1,8,11,2,5,12,15,6,9,\
16,3,10,13},{5,6,7,8,9,10,11,12,13,14,15,16,1,2,3,4},{6,5,12,3,10,9,16,7,14,\
13,4,11,2,1,8,15},{7,4,5,10,11,8,9,14,15,12,13,2,3,16,1,6},{8,11,2,5,12,15,6,\
9,16,3,10,13,4,7,14,1},{9,10,11,12,13,14,15,16,1,2,3,4,5,6,7,8},{10,9,16,7,14,\
13,4,11,2,1,8,15,6,5,12,3},{11,8,9,14,15,12,13,2,3,16,1,6,7,4,5,10},{12,15,6,\
9,16,3,10,13,4,7,14,1,8,11,2,5},{13,14,15,16,1,2,3,4,5,6,7,8,9,10,11,12},{14,\
13,4,11,2,1,8,15,6,5,12,3,10,9,16,7},{15,12,13,2,3,16,1,6,7,4,5,10,11,8,9,14},\
{16,3,10,13,4,7,14,1,8,11,2,5,12,15,6,9}},{a+b+c+d+e+f+g+h+i+j+k+l+m+n+o+p,a-\
b+c-d+e-f+g-h+i-j+k-l+m-n+o-p,a+b-c-d+e+f-g-h+i+j-k-l+m+n-o-p,a-b-c+d+e-f-g+h+\
i-j-k+l+m-n-o+p,a+b+c-d-e-f-g+h+i+j+k-l-m-n-o+p,a+b-c+d-e-f+g-h+i+j-k+l-m-n+o-\
p,a-b+c+d-e+f-g-h+i-j+k+l-m+n-o-p,a-b-c-d-e+f+g+h+i-j-k-l-m+n+o+p,4*((a-i)*(e-\
m)-(b-j)*(f-n)-(c-k)*(g-o)-(d-l)*(h-p))^2+((a-i)^2-(b-j)^2-(c-k)^2-(d-l)^2-(e-\
m)^2+(f-n)^2+(g-o)^2+(h-p)^2)^2},,,{1,2,3,4,13,14,15,16,9,10,11,12,5,6,7,8,1,\
1,1,1,1,1,1,1,2},gp,{a,b,c,-d,e,-f,-g,-h,i,-j,-k,-l,-m,-n,-o,p}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Hoop["\<KK\>"] = {16, 
          14, \[IndentingNewLine]{{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 
              14, 15, 16}, {2, 1, 4, 3, 6, 5, 8, 7, 10, 9, 12, 11, 14, 13, 
              16, 15}, {3, 4, 1, 2, 7, 8, 5, 6, 11, 12, 9, 10, 15, 16, 13, 
              14}, {4, 3, 2, 1, 8, 7, 6, 5, 12, 11, 10, 9, 16, 15, 14, 
              13}, {5, 6, 7, 8, 1, 2, 3, 4, 13, 14, 15, 16, 9, 10, 11, 
              12}, {6, 5, 8, 7, 2, 1, 4, 3, 14, 13, 16, 15, 10, 9, 12, 
              11}, {7, 8, 5, 6, 3, 4, 1, 2, 15, 16, 13, 14, 11, 12, 9, 
              10}, {8, 7, 6, 5, 4, 3, 2, 1, 16, 15, 14, 13, 12, 11, 10, 
              9}, {9, 10, 11, 12, 13, 14, 15, 16, 1, 2, 3, 4, 5, 6, 7, 
              8}, {10, 9, 12, 11, 14, 13, 16, 15, 2, 1, 4, 3, 6, 5, 8, 
              7}, {11, 12, 9, 10, 15, 16, 13, 14, 3, 4, 1, 2, 7, 8, 5, 
              6}, {12, 11, 10, 9, 16, 15, 14, 13, 4, 3, 2, 1, 8, 7, 6, 
              5}, {13, 14, 15, 16, 9, 10, 11, 12, 5, 6, 7, 8, 1, 2, 3, 
              4}, {14, 13, 16, 15, 10, 9, 12, 11, 6, 5, 8, 7, 2, 1, 4, 
              3}, {15, 16, 13, 14, 11, 12, 9, 10, 7, 8, 5, 6, 3, 4, 1, 
              2}, {16, 15, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 3, 2, 
              1}}, {a + b + c + d + e + f + g + h + i + j + k + l + m + n + 
              o + p, a - b - c + d + e - f - g + h + i - j - k + l + m - n - 
              o + p, a - b + c - d + e - f + g - h + i - j + k - l + m - n + 
              o - p, a + b - c - d + e + f - g - h + i + j - k - l + m + n - 
              o - p, a - b + c - d - e + f - g + h + i - j + k - l - m + n - 
              o + p, a + b - c - d - e - f + g + h + i + j - k - l - m - n + 
              o + p, a + b + c + d - e - f - g - h + i + j + k + l - m - n - 
              o - p, a - b - c + d - e + f + g - h + i - j - k + l - m + n + 
              o - p, a + b + c + d + e + f + g + h - i - j - k - l - m - n - 
              o - p, a + b + c + d - e - f - g - h - i - j - k - l + m + n + 
              o + p, a + b - c - d - e - f + g + h - i - j + k + l + m + n - 
              o - p, a - b + c - d - e + f - g + h - i + j - k + l + m - n + 
              o - p, a + b - c - d + e + f - g - h - i - j + k + l - m - n + 
              o + p, a - b - c + d + e - f - g + h - i + j + k - l - m + n + 
              o - p, a - b + c - d + e - f + g - h - i + j - k + l - m + n - 
              o + p, 
            a - b - c + d - e + f + g - h - i + j + k - l + m - n - o + 
              p}, {a + b + c + d + e + f + g + h + i + j + k + l + m + n + 
              o + p, a - b - c + d + e - f - g + h + i - j - k + l + m - n - 
              o + p, a - b + c - d + e - f + g - h + i - j + k - l + m - n + 
              o - p, a + b - c - d + e + f - g - h + i + j - k - l + m + n - 
              o - p, a - b + c - d - e + f - g + h + i - j + k - l - m + n - 
              o + p, a + b - c - d - e - f + g + h + i + j - k - l - m - n + 
              o + p, a + b + c + d - e - f - g - h + i + j + k + l - m - n - 
              o - p, a - b - c + d - e + f + g - h + i - j - k + l - m + n + 
              o - p, a + b + c + d + e + f + g + h - i - j - k - l - m - n - 
              o - p, a + b + c + d - e - f - g - h - i - j - k - l + m + n + 
              o + p, a + b - c - d - e - f + g + h - i - j + k + l + m + n - 
              o - p, a - b + c - d - e + f - g + h - i + j - k + l + m - n + 
              o - p, a + b - c - d + e + f - g - h - i - j + k + l - m - n + 
              o + p, a - b - c + d + e - f - g + h - i + j + k - l - m + n + 
              o - p, a - b + c - d + e - f + g - h - i + j - k + l - m + n - 
              o + p, a - b - c + d - e + f + g - h - i + j + k - l + m - n - 
              o + p}, {\ \((a + b + c + d + e + f + g + h + i + j + k + l + 
                  m + n + o + p)\), \((a - b - c + d - e + f + g - h + i + 
                  j + k - l + m - n - o - p)\), \ \((a - b + c - d + e - f + 
                  g - h + i + j - k + l - m - n + o - p)\), \ \((a + b - c - 
                  d - e - f + g + h + i + j - k - l - m + n - o + 
                  p)\), \ \((a + b + c + d - e - f - g - h + i - j - k - l + 
                  m + n + o - p)\), \ \((a - b - c + d + e - f - g + h + i - 
                  j - k + l + m - n - o + p)\), \((a - b + c - d - e + f - 
                  g + h + i - j + k - l - m - n + o + p)\), \ \((a + b - c - 
                  d + e + f - g - h + i - j + k + l - m + n - o - 
                  p)\), \((a + b + c + d + e + f + g + h - i - j - k - l - 
                  m - n - o - p)\), \((a - b - c + d - e + f + g - h - i - 
                  j - k + l - m + n + o + p)\), \((a - b + c - d + e - f + 
                  g - h - i - j + k - l + m + n - o + p)\), \((a + b - c - 
                  d - e - f + g + h - i - j + k + l + m - n + o - 
                  p)\), \ \((a + b + c + d - e - f - g - h - i + j + k + l - 
                  m - n - o + p)\), \ \((a - b - c + d + e - f - g + h - i + 
                  j + k - l - m + n + o - p)\), \ \((a - b + c - d - e + f - 
                  g + h - i + j - k + l + m + n - o - p)\), \ \((a + b - c - 
                  d + e + f - g - h - i + j - k - l + m - n + o + p)\)}/
            16, {1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 1, 1, 
            1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1}, {1, 1, 1, 1, 1, 1, 1, 
            1, 1, 1, 1, 1, 1, 1, 1, 1}, {a, c, b, d, f, e, g, i, h, j, l, 
            k}};\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Hoop["\<Oct\>"] = {16, 
          15, \[IndentingNewLine]{{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 
              14, 15, 16}, {2, 9, 12, 3, 14, 5, 8, 15, 10, 1, 4, 11, 6, 13, 
              16, 7}, {3, 4, 9, 10, 15, 16, 5, 6, 11, 12, 1, 2, 7, 8, 13, 
              14}, {4, 11, 2, 9, 16, 7, 14, 5, 12, 3, 10, 1, 8, 15, 6, 
              13}, {5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 1, 2, 3, 
              4}, {6, 13, 8, 15, 2, 9, 4, 11, 14, 5, 16, 7, 10, 1, 12, 
              3}, {7, 16, 13, 6, 3, 12, 9, 2, 15, 8, 5, 14, 11, 4, 1, 
              10}, {8, 7, 14, 13, 4, 3, 10, 9, 16, 15, 6, 5, 12, 11, 2, 
              1}, {9, 10, 11, 12, 13, 14, 15, 16, 1, 2, 3, 4, 5, 6, 7, 
              8}, {10, 1, 4, 11, 6, 13, 16, 7, 2, 9, 12, 3, 14, 5, 8, 
              15}, {11, 12, 1, 2, 7, 8, 13, 14, 3, 4, 9, 10, 15, 16, 5, 
              6}, {12, 3, 10, 1, 8, 15, 6, 13, 4, 11, 2, 9, 16, 7, 14, 
              5}, {13, 14, 15, 16, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 
              12}, {14, 5, 16, 7, 10, 1, 12, 3, 6, 13, 8, 15, 2, 9, 4, 
              11}, {15, 8, 5, 14, 11, 4, 1, 10, 7, 16, 13, 6, 3, 12, 9, 
              2}, {16, 15, 6, 5, 12, 11, 2, 1, 8, 7, 14, 13, 4, 3, 10, 
              9}}, {a + b + c + d + e + f + g + h + i + j + k + l + m + n + 
              o + p, a - b - c + d + e - f - g + h + i - j - k + l + m - n - 
              o + p, a - b + c - d + e - f + g - h + i - j + k - l + m - n + 
              o - p, a + b - c - d + e + f - g - h + i + j - k - l + m + n - 
              o - p, a - b + c - d - e + f - g + h + i - j + k - l - m + n - 
              o + p, a + b - c - d - e - f + g + h + i + j - k - l - m - n + 
              o + p, a + b + c + d - e - f - g - h + i + j + k + l - m - n - 
              o - p, a - b - c + d - e + f + g - h + i - j - k + l - m + n + 
              o - p, \((a - i)\)\^2 + \((b - j)\)\^2 + \((c - k)\)\^2 + \((d \
- l)\)\^2 + \((e - m)\)\^2 + \((f - n)\)\^2 + \((g - o)\)\^2 + \((h - \
p)\)\^2}, , , {1, 10, 11, 12, 13, 14, 15, 16, 9, 2, 3, 4, 5, 6, 7, 8, 1, 1, 
            1, 1, 1, 1, 1, 1, 4}, , {a, c, b, d, f, e, g, i, h, j, l, 
            k}};\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"r31r\"]={16,17,
{{1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16},{2,1,4,3,6,5,8,7,10,9,12,11,14,13,\
16,15},{3,-4,1,-2,7,-8,5,-6,11,-12,9,-10,15,-16,13,-14},{4,-3,2,-1,8,-7,6,-5,\
12,-11,10,-9,16,-15,14,-13},{5,-6,-7,8,-1,2,3,-4,13,-14,-15,16,-9,10,11,-12},{\
6,-5,-8,7,-2,1,4,-3,14,-13,-16,15,-10,9,12,-11},{7,8,-5,-6,-3,-4,1,2,15,16,-\
13,-14,-11,-12,9,10},{8,7,-6,-5,-4,-3,2,1,16,15,-14,-13,-12,-11,10,9},{9,-10,-\
11,12,-13,14,15,-16,1,-2,-3,4,-5,6,7,-8},{10,-9,-12,11,-14,13,16,-15,2,-1,-4,\
3,-6,5,8,-7},{11,12,-9,-10,-15,-16,13,14,3,4,-1,-2,-7,-8,5,6},{12,11,-10,-9,-\
16,-15,14,13,4,3,-2,-1,-8,-7,6,5},{13,14,15,16,9,10,11,12,5,6,7,8,1,2,3,4},{\
14,13,16,15,10,9,12,11,6,5,8,7,2,1,4,3},{15,-16,13,-14,11,-12,9,-10,7,-8,5,-6,\
3,-4,1,-2},{16,-15,14,-13,12,-11,10,-9,8,-7,6,-5,4,-3,2,-1}},{(a^2+b^2+c^2+d^\
2-e^2-f^2-g^2-h^2+i^2+j^2+k^2+l^2-m^2-n^2-o^2-p^2)^2-4*(-(h*i-g*j+f*k-e*l-d*m+\
c*n-b*o+a*p)^2+(a*i-b*j-c*k+d*l+e*m-f*n-g*o+h*p)^2-(a*e-b*f-c*g+d*h+i*m-j*n-k*\
o+l*p)^2+(a*c-b*d-e*g+f*h+i*k-j*l-m*o+n*p)^2+(a*b+c*d-e*f-g*h+i*j+k*l-m*n-o*p)\
^2)},,,{1,2,3,-4,-5,6,7,8,9,-10,-11,-12,13,14,15,-16,4},gp,{a,b,c,-d,e,-f,-g,-\
h,i,-j,-k,-l,-m,-n,-o,p}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Hoop["\<CL4\>"] = {16, 
          21, \[IndentingNewLine]{{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 
              14, 15, 16}, {2, 1, 4, 3, 6, 5, 8, 7, 10, 9, 12, 11, 14, 13, 
              16, 15}, {3, \(-4\), 1, \(-2\), 7, \(-8\), 5, \(-6\), 
              11, \(-12\), 9, \(-10\), 15, \(-16\), 13, \(-14\)}, {4, \(-3\), 
              2, \(-1\), 8, \(-7\), 6, \(-5\), 12, \(-11\), 10, \(-9\), 
              16, \(-15\), 14, \(-13\)}, {5, \(-6\), \(-7\), 8, 
              1, \(-2\), \(-3\), 4, 13, \(-14\), \(-15\), 16, 
              9, \(-10\), \(-11\), 12}, {6, \(-5\), \(-8\), 7, 
              2, \(-1\), \(-4\), 3, 14, \(-13\), \(-16\), 15, 
              10, \(-9\), \(-12\), 11}, {7, 8, \(-5\), \(-6\), 3, 
              4, \(-1\), \(-2\), 15, 16, \(-13\), \(-14\), 11, 
              12, \(-9\), \(-10\)}, {8, 7, \(-6\), \(-5\), 4, 
              3, \(-2\), \(-1\), 16, 15, \(-14\), \(-13\), 12, 
              11, \(-10\), \(-9\)}, {9, \(-10\), \(-11\), 12, \(-13\), 14, 
              15, \(-16\), 1, \(-2\), \(-3\), 4, \(-5\), 6, 
              7, \(-8\)}, {10, \(-9\), \(-12\), 11, \(-14\), 13, 16, \(-15\), 
              2, \(-1\), \(-4\), 3, \(-6\), 5, 8, \(-7\)}, {11, 
              12, \(-9\), \(-10\), \(-15\), \(-16\), 13, 14, 3, 
              4, \(-1\), \(-2\), \(-7\), \(-8\), 5, 6}, {12, 
              11, \(-10\), \(-9\), \(-16\), \(-15\), 14, 13, 4, 
              3, \(-2\), \(-1\), \(-8\), \(-7\), 6, 5}, {13, 14, 15, 
              16, \(-9\), \(-10\), \(-11\), \(-12\), 5, 6, 7, 
              8, \(-1\), \(-2\), \(-3\), \(-4\)}, {14, 13, 16, 
              15, \(-10\), \(-9\), \(-12\), \(-11\), 6, 5, 8, 
              7, \(-2\), \(-1\), \(-4\), \(-3\)}, {15, \(-16\), 
              13, \(-14\), \(-11\), 12, \(-9\), 10, 7, \(-8\), 
              5, \(-6\), \(-3\), 4, \(-1\), 2}, {16, \(-15\), 
              14, \(-13\), \(-12\), 11, \(-10\), 9, 8, \(-7\), 
              6, \(-5\), \(-4\), 3, \(-2\), 
              1}}, {\((a\^2 + b\^2 + c\^2 + d\^2 + e\^2 + f\^2 + g\^2 + h\^2 \
+ i\^2 + j\^2 + k\^2 + l\^2 + m\^2 + n\^2 + o\^2 + p\^2)\)\^2 - 
              4\ \((\((h\ i - g\ j + f\ k - e\ l - d\ m + c\ n - b\ o + a\ p)\
\)\^2 + \((a\ i - b\ j - c\ k + d\ l - e\ m + f\ n + g\ o - h\ p)\)\^2 + \((a\
\ e - b\ f - c\ g + d\ h + i\ m - j\ n - k\ o + l\ p)\)\^2 + \((a\ c - b\ d + \
e\ g - f\ h + i\ k - j\ l + m\ o - n\ p)\)\^2 + \((a\ b + c\ d + e\ f + g\ h \
+ i\ j + k\ l + m\ n + o\ p)\)\^2)\)}, , , {1, 2, 3, \(-4\), 
            5, \(-6\), \(-7\), \(-8\), 
            9, \(-10\), \(-11\), \(-12\), \(-13\), \(-14\), \(-15\), 16, 
            4}, , };\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"CL31\"]={16,22,
{{1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16},{2,-1,4,-3,6,-5,8,-7,10,-9,12,-11,\
14,-13,16,-15},{3,-4,1,-2,7,-8,5,-6,11,-12,9,-10,15,-16,13,-14},{4,3,2,1,8,7,\
6,5,12,11,10,9,16,15,14,13},{5,-6,-7,8,1,-2,-3,4,13,-14,-15,16,9,-10,-11,12},{\
6,5,-8,-7,2,1,-4,-3,14,13,-16,-15,10,9,-12,-11},{7,8,-5,-6,3,4,-1,-2,15,16,-\
13,-14,11,12,-9,-10},{8,-7,-6,5,4,-3,-2,1,16,-15,-14,13,12,-11,-10,9},{9,-10,-\
11,12,-13,14,15,-16,1,-2,-3,4,-5,6,7,-8},{10,9,-12,-11,-14,-13,16,15,2,1,-4,-\
3,-6,-5,8,7},{11,12,-9,-10,-15,-16,13,14,3,4,-1,-2,-7,
-8,5,6},{12,-11,-10,9,-16,15,14,-13,4,-3,-2,1,-8,7,6,-5},{13,14,15,16,-9,-10,-\
11,-12,5,6,7,8,-1,-2,-3,-4},{14,-13,16,-15,-10,9,-12,11,6,-5,8,-7,-2,1,-4,3},{\
15,-16,13,-14,-11,12,-9,10,7,-8,5,-6,-3,4,-1,2},{16,15,14,13,-12,-11,-10,-9,8,\
7,6,5,-4,-3,-2,-1}},{(a^2+b^2-c^2-d^2-e^2-f^2+g^2+h^2-i^2-j^2+k^2+l^2+m^2+n^2-\
o^2-p^2)^2-4*(-(-(h*i)-g*j+f*k+e*l-d*m-c*n+b*o+a*p)^2-(-(g*i)+h*j+e*k-f*l-c*m+\
d*n+a*o-b*p)^2+(-(f*i)+e*j+h*k-g*l-b*m+a*n+d*o-c*p)^2+(-(d*i)+c*j-b*k+a*l-h*m+\
g*n-f*o+e*p)^2+(-(d*e)+c*f-b*g+a*h+l*m-k*n+j*o-i*p)^2)},,,{1,-2,3,4,5,6,-7,8,\
9,10,-11,12,-13,14,-15,-16,4},gp,{a,c,b,-d,-e,-f}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Hoop["\<CL22\>"] = {16, 
          23, \[IndentingNewLine]{{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 
              14, 15, 16}, {2, \(-1\), 4, \(-3\), 6, \(-5\), 8, \(-7\), 
              10, \(-9\), 12, \(-11\), 14, \(-13\), 
              16, \(-15\)}, {3, \(-4\), \(-1\), 2, 7, \(-8\), \(-5\), 6, 
              11, \(-12\), \(-9\), 10, 15, \(-16\), \(-13\), 14}, {4, 
              3, \(-2\), \(-1\), 8, 7, \(-6\), \(-5\), 12, 
              11, \(-10\), \(-9\), 16, 
              15, \(-14\), \(-13\)}, {5, \(-6\), \(-7\), 8, 
              1, \(-2\), \(-3\), 4, 13, \(-14\), \(-15\), 16, 
              9, \(-10\), \(-11\), 12}, {6, 5, \(-8\), \(-7\), 2, 
              1, \(-4\), \(-3\), 14, 13, \(-16\), \(-15\), 10, 
              9, \(-12\), \(-11\)}, {7, 8, 5, 6, 3, 4, 1, 2, 15, 16, 13, 14, 
              11, 12, 9, 10}, {8, \(-7\), 6, \(-5\), 4, \(-3\), 2, \(-1\), 
              16, \(-15\), 14, \(-13\), 12, \(-11\), 
              10, \(-9\)}, {9, \(-10\), \(-11\), 12, \(-13\), 14, 
              15, \(-16\), 1, \(-2\), \(-3\), 4, \(-5\), 6, 7, \(-8\)}, {10, 
              9, \(-12\), \(-11\), \(-14\), \(-13\), 16, 15, 2, 
              1, \(-4\), \(-3\), \(-6\), \(-5\), 8, 7}, {11, 12, 9, 
              10, \(-15\), \(-16\), \(-13\), \(-14\), 3, 4, 1, 
              2, \(-7\), \(-8\), \(-5\), \(-6\)}, {12, \(-11\), 
              10, \(-9\), \(-16\), 15, \(-14\), 13, 4, \(-3\), 
              2, \(-1\), \(-8\), 7, \(-6\), 5}, {13, 14, 15, 
              16, \(-9\), \(-10\), \(-11\), \(-12\), 5, 6, 7, 
              8, \(-1\), \(-2\), \(-3\), \(-4\)}, {14, \(-13\), 
              16, \(-15\), \(-10\), 9, \(-12\), 11, 6, \(-5\), 
              8, \(-7\), \(-2\), 1, \(-4\), 3}, {15, \(-16\), \(-13\), 
              14, \(-11\), 12, 9, \(-10\), 7, \(-8\), \(-5\), 6, \(-3\), 4, 
              1, \(-2\)}, {16, 15, \(-14\), \(-13\), \(-12\), \(-11\), 10, 9, 
              8, 7, \(-6\), \(-5\), \(-4\), \(-3\), 2, 
              1}}, {\((a\^2 + b\^2 + c\^2 + d\^2 - e\^2 - f\^2 - g\^2 - h\^2 \
- i\^2 - j\^2 - k\^2 - l\^2 + m\^2 + n\^2 + o\^2 + p\^2)\)\^2 - 
              4\ \((\((\(-h\)\ i - g\ j + f\ k + e\ l - d\ m - c\ n + b\ o + \
a\ p)\)\^2 + \((\(-g\)\ i + h\ j + e\ k - f\ l - c\ m + d\ n + a\ o - b\ p)\)\
\^2 + \((\(-f\)\ i + e\ j - h\ k + g\ l - b\ m + a\ n - d\ o + c\ p)\)\^2 - \
\((\(-d\)\ i + c\ j - b\ k + a\ l - h\ m + g\ n - f\ o + e\ p)\)\^2 - \((\(-d\
\)\ e + c\ f - b\ g + a\ h + l\ m - k\ n + j\ o - i\ p)\)\^2)\)}, , , {1, \
\(-2\), \(-3\), \(-4\), 5, 6, 7, \(-8\), 9, 10, 11, \(-12\), \(-13\), 14, 15, 
            16, 4}, , };\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Hoop["\<CL13\>"] = {16, 
          24, \[IndentingNewLine]{{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 
              14, 15, 16}, {2, \(-1\), 4, \(-3\), 6, \(-5\), 8, \(-7\), 
              10, \(-9\), 12, \(-11\), 14, \(-13\), 
              16, \(-15\)}, {3, \(-4\), \(-1\), 2, 7, \(-8\), \(-5\), 6, 
              11, \(-12\), \(-9\), 10, 15, \(-16\), \(-13\), 14}, {4, 
              3, \(-2\), \(-1\), 8, 7, \(-6\), \(-5\), 12, 
              11, \(-10\), \(-9\), 16, 
              15, \(-14\), \(-13\)}, {5, \(-6\), \(-7\), 8, \(-1\), 2, 
              3, \(-4\), 13, \(-14\), \(-15\), 16, \(-9\), 10, 
              11, \(-12\)}, {6, 5, \(-8\), \(-7\), \(-2\), \(-1\), 4, 3, 14, 
              13, \(-16\), \(-15\), \(-10\), \(-9\), 12, 11}, {7, 8, 5, 
              6, \(-3\), \(-4\), \(-1\), \(-2\), 15, 16, 13, 
              14, \(-11\), \(-12\), \(-9\), \(-10\)}, {8, \(-7\), 
              6, \(-5\), \(-4\), 3, \(-2\), 1, 16, \(-15\), 
              14, \(-13\), \(-12\), 11, \(-10\), 9}, {9, \(-10\), \(-11\), 
              12, \(-13\), 14, 15, \(-16\), 1, \(-2\), \(-3\), 4, \(-5\), 6, 
              7, \(-8\)}, {10, 9, \(-12\), \(-11\), \(-14\), \(-13\), 16, 15, 
              2, 1, \(-4\), \(-3\), \(-6\), \(-5\), 8, 7}, {11, 12, 9, 
              10, \(-15\), \(-16\), \(-13\), \(-14\), 3, 4, 1, 
              2, \(-7\), \(-8\), \(-5\), \(-6\)}, {12, \(-11\), 
              10, \(-9\), \(-16\), 15, \(-14\), 13, 4, \(-3\), 
              2, \(-1\), \(-8\), 7, \(-6\), 5}, {13, 14, 15, 16, 9, 10, 11, 
              12, 5, 6, 7, 8, 1, 2, 3, 4}, {14, \(-13\), 16, \(-15\), 
              10, \(-9\), 12, \(-11\), 6, \(-5\), 8, \(-7\), 2, \(-1\), 
              4, \(-3\)}, {15, \(-16\), \(-13\), 14, 11, \(-12\), \(-9\), 10, 
              7, \(-8\), \(-5\), 6, 3, \(-4\), \(-1\), 2}, {16, 
              15, \(-14\), \(-13\), 12, 11, \(-10\), \(-9\), 8, 
              7, \(-6\), \(-5\), 4, 
              3, \(-2\), \(-1\)}}, {\((a\^2 + b\^2 + c\^2 + d\^2 + e\^2 + \
f\^2 + g\^2 + h\^2 + i\^2 + j\^2 + k\^2 + l\^2 + m\^2 + n\^2 + o\^2 + p\^2)\)\
\^2 - 4\ \((\((e\ i + f\ j + g\ k + h\ l + a\ m + b\ n + c\ o + d\ p)\)\^2 + \
\((c\ i + d\ j + a\ k + b\ l - g\ m - h\ n - e\ o - f\ p)\)\^2 + \((b\ i + a\ \
j - d\ k - c\ l - f\ m - e\ n + h\ o + g\ p)\)\^2 + \((a\ i - b\ j - c\ k + d\
\ l - e\ m + f\ n + g\ o - h\ p)\)\^2 + \((\(-d\)\ e + c\ f - b\ g + a\ h - l\
\ m + k\ n - j\ o + i\ p)\)\^2)\)}, , , {1, \(-2\), \(-3\), \(-4\), \(-5\), \
\(-6\), \(-7\), 8, 9, 10, 11, \(-12\), 13, \(-14\), \(-15\), \(-16\), 
            4}, , };\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"CL04\"]={16,25,
{{1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16},{2,-1,4,-3,6,-5,8,-7,10,-9,12,-11,\
14,-13,16,-15},{3,-4,-1,2,7,-8,-5,6,11,-12,-9,10,15,-16,-13,14},{4,3,-2,-1,8,\
7,-6,-5,12,11,-10,-9,16,15,-14,-13},{5,-6,-7,8,-1,2,3,-4,13,-14,-15,16,-9,10,\
11,-12},{6,5,-8,-7,-2,-1,4,3,14,13,-16,-15,-10,-9,12,11},{7,8,5,6,-3,-4,-1,-2,\
15,16,13,14,-11,-12,-9,-10},{8,-7,6,-5,-4,3,-2,1,16,-15,14,-13,-12,11,-10,9},{\
9,-10,-11,12,-13,14,15,-16,-1,2,3,-4,5,-6,-7,8},{10,9,-12,-11,-14,-13,16,15,-\
2,-1,4,3,6,5,-8,-7},{11,12,9,10,-15,-16,-13,-14,-3,-4,-1,-2,7,8,5,6},{12,-11,\
10,-9,-16,15,-14,13,-4,3,-2,1,8,-7,6,-5},{13,14,15,16,9,10,11,12,-5,-6,-7,-8,-\
1,-2,-3,-4},{14,-13,16,-15,10,-9,12,-11,-6,5,-8,7,-2,1,-4,3},{15,-16,-13,14,\
11,-12,-9,10,-7,8,5,-6,-3,4,1,-2},{16,15,-14,-13,12,11,-10,-9,-8,-7,6,5,-4,-3,\
2,1}},
{(a^2+b^2+c^2+d^2+e^2+f^2+g^2+h^2+i^2+j^2+k^2+l^2+m^2+n^2+o^2+p^2)^2-4*((-(h*\
i)-g*j+f*k+e*l-d*m-c*n+b*o+a*p)^2+(-(g*i)+h*j+e*k-f*l-c*m+d*n+a*o-b*p)^2+(-(f*\
i)+e*j-h*k+g*l-b*m+a*n-d*o+c*p)^2+(-(d*i)+c*j-b*k+a*l+h*m-g*n+f*o-e*p)^2+(-(d*\
e)+c*f-b*g+a*h-l*m+k*n-j*o+i*p)^2)},,,{1,-2,-3,-4,-5,-6,-7,8,-9,-10,-11,12,-\
13,14,15,16,4},gp,{a,c,b,-d,-e,-f}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"O8\"]={16,27,
{{1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16},{2,1,4,3,6,5,8,7,10,9,12,11,14,13,\
16,15},{3,4,1,2,7,8,5,6,11,12,9,10,15,16,13,14},{4,3,2,1,8,7,6,5,12,11,10,9,\
16,15,14,13},{5,6,7,8,1,2,3,4,13,14,15,16,9,10,11,12},{6,5,8,7,2,1,4,3,14,13,\
16,15,10,9,12,11},{7,8,5,6,3,4,1,2,15,16,13,14,11,12,9,10},{8,7,6,5,4,3,2,1,\
16,15,14,13,12,11,10,9},{9,10,11,12,13,14,15,16,-1,-2,-3,-4,-5,-6,-7,-8},{10,\
9,12,11,14,13,16,15,-2,-1,-4,-3,-6,-5,-8,-7},{11,12,9,10,15,16,13,14,-3,-4,-1,\
-2,-7,-8,-5,-6},{12,11,10,9,16,15,14,13,-4,-3,-2,-1,-8,-7,-6,-5},{13,14,15,16,\
9,10,11,12,-5,-6,-7,-8,-1,-2,-3,-4},{14,13,16,15,10,9,12,11,-6,-5,-8,-7,-2,-1,\
-4,-3},{15,16,13,14,11,12,9,10,-7,-8,-5,-6,-3,-4,-1,-2},{16,15,14,13,12,11,10,\
9,-8,-7,-6,-5,-4,-3,-2,-1}},{(a+b+c+d+e+f+g+h)^2+(i+j+k+l+m+n+o+p)^2,(a-b-c+d+\
e-f-g+h)^2+(i-j-k+l+m-n-o+p)^2,(a-b+c-d+e-f+g-h)^2+(i-j+k-l+m-n+o-p)^2,(a+b-c-\
d+e+f-g-h)^2+(i+j-k-l+m+n-o-p)^2,(a+b+c+d-e-f-g-h)^2+(i+j+k+l-m-n-o-p)^2,(a-b-\
c+d-e+f+g-h)^2+(i-j-k+l-m+n+o-p)^2,(a-b+c-d-e+f-g+h)^2+(i-j+k-l-m+n-o+p)^2,(a+\
b-c-d-e-f+g+h)^2+(i+j-k-l-m-n+o+p)^2},{(a+b+c+d+e+f+g+h)^2+(i+j+k+l+m+n+o+p)^\
2,ArcTan[a+b+c+d+e+f+g+h,i+j+k+l+m+n+o+p],(a-b-c+d+e-f-g+h)^2+(i-j-k+l+m-n-o+\
p)^2,ArcTan[a-b-c+d+e-f-g+h,i-j-k+l+m-n-o+p],(a-b+c-d+e-f+g-h)^2+(i-j+k-l+m-n+\
o-p)^2,ArcTan[a-b+c-d+e-f+g-h,i-j+k-l+m-n+o-p],(a+b-c-d+e+f-g-h)^2+(i+j-k-l+m+\
n-o-p)^2,ArcTan[a+b-c-d+e+f-g-h,i+j-k-l+m+n-o-p],(a+b+c+d-e-f-g-h)^2+(i+j+k+l-\
m-n-o-p)^2,ArcTan[a+b+c+d-e-f-g-h,i+j+k+l-m-n-o-p],(a-b-c+d-e+f+g-h)^2+(i-j-k+\
l-m+n+o-p)^2,ArcTan[a-b-c+d-e+f+g-h,i-j-k+l-m+n+o-p],(a-b+c-d-e+f-g+h)^2+(i-j+\
k-l-m+n-o+p)^2,ArcTan[a-b+c-d-e+f-g+h,i-j+k-l-m+n-o+p],(a+b-c-d-e-f+g+h)^2+(i+\
j-k-l-m-n+o+p)^2,ArcTan[a+b-c-d-e-f+g+h,i+j-k-l-m-n+o+p]},{(Sqrt[a]*Cos[b]+\
Sqrt[c]*Cos[d]+Sqrt[e]*Cos[f]+Sqrt[g]*Cos[h]+Sqrt[i]*Cos[j]+Sqrt[k]*Cos[l]+\
Sqrt[m]*Cos[n]+Sqrt[o]*Cos[p])/8,(Sqrt[a]*Cos[b]-Sqrt[c]*Cos[d]-Sqrt[e]*Cos[f]\
+Sqrt[g]*Cos[h]+Sqrt[i]*Cos[j]-Sqrt[k]*Cos[l]-Sqrt[m]*Cos[n]+Sqrt[o]*Cos[p])/\
8,(Sqrt[a]*Cos[b]-Sqrt[c]*Cos[d]+Sqrt[e]*Cos[f]-Sqrt[g]*Cos[h]+Sqrt[i]*Cos[j]-\
Sqrt[k]*Cos[l]+Sqrt[m]*Cos[n]-Sqrt[o]*Cos[p])/8,(Sqrt[a]*Cos[b]+Sqrt[c]*Cos[d]\
-Sqrt[e]*Cos[f]-Sqrt[g]*Cos[h]+Sqrt[i]*Cos[j]+Sqrt[k]*Cos[l]-Sqrt[m]*Cos[n]-\
Sqrt[o]*Cos[p])/8,(Sqrt[a]*Cos[b]+Sqrt[c]*Cos[d]+Sqrt[e]*Cos[f]+Sqrt[g]*Cos[h]\
-Sqrt[i]*Cos[j]-Sqrt[k]*Cos[l]-Sqrt[m]*Cos[n]-Sqrt[o]*Cos[p])/8,(Sqrt[a]*Cos[\
b]-Sqrt[c]*Cos[d]-Sqrt[e]*Cos[f]+Sqrt[g]*Cos[h]-Sqrt[i]*Cos[j]+Sqrt[k]*Cos[l]+\
Sqrt[m]*Cos[n]-Sqrt[o]*Cos[p])/8,(Sqrt[a]*Cos[b]-Sqrt[c]*Cos[d]+Sqrt[e]*Cos[f]\
-Sqrt[g]*Cos[h]-Sqrt[i]*Cos[j]+Sqrt[k]*Cos[l]-Sqrt[m]*Cos[n]+Sqrt[o]*Cos[p])/\
8,(Sqrt[a]*Cos[b]+Sqrt[c]*Cos[d]-Sqrt[e]*Cos[f]-Sqrt[g]*Cos[h]-Sqrt[i]*Cos[j]-\
Sqrt[k]*Cos[l]+Sqrt[m]*Cos[n]+Sqrt[o]*Cos[p])/8,(Sqrt[a]*Sin[b]+Sqrt[c]*Sin[d]\
+Sqrt[e]*Sin[f]+Sqrt[g]*Sin[h]+Sqrt[i]*Sin[j]+Sqrt[k]*Sin[l]+Sqrt[m]*Sin[n]+\
Sqrt[o]*Sin[p])/8,(Sqrt[a]*Sin[b]-Sqrt[c]*Sin[d]-Sqrt[e]*Sin[f]+Sqrt[g]*Sin[h]\
+Sqrt[i]*Sin[j]-Sqrt[k]*Sin[l]-Sqrt[m]*Sin[n]+Sqrt[o]*Sin[p])/8,(Sqrt[a]*Sin[\
b]-Sqrt[c]*Sin[d]+Sqrt[e]*Sin[f]-Sqrt[g]*Sin[h]+Sqrt[i]*Sin[j]-Sqrt[k]*Sin[l]+\
Sqrt[m]*Sin[n]-Sqrt[o]*Sin[p])/8,(Sqrt[a]*Sin[b]+Sqrt[c]*Sin[d]-Sqrt[e]*Sin[f]\
-Sqrt[g]*Sin[h]+Sqrt[i]*Sin[j]+Sqrt[k]*Sin[l]-Sqrt[m]*Sin[n]-Sqrt[o]*Sin[p])/\
8,(Sqrt[a]*Sin[b]+Sqrt[c]*Sin[d]+Sqrt[e]*Sin[f]+Sqrt[g]*Sin[h]-Sqrt[i]*Sin[j]-\
Sqrt[k]*Sin[l]-Sqrt[m]*Sin[n]-Sqrt[o]*Sin[p])/8,(Sqrt[a]*Sin[b]-Sqrt[c]*Sin[d]\
-Sqrt[e]*Sin[f]+Sqrt[g]*Sin[h]-Sqrt[i]*Sin[j]+Sqrt[k]*Sin[l]+Sqrt[m]*Sin[n]-\
Sqrt[o]*Sin[p])/8,(Sqrt[a]*Sin[b]-Sqrt[c]*Sin[d]+Sqrt[e]*Sin[f]-Sqrt[g]*Sin[h]\
-Sqrt[i]*Sin[j]+Sqrt[k]*Sin[l]-Sqrt[m]*Sin[n]+Sqrt[o]*Sin[p])/8,(Sqrt[a]*Sin[\
b]+Sqrt[c]*Sin[d]-Sqrt[e]*Sin[f]-Sqrt[g]*Sin[h]-Sqrt[i]*Sin[j]-Sqrt[k]*Sin[l]+\
Sqrt[m]*Sin[n]+Sqrt[o]*Sin[p])/8},{1,2,3,4,5,6,7,8,-9,-10,-11,-12,-13,-14,-15,\
-16,1,1,1,1,1,1,1,1},{1,0.,1,0.,1,0.,1,0.,1,0.,1,0.,1,0.,1,0.},{a,b,c,-d,e,-f,\
-g,-h,i,-j,-k,-l,-m,-n,-o,p}};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"Q8M2\"]={16,34,
{{1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16},
{2,5,8,3,6,1,4,7,10,13,12,15,14,9,16,11},
{3,4,5,6,7,8,1,2,11,16,13,10,15,12,9,14},
{4,7,2,5,8,3,6,1,12,11,14,13,16,15,10,9},
{5,6,7,8,1,2,3,4,13,14,15,16,9,10,11,12},
{6,1,4,7,2,5,8,3,14,9,16,11,10,13,12,15},
{7,8,1,2,3,4,5,6,15,12,9,14,11,16,13,10},
{8,3,6,1,4,7,2,5,16,15,10,9,12,11,14,13},
{9,14,15,16,13,10,11,12,1,6,7,8,5,2,3,4},
{10,9,12,15,14,13,16,11,2,1,8,3,6,5,4,7},
{11,16,9,10,15,12,13,14,3,4,1,6,7,8,5,2},
{12,11,14,9,16,15,10,13,4,7,2,1,8,3,6,5},
{13,10,11,12,9,14,15,16,5,2,3,4,1,6,7,8},
{14,13,16,11,10,9,12,15,6,5,4,7,2,1,8,3},
{15,12,13,14,11,16,9,10,7,8,5,2,3,4,1,6},
{16,15,10,13,12,11,14,9,8,3,6,5,4,7,2,1}},
{a+b+c+d+e+f+g+h-i-j-k-l-m-n-o-p,
 a+b-c-d+e+f-g-h+i+j-k-l+m+n-o-p,
 a-b+c-d+e-f+g-h+i-j+k-l+m-n+o-p, 
 a-b-c+d+e-f-g+h-i+j+k-l-m+n+o-p,
 a-b-c+d+e-f-g+h+i-j-k+l+m-n-o+p,
 a-b+c-d+e-f+g-h-i+j-k+l-m+n-o+p,
 a+b-c-d+e+f-g-h-i-j+k+l-m-n+o+p,
 a+b+c+d+e+f+g+h+i+j+k+l+m+n+o+p,
 (a-e)^2+(b-f)^2+(c-g)^2+(d-h)^2-(j-n)^2 -(k-o)^2-(l-p)^2-(i-m)^2},,,
 {1,6,7,8,5,2,3,4,9,10,11,12,13,14,15,16,1,1,1,1,1,1,1,1,4},,};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
Hoop[\"C3C4C2\"] = {24,9,{
{1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24},
{2,3,1,5,6,4,8,9,7,11,12,10,14,15,13,17,18,16,20,21,19,23,24,22},
{3,1,2,6,4,5,9,7,8,12,10,11,15,13,14,18,16,17,21,19,20,24,22,23},
{4,5,6,7,8,9,10,11,12,1,2,3,16,17,18,19,20,21,22,23,24,13,14,15},
{5,6,4,8,9,7,11,12,10,2,3,1,17,18,16,20,21,19,23,24,22,14,15,13},
{6,4,5,9,7,8,12,10,11,3,1,2,18,16,17,21,19,20,24,22,23,15,13,14},
{7,8,9,10,11,12,1,2,3,4,5,6,19,20,21,22,23,24,13,14,15,16,17,18},
{8,9,7,11,12,10,2,3,1,5,6,4,20,21,19,23,24,22,14,15,13,17,18,16},
{9,7,8,12,10,11,3,1,2,6,4,5,21,19,20,24,22,23,15,13,14,18,16,17},
{10,11,12,1,2,3,4,5,6,7,8,9,22,23,24,13,14,15,16,17,18,19,20,21},
{11,12,10,2,3,1,5,6,4,8,9,7,23,24,22,14,15,13,17,18,16,20,21,19},
{12,10,11,3,1,2,6,4,5,9,7,8,24,22,23,15,13,14,18,16,17,21,19,20},
{13,14,15,16,17,18,19,20,21,22,23,24,1,2,3,4,5,6,7,8,9,10,11,12},
{14,15,13,17,18,16,20,21,19,23,24,22,2,3,1,5,6,4,8,9,7,11,12,10},
{15,13,14,18,16,17,21,19,20,24,22,23,3,1,2,6,4,5,9,7,8,12,10,11},
{16,17,18,19,20,21,22,23,24,13,14,15,4,5,6,7,8,9,10,11,12,1,2,3},
{17,18,16,20,21,19,23,24,22,14,15,13,5,6,4,8,9,7,11,12,10,2,3,1},
{18,16,17,21,19,20,24,22,23,15,13,14,6,4,5,9,7,8,12,10,11,3,1,2}, 
{19,20,21,22,23,24,13,14,15,16,17,18,7,8,9,10,11,12,1,2,3,4,5,6},
{20,21,19,23,24,22,14,15,13,17,18,16,8,9,7,11,12,10,2,3,1,5,6,4},
{21,19,20,24,22,23,15,13,14,18,16,17,9,7,8,12,10,11,3,1,2,6,4,5},
{22,23,24,13,14,15,16,17,18,19,20,21,10,11,12,1,2,3,4,5,6,7,8,9},
{23,24,22,14,15,13,17,18,16,20,21,19,11,12,10,2,3,1,5,6,4,8,9,7},
{24,22,23,15,13,14,18,16,17,21,19,20,12,10,11,3,1,2,6,4,5,9,7,8}},
{a+b+c+d+e+f+g+h+i+j+k+l+m+n+o+p+q+r+s+t+u+v+w+x,
 a+b+c-d-e-f+g+h+i-j-k-l+m+n+o-p-q-r+s+t+u-v-w-x,
 a+b+c+d+e+f+g+h+i+j+k+l-m-n-o-p-q-r-s-t-u-v-w-x,
 a+b+c-d-e-f+g+h+i-j-k-l-m-n-o+p+q+r-s-t-u+v+w+x,
 (a+b+c-g-h-i-m-n-o+s+t+u)^2+(d+e+f-j-k-l-p-q-r+v+w+x)^2,
 (a+b+c-g-h-i+m+n+o-s-t-u)^2+(d+e+f-j-k-l+p+q+r-v-w-x)^2,
((a-b+d-e+g-h+j-k+m-n+p-q+s-t+v-w)^2+(b-c+e-f+h-i+k-l+n-o+q-r+t-u+w-x)^2+
(-a+c-d+f-g+i-j+l-m+o-p+r-s+u-v+x)^2)/2, 
((a-b+d-e+g-h+j-k-m+n-p+q-s+t-v+w)^2+(-a+c-d+f-g+i-j+l+m-o+p-r+s-u+v-x)^2+ \
(b-c+e-f+h-i+k-l-n+o-q+r-t+u-w+x)^2)/2,
((a-b-d+e+g-h-j+k+m-n-p+q+s-t-v+w)^2+(-a+c+d-f-g+i+j-l-m+o+p-r-s+u+v-x)^2+
(b-c-e+f+h-i-k+l+n-o-q+r+t-u-w+x)^2)/2,
((a-b-d+e+g-h-j+k-m+n+p-q-s+t+v-w)^2+(b-c-e+f+h-i-k+l-n+o+q-r-t+u+w-x)^2+
(-a+c+d-f-g+i+j-l+m-o-p+r+s-u-v+x)^2)/2,
(1/4)*((a-b-d+e-g+h+j-k+m-n-p+q-s+t+v-w)^4+
(a-b+d-e-g+h-j+k+m-n+p-q-s+t-v+w)^4+(-a+c-d+f+g-i+j-l-m+o-p+r+s-u+v-x)^4+
(b-c-e+f-h+i+k-l+n-o-q+r-t+u+w-x)^4+(-a+c+d-f+g-i-j+l-m+o+p-r+s-u-v+x)^4+
(b-c+e-f-h+i-k+l+n-o+q-r-t+u-w+x)^4)-
((a-b-g+h+m-n-s+t)^2+(-a+c+g-i-m+o+s-u)^2+(b-c-h+i+n-o-t+u)^2)*
((d-e-j+k+p-q-v+w)^2+(-d+f+j-l-p+r+v-x)^2+(e-f-k+l+q-r-w+x)^2),
(1/4)*((a-b+d-e-g+h-j+k-m+n-p+q+s-t+v-w)^4+
(a-b-d+e-g+h+j-k-m+n+p-q+s-t-v+w)^4+(-a+c+d-f+g-i-j+l+m-o-p+r-s+u+v-x)^4+
(b-c+e-f-h+i-k+l-n+o-q+r+t-u+w-x)^4+(-a+c-d+f+g-i+j-l+m-o+p-r-s+u-v+x)^4+
(b-c-e+f-h+i+k-l-n+o+q-r+t-u-w+x)^4)-
((a-b-g+h-m+n+s-t)^2+(b-c-h+i-n+o+t-u)^2+(-a+c+g-i+m-o-s+u)^2)*
((d-e-j+k-p+q+v-w)^2+(e-f-k+l-q+r+w-x)^2+(-d+f+j-l+p-r-v+x)^2)},,, \
{1,3,2,10,12,11,7,9,8,4,6,5,13,15,14,22,24,23,19,21,20,16,18,17,1,1,1,1,1,1,1,\
1,1,1,1,1},,};\
\>", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
\tFive non-Moufang tables are appended. They do not have the Frobenius \
property. They are not Hoops, as indicated by the final \"n\" in their names.\
\
\>", "Text",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Hoop["\<Q4n\>"] := {mm = 4, nn = 14, 
          hoopTbl = {{1, 2, 3, 4}, {2, 1, 4, \(-3\)}, {3, \(-4\), 1, 2}, {4, 
                3, \(-2\), 1}}, 
          sh = {a\^2 - b\^2 - c\^2 - d\^2, a\^2 + b\^2 + c\^2 + d\^2}, , , 
          gi = {1, 2, 3, 4, 1, 1}, , 
          plex = {a, \(-b\), \(-c\), \(-d\)}};\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Hoop["\<C6n\>"] := {mm = 6, nn = 13, 
          hoopTbl = {{1, 2, 3, 4, 5, 6}, {2, 3, 1, 6, 4, 5}, {3, 1, 2, 5, 6, 
                4}, {4, 5, 6, 2, 1, 3}, {5, 6, 4, 1, 3, 2}, {6, 4, 5, 3, 2, 
                1}}, sh = {a + b + c - d - e - f, a + b + c + d + e + f, 
              1\/2\ \((\((a - b)\)\^2 + \((b - c)\)\^2 + \((\(-a\) + c)\)\^2 \
- \((d - e)\)\^2 - \((e - f)\)\^2 - \((\(-d\) + f)\)\^2)\), 
              1\/2\ \((\((a - b)\)\^2 + \((b - c)\)\^2 + \((\(-a\) + c)\)\^2 \
+ \((d - e)\)\^2 + \((e - f)\)\^2 + \((\(-d\) + f)\)\^2)\)}, , , 
          gi = {1, 3, 2, 5, 4, 6, 1, 1, 1, 1}, , 
          a + b + c - d - e - f};\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Hoop["\<Q8n\>"] := {mm = 8, nn = 36, 
          hoopTbl = {{1, 2, 3, 4, 5, 6, 7, 8}, {2, 1, 4, 7, 6, 5, 8, 3}, {3, 
                8, 1, 2, 7, 4, 5, 6}, {4, 3, 6, 1, 8, 7, 2, 5}, {5, 6, 7, 8, 
                1, 2, 3, 4}, {6, 5, 8, 3, 2, 1, 4, 7}, {7, 4, 5, 6, 3, 8, 1, 
                2}, {8, 7, 2, 5, 4, 3, 6, 1}}, 
          sh = {a + b - c - d + e + f - g - h, a - b + c - d + e - f + g - h, 
              a - b - c + d + e - f - g + h, 
              a + b + c + d + e + f + g + 
                h, \((a - e)\)\^2 - \((b - f)\)\^2 - \((c - g)\)\^2 - \((d - \
h)\)\^2, \((a - e)\)\^2 + \((b - f)\)\^2 + \((c - g)\)\^2 + \((d - h)\)\^2}, \
, , gi = {1, 2, 3, 4, 5, 6, 7, 8, 1, 1, 1, 1, 1, 1}, , };\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
The Alt8n table passes the alternativeQ and moufangQ test (i.e. up to a sign) \
but is not conservative.\
\>", "Text",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    \(\(Hoop["\<Alt8n\>"] = {mm = 8, nn = 33, 
          hoopTbl = {{1, 2, 3, 4, 5, 6, 7, 8}, {2, \(-1\), 4, \(-3\), 
                6, \(-5\), 8, \(-7\)}, {3, 4, 1, 2, 7, 8, 5, 6}, {4, \(-3\), 
                2, \(-1\), 8, \(-7\), 
                6, \(-5\)}, {5, \(-6\), \(-7\), \(-8\), \(-1\), 2, 3, 4}, {6, 
                5, \(-8\), 7, \(-2\), \(-1\), 
                4, \(-3\)}, {7, \(-8\), \(-5\), \(-6\), \(-3\), 4, 1, 2}, {8, 
                7, \(-6\), 5, \(-4\), \(-3\), 2, \(-1\)}}, , , , 
          gi = {1, \(-2\), 3, \(-4\), \(-5\), \(-6\), 7, \(-8\), 
              1}, , };\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["\<\
The D3Mn loop is the smallest noncommutative Moufang loop, created by Chein \
doubling of the D3 group. It is not conservative.\
\>", "Text",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(id["\<D3Mn\>"]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \("D3Mn"\)], "Output",
  PageWidth->WindowWidth]
}, Open  ]],

Cell[BoxData[
    \(gd[]\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(glo // tf\)], "Input",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\(Hoop["\<D3Mn\>"] = {mm = 12, nn = 28, 
          hoopTbl = {{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {2, 1, 6, 5, 4, 
                3, 8, 7, 10, 9, 12, 11}, {3, 4, 5, 6, 1, 2, 9, 12, 11, 8, 7, 
                10}, {4, 3, 2, 1, 6, 5, 10, 11, 12, 7, 8, 9}, {5, 6, 1, 2, 3, 
                4, 11, 10, 7, 12, 9, 8}, {6, 5, 4, 3, 2, 1, 12, 9, 8, 11, 10, 
                7}, {7, 8, 11, 10, 9, 12, 1, 2, 5, 4, 3, 6}, {8, 7, 10, 11, 
                12, 9, 2, 1, 6, 3, 4, 5}, {9, 10, 7, 12, 11, 8, 3, 6, 1, 2, 
                5, 4}, {10, 9, 12, 7, 8, 11, 4, 5, 2, 1, 6, 3}, {11, 12, 9, 
                8, 7, 10, 5, 4, 3, 6, 1, 2}, {12, 11, 8, 9, 10, 7, 6, 3, 4, 
                5, 2, 1}}, , , , 
          gi = {1, 5, 4, 3, 6.7, 8, 9, 10, 11, 12}, , };\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["9.",
    FontFamily->"Times New Roman"],
  " ",
  StyleBox["Exported functions.",
    FontFamily->"Times New Roman"]
}], "Subsection",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0.5625}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[CellGroupData[{

Cell[TextData[{
  "9.1. Main Procedures;  ",
  StyleBox["as, hoopTimes, hoopInverse, hoopPower, Use",
    FontSlant->"Italic"],
  "."
}], "Subsubsection",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[TextData[{
  "\tSymbolic functions such as ",
  StyleBox["topol. tovec",
    FontSlant->"Italic"],
  " are given new values by e.g. ",
  StyleBox["topol/.as[{3.,1.,4.}].",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(as[A_] :=  (*Relace\ alph\ dummy\ variables\ by\ the\ coefficients\ in\ \
A\ *) \[IndentingNewLine]Table[
        alph[\([ii]\)] \[Rule] A[\([ii]\)], {ii, Min[mm, Length[A]]}]; 
    as[A_, B_] :=  (*Relace\ B\ variables\ by\ the\ coefficients\ in\ A\ \
*) \[IndentingNewLine]Table[
        B[\([ii]\)] \[Rule] A[\([ii]\)], {ii, 
          Min[mm, Length[A], Length[B]]}];\)], "Input",
  InitializationCell->True,
  FormatType->TraditionalForm],

Cell[TextData[{
  "\t",
  StyleBox["hoopTimes",
    FontSlant->"Italic"],
  StyleBox[" multiplies two vectors and (if ",
    FontSlant->"Plain"],
  StyleBox["c",
    FontSlant->"Italic"],
  StyleBox["==0) sets the remainders ",
    FontSlant->"Plain"],
  StyleBox["Rl & Rr",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Lists of zeroes",
    FontSlant->"Plain"],
  " ",
  StyleBox["t, Rl, Rr",
    FontSlant->"Italic"],
  StyleBox[" are initialised. A & B are padded with zeroes and truncated to \
the correct length.\n\tThe product ",
    FontSlant->"Plain"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox[" is built up by adding each (signed) product to the appropriate \
element. If disparate zero-sizes occur, some sizes will be lost from the \
product AB and AB/A will not recover B; left and right remainders are created \
so that sizes are conserved and ",
    FontSlant->"Plain"],
  "B=AB/A+Rr",
  StyleBox[" & ",
    FontSlant->"Plain"],
  "A=AB/B+Rl",
  StyleBox[".",
    FontSlant->"Plain"]
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(hoopTimes[AA_, BB_, c_:  0] :=  (*Multiply\ two\ vectors, \ 
        calculating\ remainders\ if\ c \[Equal] 
          0*) \[IndentingNewLine]Module[{t = Table[0, {mm}], R, A, B}, 
        Rl = t; Rr = t; R = t; A = Take[Flatten[Append[AA, t]], mm]; 
        B = Take[Flatten[Append[BB, t]], mm]; \[IndentingNewLine]Do[
          Do[t\[LeftDoubleBracket]Abs[
                  hoopTbl[\([ll, kk]\)]]\[RightDoubleBracket] += 
              A\[LeftDoubleBracket]
                  ll\[RightDoubleBracket]\ B\[LeftDoubleBracket]
                  kk\[RightDoubleBracket] Sign[hoopTbl[\([ll, kk]\)]]\ , {kk, 
              mm}], {ll, 
            mm}];  (*\(Calculate\ remainders\ Rl\  &\)\ Rr\ if\ any\ sizes\ \
are\ lost*) \[IndentingNewLine]If[
          c \[Equal] 0, \[IndentingNewLine]R = 
            Chop[Simplify[B - hoopTimes[hoopInverse[A], t, 1]], hmin]; 
          Rl = Chop[Simplify[A - hoopTimes[t, hoopInverse[B], 1]], hmin], ]; 
        Rr = R; t]\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[TextData[{
  "\tDivision is effected by the same procedure, ",
  StyleBox["hoopTimes",
    FontSlant->"Italic"],
  ", as multiplication, using the multiplicative inverse of the divisor. The \
inverse always exists because all known hoops have the Moufang property; it \
is calculated by ",
  StyleBox["hoopInverse",
    FontSlant->"Italic"],
  " so that Ainv.A={1,0,..}. \n\t",
  StyleBox["inv",
    FontSlant->"Italic"],
  " is set up as a table of zeroes, and then filled with symbolic \
partial-fractions ",
  StyleBox["D[sh[[jj]],var]/sh[[jj]]",
    FontSlant->"Italic"],
  " with sizes (defined in ",
  StyleBox["sh",
    FontSlant->"Italic"],
  ") as denominators and their derivations as numerators. ",
  StyleBox["gi",
    FontSlant->"Italic"],
  " contains the signed list of locations of 1's in the Cayley table; this \
identifies the differentiation variable ",
  StyleBox["var",
    FontSlant->"Italic"],
  ". In the ",
  StyleBox["jj",
    FontSlant->"Italic"],
  " loop, a substitution rule ",
  StyleBox["as",
    FontSlant->"Italic"],
  " attempts to calculate the numeric value of each shape for A. Any that \
differ from zero by less than ",
  StyleBox["hmin ",
    FontSlant->"Italic"],
  "(arbitrarily set at 4 times the \"Machine Epsilon\") are ignored -  the \
calculations continue in a constrained sub-algebra by omitting the \"infinite\
\" partial fractions. ",
  StyleBox["gi",
    FontSlant->"Italic"],
  " also contains ",
  StyleBox["gi[[mm+jj]],",
    FontSlant->"Italic"],
  " the multiplicity of each size; this is a multiplier for the signed \
partial fraction. Finally ",
  StyleBox["inv",
    FontSlant->"Italic"],
  " is divided by ",
  StyleBox["mm",
    FontSlant->"Italic"],
  ", and the symbols are replaced by the elements of A. In effect, Cramer's \
method has been used, so each term of the result has the determinant as a \
divisor. If the determinant factorizes, each term is expressed as a sum of \
partial fraction with factors (sizes) as denominators. "
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(hoopInverse[
        A_] :=  (*Calculate\ inverse\ of\ \(\(A\)\(.\)\)\ \
*) \[IndentingNewLine]Module[{inv = Table[0, {ii, mm}], ls = Length[sh], var, 
          t}, \[IndentingNewLine]Do[ (*\ ii\ elements\ *) ss = 
            Sign[gi[\([ii]\)]]; t = 0; 
          var = alph[\([gi[\([ii]\)]/ss]\)];  (*Diff' 
              n\ variable*) \[IndentingNewLine]Do[ (*jj\ shapes*) If[
              Chop[Simplify[sh[\([jj]\)] /. \ as[A]], hmin] === 0, 
              Null (*Omits\ any\ near - zero\ cases*) , 
              t += ss*gi[\([mm + jj]\)]*\((D[sh[\([jj]\)], var]/
                      sh[\([jj]\)])\)], {jj, 
              ls}]; \[IndentingNewLine]inv[\([ii]\)] += t, {ii, mm}]; 
        Simplify[inv/mm /. \ as[A]]]\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[TextData[{
  "\t",
  StyleBox["hoopPower",
    FontSlant->"Italic"],
  " ",
  StyleBox["calculates ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`A\^p\)]],
  StyleBox[", giving ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\@A\)]],
  StyleBox[" if ",
    FontSlant->"Plain"],
  StyleBox["p",
    FontSlant->"Italic"],
  StyleBox[" is not specified",
    FontSlant->"Plain"],
  ".",
  StyleBox[" The polar-vector interconversions ",
    FontSlant->"Plain"],
  StyleBox["topol, tovec",
    FontSlant->"Italic"],
  StyleBox[" are needed for the algebra (not all are available, many may not \
exist). Sizes are raised to the power (indicated by 1 in ",
    FontSlant->"Plain"],
  "gp",
  StyleBox[") with signed sizes needing special treatment, and angles \
(indicated by 0. in ",
    FontSlant->"Plain"],
  "gp",
  StyleBox[") are multiplied by the power. Finally, ",
    FontSlant->"Plain"],
  StyleBox["tovec",
    FontSlant->"Italic"],
  StyleBox[" is used to obtain the vector form. Negative powers are handled \
via the inverse. Non-abelian hoops give \"pseudo-powers\", unrelated to \
repeated products, because their angles do not add on vector multiplication; \
this may introduce uncertainty.",
    FontSlant->"Plain"]
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(hoopPower[A_, r_:  1/2] :=  (*Raise\ A\ to\ power\ r, \ 
        with\ default\ \@A, \ 
        r = 1/2\ *) \[IndentingNewLine]Module[{res = {}, lg = Length[gp], 
          p = topol /. \ as[A]}, 
        If[r < 0, hoopPower[hoopInverse[A], \(-r\)], 
          Do[AppendTo[res, 
              If[IntegerQ[gp[\([ii]\)]], 
                If[Head[p[\([ii]\)]] === Complex, 
                  p[\([ii]\)]\^r, \(Abs[p[\([ii]\)]]\^r\) Sign[p[\([ii]\)]]], 
                r\ p[\([ii]\)]]\[IndentingNewLine] (*Sizes\ raised\ to\ \
power, \ angles\ multiplied\ by\ power*) ], {ii, lg}]]; 
        tovec /. \ as[res /. \ as[A]]]\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[TextData[{
  "A Hoop Algebra \"H\" is selected by ",
  StyleBox["Use[\"H\"]",
    FontSlant->"Italic"],
  "; this sets the relevant expressions ",
  StyleBox["mm,nn, hoopTbl, sh, topol, tovec, gi, gp, plex ",
    FontSlant->"Italic"],
  "that are needed by the other procedures, until another ",
  StyleBox["Use",
    FontSlant->"Italic"],
  " instruction is implemented."
}], "Text",
  PageWidth->WindowWidth],

Cell[BoxData[
    \(\(Use[
          H_] :=  (*Procedures\ will\ henceforward\ use\ Hoop[
              H]*) \[IndentingNewLine]Module[{h = Hoop[H]}, mm = h[\([1]\)]; 
          nn = h[\([2]\)]; hoopTbl = h[\([3]\)]; sh = h[\([4]\)]; 
          topol = h[\([5]\)]; tovec = h[\([6]\)]; gi = h[\([7]\)]; 
          gp = h[\([8]\)]; plex = h[\([9]\)]];\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["9.2. Constants. J as a sign. BoldFace.", "Subsubsection",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[TextData[{
  "\tThree constants are set up, and the symbol J is given properties that \
make it work as a sign with J^3=1 in the same way as I is a sign with I^4=1. \
",
  StyleBox["bf",
    FontSlant->"Italic"],
  " allows printed results to be shown in boldface."
}], "Text",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{
    RowBox[{\(r3 = Sqrt[3. ]; 
      r6 = 2  r3;  (*frequently\ used\ constants*) \[IndentingNewLine]hmin = 
        4  $MachineEpsilon\  (*Arbitrary\ minimum\ magnitude*) ;\), 
      "\[IndentingNewLine]", \( (*Set\ up\ J\ as\ a\ primitive\ cube\ root\ \
of\  + 1\ as\ a\ typical\ generalized\ sign*) \)}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"js", "=", 
        RowBox[{
          SuperscriptBox[
            StyleBox["J",
              FontWeight->"Plain"], "any_"], "\[Rule]", 
          SuperscriptBox[
            StyleBox["J",
              FontWeight->"Plain"], \(Mod[any, 3]\)]}]}], 
      ";", \(NumberQ[J] = True\), ";", \(Positive[J] = False\), 
      ";", \(Positive[\(-J\)] = False\), ";", \(Abs[J] = 1\), 
      ";", \(Sign[J] = J\), ";", \(Re[J] = 0\), ";", \(Im[J] = 0\), 
      ";", \(Re[\ \ \ a_\ J^b_] := 0\), ";", \(Im[\ \ a_\ \ J^b_] := 0\), 
      ";", \(Re[\ J^b_] := 0\), ";", \(Im[J^b_] := 0\), 
      ";", \(Re[a_\ \ J] = 0\), ";", \(Im[a_\ J] = 0\), 
      ";"}], "\[IndentingNewLine]", \(bf[any_] = 
        StyleForm[any, FontWeight \[Rule] "\<Bold\>"];\)}], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
9.3. Trigonometric extensions; generalized sinusoids, Quadrant-sensitive \
hyperbolic tangent, Polyhelix.\
\>", "Subsubsection",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[{
    \(\(genCos[x_, j_:  0] := 
        If[mm < 3, 
          Abort[], \[IndentingNewLine]Re[\(\((\(-1\))\)\^\(2 \((mm - j)\)/
                      mm\)\) \[ExponentialE]\^\(\[ImaginaryI]\ \
Im[\((\(-1\))\)\^\(2/mm\)]\ x\)]];\)\), "\[IndentingNewLine]", 
    \(\(genSin[x_, j_:  0] := 
        If[mm < 3, 
          Abort[], \[IndentingNewLine]Im[\(\((\(-1\))\)\^\(2 \((mm - j)\)/
                      mm\)\) \[ExponentialE]\^\(\[ImaginaryI]\ \
Im[\((\(-1\))\)\^\(2/mm\)]\ x\)]];\)\)}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell[BoxData[
    \(\(arcTanh[adj_, 
          opp_] :=  (*Quadrant - sensitive*) \[IndentingNewLine]If[
          adj\^2 == opp\^2, \[Infinity], 
          Chop[Log[\((adj + opp)\)/\@\(adj\^2 - opp\^2\) // 
                N]]];\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"PolyHelix", " ", 
          RowBox[{
          "Identity", ".", " ", \((Included\ for\ reference)\), ".", 
            "\[IndentingNewLine]", "  ", 
            RowBox[{
              FormBox[\(\[Sum]\_\(n = 0\)\%\(n = m - 1\)\),
                "TraditionalForm"], 
              FormBox[\(\((Sin[x + 2  n\ \[Pi]/m])\)\^\(2  p\)\),
                "TraditionalForm"]}]}]}], "=", 
        RowBox[{
          FormBox[\(4\^\(-p\)\),
            "TraditionalForm"], 
          StyleBox["m",
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontSlant->"Italic"], 
          FormBox[
            RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                  {\(2  p\)},
                  {"p"}
                  }], "\[NegativeThinSpace]", ")"}],
            "TraditionalForm"]}]}], ",", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              StyleBox["p",
                FontSlant->"Italic"], 
              StyleBox["<",
                FontSlant->"Italic"], 
              RowBox[{
                StyleBox["m",
                  FontSlant->"Italic"], " ", "if", " ", 
                StyleBox["m",
                  FontSlant->"Italic"], " ", "is", " ", "even"}]}], ",", 
            RowBox[{
              RowBox[{"else", 
                StyleBox[" ",
                  FontSlant->"Italic"], 
                StyleBox["p",
                  FontSlant->"Italic"]}], 
              StyleBox["<",
                FontSlant->"Italic"], 
              StyleBox[\(2  m\),
                FontSlant->"Italic"]}]}], "}"}], "."}]}]], "Text",
  PageWidth->WindowWidth,
  InitializationCell->True,
  FontFamily->"Courier New",
  FontWeight->"Bold"],

Cell[TextData[{
  "This states that the sum of",
  " even powers of ",
  StyleBox["m",
    FontSlant->"Italic"],
  " equally-spaced sinusoids is a constant. J.J.Thwaites (personal \
communication) provided the expression for the constant. The ",
  StyleBox["m",
    FontSlant->"Italic"],
  "=2, ",
  StyleBox["p",
    FontSlant->"Italic"],
  "=1 case gives ",
  Cell[BoxData[
      \(TraditionalForm\`Cos\^2\)]],
  "(",
  StyleBox["x",
    FontSlant->"Italic"],
  ") + ",
  Cell[BoxData[
      \(TraditionalForm\`Sin\^2\)]],
  "(",
  StyleBox["x",
    FontSlant->"Italic"],
  ") = 1, the solution to ",
  Cell[BoxData[
      \(TraditionalForm\`x\&\[DoubleDot]\)]],
  "=",
  StyleBox["-1",
    FontSlant->"Italic"],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\)\& . \)]],
  StyleBox[" = ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`x\_\(\(2\)\(,\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(x\_2\)\& . \)\)\)]],
  StyleBox["= -",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  ". "
}], "Text",
  PageWidth->WindowWidth]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "10. Protect system symbols, end private context. ",
  StyleBox["Unprotect some exported symbols, end package context",
    FontFamily->"Times New Roman"],
  StyleBox[".",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"]
}], "Subsection",
  PageWidth->WindowWidth,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(Protect[NumberQ, Positive, Abs, Sign, Re, Im];\)\)], "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["End[ ];", "Input",
  PageWidth->WindowWidth,
  InitializationCell->True],

Cell["(*Protect[Evaluate[$Context <> \"*\"]]*)", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True],

Cell["EndPackage[ ];", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 887}},
AutoGeneratedPackage->Automatic,
WindowToolbars->"EditBar",
WindowSize->{1035, 698},
WindowMargins->{{37, Automatic}, {Automatic, 0}},
PageHeaders->{{Inherited, Inherited, Inherited}, {None, Inherited, None}},
PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Cell[ 
        TextData[ {"21/2/2007"}], Null], Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}},
Magnification->1.5
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 65, 1, 141, "Title"],
Cell[1844, 56, 74, 1, 44, "Subsubtitle"],
Cell[1921, 59, 48, 0, 41, "Input"],
Cell[1972, 61, 151, 5, 64, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[2148, 70, 174, 3, 56, "Subsection"],
Cell[2325, 75, 793, 15, 203, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3155, 95, 158, 3, 56, "Subsection"],
Cell[3316, 100, 301, 8, 125, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3654, 113, 156, 3, 56, "Subsection"],
Cell[3813, 118, 392, 8, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4242, 131, 156, 3, 42, "Subsection"],
Cell[4401, 136, 174, 6, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4612, 147, 159, 3, 42, "Subsection"],
Cell[4774, 152, 70, 1, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4881, 158, 107, 2, 42, "Subsection"],
Cell[4991, 162, 3243, 85, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[8271, 252, 152, 5, 42, "Subsection"],

Cell[CellGroupData[{
Cell[8448, 261, 175, 7, 40, "Subsubsection",
  InitializationCell->True],
Cell[8626, 270, 263, 11, 70, "Input",
  InitializationCell->True],
Cell[8892, 283, 592, 13, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[9521, 301, 111, 2, 29, "Subsubsection"],
Cell[9635, 305, 604, 11, 172, "Input",
  InitializationCell->True],
Cell[10242, 318, 204, 6, 64, "Input",
  InitializationCell->True],
Cell[10449, 326, 153, 4, 42, "Input",
  InitializationCell->True],
Cell[10605, 332, 1192, 25, 120, "Input",
  InitializationCell->True],
Cell[11800, 359, 149, 4, 42, "Input",
  InitializationCell->True],
Cell[11952, 365, 564, 11, 120, "Input",
  InitializationCell->True],
Cell[12519, 378, 325, 8, 68, "Input",
  InitializationCell->True],
Cell[12847, 388, 376, 8, 120, "Input",
  InitializationCell->True],
Cell[13226, 398, 136, 3, 42, "Input",
  InitializationCell->True],
Cell[13365, 403, 135, 3, 42, "Input",
  InitializationCell->True],
Cell[13503, 408, 183, 5, 42, "Input",
  InitializationCell->True],
Cell[13689, 415, 276, 7, 42, "Input",
  InitializationCell->True],
Cell[13968, 424, 133, 3, 42, "Input",
  InitializationCell->True],
Cell[14104, 429, 133, 3, 42, "Input",
  InitializationCell->True],
Cell[14240, 434, 294, 6, 120, "Input",
  InitializationCell->True],
Cell[14537, 442, 116, 3, 42, "Input",
  InitializationCell->True],
Cell[14656, 447, 125, 3, 42, "Input",
  InitializationCell->True],
Cell[14784, 452, 166, 4, 42, "Input",
  InitializationCell->True],
Cell[14953, 458, 139, 3, 42, "Input",
  InitializationCell->True],
Cell[15095, 463, 177, 4, 42, "Input",
  InitializationCell->True],
Cell[15275, 469, 190, 4, 94, "Input",
  InitializationCell->True],
Cell[15468, 475, 118, 3, 42, "Input",
  InitializationCell->True],
Cell[15589, 480, 120, 3, 42, "Input",
  InitializationCell->True],
Cell[15712, 485, 124, 3, 42, "Input",
  InitializationCell->True],
Cell[15839, 490, 125, 3, 42, "Input",
  InitializationCell->True],
Cell[15967, 495, 172, 4, 42, "Input",
  InitializationCell->True],
Cell[16142, 501, 154, 4, 42, "Input",
  InitializationCell->True],
Cell[16299, 507, 173, 4, 42, "Input",
  InitializationCell->True],
Cell[16475, 513, 189, 4, 94, "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[16713, 523, 176, 3, 56, "Subsection",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[16914, 530, 226, 7, 40, "Subsubsection",
  InitializationCell->True],
Cell[17143, 539, 114, 3, 70, "Input",
  InitializationCell->True],
Cell[17260, 544, 139, 3, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[17436, 552, 328, 11, 30, "Subsubsection",
  InitializationCell->True],
Cell[17767, 565, 268, 6, 68, "Input",
  InitializationCell->True],
Cell[18038, 573, 112, 2, 47, "Text",
  InitializationCell->True],
Cell[18153, 577, 1131, 17, 276, "Input",
  InitializationCell->True],
Cell[19287, 596, 226, 5, 73, "Text"],
Cell[19516, 603, 1235, 42, 177, "Text",
  InitializationCell->True],
Cell[20754, 647, 274, 6, 68, "Input",
  InitializationCell->True],
Cell[21031, 655, 298, 6, 69, "Input",
  InitializationCell->True],
Cell[21332, 663, 375, 7, 110, "Input",
  InitializationCell->True],
Cell[21710, 672, 736, 13, 198, "Input"],
Cell[22449, 687, 384, 7, 110, "Input",
  InitializationCell->True],
Cell[22836, 696, 214, 5, 64, "Input",
  InitializationCell->True],
Cell[23053, 703, 175, 5, 64, "Input",
  InitializationCell->True],
Cell[23231, 710, 377, 7, 110, "Input",
  InitializationCell->True],
Cell[23611, 719, 376, 7, 110, "Input",
  InitializationCell->True],
Cell[23990, 728, 303, 6, 87, "Input",
  InitializationCell->True],
Cell[24296, 736, 371, 7, 110, "Input",
  InitializationCell->True],
Cell[24670, 745, 327, 8, 110, "Input",
  InitializationCell->True],
Cell[25000, 755, 436, 8, 133, "Input",
  InitializationCell->True],
Cell[25439, 765, 444, 8, 133, "Input",
  InitializationCell->True],
Cell[25886, 775, 352, 7, 110, "Input",
  InitializationCell->True],
Cell[26241, 784, 437, 8, 133, "Input",
  InitializationCell->True],
Cell[26681, 794, 323, 7, 87, "Input",
  InitializationCell->True],
Cell[27007, 803, 383, 7, 110, "Input",
  InitializationCell->True],
Cell[27393, 812, 384, 8, 133, "Input",
  InitializationCell->True],
Cell[27780, 822, 279, 6, 87, "Input",
  InitializationCell->True],
Cell[28062, 830, 441, 8, 133, "Input",
  InitializationCell->True],
Cell[28506, 840, 1122, 17, 317, "Input",
  InitializationCell->True],
Cell[29631, 859, 884, 14, 248, "Input",
  InitializationCell->True],
Cell[30518, 875, 835, 18, 340, "Input",
  InitializationCell->True],
Cell[31356, 895, 842, 13, 248, "Input",
  InitializationCell->True],
Cell[32201, 910, 357, 8, 110, "Input",
  InitializationCell->True],
Cell[32561, 920, 371, 7, 110, "Input",
  InitializationCell->True],
Cell[32935, 929, 365, 10, 156, "Input",
  InitializationCell->True],
Cell[33303, 941, 1700, 33, 606, "Input",
  InitializationCell->True],
Cell[35006, 976, 3356, 59, 588, "Input",
  InitializationCell->True],
Cell[38365, 1037, 338, 7, 110, "Input",
  InitializationCell->True],
Cell[38706, 1046, 371, 7, 110, "Input",
  InitializationCell->True],
Cell[39080, 1055, 373, 7, 110, "Input",
  InitializationCell->True],
Cell[39456, 1064, 350, 8, 133, "Input",
  InitializationCell->True],
Cell[39809, 1074, 471, 10, 179, "Input",
  InitializationCell->True],
Cell[40283, 1086, 981, 21, 432, "Input",
  InitializationCell->True],
Cell[41267, 1109, 779, 16, 317, "Input",
  InitializationCell->True],
Cell[42049, 1127, 776, 15, 294, "Input",
  InitializationCell->True],
Cell[42828, 1144, 758, 17, 340, "Input",
  InitializationCell->True],
Cell[43589, 1163, 1372, 21, 409, "Input",
  InitializationCell->True],
Cell[44964, 1186, 1141, 17, 340, "Input",
  InitializationCell->True],
Cell[46108, 1205, 427, 8, 133, "Input",
  InitializationCell->True],
Cell[46538, 1215, 417, 8, 133, "Input",
  InitializationCell->True],
Cell[46958, 1225, 819, 17, 340, "Input",
  InitializationCell->True],
Cell[47780, 1244, 1244, 19, 363, "Input",
  InitializationCell->True],
Cell[49027, 1265, 873, 14, 248, "Input",
  InitializationCell->True],
Cell[49903, 1281, 870, 14, 248, "Input",
  InitializationCell->True],
Cell[50776, 1297, 405, 8, 110, "Input",
  InitializationCell->True],
Cell[51184, 1307, 656, 11, 202, "Input",
  InitializationCell->True],
Cell[51843, 1320, 434, 8, 133, "Input",
  InitializationCell->True],
Cell[52280, 1330, 837, 13, 248, "Input",
  InitializationCell->True],
Cell[53120, 1345, 843, 13, 248, "Input",
  InitializationCell->True],
Cell[53966, 1360, 608, 10, 179, "Input",
  InitializationCell->True],
Cell[54577, 1372, 1976, 28, 570, "Input",
  InitializationCell->True],
Cell[56556, 1402, 4103, 68, 1331, "Input",
  InitializationCell->True],
Cell[60662, 1472, 6330, 102, 2071, "Input",
  InitializationCell->True],
Cell[66995, 1576, 1560, 23, 406, "Input",
  InitializationCell->True],
Cell[68558, 1601, 3950, 62, 1304, "Input",
  InitializationCell->True],
Cell[72511, 1665, 5682, 89, 2000, "Input",
  InitializationCell->True],
Cell[78196, 1756, 2001, 33, 556, "Input",
  InitializationCell->True],
Cell[80200, 1791, 2720, 45, 556, "Input",
  InitializationCell->True],
Cell[82923, 1838, 1610, 27, 528, "Input",
  InitializationCell->True],
Cell[84536, 1867, 1910, 28, 692, "Input",
  InitializationCell->True],
Cell[86449, 1897, 1909, 28, 718, "Input",
  InitializationCell->True],
Cell[88361, 1927, 2201, 31, 770, "Input",
  InitializationCell->True],
Cell[90565, 1960, 2098, 30, 692, "Input",
  InitializationCell->True],
Cell[92666, 1992, 2099, 30, 692, "Input",
  InitializationCell->True],
Cell[94768, 2024, 2166, 30, 733, "Input",
  InitializationCell->True],
Cell[96937, 2056, 4572, 70, 1082, "Input",
  InitializationCell->True],
Cell[101512, 2128, 7273, 110, 2174, "Input",
  InitializationCell->True],
Cell[108788, 2240, 2301, 33, 770, "Input",
  InitializationCell->True],
Cell[111092, 2275, 2301, 33, 770, "Input",
  InitializationCell->True],
Cell[113396, 2310, 1276, 19, 386, "Input",
  InitializationCell->True],
Cell[114675, 2331, 5549, 76, 1784, "Input",
  InitializationCell->True],
Cell[120227, 2409, 2221, 32, 744, "Input",
  InitializationCell->True],
Cell[122451, 2443, 1238, 19, 386, "Input",
  InitializationCell->True],
Cell[123692, 2464, 2695, 42, 654, "Input",
  InitializationCell->True],
Cell[126390, 2508, 1241, 19, 386, "Input",
  InitializationCell->True],
Cell[127634, 2529, 2677, 41, 654, "Input",
  InitializationCell->True],
Cell[130314, 2572, 2649, 40, 654, "Input",
  InitializationCell->True],
Cell[132966, 2614, 1254, 20, 386, "Input",
  InitializationCell->True],
Cell[134223, 2636, 4022, 54, 1168, "Input",
  InitializationCell->True],
Cell[138248, 2692, 1182, 30, 639, "Input",
  InitializationCell->True],
Cell[139433, 2724, 3286, 56, 1237, "Input",
  InitializationCell->True],
Cell[142722, 2782, 230, 6, 73, "Text",
  InitializationCell->True],
Cell[142955, 2790, 400, 8, 146, "Input",
  InitializationCell->True],
Cell[143358, 2800, 726, 12, 290, "Input",
  InitializationCell->True],
Cell[144087, 2814, 794, 13, 250, "Input",
  InitializationCell->True],
Cell[144884, 2829, 182, 5, 47, "Text",
  InitializationCell->True],
Cell[145069, 2836, 677, 12, 198, "Input",
  InitializationCell->True],
Cell[145749, 2850, 177, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[145951, 2858, 73, 2, 70, "Input"],
Cell[146027, 2862, 66, 2, 70, "Output"]
}, Open  ]],
Cell[146108, 2867, 63, 2, 70, "Input"],
Cell[146174, 2871, 68, 2, 42, "Input"],
Cell[146245, 2875, 843, 13, 276, "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[147137, 2894, 278, 9, 56, "Subsection",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[147440, 2907, 208, 7, 41, "Subsubsection",
  InitializationCell->True],
Cell[147651, 2916, 239, 8, 47, "Text"],
Cell[147893, 2926, 463, 9, 120, "Input",
  InitializationCell->True],
Cell[148359, 2937, 1047, 35, 151, "Text"],
Cell[149409, 2974, 1048, 19, 250, "Input",
  InitializationCell->True],
Cell[150460, 2995, 2044, 56, 333, "Text"],
Cell[152507, 3053, 811, 15, 224, "Input",
  InitializationCell->True],
Cell[153321, 3070, 1312, 42, 151, "Text"],
Cell[154636, 3114, 707, 14, 230, "Input",
  InitializationCell->True],
Cell[155346, 3130, 415, 12, 73, "Text"],
Cell[155764, 3144, 418, 8, 120, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[156219, 3157, 117, 2, 29, "Subsubsection",
  InitializationCell->True],
Cell[156339, 3161, 336, 9, 70, "Text",
  InitializationCell->True],
Cell[156678, 3172, 1181, 24, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[157896, 3201, 192, 5, 29, "Subsubsection",
  InitializationCell->True],
Cell[158091, 3208, 622, 13, 70, "Input",
  InitializationCell->True],
Cell[158716, 3223, 298, 7, 70, "Input",
  InitializationCell->True],
Cell[159017, 3232, 1760, 51, 70, "Text",
  InitializationCell->True],
Cell[160780, 3285, 1113, 46, 70, "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[161942, 3337, 326, 9, 82, "Subsection"],
Cell[162271, 3348, 137, 3, 70, "Input",
  InitializationCell->True],
Cell[162411, 3353, 78, 2, 70, "Input",
  InitializationCell->True],
Cell[162492, 3357, 168, 3, 70, "Input",
  InitializationCell->True],
Cell[162663, 3362, 142, 3, 70, "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

